import json
import click
import os


@click.command()
@click.option('--fout', default='config', help='File to save the modules data.')
@click.option('--project', default='postgresql', help='File to save the modules data.')
@click.option('--fin', default='db', help='File to save the modules data.')
def transform(fin, fout, project):

    cpes = load_file(f"{fin}/{project}.json")
    versions = dict()
    for cpe in cpes:
        if project == 'redis' and 'redis' in cpe['cpe_match']['cpe23Uri']:
            owner = cpe['cpe_match']['cpe23Uri'].split(':')[3]
            if owner not in ('redislabs', 'redis'):
                continue
        cve_id, cpe_match = cpe['cve_id'], cpe['cpe_match']
        if 'versionStartIncluding' not in cpe_match.keys() and \
            'versionStartExcluding' not in cpe_match.keys() and \
            'versionEndExcluding' not in cpe_match.keys() and \
            'versionEndIncluding' not in cpe_match.keys() and \
            cpe_match['vulnerable']:
            version = cpe_match['cpe23Uri'].split(':')[5]
            if version in ("*", "-"):
                continue
            print(version)
            if version not in versions:
                versions[version] = [cve_id]
            else:
                if cve_id not in versions[version]:
                    versions[version].append(cve_id)
    save_json(f"{fout}/{project}.json", versions)


def load_file(fin):
    with open(fin) as f:
        return json.load(f)
    
def save_json(fout, data):
    with open(fout, 'w') as out:
        json.dump(data, out, indent=4)


                        

if __name__ == '__main__':
    transform()
