import json
import click
import os


@click.command()
@click.option('--fout', default='db', help='File to save the modules data.')
@click.option('--projects', default='projects.json', help='File to save the modules data.')
@click.option('--fin', default='cves', help='File to save the modules data.')
@click.option('--approach', default='cpe_product', help='Approach to collect cpes.')
def nvd(fin, fout, projects, approach):

    # load projects
    projects = load_file(projects).keys()

    if not os.path.exists(fout):
        os.makedirs(fout)
    
    # process cves
    for project in projects:
        print(f"Processing project {project}...")
        process_cves(fin, fout, project, approach)


def load_file(fin):
    with open(fin) as f:
        return json.load(f)
    
def save_json(fout, data):
    with open(fout, 'w') as out:
        json.dump(data, out, indent=4)


def process_cves(fin, fout, project, approach):
    paths = [f for f in os.listdir(
        fin) if os.path.isfile(os.path.join(fin, f))]

    cpes_project = dict()
    cpes_project[project] = []
    for path in paths:
        cves = load_file(f"{fin}{path}")

        for cve in cves["CVE_Items"]:
            cve_id = cve['cve']['CVE_data_meta']['ID']
            cpes = cve["configurations"]["nodes"]
            for cpe in cpes:
                cpe_matches = cpe['cpe_match']
                for cpe_match in cpe_matches:
                    if approach == 'cpe_product':
                        product = cpe_match['cpe23Uri'].split(':')[4]
                        is_puppet = (project == product)
                    elif approach == 'naive':
                        is_puppet = project in cpe_match['cpe23Uri']
                    if cpe_match['vulnerable'] and is_puppet:
                        cpes_project[project].append({'cve_id': cve_id, 'cpe_match': cpe_match})

    if len(cpes_project[project]) > 0:
        save_json(f"{fout}/{project}.json", cpes_project[project])
                        

if __name__ == '__main__':
    nvd()
