import argparse
import json

import pandas as pd

rules = {
    'Invalid IP Address Binding': 'invalid_ip_addr_binding',
    'Weak Crypto Algorithm': 'use_of_weak_crypto_algorithm',
    'HTTP without TLS': 'use_http_without_tls',
    'Admin by default': 'admin_by_default',
    'Empty Password': 'empty_password',
    'Hard Coded Secret': 'hardcoded_secret',
    'Malicious Dependency': 'malicious_dependency',
    'Weak Password': 'weak_password',
    'Cyrillic Homograph Attack': 'cyrillic_homograph_attack',
    'Suspicious Comment': 'suspicious_comment'
}



def normalize(fin, cache, fout):
    def dfinit(data):
        return pd.DataFrame(data, index=[0])
    
    def load_forms(cache):
        with open(cache) as jfile:
            return json.load(jfile)

    def get_answer_info(forms, _id):
        for form in forms:
            for answer in form['answers'][0]:
                if _id == answer['_id']:
                    return answer
                
    df = pd.read_csv(fin)
    forms = load_forms(cache)
    
    dfi = pd.DataFrame()
    for _, row in df.iterrows():
        file = dict()
        for q in ('1', '2', '3'):  
            info = get_answer_info(forms, row[f'q{q}_id'])   
            
            # missing answer 
            if 'result' not in info.keys():
                continue
             # unsure answer
            if info['result'] not in ('yes', 'no'):
                continue
            file = {
                'git_blob': info['url'].replace('/tree/', '/blob/'),
                'raw_file': info['url'].split('#')[0].replace('/tree/', '/raw/'),
                'smell_type': rules[info['type']],
                'line': info['url'].split('#')[-1].replace('L',''),
                'alert': 'TP' if info['result'] == 'yes' else 'FP',
                'analysis': 'practitioners-analysis'
            }
            dfi = pd.concat([dfi, dfinit(file)], ignore_index=True)
    dfi.to_csv(fout, index=False)


if __name__ == '__main__':
    parser = argparse.ArgumentParser(description='Normalize Results')
    parser.add_argument('--fin', type=str,
                        metavar='input file', help='base file')
    parser.add_argument('--cache', type=str,
                        metavar='cache file', help='base file')
    parser.add_argument('--fout', type=str,
                        metavar='output file', help='base file')
    args = parser.parse_args()

    if args.fin and args.cache and args.fout:
        normalize(args.fin, args.cache, args.fout)
    else:
        print('Something is wrong. Verify your parameters')
