# == Class: govuk::apps::ckan::db
#
# === Parameters
#
# [*password*]
#   The DB instance password.
#
# [*backend_ip_range*]
#   Backend IP addresses to allow access to the database.
#
# [*allow_auth_from_lb*]
#   Whether to allow this user to authenticate for this database from
#   the load balancer using its password.
#   Default: false
#
# [*lb_ip_range*]
#   Network range for the load balancer.
#
class govuk::apps::ckan::db (
  $user = 'ckan',
  $password,
  $backend_ip_range = '10.3.0.0/16',
  $allow_auth_from_lb = false,
  $lb_ip_range = undef,
  $rds = false,
) {
  if !$rds {
    class { 'postgresql::server::postgis': }
  }

  govuk_postgresql::db { 'ckan_production':
    user                    => $user,
    password                => $password,
    connection_limit        => '1000',
    allow_auth_from_backend => true,
    backend_ip_range        => $backend_ip_range,
    allow_auth_from_lb      => $allow_auth_from_lb,
    lb_ip_range             => $lb_ip_range,
    rds                     => $rds,
    extensions              => ['postgis'],
  }

  govuk_postgresql::db { 'ckan_pycsw_production':
    user                    => $user,
    password                => $password,
    connection_limit        => '1000',
    allow_auth_from_backend => true,
    backend_ip_range        => $backend_ip_range,
    allow_auth_from_lb      => $allow_auth_from_lb,
    lb_ip_range             => $lb_ip_range,
    rds                     => $rds,
    extensions              => ['postgis'],
  }
}
