#   Class: profile::kubernetes::params default variables
#
#   This class define default parameters used by all Kubernetes classes,definitions
#
#   Parameters:
#     $backup:
#       Directory that contains Kubernetes resources exported from clusters.
#       Ex: Secrets generated by kube-lego that contain letsencrypt certificate
#
#     $bin:
#       Directory that contains Binary/Tools/scripts for Kubernetes project
#
#     $clusters:
#       clusters contains a list of cluster information.
#       This variable must respect following format:
#       example:
#           $clusters:
#             - server: https://clusterexample1.eastus.cloudapp.azure.com
#               username: clusterexample1-admin
#               clustername: clusterexample1
#               certificate_authority_data: UNG4xdlNhZlBlZnNjWXZY
#               client_certificate_data: UNG4xdlNhZlBlZnNjWXZY
#               client_key_data: UNG4xdlNhZlBlZnNjWXZY
#             - server: https://clusterexample2.eastus.cloudapp.azure.com
#               username: clusterexample2-admin
#               clustername: clusterexample2
#               certificate_authority_data: UNG4xdlNhZlBlZnNjWXZY
#               client_certificate_data: UNG4xdlNhZlBlZnNjWXZY
#               client_key_data: UNG4xdlNhZlBlZnNjWXZY
#
#     $config:
#       Directory that contains Kubernetes configuration files
#     $home:
#       Home directory for Kubernetes project
#
#     $kubeconfig:
#        Kubernetes kubeconfig file path
#
#     $resources:
#       Directory that contains Kubernetes resources that will be deploy on Kubernetes
#       clusters
#
#     $trash:
#       Directory that contains Kubernetes resources that need to be removed from Kubernetes
#       clusters.
#
#     $users:
#       System user who own Kubernetes project
#
class profile::kubernetes::params (
  $backup = '/home/k8s/backup',
  $bin = '/home/k8s/.bin',
  $clusters = [
    {
      'clustername'                => 'minikube',
      'certificate_authority_data' => 'fake_certificate_authority_data',
      'server'                     => 'https://minikube',
      'username'                   => 'minikube',
      'client_certificate_data'    => 'fake_client_certificate_data',
      'client_key_data'            => 'fake_client_key_data'
    }
  ],
  $config = '/home/k8s/.kube',
  $home = '/home/k8s',
  $kubeconfig = '/home/k8s/.kube/config',
  $resources = '/home/k8s/resources',
  $trash = '/home/k8s/trash',
  $user = 'k8s'
  ){
}
