## Try linter

Steps to install tool. Ruby 3.0.3 is required.

```bash
cd puppet-lint-infrasecure
bundle install
gem build puppet_lint_infrasecure.gemspec
gem install ./puppet-lint-infrasecure-1.1.0.gem
```

## Run linter

```bash
puppet-lint files/test.pp --json
```

Output should show the following list of warnings:

```json
{
    "message": "[SECURITY][CWE-250] Admin by default (line=3, col=18) | Do not make user as admin as for $power_username in line 3. This can be easily exploited.",
    "line": 3,
    "column": 18,
    "token": "admin",
    "cwe": "CWE-250",
    "kind": "warning",
    "check": "admin_by_default",
    "fullpath": "/Volumes/sofiaoreis_/puppet-iac/replication_package/puppet-lint-infrasecure/files/test.pp",
    "path": "files/test.pp",
    "filename": "test.pp",
    "KIND": "WARNING"
  },
  {
    "message": "[SECURITY][CWE-258] Empty Password (line=4, col=20) | Do not keep the password field empty as for $power_password in line 4. Use a stronger password.",
    "line": 4,
    "column": 20,
    "token": "",
    "cwe": "CWE-258",
    "kind": "warning",
    "check": "empty_password",
    "fullpath": "/Volumes/sofiaoreis_/puppet-iac/replication_package/puppet-lint-infrasecure/files/test.pp",
    "path": "files/test.pp",
    "filename": "test.pp",
    "KIND": "WARNING"
  },
  {
    "message": "[SECURITY][CWE-259] Hard Coded Password (line=5, col=10) | Do not keep secrets on your scripts as for $pwd = EHDJSKD in line 5. Store secrets in a vault instead.",
    "line": 5,
    "column": 10,
    "token": "EHDJSKD",
    "cwe": "CWE-259",
    "kind": "warning",
    "check": "hardcoded_secret_password",
    "fullpath": "/Volumes/sofiaoreis_/puppet-iac/replication_package/puppet-lint-infrasecure/files/test.pp",
    "path": "files/test.pp",
    "filename": "test.pp",
    "KIND": "WARNING"
  },
  {
    "message": "[SECURITY][CWE-798] Hard Coded Secret (line=5, col=10) | Do not keep secrets on your scripts as for $pwd = EHDJSKD in line 5. Store secrets in a vault instead.",
    "line": 5,
    "column": 10,
    "token": "ehdjskd",
    "cwe": "CWE-798",
    "kind": "warning",
    "check": "hardcoded_secret",
    "fullpath": "/Volumes/sofiaoreis_/puppet-iac/replication_package/puppet-lint-infrasecure/files/test.pp",
    "path": "files/test.pp",
    "filename": "test.pp",
    "KIND": "WARNING"
  },
  {
    "message": "[SECURITY][CWE-284] Invalid IP Address Binding (line=7, col=17) | Don't bind your host to 0.0.0.0. This config allows connections from every possible network. Restrict your available IPs.",
    "line": 7,
    "column": 17,
    "token": "0.0.0.0",
    "cwe": "CWE-284",
    "kind": "warning",
    "check": "invalid_ip_addr_binding",
    "fullpath": "/Volumes/sofiaoreis_/puppet-iac/replication_package/puppet-lint-infrasecure/files/test.pp",
    "path": "files/test.pp",
    "filename": "test.pp",
    "KIND": "WARNING"
  },
  {
    "message": "[SECURITY][CWE-829] Malicious Dependency (line=12, col=25) | This software is using a third-party library/software (postgresql v9.6) affected by known CVEs (CVE-2017-12172, CVE-2017-15098, CVE-2017-15099, CVE-2017-7484, CVE-2017-7485, CVE-2017-7486, CVE-2017-7546, CVE-2017-7547, CVE-2017-7548).",
    "line": 12,
    "column": 25,
    "token": "postgresql_version",
    "cwe": "CWE-829",
    "kind": "warning",
    "check": "malicious_dependency",
    "fullpath": "/Volumes/sofiaoreis_/puppet-iac/replication_package/puppet-lint-infrasecure/files/test.pp",
    "path": "files/test.pp",
    "filename": "test.pp",
    "KIND": "WARNING"
  },
  {
    "message": "[SECURITY][CWE-546] Suspicious Comment (line=1, col=1) | Avoid doing comments containing info about a defect, missing functionality or weakness of the system.",
    "line": 1,
    "column": 1,
    "token": " addresses bug: https://bugs.launchpad.net/keystone/+bug/1472285",
    "cwe": "CWE-546",
    "kind": "warning",
    "check": "suspicious_comment",
    "fullpath": "/Volumes/sofiaoreis_/puppet-iac/replication_package/puppet-lint-infrasecure/files/test.pp",
    "path": "files/test.pp",
    "filename": "test.pp",
    "KIND": "WARNING"
  },
  {
    "message": "[SECURITY][CWE-319] HTTP without TLS (line=8, col=24) | Do not use HTTP without TLS as in http://127.0.0.1:35357/v2.0. This may cause a MITM attack.",
    "line": 8,
    "column": 24,
    "token": "http://127.0.0.1:35357/v2.0",
    "cwe": "CWE-319",
    "kind": "warning",
    "check": "use_http_without_tls",
    "fullpath": "/Volumes/sofiaoreis_/puppet-iac/replication_package/puppet-lint-infrasecure/files/test.pp",
    "path": "files/test.pp",
    "filename": "test.pp",
    "KIND": "WARNING"
  },
  {
    "message": "[SECURITY][CWE-326] Weak Crypto Algorithm (line=11, col=15) | Do not use sha1, as they have security weakness. Use SHA-512 instead.",
    "line": 11,
    "column": 15,
    "token": "sha1",
    "cwe": "CWE-326",
    "kind": "warning",
    "check": "use_of_weak_crypto_algorithm",
    "fullpath": "/Volumes/sofiaoreis_/puppet-iac/replication_package/puppet-lint-infrasecure/files/test.pp",
    "path": "files/test.pp",
    "filename": "test.pp",
    "KIND": "WARNING"
  },
  {
    "message": "[SECURITY][CWE-521] Weak Password (line=5, col=10) | Passwords should be strong to be hard to uncover by hackers (weak_password=EHDJSKD, entropy=13.5). Recommendation is to use a password with at least 18 bits of entropy. In any case, secrets should be stored in services like kms/heira/vault not in plain text.",
    "line": 5,
    "column": 10,
    "token": "EHDJSKD",
    "cwe": "CWE-521",
    "entropy": 13.5,
    "kind": "warning",
    "check": "weak_password",
    "fullpath": "/Volumes/sofiaoreis_/puppet-iac/replication_package/puppet-lint-infrasecure/files/test.pp",
    "path": "files/test.pp",
    "filename": "test.pp",
    "KIND": "WARNING"
  }
```