# == Define: quartermaster::matchbox
# Adds CoreOS Matchbox as part of the CoreOS deployment infrastructure
#
class quartermaster::matchbox (
  $matchbox_enable = $quartermaster::matchbox_enable,
){

  validate_bool( $quartermaster::matchbox_enable )
  validate_string( $quartermaster::matchbox_version )

  if $quartermaster::matchbox_enable == true {
    user { 'matchbox':
      ensure     => 'present',
      managehome => true,
    }
->  file{[
      '/var/lib/matchbox',
      '/var/lib/matchbox/examples',
      '/var/lib/matchbox/assets',
      '/var/lib/matchbox/profiles',
      '/var/lib/matchbox/cloud',
      '/var/lib/matchbox/generic',
      '/etc/matchbox',
      '/etc/systemd/system/matchbox.service.d',
    ]:
      ensure => directory,
      owner  => 'matchbox',
      group  => 'matchbox',

    }
    # matchbox terraform
->  file{'/root/.matchbox':
      ensure => directory,
      owner  => 'root',
      group  => 'root',
    }
->  file{ '/var/lib/matchbox/addons':
      ensure  => directory,
      recurse => true,
      owner   => 'matchbox',
      group   => 'matchbox',
      source  => 'puppet:///modules/quartermaster/coreos/matchbox/addons',
    }
-> file{ '/var/lib/matchbox/terraform':
      ensure  => directory,
      recurse => true,
      owner   => 'matchbox',
      group   => 'matchbox',
      source  => 'puppet:///modules/quartermaster/coreos/matchbox/terraform',
    }
->  file{ '/var/lib/matchbox/groups':
      ensure  => directory,
      recurse => true,
      owner   => 'matchbox',
      group   => 'matchbox',
#      source  => 'puppet:///modules/quartermaster/coreos/matchbox/groups',
    }
->  file{ '/var/lib/matchbox/terraform/etcd3-install/terraform.tfvars':
      ensure  => file,
      owner   => 'matchbox',
      group   => 'matchbox',
      content => template('quartermaster/matchbox/terraform/etcd3-install.terraform.tfvars.erb'),
    }
->  file{ '/var/lib/matchbox/terraform/simple-install/terraform.tfvars':
      ensure  => file,
      owner   => 'matchbox',
      group   => 'matchbox',
      content => template('quartermaster/matchbox/terraform/simple-install.terraform.tfvars.erb'),
    }
    # matchbox ignition
->  file{ '/var/lib/matchbox/ignition':
      ensure  => directory,
      recurse => true,
      owner   => 'matchbox',
      group   => 'matchbox',
      source  => 'puppet:///modules/quartermaster/coreos/matchbox/ignition',
    }
-> staging::deploy{"matchbox-v${quartermaster::matchbox_version}-linux-amd64.tar.gz":
      source   => "https://github.com/coreos/matchbox/releases/download/v${quartermaster::matchbox_version}/matchbox-v${quartermaster::matchbox_version}-linux-amd64.tar.gz",
      target   => '/home/matchbox',
      username => 'root',
      creates  => [
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/CHANGES.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/contrib",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/contrib/systemd",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/contrib/systemd/matchbox-for-tectonic.service",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/contrib/systemd/matchbox-local.service",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/contrib/systemd/matchbox-on-coreos.service",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/contrib/systemd/matchbox.service",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/api.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/bootkube.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/bootkube-upgrades.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/cloud-config.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/config.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/container-linux-config.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/deployment.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/dev",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/dev/develop.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/dev/release.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/getting-started-docker.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/getting-started.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/getting-started-rkt.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/grub.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/img",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/img/ipxe.png",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/img/kubernetes-dashboard.png",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/img/machine-lifecycle.png",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/img/network-setup-flow.png",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/img/overview.png",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/img/proxydhcp.png",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/img/pxelinux.png",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/img/tectonic-console.png",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/img/tectonic-installer.png",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/machine-lifecycle.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/matchbox.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/network-booting.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/network-setup.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/openpgp.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/docs/Documentation/troubleshooting.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/cloud",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/bootkube",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/bootkube/node1.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/bootkube/node2.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/bootkube/node3.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/bootkube-install",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/bootkube-install/install.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/bootkube-install/node1.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/bootkube-install/node2.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/bootkube-install/node3.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/etcd3",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/etcd3/gateway.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/etcd3/node1.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/etcd3/node2.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/etcd3/node3.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/etcd3-install",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/etcd3-install/gateway.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/etcd3-install/install.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/etcd3-install/node1.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/etcd3-install/node2.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/etcd3-install/node3.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/grub",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/grub/default.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/simple",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/simple/default.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/simple-install",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/simple-install/install.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/groups/simple-install/simple.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/ignition",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/ignition/bootkube-controller.yaml",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/ignition/bootkube-worker.yaml",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/ignition/etcd3-gateway.yaml",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/ignition/etcd3.yaml",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/ignition/install-reboot.yaml",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/ignition/ssh.yaml",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/profiles",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/profiles/bootkube-controller.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/profiles/bootkube-worker.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/profiles/etcd3-gateway.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/profiles/etcd3.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/profiles/grub.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/profiles/install-reboot.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/profiles/simple-install.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/profiles/simple.json",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/examples/README.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/LICENSE",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/matchbox",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/README.md",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/get-coreos",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/cert-gen",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/openssl.conf",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/README.md",
      ],
    }
->  file{'/usr/local/bin/matchbox':
      ensure => file,
      source => "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/matchbox",
      mode   => '0777',
    }
->  file{'/usr/local/bin/get-coreos':
      ensure => file,
      source => "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/get-coreos",
      mode   => '0777',
    }
->  file{'/etc/systemd/system/matchbox.service':
      ensure => file,
      source => "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/contrib/systemd/matchbox-local.service",
      mode   => '0644',
    }
->  file{'/etc/systemd/system/matchbox.service.d/override.conf':
      ensure  => file,
      mode    => '0644',
      content => '#Puppet Managed
 # /etc/systemd/system/matchbox.service.d/override.conf
[Service]
Environment="MATCHBOX_RPC_ADDRESS=0.0.0.0:8081"
Environment="MATCHBOX_LOG_LEVEL=debug"
',
    }
->  staging::deploy{"terraform_${quartermaster::terraform_version}_linux_amd64.zip":
      source  => "https://releases.hashicorp.com/terraform/${quartermaster::terraform_version}/terraform_${quartermaster::terraform_version}_linux_amd64.zip",
      target  => '/usr/local/bin',
      creates => '/usr/local/bin/terraform'
    }
->  staging::deploy{"go${quartermaster::go_version}.linux-amd64.tar.gz":
      source  => "https://redirector.gvt1.com/edgedl/go/go${quartermaster::go_version}.linux-amd64.tar.gz",
      target  => '/usr/local',
      require => Package['unzip'],
      creates => [
      '/usr/local/go',
      '/usr/local/go/api',
      '/usr/local/go/api/except.txt',
      '/usr/local/go/api/go1.1.txt',
      '/usr/local/go/api/go1.2.txt',
      '/usr/local/go/api/go1.3.txt',
      '/usr/local/go/api/go1.4.txt',
      '/usr/local/go/api/go1.5.txt',
      '/usr/local/go/api/go1.6.txt',
      '/usr/local/go/api/go1.7.txt',
      '/usr/local/go/api/go1.8.txt',
      '/usr/local/go/api/go1.9.txt',
      '/usr/local/go/api/go1.txt',
      '/usr/local/go/api/next.txt',
      '/usr/local/go/api/README',
      '/usr/local/go/AUTHORS',
      '/usr/local/go/bin',
      '/usr/local/go/bin/go',
      '/usr/local/go/bin/godoc',
      '/usr/local/go/bin/gofmt',
      '/usr/local/go/blog',
      '/usr/local/go/blog/content',
      '/usr/local/go/blog/content/4years.article',
      '/usr/local/go/blog/content/4years-gopher.png',
      '/usr/local/go/blog/content/4years-graph.png',
      '/usr/local/go/blog/content/5years',
      '/usr/local/go/blog/content/5years/conferences.jpg',
      '/usr/local/go/blog/content/5years/gophers5th.jpg',
      '/usr/local/go/blog/content/5years.article',
      '/usr/local/go/blog/content/6years.article',
      '/usr/local/go/blog/content/6years-gopher.png',
      '/usr/local/go/blog/content/7years.article',
      '/usr/local/go/blog/content/a-conversation-with-the-go-team.article',
      '/usr/local/go/blog/content/advanced-go-concurrency-patterns.article',
      '/usr/local/go/blog/content/appengine-dec2013.article',
      '/usr/local/go/blog/content/building-stathat-with-go.article',
      '/usr/local/go/blog/content/building-stathat-with-go_stathat_architecture.png',
      '/usr/local/go/blog/content/building-stathat-with-go_weather.png',
      '/usr/local/go/blog/content/c-go-cgo.article',
      '/usr/local/go/blog/content/community-outreach-working-group',
      '/usr/local/go/blog/content/community-outreach-working-group/project.png',
      '/usr/local/go/blog/content/community-outreach-working-group.article',
      '/usr/local/go/blog/content/concurrency-is-not-parallelism.article',
      '/usr/local/go/blog/content/constants',
      '/usr/local/go/blog/content/constants/bool.go',
      '/usr/local/go/blog/content/constants/complex1.go',
      '/usr/local/go/blog/content/constants/complex2.go',
      '/usr/local/go/blog/content/constants/complex3.go',
      '/usr/local/go/blog/content/constants/default1.go',
      '/usr/local/go/blog/content/constants/default2.go',
      '/usr/local/go/blog/content/constants/default3.go',
      '/usr/local/go/blog/content/constants/exercise1.go',
      '/usr/local/go/blog/content/constants/exercise2.go',
      '/usr/local/go/blog/content/constants/exercise3.go',
      '/usr/local/go/blog/content/constants/exercise4.go',
      '/usr/local/go/blog/content/constants/exercise5.go',
      '/usr/local/go/blog/content/constants/exercise6.go',
      '/usr/local/go/blog/content/constants/float1.go',
      '/usr/local/go/blog/content/constants/float2.go',
      '/usr/local/go/blog/content/constants/float3.go',
      '/usr/local/go/blog/content/constants/float4.go',
      '/usr/local/go/blog/content/constants/float5.go',
      '/usr/local/go/blog/content/constants/int1.go',
      '/usr/local/go/blog/content/constants/int2.go',
      '/usr/local/go/blog/content/constants/int3.go',
      '/usr/local/go/blog/content/constants/int4.go',
      '/usr/local/go/blog/content/constants/numbers1.go',
      '/usr/local/go/blog/content/constants/numbers2.go',
      '/usr/local/go/blog/content/constants/string1.go',
      '/usr/local/go/blog/content/constants/string2.go',
      '/usr/local/go/blog/content/constants/string3.go',
      '/usr/local/go/blog/content/constants/string4.go',
      '/usr/local/go/blog/content/constants/syntax.go',
      '/usr/local/go/blog/content/constants.article',
      '/usr/local/go/blog/content/context',
      '/usr/local/go/blog/content/context/google',
      '/usr/local/go/blog/content/context/google/google.go',
      '/usr/local/go/blog/content/context/gorilla',
      '/usr/local/go/blog/content/context/gorilla/gorilla.go',
      '/usr/local/go/blog/content/context/interface.go',
      '/usr/local/go/blog/content/context/server',
      '/usr/local/go/blog/content/context/server/server.go',
      '/usr/local/go/blog/content/context/tomb',
      '/usr/local/go/blog/content/context/tomb/tomb.go',
      '/usr/local/go/blog/content/context/userip',
      '/usr/local/go/blog/content/context/userip/userip.go',
      '/usr/local/go/blog/content/context.article',
      '/usr/local/go/blog/content/contributors-summit',
      '/usr/local/go/blog/content/contributors-summit/IMG_20170712_145844.jpg',
      '/usr/local/go/blog/content/contributors-summit/IMG_20170712_145854.jpg',
      '/usr/local/go/blog/content/contributors-summit/IMG_20170712_145905.jpg',
      '/usr/local/go/blog/content/contributors-summit/IMG_20170712_145911.jpg',
      '/usr/local/go/blog/content/contributors-summit/IMG_20170712_145950.jpg',
      '/usr/local/go/blog/content/contributors-summit.article',
      '/usr/local/go/blog/content/contributor-workshop',
      '/usr/local/go/blog/content/contributor-workshop/image10.png',
      '/usr/local/go/blog/content/contributor-workshop/image11.png',
      '/usr/local/go/blog/content/contributor-workshop/image12.png',
      '/usr/local/go/blog/content/contributor-workshop/image13.png',
      '/usr/local/go/blog/content/contributor-workshop/image14.jpg',
      '/usr/local/go/blog/content/contributor-workshop/image15.png',
      '/usr/local/go/blog/content/contributor-workshop/image16.png',
      '/usr/local/go/blog/content/contributor-workshop/image17.png',
      '/usr/local/go/blog/content/contributor-workshop/image18.jpg',
      '/usr/local/go/blog/content/contributor-workshop/image19.png',
      '/usr/local/go/blog/content/contributor-workshop/image1.png',
      '/usr/local/go/blog/content/contributor-workshop/image20.jpg',
      '/usr/local/go/blog/content/contributor-workshop/image21.jpg',
      '/usr/local/go/blog/content/contributor-workshop/image22.png',
      '/usr/local/go/blog/content/contributor-workshop/image23.png',
      '/usr/local/go/blog/content/contributor-workshop/image2.jpg',
      '/usr/local/go/blog/content/contributor-workshop/image3.png',
      '/usr/local/go/blog/content/contributor-workshop/image4.jpg',
      '/usr/local/go/blog/content/contributor-workshop/image5.jpg',
      '/usr/local/go/blog/content/contributor-workshop/image6.png',
      '/usr/local/go/blog/content/contributor-workshop/image7.png',
      '/usr/local/go/blog/content/contributor-workshop/image8.jpg',
      '/usr/local/go/blog/content/contributor-workshop/image9.jpg',
      '/usr/local/go/blog/content/contributor-workshop.article',
      '/usr/local/go/blog/content/cover',
      '/usr/local/go/blog/content/cover/count.png',
      '/usr/local/go/blog/content/cover/pkg.cover',
      '/usr/local/go/blog/content/cover/pkg.go',
      '/usr/local/go/blog/content/cover/pkg_test.go',
      '/usr/local/go/blog/content/cover/set.png',
      '/usr/local/go/blog/content/cover.article',
      '/usr/local/go/blog/content/debugging-go-code-status-report.article',
      '/usr/local/go/blog/content/debugging-go-programs-with-gnu-debugger.article',
      '/usr/local/go/blog/content/defer-panic-and-recover.article',
      '/usr/local/go/blog/content/developer-experience.article',
      '/usr/local/go/blog/content/docker.article',
      '/usr/local/go/blog/content/docker-outyet.png',
      '/usr/local/go/blog/content/error-handling-and-go.article',
      '/usr/local/go/blog/content/errors-are-values.article',
      '/usr/local/go/blog/content/examples',
      '/usr/local/go/blog/content/examples/reverse.png',
      '/usr/local/go/blog/content/examples.article',
      '/usr/local/go/blog/content/first-class-functions-in-go-and-new-go.article',
      '/usr/local/go/blog/content/first-go-program',
      '/usr/local/go/blog/content/first-go-program/slist.go',
      '/usr/local/go/blog/content/first-go-program.article',
      '/usr/local/go/blog/content/fosdem14.article',
      '/usr/local/go/blog/content/from-zero-to-go-launching-on-google.article',
      '/usr/local/go/blog/content/from-zero-to-go-launching-on-google_image00.png',
      '/usr/local/go/blog/content/from-zero-to-go-launching-on-google_image01.jpg',
      '/usr/local/go/blog/content/from-zero-to-go-launching-on-google_image02.png',
      '/usr/local/go/blog/content/from-zero-to-go-launching-on-google_image03.png',
      '/usr/local/go/blog/content/gccgo-in-gcc-471.article',
      '/usr/local/go/blog/content/generate.article',
      '/usr/local/go/blog/content/getthee-to-go-meetup.article',
      '/usr/local/go/blog/content/getting-to-know-go-community.article',
      '/usr/local/go/blog/content/gif-decoder-exercise-in-go-interfaces.article',
      '/usr/local/go/blog/content/gif-decoder-exercise-in-go-interfaces_image00.jpg',
      '/usr/local/go/blog/content/gif-decoder-exercise-in-go-interfaces_image01.gif',
      '/usr/local/go/blog/content/gif-decoder-exercise-in-go-interfaces_image02.jpg',
      '/usr/local/go/blog/content/gif-decoder-exercise-in-go-interfaces_image03.gif',
      '/usr/local/go/blog/content/go-11-is-released.article',
      '/usr/local/go/blog/content/go-11-is-released_gopherbiplane5.jpg',
      '/usr/local/go/blog/content/go12.article',
      '/usr/local/go/blog/content/go1.3.article',
      '/usr/local/go/blog/content/go1.4.article',
      '/usr/local/go/blog/content/go1.5.article',
      '/usr/local/go/blog/content/go15gc.article',
      '/usr/local/go/blog/content/go1.6.article',
      '/usr/local/go/blog/content/go1.7.article',
      '/usr/local/go/blog/content/go1.7-binary-size.article',
      '/usr/local/go/blog/content/go1.7-binary-size.png',
      '/usr/local/go/blog/content/go1.8.article',
      '/usr/local/go/blog/content/go1.9',
      '/usr/local/go/blog/content/go1.9/helper_test.go',
      '/usr/local/go/blog/content/go1.9.article',
      '/usr/local/go/blog/content/go-and-google-app-engine.article',
      '/usr/local/go/blog/content/go-and-google-cloud-platform.article',
      '/usr/local/go/blog/content/go-app-engine-sdk-155-released.article',
      '/usr/local/go/blog/content/go-at-google-io-2011-videos.article',
      '/usr/local/go/blog/content/go-at-google-io-2011-videos_gopher.jpg',
      '/usr/local/go/blog/content/go-at-heroku.article',
      '/usr/local/go/blog/content/go-at-io-frequently-asked-questions.article',
      '/usr/local/go/blog/content/go-becomes-more-stable.article',
      '/usr/local/go/blog/content/gobs-of-data.article',
      '/usr/local/go/blog/content/go-concurrency-patterns-timing-out-and.article',
      '/usr/local/go/blog/content/godoc-documenting-go-code.article',
      '/usr/local/go/blog/content/go-fmt-your-code.article',
      '/usr/local/go/blog/content/go-fonts',
      '/usr/local/go/blog/content/go-fonts/abdgpq-mono.png',
      '/usr/local/go/blog/content/go-fonts/abdgpq-proportional.png',
      '/usr/local/go/blog/content/go-fonts/go-font-code.png',
      '/usr/local/go/blog/content/go-fonts/go-font-greek.png',
      '/usr/local/go/blog/content/go-fonts/go-font-jabberwocky.png',
      '/usr/local/go/blog/content/go-fonts/go-mono.png',
      '/usr/local/go/blog/content/go-fonts/go-regular.png',
      '/usr/local/go/blog/content/go-fonts.article',
      '/usr/local/go/blog/content/go-for-app-engine-is-now-generally.article',
      '/usr/local/go/blog/content/go-imagedraw-package_20.png',
      '/usr/local/go/blog/content/go-imagedraw-package_2a.png',
      '/usr/local/go/blog/content/go-imagedraw-package_2b.png',
      '/usr/local/go/blog/content/go-imagedraw-package_2c.png',
      '/usr/local/go/blog/content/go-imagedraw-package_2d.png',
      '/usr/local/go/blog/content/go-imagedraw-package_2e.png',
      '/usr/local/go/blog/content/go-imagedraw-package_2f.png',
      '/usr/local/go/blog/content/go-imagedraw-package.article',
      '/usr/local/go/blog/content/go-image-package.article',
      '/usr/local/go/blog/content/go-image-package_image-package-01.png',
      '/usr/local/go/blog/content/go-image-package_image-package-02.png',
      '/usr/local/go/blog/content/go-image-package_image-package-03.png',
      '/usr/local/go/blog/content/go-image-package_image-package-04.png',
      '/usr/local/go/blog/content/go-image-package_image-package-05.png',
      '/usr/local/go/blog/content/go-maps-in-action',
      '/usr/local/go/blog/content/go-maps-in-action/list.go',
      '/usr/local/go/blog/content/go-maps-in-action/people.go',
      '/usr/local/go/blog/content/go-maps-in-action.article',
      '/usr/local/go/blog/content/go-one-year-ago-today.article',
      '/usr/local/go/blog/content/gopher',
      '/usr/local/go/blog/content/gopher/avatars.png',
      '/usr/local/go/blog/content/gopher/glenda.png',
      '/usr/local/go/blog/content/gopher/gopher.png',
      '/usr/local/go/blog/content/gopher/header.jpg',
      '/usr/local/go/blog/content/gopher/logo.png',
      '/usr/local/go/blog/content/gopher/plush.jpg',
      '/usr/local/go/blog/content/gopher/portrait.jpg',
      '/usr/local/go/blog/content/gopher/prototype.jpg',
      '/usr/local/go/blog/content/gopher/usergroups.png',
      '/usr/local/go/blog/content/gopher/vinyl.jpg',
      '/usr/local/go/blog/content/gopher/wfmu.jpg',
      '/usr/local/go/blog/content/gopher.article',
      '/usr/local/go/blog/content/gopherbelly300.jpg',
      '/usr/local/go/blog/content/gopherbelly.html',
      '/usr/local/go/blog/content/gopherchina',
      '/usr/local/go/blog/content/gopherchina/image00.jpg',
      '/usr/local/go/blog/content/gopherchina/image01.jpg',
      '/usr/local/go/blog/content/gopherchina/image02.jpg',
      '/usr/local/go/blog/content/gopherchina/image03.jpg',
      '/usr/local/go/blog/content/gopherchina/image04.jpg',
      '/usr/local/go/blog/content/gopherchina/image05.jpg',
      '/usr/local/go/blog/content/gopherchina/image06.jpg',
      '/usr/local/go/blog/content/gopherchina.article',
      '/usr/local/go/blog/content/gophercon',
      '/usr/local/go/blog/content/gophercon/image00.jpg',
      '/usr/local/go/blog/content/gophercon/image01.jpg',
      '/usr/local/go/blog/content/gophercon/image02.jpg',
      '/usr/local/go/blog/content/gophercon2015.article',
      '/usr/local/go/blog/content/gophercon2015.caption',
      '/usr/local/go/blog/content/gophercon2015.jpg',
      '/usr/local/go/blog/content/gophercon.article',
      '/usr/local/go/blog/content/gophergala',
      '/usr/local/go/blog/content/gophergala/fancygopher.jpg',
      '/usr/local/go/blog/content/gophergala.article',
      '/usr/local/go/blog/content/go-programming-language-turns-two.article',
      '/usr/local/go/blog/content/go-programming-language-turns-two_costume.jpg',
      '/usr/local/go/blog/content/go-programming-language-turns-two_gophers.jpg',
      '/usr/local/go/blog/content/go-programming-session-video-from.article',
      '/usr/local/go/blog/content/gos-declaration-syntax.article',
      '/usr/local/go/blog/content/go-slices-usage-and-internals.article',
      '/usr/local/go/blog/content/go-slices-usage-and-internals_slice-1.png',
      '/usr/local/go/blog/content/go-slices-usage-and-internals_slice-2.png',
      '/usr/local/go/blog/content/go-slices-usage-and-internals_slice-3.png',
      '/usr/local/go/blog/content/go-slices-usage-and-internals_slice-array.png',
      '/usr/local/go/blog/content/go-slices-usage-and-internals_slice-struct.png',
      '/usr/local/go/blog/content/gothamgo',
      '/usr/local/go/blog/content/gothamgo/gothamgo.jpg',
      '/usr/local/go/blog/content/gothamgo.article',
      '/usr/local/go/blog/content/go-turns-three.article',
      '/usr/local/go/blog/content/gouk15',
      '/usr/local/go/blog/content/gouk15/gouk.jpg',
      '/usr/local/go/blog/content/gouk15.article',
      '/usr/local/go/blog/content/go-updates-in-app-engine-171.article',
      '/usr/local/go/blog/content/go-version-1-is-released.article',
      '/usr/local/go/blog/content/go-version-1-is-released_gophermega.jpg',
      '/usr/local/go/blog/content/go-videos-from-google-io-2012.article',
      '/usr/local/go/blog/content/go-whats-new-in-march-2010.article',
      '/usr/local/go/blog/content/go-wins-2010-bossie-award.article',
      '/usr/local/go/blog/content/h2push',
      '/usr/local/go/blog/content/h2push/networktimeline.png',
      '/usr/local/go/blog/content/h2push/pusher.go',
      '/usr/local/go/blog/content/h2push/server',
      '/usr/local/go/blog/content/h2push/server/cert.pem',
      '/usr/local/go/blog/content/h2push/server/key.pem',
      '/usr/local/go/blog/content/h2push/server/main.go',
      '/usr/local/go/blog/content/h2push/server/static',
      '/usr/local/go/blog/content/h2push/server/static/app.js',
      '/usr/local/go/blog/content/h2push/server/static/style.css',
      '/usr/local/go/blog/content/h2push/serverpush.svg',
      '/usr/local/go/blog/content/h2push.article',
      '/usr/local/go/blog/content/http-tracing',
      '/usr/local/go/blog/content/http-tracing/client.go',
      '/usr/local/go/blog/content/http-tracing/trace.go',
      '/usr/local/go/blog/content/http-tracing.article',
      '/usr/local/go/blog/content/introducing-gofix.article',
      '/usr/local/go/blog/content/introducing-go-playground.article',
      '/usr/local/go/blog/content/introducing-go-playground_Untitled.png',
      '/usr/local/go/blog/content/io2014',
      '/usr/local/go/blog/content/io2014/booth.jpg',
      '/usr/local/go/blog/content/io2014/collage.jpg',
      '/usr/local/go/blog/content/io2014/crowd.jpg',
      '/usr/local/go/blog/content/io2014/summerfest.jpg',
      '/usr/local/go/blog/content/io2014.article',
      '/usr/local/go/blog/content/json-and-go.article',
      '/usr/local/go/blog/content/json-rpc-tale-of-interfaces.article',
      '/usr/local/go/blog/content/laws-of-reflection.article',
      '/usr/local/go/blog/content/learn-go-from-your-browser.article',
      '/usr/local/go/blog/content/matchlang',
      '/usr/local/go/blog/content/matchlang/complete.go',
      '/usr/local/go/blog/content/matchlang/display.go',
      '/usr/local/go/blog/content/matchlang/tags.html',
      '/usr/local/go/blog/content/matchlang.article',
      '/usr/local/go/blog/content/new-talk-and-tutorials.article',
      '/usr/local/go/blog/content/normalization',
      '/usr/local/go/blog/content/normalization/table1.html',
      '/usr/local/go/blog/content/normalization/table2.html',
      '/usr/local/go/blog/content/normalization.article',
      '/usr/local/go/blog/content/open-source.article',
      '/usr/local/go/blog/content/organizing-go-code.article',
      '/usr/local/go/blog/content/oscon.article',
      '/usr/local/go/blog/content/osconreport',
      '/usr/local/go/blog/content/osconreport/meetup.png',
      '/usr/local/go/blog/content/osconreport/random.png',
      '/usr/local/go/blog/content/osconreport/talks.png',
      '/usr/local/go/blog/content/osconreport/workshops.png',
      '/usr/local/go/blog/content/osconreport.article',
      '/usr/local/go/blog/content/package-names.article',
      '/usr/local/go/blog/content/pipelines',
      '/usr/local/go/blog/content/pipelines/bounded.go',
      '/usr/local/go/blog/content/pipelines/parallel.go',
      '/usr/local/go/blog/content/pipelines/serial.go',
      '/usr/local/go/blog/content/pipelines/sqbuffer.go',
      '/usr/local/go/blog/content/pipelines/sqdone1.go',
      '/usr/local/go/blog/content/pipelines/sqdone2.go',
      '/usr/local/go/blog/content/pipelines/sqdone3.go',
      '/usr/local/go/blog/content/pipelines/sqfan.go',
      '/usr/local/go/blog/content/pipelines/sqleak.go',
      '/usr/local/go/blog/content/pipelines/square2.go',
      '/usr/local/go/blog/content/pipelines/square.go',
      '/usr/local/go/blog/content/pipelines.article',
      '/usr/local/go/blog/content/playground',
      '/usr/local/go/blog/content/playground/net.go',
      '/usr/local/go/blog/content/playground/os.go',
      '/usr/local/go/blog/content/playground/overview.png',
      '/usr/local/go/blog/content/playground/time.go',
      '/usr/local/go/blog/content/playground.article',
      '/usr/local/go/blog/content/preview-of-go-version-1.article',
      '/usr/local/go/blog/content/profiling-go-programs.article',
      '/usr/local/go/blog/content/profiling-go-programs_havlak1a-75.png',
      '/usr/local/go/blog/content/profiling-go-programs_havlak1-hash_lookup-75.png',
      '/usr/local/go/blog/content/profiling-go-programs_havlak4a-mallocgc.png',
      '/usr/local/go/blog/content/profiling-go-programs_havlak4a-mallocgc-trim.png',
      '/usr/local/go/blog/content/qihoo',
      '/usr/local/go/blog/content/qihoo/image00.png',
      '/usr/local/go/blog/content/qihoo/image01.png',
      '/usr/local/go/blog/content/qihoo/image02.png',
      '/usr/local/go/blog/content/qihoo/image03.png',
      '/usr/local/go/blog/content/qihoo/table.png',
      '/usr/local/go/blog/content/qihoo.article',
      '/usr/local/go/blog/content/race-detector',
      '/usr/local/go/blog/content/race-detector/blackhole.go',
      '/usr/local/go/blog/content/race-detector/timer-fixed.go',
      '/usr/local/go/blog/content/race-detector/timer.go',
      '/usr/local/go/blog/content/race-detector.article',
      '/usr/local/go/blog/content/real-go-projects-smarttwitter-and-webgo.article',
      '/usr/local/go/blog/content/share-memory-by-communicating.article',
      '/usr/local/go/blog/content/slices',
      '/usr/local/go/blog/content/slices/prog010.go',
      '/usr/local/go/blog/content/slices/prog020.go',
      '/usr/local/go/blog/content/slices/prog030.go',
      '/usr/local/go/blog/content/slices/prog040.go',
      '/usr/local/go/blog/content/slices/prog050.go',
      '/usr/local/go/blog/content/slices/prog060.go',
      '/usr/local/go/blog/content/slices/prog070.go',
      '/usr/local/go/blog/content/slices/prog080.go',
      '/usr/local/go/blog/content/slices/prog090.go',
      '/usr/local/go/blog/content/slices/prog100.go',
      '/usr/local/go/blog/content/slices/prog110.go',
      '/usr/local/go/blog/content/slices/prog120.go',
      '/usr/local/go/blog/content/slices/prog130.go',
      '/usr/local/go/blog/content/slices/prog140.go',
      '/usr/local/go/blog/content/slices/prog150.go',
      '/usr/local/go/blog/content/slices.article',
      '/usr/local/go/blog/content/spotlight-on-external-go-libraries.article',
      '/usr/local/go/blog/content/strings',
      '/usr/local/go/blog/content/strings/basic.go',
      '/usr/local/go/blog/content/strings/encoding.go',
      '/usr/local/go/blog/content/strings/range.go',
      '/usr/local/go/blog/content/strings/utf8.go',
      '/usr/local/go/blog/content/strings.article',
      '/usr/local/go/blog/content/subtests.article',
      '/usr/local/go/blog/content/survey2016',
      '/usr/local/go/blog/content/survey2016/aboutme.svg',
      '/usr/local/go/blog/content/survey2016/adequate.svg',
      '/usr/local/go/blog/content/survey2016/agree6.svg',
      '/usr/local/go/blog/content/survey2016/answers.svg',
      '/usr/local/go/blog/content/survey2016/areas.svg',
      '/usr/local/go/blog/content/survey2016/attend.svg',
      '/usr/local/go/blog/content/survey2016/background.html',
      '/usr/local/go/blog/content/survey2016/challenge2.svg',
      '/usr/local/go/blog/content/survey2016/challenge.svg',
      '/usr/local/go/blog/content/survey2016/community.html',
      '/usr/local/go/blog/content/survey2016/contribute1.svg',
      '/usr/local/go/blog/content/survey2016/contribute2.svg',
      '/usr/local/go/blog/content/survey2016/country.svg',
      '/usr/local/go/blog/content/survey2016/deploy.svg',
      '/usr/local/go/blog/content/survey2016/dev.html',
      '/usr/local/go/blog/content/survey2016/docs.svg',
      '/usr/local/go/blog/content/survey2016/ed-feature.svg',
      '/usr/local/go/blog/content/survey2016/ed-satisfy.svg',
      '/usr/local/go/blog/content/survey2016/ed.svg',
      '/usr/local/go/blog/content/survey2016/effective.html',
      '/usr/local/go/blog/content/survey2016/effective.svg',
      '/usr/local/go/blog/content/survey2016/final.svg',
      '/usr/local/go/blog/content/survey2016/howlong.svg',
      '/usr/local/go/blog/content/survey2016/identify.svg',
      '/usr/local/go/blog/content/survey2016/improve.svg',
      '/usr/local/go/blog/content/survey2016/keyword.svg',
      '/usr/local/go/blog/content/survey2016/lang-expertise.svg',
      '/usr/local/go/blog/content/survey2016/lang-preference.svg',
      '/usr/local/go/blog/content/survey2016/library.svg',
      '/usr/local/go/blog/content/survey2016/like.svg',
      '/usr/local/go/blog/content/survey2016/mkhtml.go',
      '/usr/local/go/blog/content/survey2016/news.svg',
      '/usr/local/go/blog/content/survey2016/project.html',
      '/usr/local/go/blog/content/survey2016/quotes.html',
      '/usr/local/go/blog/content/survey2016/README',
      '/usr/local/go/blog/content/survey2016/recommend.svg',
      '/usr/local/go/blog/content/survey2016/system.svg',
      '/usr/local/go/blog/content/survey2016/usage.html',
      '/usr/local/go/blog/content/survey2016/uses.svg',
      '/usr/local/go/blog/content/survey2016/welcome.svg',
      '/usr/local/go/blog/content/survey2016/welcoming.svg',
      '/usr/local/go/blog/content/survey2016/when.svg',
      '/usr/local/go/blog/content/survey2016/why-not.svg',
      '/usr/local/go/blog/content/survey2016/why-not-text.svg',
      '/usr/local/go/blog/content/survey2016.article',
      '/usr/local/go/blog/content/survey2016-results.article',
      '/usr/local/go/blog/content/the-app-engine-sdk-and-workspaces-gopath.article',
      '/usr/local/go/blog/content/the-path-to-go-1.article',
      '/usr/local/go/blog/content/third-party-libraries-goprotobuf-and.article',
      '/usr/local/go/blog/content/toward-go2',
      '/usr/local/go/blog/content/toward-go2/div-end.html',
      '/usr/local/go/blog/content/toward-go2/div-indent.html',
      '/usr/local/go/blog/content/toward-go2/error.png',
      '/usr/local/go/blog/content/toward-go2/go1-preview.png',
      '/usr/local/go/blog/content/toward-go2/go1-release.png',
      '/usr/local/go/blog/content/toward-go2/mail.png',
      '/usr/local/go/blog/content/toward-go2/process2.graffle',
      '/usr/local/go/blog/content/toward-go2/process2.png',
      '/usr/local/go/blog/content/toward-go2/process2.svg',
      '/usr/local/go/blog/content/toward-go2/process34.graffle',
      '/usr/local/go/blog/content/toward-go2/process34.png',
      '/usr/local/go/blog/content/toward-go2/process34.svg',
      '/usr/local/go/blog/content/toward-go2/process5.graffle',
      '/usr/local/go/blog/content/toward-go2/process5.png',
      '/usr/local/go/blog/content/toward-go2/process5.svg',
      '/usr/local/go/blog/content/toward-go2/process.graffle',
      '/usr/local/go/blog/content/toward-go2/process.png',
      '/usr/local/go/blog/content/toward-go2/process.svg',
      '/usr/local/go/blog/content/toward-go2/tweet.png',
      '/usr/local/go/blog/content/toward-go2.article',
      '/usr/local/go/blog/content/two-go-talks-lexical-scanning-in-go-and.article',
      '/usr/local/go/blog/content/two-recent-go-articles.article',
      '/usr/local/go/blog/content/two-recent-go-talks.article',
      '/usr/local/go/blog/content/upcoming-google-io-go-events.article',
      '/usr/local/go/blog/content/writing-scalable-app-engine.article',
      '/usr/local/go/blog/template',
      '/usr/local/go/blog/template/article.tmpl',
      '/usr/local/go/blog/template/doc.tmpl',
      '/usr/local/go/blog/template/home.tmpl',
      '/usr/local/go/blog/template/index.tmpl',
      '/usr/local/go/blog/template/root.tmpl',
      '/usr/local/go/CONTRIBUTING.md',
      '/usr/local/go/CONTRIBUTORS',
      '/usr/local/go/doc',
      '/usr/local/go/doc/articles',
      '/usr/local/go/doc/articles/go_command.html',
      '/usr/local/go/doc/articles/index.html',
      '/usr/local/go/doc/articles/race_detector.html',
      '/usr/local/go/doc/articles/wiki',
      '/usr/local/go/doc/articles/wiki/edit.html',
      '/usr/local/go/doc/articles/wiki/final.go',
      '/usr/local/go/doc/articles/wiki/final-noclosure.go',
      '/usr/local/go/doc/articles/wiki/final-noerror.go',
      '/usr/local/go/doc/articles/wiki/final-parsetemplate.go',
      '/usr/local/go/doc/articles/wiki/final-template.go',
      '/usr/local/go/doc/articles/wiki/final-test.patch',
      '/usr/local/go/doc/articles/wiki/get.go',
      '/usr/local/go/doc/articles/wiki/http-sample.go',
      '/usr/local/go/doc/articles/wiki/index.html',
      '/usr/local/go/doc/articles/wiki/notemplate.go',
      '/usr/local/go/doc/articles/wiki/part1.go',
      '/usr/local/go/doc/articles/wiki/part1-noerror.go',
      '/usr/local/go/doc/articles/wiki/part2.go',
      '/usr/local/go/doc/articles/wiki/part3-errorhandling.go',
      '/usr/local/go/doc/articles/wiki/part3.go',
      '/usr/local/go/doc/articles/wiki/test.bash',
      '/usr/local/go/doc/articles/wiki/test_edit.good',
      '/usr/local/go/doc/articles/wiki/test_Test.txt.good',
      '/usr/local/go/doc/articles/wiki/test_view.good',
      '/usr/local/go/doc/articles/wiki/view.html',
      '/usr/local/go/doc/asm.html',
      '/usr/local/go/doc/cmd.html',
      '/usr/local/go/doc/code.html',
      '/usr/local/go/doc/codewalk',
      '/usr/local/go/doc/codewalk/codewalk.css',
      '/usr/local/go/doc/codewalk/codewalk.js',
      '/usr/local/go/doc/codewalk/codewalk.xml',
      '/usr/local/go/doc/codewalk/functions.xml',
      '/usr/local/go/doc/codewalk/markov.go',
      '/usr/local/go/doc/codewalk/markov.xml',
      '/usr/local/go/doc/codewalk/pig.go',
      '/usr/local/go/doc/codewalk/popout.png',
      '/usr/local/go/doc/codewalk/run',
      '/usr/local/go/doc/codewalk/sharemem.xml',
      '/usr/local/go/doc/codewalk/urlpoll.go',
      '/usr/local/go/doc/conduct.html',
      '/usr/local/go/doc/contrib.html',
      '/usr/local/go/doc/contribute.html',
      '/usr/local/go/doc/debugging_with_gdb.html',
      '/usr/local/go/doc/devel',
      '/usr/local/go/doc/devel/pre_go1.html',
      '/usr/local/go/doc/devel/release.html',
      '/usr/local/go/doc/devel/weekly.html',
      '/usr/local/go/doc/docs.html',
      '/usr/local/go/doc/editors',
      '/usr/local/go/doc/editors/gogland.png',
      '/usr/local/go/doc/editors/go-plus.png',
      '/usr/local/go/doc/editors/vimgo.png',
      '/usr/local/go/doc/editors/vscodego.png',
      '/usr/local/go/doc/editors.html',
      '/usr/local/go/doc/effective_go.html',
      '/usr/local/go/doc/gccgo_contribute.html',
      '/usr/local/go/doc/gccgo_install.html',
      '/usr/local/go/doc/go1.1.html',
      '/usr/local/go/doc/go1.2.html',
      '/usr/local/go/doc/go1.3.html',
      '/usr/local/go/doc/go1.4.html',
      '/usr/local/go/doc/go1.5.html',
      '/usr/local/go/doc/go1.6.html',
      '/usr/local/go/doc/go1.7.html',
      '/usr/local/go/doc/go1.8.html',
      '/usr/local/go/doc/go1.9.html',
      '/usr/local/go/doc/go1compat.html',
      '/usr/local/go/doc/go1.html',
      '/usr/local/go/doc/go_faq.html',
      '/usr/local/go/doc/go-logo-black.png',
      '/usr/local/go/doc/go-logo-blue.png',
      '/usr/local/go/doc/go-logo-white.png',
      '/usr/local/go/doc/go_mem.html',
      '/usr/local/go/doc/gopher',
      '/usr/local/go/doc/gopher/appenginegophercolor.jpg',
      '/usr/local/go/doc/gopher/appenginegopher.jpg',
      '/usr/local/go/doc/gopher/appenginelogo.gif',
      '/usr/local/go/doc/gopher/biplane.jpg',
      '/usr/local/go/doc/gopher/bumper192x108.png',
      '/usr/local/go/doc/gopher/bumper320x180.png',
      '/usr/local/go/doc/gopher/bumper480x270.png',
      '/usr/local/go/doc/gopher/bumper640x360.png',
      '/usr/local/go/doc/gopher/bumper.png',
      '/usr/local/go/doc/gopher/doc.png',
      '/usr/local/go/doc/gopher/favicon.svg',
      '/usr/local/go/doc/gopher/fiveyears.jpg',
      '/usr/local/go/doc/gopher/frontpage.png',
      '/usr/local/go/doc/gopher/gopherbw.png',
      '/usr/local/go/doc/gopher/gophercolor16x16.png',
      '/usr/local/go/doc/gopher/gophercolor.png',
      '/usr/local/go/doc/gopher/help.png',
      '/usr/local/go/doc/gopher/pencil',
      '/usr/local/go/doc/gopher/pencil/gopherhat.jpg',
      '/usr/local/go/doc/gopher/pencil/gopherhelmet.jpg',
      '/usr/local/go/doc/gopher/pencil/gophermega.jpg',
      '/usr/local/go/doc/gopher/pencil/gopherrunning.jpg',
      '/usr/local/go/doc/gopher/pencil/gopherswim.jpg',
      '/usr/local/go/doc/gopher/pencil/gopherswrench.jpg',
      '/usr/local/go/doc/gopher/pkg.png',
      '/usr/local/go/doc/gopher/project.png',
      '/usr/local/go/doc/gopher/README',
      '/usr/local/go/doc/gopher/ref.png',
      '/usr/local/go/doc/gopher/run.png',
      '/usr/local/go/doc/gopher/talks.png',
      '/usr/local/go/doc/go_spec.html',
      '/usr/local/go/doc/help.html',
      '/usr/local/go/doc/ie.css',
      '/usr/local/go/doc/install.html',
      '/usr/local/go/doc/install-source.html',
      '/usr/local/go/doc/play',
      '/usr/local/go/doc/play/fib.go',
      '/usr/local/go/doc/play/hello.go',
      '/usr/local/go/doc/play/life.go',
      '/usr/local/go/doc/play/peano.go',
      '/usr/local/go/doc/play/pi.go',
      '/usr/local/go/doc/play/sieve.go',
      '/usr/local/go/doc/play/solitaire.go',
      '/usr/local/go/doc/play/tree.go',
      '/usr/local/go/doc/progs',
      '/usr/local/go/doc/progs/cgo1.go',
      '/usr/local/go/doc/progs/cgo2.go',
      '/usr/local/go/doc/progs/cgo3.go',
      '/usr/local/go/doc/progs/cgo4.go',
      '/usr/local/go/doc/progs/defer2.go',
      '/usr/local/go/doc/progs/defer.go',
      '/usr/local/go/doc/progs/eff_bytesize.go',
      '/usr/local/go/doc/progs/eff_qr.go',
      '/usr/local/go/doc/progs/eff_sequence.go',
      '/usr/local/go/doc/progs/eff_unused1.go',
      '/usr/local/go/doc/progs/eff_unused2.go',
      '/usr/local/go/doc/progs/error2.go',
      '/usr/local/go/doc/progs/error3.go',
      '/usr/local/go/doc/progs/error4.go',
      '/usr/local/go/doc/progs/error.go',
      '/usr/local/go/doc/progs/go1.go',
      '/usr/local/go/doc/progs/gobs1.go',
      '/usr/local/go/doc/progs/gobs2.go',
      '/usr/local/go/doc/progs/image_draw.go',
      '/usr/local/go/doc/progs/image_package1.go',
      '/usr/local/go/doc/progs/image_package2.go',
      '/usr/local/go/doc/progs/image_package3.go',
      '/usr/local/go/doc/progs/image_package4.go',
      '/usr/local/go/doc/progs/image_package5.go',
      '/usr/local/go/doc/progs/image_package6.go',
      '/usr/local/go/doc/progs/interface2.go',
      '/usr/local/go/doc/progs/interface.go',
      '/usr/local/go/doc/progs/json1.go',
      '/usr/local/go/doc/progs/json2.go',
      '/usr/local/go/doc/progs/json3.go',
      '/usr/local/go/doc/progs/json4.go',
      '/usr/local/go/doc/progs/json5.go',
      '/usr/local/go/doc/progs/run.go',
      '/usr/local/go/doc/progs/slices.go',
      '/usr/local/go/doc/progs/timeout1.go',
      '/usr/local/go/doc/progs/timeout2.go',
      '/usr/local/go/doc/root.html',
      '/usr/local/go/doc/security.html',
      '/usr/local/go/doc/share.png',
      '/usr/local/go/doc/tos.html',
      '/usr/local/go/favicon.ico',
      '/usr/local/go/lib',
      '/usr/local/go/lib/time',
      '/usr/local/go/lib/time/README',
      '/usr/local/go/lib/time/update.bash',
      '/usr/local/go/lib/time/zoneinfo.zip',
      '/usr/local/go/LICENSE',
      '/usr/local/go/misc',
      '/usr/local/go/misc/android',
      '/usr/local/go/misc/android/cleaner.go',
      '/usr/local/go/misc/android/go_android_exec.go',
      '/usr/local/go/misc/android/README',
      '/usr/local/go/misc/arm',
      '/usr/local/go/misc/arm/a',
      '/usr/local/go/misc/benchcmp',
      '/usr/local/go/misc/cgo',
      '/usr/local/go/misc/cgo/errors',
      '/usr/local/go/misc/cgo/errors/err1.go',
      '/usr/local/go/misc/cgo/errors/err2.go',
      '/usr/local/go/misc/cgo/errors/err3.go',
      '/usr/local/go/misc/cgo/errors/issue11097a.go',
      '/usr/local/go/misc/cgo/errors/issue11097b.go',
      '/usr/local/go/misc/cgo/errors/issue13129.go',
      '/usr/local/go/misc/cgo/errors/issue13423.go',
      '/usr/local/go/misc/cgo/errors/issue13635.go',
      '/usr/local/go/misc/cgo/errors/issue13830.go',
      '/usr/local/go/misc/cgo/errors/issue14669.go',
      '/usr/local/go/misc/cgo/errors/issue16116.go',
      '/usr/local/go/misc/cgo/errors/issue16591.go',
      '/usr/local/go/misc/cgo/errors/issue18452.go',
      '/usr/local/go/misc/cgo/errors/issue18889.go',
      '/usr/local/go/misc/cgo/errors/issue7757.go',
      '/usr/local/go/misc/cgo/errors/issue8442.go',
      '/usr/local/go/misc/cgo/errors/malloc.go',
      '/usr/local/go/misc/cgo/errors/ptr.go',
      '/usr/local/go/misc/cgo/errors/test.bash',
      '/usr/local/go/misc/cgo/fortran',
      '/usr/local/go/misc/cgo/fortran/answer.f90',
      '/usr/local/go/misc/cgo/fortran/fortran.go',
      '/usr/local/go/misc/cgo/fortran/fortran_test.go',
      '/usr/local/go/misc/cgo/fortran/helloworld',
      '/usr/local/go/misc/cgo/fortran/helloworld/helloworld.f90',
      '/usr/local/go/misc/cgo/fortran/test.bash',
      '/usr/local/go/misc/cgo/gmp',
      '/usr/local/go/misc/cgo/gmp/fib.go',
      '/usr/local/go/misc/cgo/gmp/gmp.go',
      '/usr/local/go/misc/cgo/gmp/pi.go',
      '/usr/local/go/misc/cgo/life',
      '/usr/local/go/misc/cgo/life/c-life.c',
      '/usr/local/go/misc/cgo/life/life.go',
      '/usr/local/go/misc/cgo/life/life.h',
      '/usr/local/go/misc/cgo/life/main.go',
      '/usr/local/go/misc/cgo/life/main.out',
      '/usr/local/go/misc/cgo/nocgo',
      '/usr/local/go/misc/cgo/nocgo/nocgo.go',
      '/usr/local/go/misc/cgo/nocgo/nocgo_test.go',
      '/usr/local/go/misc/cgo/stdio',
      '/usr/local/go/misc/cgo/stdio/chain.go',
      '/usr/local/go/misc/cgo/stdio/chain.out',
      '/usr/local/go/misc/cgo/stdio/fib.go',
      '/usr/local/go/misc/cgo/stdio/fib.out',
      '/usr/local/go/misc/cgo/stdio/file.go',
      '/usr/local/go/misc/cgo/stdio/hello.go',
      '/usr/local/go/misc/cgo/stdio/hello.out',
      '/usr/local/go/misc/cgo/stdio/run.out',
      '/usr/local/go/misc/cgo/stdio/stdio.go',
      '/usr/local/go/misc/cgo/test',
      '/usr/local/go/misc/cgo/test/align.go',
      '/usr/local/go/misc/cgo/test/api.go',
      '/usr/local/go/misc/cgo/test/backdoor.go',
      '/usr/local/go/misc/cgo/test/basic.go',
      '/usr/local/go/misc/cgo/test/buildid_linux.go',
      '/usr/local/go/misc/cgo/test/callback_c.c',
      '/usr/local/go/misc/cgo/test/callback_c_gc.c',
      '/usr/local/go/misc/cgo/test/callback_c_gccgo.c',
      '/usr/local/go/misc/cgo/test/callback.go',
      '/usr/local/go/misc/cgo/test/cflags.go',
      '/usr/local/go/misc/cgo/test/cgo_linux_test.go',
      '/usr/local/go/misc/cgo/test/cgo_stubs_android_test.go',
      '/usr/local/go/misc/cgo/test/cgo_test.go',
      '/usr/local/go/misc/cgo/test/cgo_thread_lock.go',
      '/usr/local/go/misc/cgo/test/cgo_unix_test.go',
      '/usr/local/go/misc/cgo/test/checkconst.go',
      '/usr/local/go/misc/cgo/test/complex.go',
      '/usr/local/go/misc/cgo/test/cthread.go',
      '/usr/local/go/misc/cgo/test/cthread_unix.c',
      '/usr/local/go/misc/cgo/test/cthread_windows.c',
      '/usr/local/go/misc/cgo/test/duplicate_symbol.go',
      '/usr/local/go/misc/cgo/test/env.go',
      '/usr/local/go/misc/cgo/test/exports.go',
      '/usr/local/go/misc/cgo/test/fpvar.go',
      '/usr/local/go/misc/cgo/test/gcc68255',
      '/usr/local/go/misc/cgo/test/gcc68255/a.go',
      '/usr/local/go/misc/cgo/test/gcc68255/c.c',
      '/usr/local/go/misc/cgo/test/gcc68255/c.h',
      '/usr/local/go/misc/cgo/test/gcc68255.go',
      '/usr/local/go/misc/cgo/test/helpers.go',
      '/usr/local/go/misc/cgo/test/issue10303.go',
      '/usr/local/go/misc/cgo/test/issue11925.go',
      '/usr/local/go/misc/cgo/test/issue12030.go',
      '/usr/local/go/misc/cgo/test/issue1222.go',
      '/usr/local/go/misc/cgo/test/issue1328.go',
      '/usr/local/go/misc/cgo/test/issue13402.go',
      '/usr/local/go/misc/cgo/test/issue13930.go',
      '/usr/local/go/misc/cgo/test/issue14838.go',
      '/usr/local/go/misc/cgo/test/issue1560.go',
      '/usr/local/go/misc/cgo/test/issue1635.go',
      '/usr/local/go/misc/cgo/test/issue17065.go',
      '/usr/local/go/misc/cgo/test/issue17537.go',
      '/usr/local/go/misc/cgo/test/issue18126.go',
      '/usr/local/go/misc/cgo/test/issue18146.go',
      '/usr/local/go/misc/cgo/test/issue18720.go',
      '/usr/local/go/misc/cgo/test/issue20129.go',
      '/usr/local/go/misc/cgo/test/issue20266',
      '/usr/local/go/misc/cgo/test/issue20266/issue20266.h',
      '/usr/local/go/misc/cgo/test/issue20266.go',
      '/usr/local/go/misc/cgo/test/issue20369.go',
      '/usr/local/go/misc/cgo/test/issue21668.go',
      '/usr/local/go/misc/cgo/test/issue21708.go',
      '/usr/local/go/misc/cgo/test/issue2462.go',
      '/usr/local/go/misc/cgo/test/issue3250.go',
      '/usr/local/go/misc/cgo/test/issue3250w.go',
      '/usr/local/go/misc/cgo/test/issue3261.go',
      '/usr/local/go/misc/cgo/test/issue3729.go',
      '/usr/local/go/misc/cgo/test/issue3729w.go',
      '/usr/local/go/misc/cgo/test/issue3741.go',
      '/usr/local/go/misc/cgo/test/issue3775.go',
      '/usr/local/go/misc/cgo/test/issue3945.go',
      '/usr/local/go/misc/cgo/test/issue4029.c',
      '/usr/local/go/misc/cgo/test/issue4029.go',
      '/usr/local/go/misc/cgo/test/issue4029w.go',
      '/usr/local/go/misc/cgo/test/issue4054a.go',
      '/usr/local/go/misc/cgo/test/issue4054b.go',
      '/usr/local/go/misc/cgo/test/issue4273b.c',
      '/usr/local/go/misc/cgo/test/issue4273.c',
      '/usr/local/go/misc/cgo/test/issue4339.c',
      '/usr/local/go/misc/cgo/test/issue4339.go',
      '/usr/local/go/misc/cgo/test/issue4339.h',
      '/usr/local/go/misc/cgo/test/issue4417.go',
      '/usr/local/go/misc/cgo/test/issue4857.go',
      '/usr/local/go/misc/cgo/test/issue5227.go',
      '/usr/local/go/misc/cgo/test/issue5242.go',
      '/usr/local/go/misc/cgo/test/issue5337.go',
      '/usr/local/go/misc/cgo/test/issue5337w.go',
      '/usr/local/go/misc/cgo/test/issue5548_c.c',
      '/usr/local/go/misc/cgo/test/issue5548.go',
      '/usr/local/go/misc/cgo/test/issue5603.go',
      '/usr/local/go/misc/cgo/test/issue5740a.c',
      '/usr/local/go/misc/cgo/test/issue5740b.c',
      '/usr/local/go/misc/cgo/test/issue5740.go',
      '/usr/local/go/misc/cgo/test/issue5986.go',
      '/usr/local/go/misc/cgo/test/issue6128.go',
      '/usr/local/go/misc/cgo/test/issue6390.go',
      '/usr/local/go/misc/cgo/test/issue6472.go',
      '/usr/local/go/misc/cgo/test/issue6506.go',
      '/usr/local/go/misc/cgo/test/issue6612.go',
      '/usr/local/go/misc/cgo/test/issue6833_c.c',
      '/usr/local/go/misc/cgo/test/issue6833.go',
      '/usr/local/go/misc/cgo/test/issue6997_linux.c',
      '/usr/local/go/misc/cgo/test/issue6997_linux.go',
      '/usr/local/go/misc/cgo/test/issue7234_test.go',
      '/usr/local/go/misc/cgo/test/issue7560.go',
      '/usr/local/go/misc/cgo/test/issue7665.go',
      '/usr/local/go/misc/cgo/test/issue7786.go',
      '/usr/local/go/misc/cgo/test/issue7978.go',
      '/usr/local/go/misc/cgo/test/issue8092.go',
      '/usr/local/go/misc/cgo/test/issue8148.go',
      '/usr/local/go/misc/cgo/test/issue8331a.go',
      '/usr/local/go/misc/cgo/test/issue8331b.go',
      '/usr/local/go/misc/cgo/test/issue8331.h',
      '/usr/local/go/misc/cgo/test/issue8428.go',
      '/usr/local/go/misc/cgo/test/issue8441.go',
      '/usr/local/go/misc/cgo/test/issue8517.go',
      '/usr/local/go/misc/cgo/test/issue8517_windows.c',
      '/usr/local/go/misc/cgo/test/issue8517_windows.go',
      '/usr/local/go/misc/cgo/test/issue8694.go',
      '/usr/local/go/misc/cgo/test/issue8756',
      '/usr/local/go/misc/cgo/test/issue8756/issue8756.go',
      '/usr/local/go/misc/cgo/test/issue8756.go',
      '/usr/local/go/misc/cgo/test/issue8811.c',
      '/usr/local/go/misc/cgo/test/issue8811.go',
      '/usr/local/go/misc/cgo/test/issue8828',
      '/usr/local/go/misc/cgo/test/issue8828/issue8828.c',
      '/usr/local/go/misc/cgo/test/issue8828/trivial.go',
      '/usr/local/go/misc/cgo/test/issue8828.go',
      '/usr/local/go/misc/cgo/test/issue8945.go',
      '/usr/local/go/misc/cgo/test/issue9026',
      '/usr/local/go/misc/cgo/test/issue9026/issue9026.go',
      '/usr/local/go/misc/cgo/test/issue9026.go',
      '/usr/local/go/misc/cgo/test/issue9400',
      '/usr/local/go/misc/cgo/test/issue9400/asm_386.s',
      '/usr/local/go/misc/cgo/test/issue9400/asm_amd64x.s',
      '/usr/local/go/misc/cgo/test/issue9400/asm_arm64.s',
      '/usr/local/go/misc/cgo/test/issue9400/asm_arm.s',
      '/usr/local/go/misc/cgo/test/issue9400/asm_mips64x.s',
      '/usr/local/go/misc/cgo/test/issue9400/asm_mipsx.s',
      '/usr/local/go/misc/cgo/test/issue9400/asm_ppc64x.s',
      '/usr/local/go/misc/cgo/test/issue9400/asm_s390x.s',
      '/usr/local/go/misc/cgo/test/issue9400/gccgo.go',
      '/usr/local/go/misc/cgo/test/issue9400/stubs.go',
      '/usr/local/go/misc/cgo/test/issue9400_linux.go',
      '/usr/local/go/misc/cgo/test/issue9510a',
      '/usr/local/go/misc/cgo/test/issue9510a/a.go',
      '/usr/local/go/misc/cgo/test/issue9510b',
      '/usr/local/go/misc/cgo/test/issue9510b/b.go',
      '/usr/local/go/misc/cgo/test/issue9510.go',
      '/usr/local/go/misc/cgo/test/issue9557.go',
      '/usr/local/go/misc/cgo/test/setgid_linux.go',
      '/usr/local/go/misc/cgo/test/sigaltstack.go',
      '/usr/local/go/misc/cgo/test/sigprocmask.c',
      '/usr/local/go/misc/cgo/test/sigprocmask.go',
      '/usr/local/go/misc/cgo/testasan',
      '/usr/local/go/misc/cgo/testasan/main.go',
      '/usr/local/go/misc/cgo/testcarchive',
      '/usr/local/go/misc/cgo/testcarchive/carchive_test.go',
      '/usr/local/go/misc/cgo/testcarchive/main2.c',
      '/usr/local/go/misc/cgo/testcarchive/main3.c',
      '/usr/local/go/misc/cgo/testcarchive/main4.c',
      '/usr/local/go/misc/cgo/testcarchive/main5.c',
      '/usr/local/go/misc/cgo/testcarchive/main6.c',
      '/usr/local/go/misc/cgo/testcarchive/main.c',
      '/usr/local/go/misc/cgo/testcarchive/main_unix.c',
      '/usr/local/go/misc/cgo/testcarchive/main_windows.c',
      '/usr/local/go/misc/cgo/testcarchive/src',
      '/usr/local/go/misc/cgo/testcarchive/src/libgo',
      '/usr/local/go/misc/cgo/testcarchive/src/libgo/libgo.go',
      '/usr/local/go/misc/cgo/testcarchive/src/libgo2',
      '/usr/local/go/misc/cgo/testcarchive/src/libgo2/libgo2.go',
      '/usr/local/go/misc/cgo/testcarchive/src/libgo3',
      '/usr/local/go/misc/cgo/testcarchive/src/libgo3/libgo3.go',
      '/usr/local/go/misc/cgo/testcarchive/src/libgo4',
      '/usr/local/go/misc/cgo/testcarchive/src/libgo4/libgo4.go',
      '/usr/local/go/misc/cgo/testcarchive/src/libgo6',
      '/usr/local/go/misc/cgo/testcarchive/src/libgo6/sigprof.go',
      '/usr/local/go/misc/cgo/testcarchive/src/p',
      '/usr/local/go/misc/cgo/testcarchive/src/p/p.go',
      '/usr/local/go/misc/cgo/testcshared',
      '/usr/local/go/misc/cgo/testcshared/main0.c',
      '/usr/local/go/misc/cgo/testcshared/main1.c',
      '/usr/local/go/misc/cgo/testcshared/main2.c',
      '/usr/local/go/misc/cgo/testcshared/main3.c',
      '/usr/local/go/misc/cgo/testcshared/main4.c',
      '/usr/local/go/misc/cgo/testcshared/main5.c',
      '/usr/local/go/misc/cgo/testcshared/src',
      '/usr/local/go/misc/cgo/testcshared/src/libgo',
      '/usr/local/go/misc/cgo/testcshared/src/libgo/libgo.go',
      '/usr/local/go/misc/cgo/testcshared/src/libgo2',
      '/usr/local/go/misc/cgo/testcshared/src/libgo2/dup2.go',
      '/usr/local/go/misc/cgo/testcshared/src/libgo2/dup3.go',
      '/usr/local/go/misc/cgo/testcshared/src/libgo2/libgo2.go',
      '/usr/local/go/misc/cgo/testcshared/src/libgo4',
      '/usr/local/go/misc/cgo/testcshared/src/libgo4/libgo4.go',
      '/usr/local/go/misc/cgo/testcshared/src/libgo5',
      '/usr/local/go/misc/cgo/testcshared/src/libgo5/libgo5.go',
      '/usr/local/go/misc/cgo/testcshared/src/p',
      '/usr/local/go/misc/cgo/testcshared/src/p/p.go',
      '/usr/local/go/misc/cgo/testcshared/test.bash',
      '/usr/local/go/misc/cgo/testgodefs',
      '/usr/local/go/misc/cgo/testgodefs/anonunion.go',
      '/usr/local/go/misc/cgo/testgodefs/issue8478.go',
      '/usr/local/go/misc/cgo/testgodefs/main.go',
      '/usr/local/go/misc/cgo/testgodefs/test.bash',
      '/usr/local/go/misc/cgo/testplugin',
      '/usr/local/go/misc/cgo/testplugin/altpath',
      '/usr/local/go/misc/cgo/testplugin/altpath/src',
      '/usr/local/go/misc/cgo/testplugin/altpath/src/common',
      '/usr/local/go/misc/cgo/testplugin/altpath/src/common/common.go',
      '/usr/local/go/misc/cgo/testplugin/altpath/src/plugin-mismatch',
      '/usr/local/go/misc/cgo/testplugin/altpath/src/plugin-mismatch/main.go',
      '/usr/local/go/misc/cgo/testplugin/src',
      '/usr/local/go/misc/cgo/testplugin/src/common',
      '/usr/local/go/misc/cgo/testplugin/src/common/common.go',
      '/usr/local/go/misc/cgo/testplugin/src/host',
      '/usr/local/go/misc/cgo/testplugin/src/host/host.go',
      '/usr/local/go/misc/cgo/testplugin/src/iface',
      '/usr/local/go/misc/cgo/testplugin/src/iface/main.go',
      '/usr/local/go/misc/cgo/testplugin/src/iface_a',
      '/usr/local/go/misc/cgo/testplugin/src/iface_a/a.go',
      '/usr/local/go/misc/cgo/testplugin/src/iface_b',
      '/usr/local/go/misc/cgo/testplugin/src/iface_b/b.go',
      '/usr/local/go/misc/cgo/testplugin/src/iface_i',
      '/usr/local/go/misc/cgo/testplugin/src/iface_i/i.go',
      '/usr/local/go/misc/cgo/testplugin/src/issue18676',
      '/usr/local/go/misc/cgo/testplugin/src/issue18676/dynamodbstreamsevt',
      '/usr/local/go/misc/cgo/testplugin/src/issue18676/dynamodbstreamsevt/definition.go',
      '/usr/local/go/misc/cgo/testplugin/src/issue18676/main.go',
      '/usr/local/go/misc/cgo/testplugin/src/issue18676/plugin.go',
      '/usr/local/go/misc/cgo/testplugin/src/issue19534',
      '/usr/local/go/misc/cgo/testplugin/src/issue19534/main.go',
      '/usr/local/go/misc/cgo/testplugin/src/issue19534/plugin.go',
      '/usr/local/go/misc/cgo/testplugin/src/plugin1',
      '/usr/local/go/misc/cgo/testplugin/src/plugin1/plugin1.go',
      '/usr/local/go/misc/cgo/testplugin/src/plugin2',
      '/usr/local/go/misc/cgo/testplugin/src/plugin2/plugin2.go',
      '/usr/local/go/misc/cgo/testplugin/src/sub',
      '/usr/local/go/misc/cgo/testplugin/src/sub/plugin1',
      '/usr/local/go/misc/cgo/testplugin/src/sub/plugin1/plugin1.go',
      '/usr/local/go/misc/cgo/testplugin/test.bash',
      '/usr/local/go/misc/cgo/testplugin/unnamed1.go',
      '/usr/local/go/misc/cgo/testplugin/unnamed2.go',
      '/usr/local/go/misc/cgo/testsanitizers',
      '/usr/local/go/misc/cgo/testsanitizers/msan2.go',
      '/usr/local/go/misc/cgo/testsanitizers/msan3.go',
      '/usr/local/go/misc/cgo/testsanitizers/msan4.go',
      '/usr/local/go/misc/cgo/testsanitizers/msan5.go',
      '/usr/local/go/misc/cgo/testsanitizers/msan_fail.go',
      '/usr/local/go/misc/cgo/testsanitizers/msan.go',
      '/usr/local/go/misc/cgo/testsanitizers/msan_shared.go',
      '/usr/local/go/misc/cgo/testsanitizers/test.bash',
      '/usr/local/go/misc/cgo/testsanitizers/tsan10.go',
      '/usr/local/go/misc/cgo/testsanitizers/tsan11.go',
      '/usr/local/go/misc/cgo/testsanitizers/tsan12.go',
      '/usr/local/go/misc/cgo/testsanitizers/tsan2.go',
      '/usr/local/go/misc/cgo/testsanitizers/tsan3.go',
      '/usr/local/go/misc/cgo/testsanitizers/tsan4.go',
      '/usr/local/go/misc/cgo/testsanitizers/tsan5.go',
      '/usr/local/go/misc/cgo/testsanitizers/tsan6.go',
      '/usr/local/go/misc/cgo/testsanitizers/tsan7.go',
      '/usr/local/go/misc/cgo/testsanitizers/tsan8.go',
      '/usr/local/go/misc/cgo/testsanitizers/tsan9.go',
      '/usr/local/go/misc/cgo/testsanitizers/tsan.go',
      '/usr/local/go/misc/cgo/testsanitizers/tsan_shared.go',
      '/usr/local/go/misc/cgo/testshared',
      '/usr/local/go/misc/cgo/testshared/shared_test.go',
      '/usr/local/go/misc/cgo/testshared/src',
      '/usr/local/go/misc/cgo/testshared/src/dep2',
      '/usr/local/go/misc/cgo/testshared/src/dep2/dep2.go',
      '/usr/local/go/misc/cgo/testshared/src/dep3',
      '/usr/local/go/misc/cgo/testshared/src/dep3/dep3.go',
      '/usr/local/go/misc/cgo/testshared/src/depBase',
      '/usr/local/go/misc/cgo/testshared/src/depBase/asm.s',
      '/usr/local/go/misc/cgo/testshared/src/depBase/dep.go',
      '/usr/local/go/misc/cgo/testshared/src/depBase/gccgo.go',
      '/usr/local/go/misc/cgo/testshared/src/depBase/stubs.go',
      '/usr/local/go/misc/cgo/testshared/src/division',
      '/usr/local/go/misc/cgo/testshared/src/division/division.go',
      '/usr/local/go/misc/cgo/testshared/src/exe',
      '/usr/local/go/misc/cgo/testshared/src/exe/exe.go',
      '/usr/local/go/misc/cgo/testshared/src/exe2',
      '/usr/local/go/misc/cgo/testshared/src/exe2/exe2.go',
      '/usr/local/go/misc/cgo/testshared/src/exe3',
      '/usr/local/go/misc/cgo/testshared/src/exe3/exe3.go',
      '/usr/local/go/misc/cgo/testshared/src/execgo',
      '/usr/local/go/misc/cgo/testshared/src/execgo/exe.go',
      '/usr/local/go/misc/cgo/testshared/src/explicit',
      '/usr/local/go/misc/cgo/testshared/src/explicit/explicit.go',
      '/usr/local/go/misc/cgo/testshared/src/iface',
      '/usr/local/go/misc/cgo/testshared/src/iface/main.go',
      '/usr/local/go/misc/cgo/testshared/src/iface_a',
      '/usr/local/go/misc/cgo/testshared/src/iface_a/a.go',
      '/usr/local/go/misc/cgo/testshared/src/iface_b',
      '/usr/local/go/misc/cgo/testshared/src/iface_b/b.go',
      '/usr/local/go/misc/cgo/testshared/src/iface_i',
      '/usr/local/go/misc/cgo/testshared/src/iface_i/i.go',
      '/usr/local/go/misc/cgo/testshared/src/implicit',
      '/usr/local/go/misc/cgo/testshared/src/implicit/implicit.go',
      '/usr/local/go/misc/cgo/testshared/src/implicitcmd',
      '/usr/local/go/misc/cgo/testshared/src/implicitcmd/implicitcmd.go',
      '/usr/local/go/misc/cgo/testshared/src/trivial',
      '/usr/local/go/misc/cgo/testshared/src/trivial/trivial.go',
      '/usr/local/go/misc/cgo/testsigfwd',
      '/usr/local/go/misc/cgo/testsigfwd/main.go',
      '/usr/local/go/misc/cgo/testso',
      '/usr/local/go/misc/cgo/testso/cgoso.c',
      '/usr/local/go/misc/cgo/testso/cgoso_c.c',
      '/usr/local/go/misc/cgo/testso/cgoso.go',
      '/usr/local/go/misc/cgo/testso/cgoso_unix.go',
      '/usr/local/go/misc/cgo/testso/main.go',
      '/usr/local/go/misc/cgo/testsovar',
      '/usr/local/go/misc/cgo/testsovar/cgoso_c.c',
      '/usr/local/go/misc/cgo/testsovar/cgoso_c.h',
      '/usr/local/go/misc/cgo/testsovar/cgoso.go',
      '/usr/local/go/misc/cgo/testsovar/main.go',
      '/usr/local/go/misc/cgo/testtls',
      '/usr/local/go/misc/cgo/testtls/tls.go',
      '/usr/local/go/misc/cgo/testtls/tls_test.go',
      '/usr/local/go/misc/cgo/testtls/tls_unix.c',
      '/usr/local/go/misc/chrome',
      '/usr/local/go/misc/chrome/gophertool',
      '/usr/local/go/misc/chrome/gophertool/background.html',
      '/usr/local/go/misc/chrome/gophertool/background.js',
      '/usr/local/go/misc/chrome/gophertool/gopher.js',
      '/usr/local/go/misc/chrome/gophertool/gopher.png',
      '/usr/local/go/misc/chrome/gophertool/manifest.json',
      '/usr/local/go/misc/chrome/gophertool/popup.html',
      '/usr/local/go/misc/chrome/gophertool/popup.js',
      '/usr/local/go/misc/chrome/gophertool/README.txt',
      '/usr/local/go/misc/editors',
      '/usr/local/go/misc/git',
      '/usr/local/go/misc/git/pre-commit',
      '/usr/local/go/misc/ios',
      '/usr/local/go/misc/ios/clangwrap.sh',
      '/usr/local/go/misc/ios/detect.go',
      '/usr/local/go/misc/ios/go_darwin_arm_exec.go',
      '/usr/local/go/misc/ios/README',
      '/usr/local/go/misc/linkcheck',
      '/usr/local/go/misc/linkcheck/linkcheck.go',
      '/usr/local/go/misc/nacl',
      '/usr/local/go/misc/nacl/go_nacl_386_exec',
      '/usr/local/go/misc/nacl/go_nacl_amd64p32_exec',
      '/usr/local/go/misc/nacl/go_nacl_arm_exec',
      '/usr/local/go/misc/nacl/mkzip.go',
      '/usr/local/go/misc/nacl/README',
      '/usr/local/go/misc/nacl/testdata',
      '/usr/local/go/misc/nacl/testdata/bin',
      '/usr/local/go/misc/nacl/testdata/bin/placeholder',
      '/usr/local/go/misc/nacl/testdata/empty',
      '/usr/local/go/misc/nacl/testdata/group',
      '/usr/local/go/misc/nacl/testdata/hosts',
      '/usr/local/go/misc/nacl/testdata/mime.types',
      '/usr/local/go/misc/nacl/testzip.proto',
      '/usr/local/go/misc/sortac',
      '/usr/local/go/misc/sortac/sortac.go',
      '/usr/local/go/misc/swig',
      '/usr/local/go/misc/swig/callback',
      '/usr/local/go/misc/swig/callback/callback.cc',
      '/usr/local/go/misc/swig/callback/callback.go',
      '/usr/local/go/misc/swig/callback/callback.h',
      '/usr/local/go/misc/swig/callback/callback.swigcxx',
      '/usr/local/go/misc/swig/callback/callback_test.go',
      '/usr/local/go/misc/swig/stdio',
      '/usr/local/go/misc/swig/stdio/file.swig',
      '/usr/local/go/misc/swig/stdio/file_test.go',
      '/usr/local/go/misc/tour',
      '/usr/local/go/misc/tour/content',
      '/usr/local/go/misc/tour/content/basics',
      '/usr/local/go/misc/tour/content/basics/basic-types.go',
      '/usr/local/go/misc/tour/content/basics/constants.go',
      '/usr/local/go/misc/tour/content/basics/exported-names.go',
      '/usr/local/go/misc/tour/content/basics/functions-continued.go',
      '/usr/local/go/misc/tour/content/basics/functions.go',
      '/usr/local/go/misc/tour/content/basics/imports.go',
      '/usr/local/go/misc/tour/content/basics/multiple-results.go',
      '/usr/local/go/misc/tour/content/basics/named-results.go',
      '/usr/local/go/misc/tour/content/basics/numeric-constants.go',
      '/usr/local/go/misc/tour/content/basics/packages.go',
      '/usr/local/go/misc/tour/content/basics/short-variable-declarations.go',
      '/usr/local/go/misc/tour/content/basics/type-conversions.go',
      '/usr/local/go/misc/tour/content/basics/type-inference.go',
      '/usr/local/go/misc/tour/content/basics/variables.go',
      '/usr/local/go/misc/tour/content/basics/variables-with-initializers.go',
      '/usr/local/go/misc/tour/content/basics/zero.go',
      '/usr/local/go/misc/tour/content/basics.article',
      '/usr/local/go/misc/tour/content/concurrency',
      '/usr/local/go/misc/tour/content/concurrency/buffered-channels.go',
      '/usr/local/go/misc/tour/content/concurrency/channels.go',
      '/usr/local/go/misc/tour/content/concurrency/default-selection.go',
      '/usr/local/go/misc/tour/content/concurrency/exercise-equivalent-binary-trees.go',
      '/usr/local/go/misc/tour/content/concurrency/exercise-web-crawler.go',
      '/usr/local/go/misc/tour/content/concurrency/goroutines.go',
      '/usr/local/go/misc/tour/content/concurrency/mutex-counter.go',
      '/usr/local/go/misc/tour/content/concurrency/range-and-close.go',
      '/usr/local/go/misc/tour/content/concurrency/select.go',
      '/usr/local/go/misc/tour/content/concurrency.article',
      '/usr/local/go/misc/tour/content/content_test.go',
      '/usr/local/go/misc/tour/content/flowcontrol',
      '/usr/local/go/misc/tour/content/flowcontrol/defer.go',
      '/usr/local/go/misc/tour/content/flowcontrol/defer-multi.go',
      '/usr/local/go/misc/tour/content/flowcontrol/exercise-loops-and-functions.go',
      '/usr/local/go/misc/tour/content/flowcontrol/for-continued.go',
      '/usr/local/go/misc/tour/content/flowcontrol/forever.go',
      '/usr/local/go/misc/tour/content/flowcontrol/for.go',
      '/usr/local/go/misc/tour/content/flowcontrol/for-is-gos-while.go',
      '/usr/local/go/misc/tour/content/flowcontrol/if-and-else.go',
      '/usr/local/go/misc/tour/content/flowcontrol/if.go',
      '/usr/local/go/misc/tour/content/flowcontrol/if-with-a-short-statement.go',
      '/usr/local/go/misc/tour/content/flowcontrol/switch-evaluation-order.go',
      '/usr/local/go/misc/tour/content/flowcontrol/switch.go',
      '/usr/local/go/misc/tour/content/flowcontrol/switch-with-no-condition.go',
      '/usr/local/go/misc/tour/content/flowcontrol.article',
      '/usr/local/go/misc/tour/content/img',
      '/usr/local/go/misc/tour/content/img/tree.png',
      '/usr/local/go/misc/tour/content/methods',
      '/usr/local/go/misc/tour/content/methods/empty-interface.go',
      '/usr/local/go/misc/tour/content/methods/errors.go',
      '/usr/local/go/misc/tour/content/methods/exercise-errors.go',
      '/usr/local/go/misc/tour/content/methods/exercise-images.go',
      '/usr/local/go/misc/tour/content/methods/exercise-reader.go',
      '/usr/local/go/misc/tour/content/methods/exercise-rot-reader.go',
      '/usr/local/go/misc/tour/content/methods/exercise-stringer.go',
      '/usr/local/go/misc/tour/content/methods/images.go',
      '/usr/local/go/misc/tour/content/methods/indirection.go',
      '/usr/local/go/misc/tour/content/methods/indirection-values.go',
      '/usr/local/go/misc/tour/content/methods/interfaces-are-satisfied-implicitly.go',
      '/usr/local/go/misc/tour/content/methods/interfaces.go',
      '/usr/local/go/misc/tour/content/methods/interface-values.go',
      '/usr/local/go/misc/tour/content/methods/interface-values-with-nil.go',
      '/usr/local/go/misc/tour/content/methods/methods-continued.go',
      '/usr/local/go/misc/tour/content/methods/methods-funcs.go',
      '/usr/local/go/misc/tour/content/methods/methods.go',
      '/usr/local/go/misc/tour/content/methods/methods-pointers-explained.go',
      '/usr/local/go/misc/tour/content/methods/methods-pointers.go',
      '/usr/local/go/misc/tour/content/methods/methods-with-pointer-receivers.go',
      '/usr/local/go/misc/tour/content/methods/nil-interface-values.go',
      '/usr/local/go/misc/tour/content/methods/reader.go',
      '/usr/local/go/misc/tour/content/methods/stringer.go',
      '/usr/local/go/misc/tour/content/methods/type-assertions.go',
      '/usr/local/go/misc/tour/content/methods/type-switches.go',
      '/usr/local/go/misc/tour/content/methods.article',
      '/usr/local/go/misc/tour/content/moretypes',
      '/usr/local/go/misc/tour/content/moretypes/append.go',
      '/usr/local/go/misc/tour/content/moretypes/array.go',
      '/usr/local/go/misc/tour/content/moretypes/exercise-fibonacci-closure.go',
      '/usr/local/go/misc/tour/content/moretypes/exercise-maps.go',
      '/usr/local/go/misc/tour/content/moretypes/exercise-slices.go',
      '/usr/local/go/misc/tour/content/moretypes/function-closures.go',
      '/usr/local/go/misc/tour/content/moretypes/function-values.go',
      '/usr/local/go/misc/tour/content/moretypes/making-slices.go',
      '/usr/local/go/misc/tour/content/moretypes/map-literals-continued.go',
      '/usr/local/go/misc/tour/content/moretypes/map-literals.go',
      '/usr/local/go/misc/tour/content/moretypes/maps.go',
      '/usr/local/go/misc/tour/content/moretypes/mutating-maps.go',
      '/usr/local/go/misc/tour/content/moretypes/nil-slices.go',
      '/usr/local/go/misc/tour/content/moretypes/pointers.go',
      '/usr/local/go/misc/tour/content/moretypes/range-continued.go',
      '/usr/local/go/misc/tour/content/moretypes/range.go',
      '/usr/local/go/misc/tour/content/moretypes/slice-bounds.go',
      '/usr/local/go/misc/tour/content/moretypes/slice-len-cap.go',
      '/usr/local/go/misc/tour/content/moretypes/slice-literals.go',
      '/usr/local/go/misc/tour/content/moretypes/slices.go',
      '/usr/local/go/misc/tour/content/moretypes/slices-of-slice.go',
      '/usr/local/go/misc/tour/content/moretypes/slices-pointers.go',
      '/usr/local/go/misc/tour/content/moretypes/struct-fields.go',
      '/usr/local/go/misc/tour/content/moretypes/struct-literals.go',
      '/usr/local/go/misc/tour/content/moretypes/struct-pointers.go',
      '/usr/local/go/misc/tour/content/moretypes/structs.go',
      '/usr/local/go/misc/tour/content/moretypes.article',
      '/usr/local/go/misc/tour/content/welcome',
      '/usr/local/go/misc/tour/content/welcome/hello.go',
      '/usr/local/go/misc/tour/content/welcome/sandbox.go',
      '/usr/local/go/misc/tour/content/welcome.article',
      '/usr/local/go/misc/tour/solutions',
      '/usr/local/go/misc/tour/solutions/binarytrees.go',
      '/usr/local/go/misc/tour/solutions/binarytrees_quit.go',
      '/usr/local/go/misc/tour/solutions/errors.go',
      '/usr/local/go/misc/tour/solutions/fib.go',
      '/usr/local/go/misc/tour/solutions/http.go',
      '/usr/local/go/misc/tour/solutions/image.go',
      '/usr/local/go/misc/tour/solutions/loops.go',
      '/usr/local/go/misc/tour/solutions/maps.go',
      '/usr/local/go/misc/tour/solutions/readers.go',
      '/usr/local/go/misc/tour/solutions/README',
      '/usr/local/go/misc/tour/solutions/rot13.go',
      '/usr/local/go/misc/tour/solutions/slices.go',
      '/usr/local/go/misc/tour/solutions/stringers.go',
      '/usr/local/go/misc/tour/solutions/webcrawler.go',
      '/usr/local/go/misc/tour/src',
      '/usr/local/go/misc/tour/src/golang.org',
      '/usr/local/go/misc/tour/src/golang.org/x',
      '/usr/local/go/misc/tour/src/golang.org/x/tour',
      '/usr/local/go/misc/tour/src/golang.org/x/tour/pic',
      '/usr/local/go/misc/tour/src/golang.org/x/tour/pic/pic.go',
      '/usr/local/go/misc/tour/src/golang.org/x/tour/reader',
      '/usr/local/go/misc/tour/src/golang.org/x/tour/reader/validate.go',
      '/usr/local/go/misc/tour/src/golang.org/x/tour/tree',
      '/usr/local/go/misc/tour/src/golang.org/x/tour/tree/tree.go',
      '/usr/local/go/misc/tour/src/golang.org/x/tour/wc',
      '/usr/local/go/misc/tour/src/golang.org/x/tour/wc/wc.go',
      '/usr/local/go/misc/tour/static',
      '/usr/local/go/misc/tour/static/css',
      '/usr/local/go/misc/tour/static/css/app.css',
      '/usr/local/go/misc/tour/static/img',
      '/usr/local/go/misc/tour/static/img/favicon.ico',
      '/usr/local/go/misc/tour/static/img/gopher.png',
      '/usr/local/go/misc/tour/static/js',
      '/usr/local/go/misc/tour/static/js/app.js',
      '/usr/local/go/misc/tour/static/js/controllers.js',
      '/usr/local/go/misc/tour/static/js/directives.js',
      '/usr/local/go/misc/tour/static/js/services.js',
      '/usr/local/go/misc/tour/static/js/values.js',
      '/usr/local/go/misc/tour/static/lib',
      '/usr/local/go/misc/tour/static/lib/angular.min.js',
      '/usr/local/go/misc/tour/static/lib/angular-ui.min.js',
      '/usr/local/go/misc/tour/static/lib/codemirror',
      '/usr/local/go/misc/tour/static/lib/codemirror/AUTHORS',
      '/usr/local/go/misc/tour/static/lib/codemirror/lib',
      '/usr/local/go/misc/tour/static/lib/codemirror/lib/codemirror.css',
      '/usr/local/go/misc/tour/static/lib/codemirror/lib/codemirror.js',
      '/usr/local/go/misc/tour/static/lib/codemirror/LICENSE',
      '/usr/local/go/misc/tour/static/lib/codemirror/mode',
      '/usr/local/go/misc/tour/static/lib/codemirror/mode/go',
      '/usr/local/go/misc/tour/static/lib/codemirror/mode/go/go.js',
      '/usr/local/go/misc/tour/static/lib/codemirror/README.md',
      '/usr/local/go/misc/tour/static/lib/jquery.min.js',
      '/usr/local/go/misc/tour/static/lib/jquery-ui.min.js',
      '/usr/local/go/misc/tour/static/partials',
      '/usr/local/go/misc/tour/static/partials/editor.html',
      '/usr/local/go/misc/tour/static/partials/feedback-button.html',
      '/usr/local/go/misc/tour/static/partials/lesson.html',
      '/usr/local/go/misc/tour/static/partials/list.html',
      '/usr/local/go/misc/tour/static/partials/toc-button.html',
      '/usr/local/go/misc/tour/static/partials/toc.html',
      '/usr/local/go/misc/tour/template',
      '/usr/local/go/misc/tour/template/action.tmpl',
      '/usr/local/go/misc/tour/template/index.tmpl',
      '/usr/local/go/misc/trace',
      '/usr/local/go/misc/trace/README.md',
      '/usr/local/go/misc/trace/trace_viewer_lean.html',
      '/usr/local/go/PATENTS',
      '/usr/local/go/pkg',
      '/usr/local/go/pkg/include',
      '/usr/local/go/pkg/include/asm_ppc64x.h',
      '/usr/local/go/pkg/include/funcdata.h',
      '/usr/local/go/pkg/include/textflag.h',
      '/usr/local/go/pkg/linux_amd64',
      '/usr/local/go/pkg/linux_amd64/archive',
      '/usr/local/go/pkg/linux_amd64/archive/tar.a',
      '/usr/local/go/pkg/linux_amd64/archive/zip.a',
      '/usr/local/go/pkg/linux_amd64/bufio.a',
      '/usr/local/go/pkg/linux_amd64/bytes.a',
      '/usr/local/go/pkg/linux_amd64/cmd',
      '/usr/local/go/pkg/linux_amd64/cmd/asm',
      '/usr/local/go/pkg/linux_amd64/cmd/asm/internal',
      '/usr/local/go/pkg/linux_amd64/cmd/asm/internal/arch.a',
      '/usr/local/go/pkg/linux_amd64/cmd/asm/internal/asm.a',
      '/usr/local/go/pkg/linux_amd64/cmd/asm/internal/flags.a',
      '/usr/local/go/pkg/linux_amd64/cmd/asm/internal/lex.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/amd64.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/arm64.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/arm.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/gc.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/mips64.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/mips.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/ppc64.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/s390x.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/ssa.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/syntax.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/test.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/types.a',
      '/usr/local/go/pkg/linux_amd64/cmd/compile/internal/x86.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/base.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/bug.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/buildid.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/cfg.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/clean.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/cmdflag.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/doc.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/envcmd.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/fix.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/fmtcmd.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/generate.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/get.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/help.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/list.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/load.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/run.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/str.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/test.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/tool.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/version.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/vet.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/web.a',
      '/usr/local/go/pkg/linux_amd64/cmd/go/internal/work.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/bio.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/browser.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/dwarf.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/gcprog.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/goobj.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/obj',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/obj/arm64.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/obj/arm.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/obj/mips.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/obj/ppc64.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/obj/s390x.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/obj/x86.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/obj.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/objabi.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/objfile.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/src.a',
      '/usr/local/go/pkg/linux_amd64/cmd/internal/sys.a',
      '/usr/local/go/pkg/linux_amd64/cmd/link',
      '/usr/local/go/pkg/linux_amd64/cmd/link/internal',
      '/usr/local/go/pkg/linux_amd64/cmd/link/internal/amd64.a',
      '/usr/local/go/pkg/linux_amd64/cmd/link/internal/arm64.a',
      '/usr/local/go/pkg/linux_amd64/cmd/link/internal/arm.a',
      '/usr/local/go/pkg/linux_amd64/cmd/link/internal/ld.a',
      '/usr/local/go/pkg/linux_amd64/cmd/link/internal/mips64.a',
      '/usr/local/go/pkg/linux_amd64/cmd/link/internal/mips.a',
      '/usr/local/go/pkg/linux_amd64/cmd/link/internal/ppc64.a',
      '/usr/local/go/pkg/linux_amd64/cmd/link/internal/s390x.a',
      '/usr/local/go/pkg/linux_amd64/cmd/link/internal/x86.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/driver.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/internal',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/internal/binutils.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/internal/driver.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/internal/elfexec.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/internal/graph.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/internal/measurement.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/internal/plugin.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/internal/proftest.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/internal/report.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/internal/symbolizer.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/internal/symbolz.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/profile.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/third_party',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/google/pprof/third_party/svg.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/ianlancetaylor',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/github.com/ianlancetaylor/demangle.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/golang.org',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/golang.org/x',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/golang.org/x/arch',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/golang.org/x/arch/arm',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/golang.org/x/arch/arm/armasm.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/golang.org/x/arch/ppc64',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/golang.org/x/arch/x86',
      '/usr/local/go/pkg/linux_amd64/cmd/vendor/golang.org/x/arch/x86/x86asm.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vet',
      '/usr/local/go/pkg/linux_amd64/cmd/vet/internal',
      '/usr/local/go/pkg/linux_amd64/cmd/vet/internal/cfg.a',
      '/usr/local/go/pkg/linux_amd64/cmd/vet/internal/whitelist.a',
      '/usr/local/go/pkg/linux_amd64/compress',
      '/usr/local/go/pkg/linux_amd64/compress/bzip2.a',
      '/usr/local/go/pkg/linux_amd64/compress/flate.a',
      '/usr/local/go/pkg/linux_amd64/compress/gzip.a',
      '/usr/local/go/pkg/linux_amd64/compress/lzw.a',
      '/usr/local/go/pkg/linux_amd64/compress/zlib.a',
      '/usr/local/go/pkg/linux_amd64/container',
      '/usr/local/go/pkg/linux_amd64/container/heap.a',
      '/usr/local/go/pkg/linux_amd64/container/list.a',
      '/usr/local/go/pkg/linux_amd64/container/ring.a',
      '/usr/local/go/pkg/linux_amd64/context.a',
      '/usr/local/go/pkg/linux_amd64/crypto',
      '/usr/local/go/pkg/linux_amd64/crypto/aes.a',
      '/usr/local/go/pkg/linux_amd64/crypto/cipher.a',
      '/usr/local/go/pkg/linux_amd64/crypto/des.a',
      '/usr/local/go/pkg/linux_amd64/crypto/dsa.a',
      '/usr/local/go/pkg/linux_amd64/crypto/ecdsa.a',
      '/usr/local/go/pkg/linux_amd64/crypto/elliptic.a',
      '/usr/local/go/pkg/linux_amd64/crypto/hmac.a',
      '/usr/local/go/pkg/linux_amd64/crypto/internal',
      '/usr/local/go/pkg/linux_amd64/crypto/internal/cipherhw.a',
      '/usr/local/go/pkg/linux_amd64/crypto/md5.a',
      '/usr/local/go/pkg/linux_amd64/crypto/rand.a',
      '/usr/local/go/pkg/linux_amd64/crypto/rc4.a',
      '/usr/local/go/pkg/linux_amd64/crypto/rsa.a',
      '/usr/local/go/pkg/linux_amd64/crypto/sha1.a',
      '/usr/local/go/pkg/linux_amd64/crypto/sha256.a',
      '/usr/local/go/pkg/linux_amd64/crypto/sha512.a',
      '/usr/local/go/pkg/linux_amd64/crypto/subtle.a',
      '/usr/local/go/pkg/linux_amd64/crypto/tls.a',
      '/usr/local/go/pkg/linux_amd64/crypto/x509',
      '/usr/local/go/pkg/linux_amd64/crypto/x509/pkix.a',
      '/usr/local/go/pkg/linux_amd64/crypto/x509.a',
      '/usr/local/go/pkg/linux_amd64/crypto.a',
      '/usr/local/go/pkg/linux_amd64/database',
      '/usr/local/go/pkg/linux_amd64/database/sql',
      '/usr/local/go/pkg/linux_amd64/database/sql/driver.a',
      '/usr/local/go/pkg/linux_amd64/database/sql.a',
      '/usr/local/go/pkg/linux_amd64/debug',
      '/usr/local/go/pkg/linux_amd64/debug/dwarf.a',
      '/usr/local/go/pkg/linux_amd64/debug/elf.a',
      '/usr/local/go/pkg/linux_amd64/debug/gosym.a',
      '/usr/local/go/pkg/linux_amd64/debug/macho.a',
      '/usr/local/go/pkg/linux_amd64/debug/pe.a',
      '/usr/local/go/pkg/linux_amd64/debug/plan9obj.a',
      '/usr/local/go/pkg/linux_amd64/encoding',
      '/usr/local/go/pkg/linux_amd64/encoding/ascii85.a',
      '/usr/local/go/pkg/linux_amd64/encoding/asn1.a',
      '/usr/local/go/pkg/linux_amd64/encoding/base32.a',
      '/usr/local/go/pkg/linux_amd64/encoding/base64.a',
      '/usr/local/go/pkg/linux_amd64/encoding/binary.a',
      '/usr/local/go/pkg/linux_amd64/encoding/csv.a',
      '/usr/local/go/pkg/linux_amd64/encoding/gob.a',
      '/usr/local/go/pkg/linux_amd64/encoding/hex.a',
      '/usr/local/go/pkg/linux_amd64/encoding/json.a',
      '/usr/local/go/pkg/linux_amd64/encoding/pem.a',
      '/usr/local/go/pkg/linux_amd64/encoding/xml.a',
      '/usr/local/go/pkg/linux_amd64/encoding.a',
      '/usr/local/go/pkg/linux_amd64/errors.a',
      '/usr/local/go/pkg/linux_amd64/expvar.a',
      '/usr/local/go/pkg/linux_amd64/flag.a',
      '/usr/local/go/pkg/linux_amd64/fmt.a',
      '/usr/local/go/pkg/linux_amd64/go',
      '/usr/local/go/pkg/linux_amd64/go/ast.a',
      '/usr/local/go/pkg/linux_amd64/go/build.a',
      '/usr/local/go/pkg/linux_amd64/go/constant.a',
      '/usr/local/go/pkg/linux_amd64/go/doc.a',
      '/usr/local/go/pkg/linux_amd64/go/format.a',
      '/usr/local/go/pkg/linux_amd64/go/importer.a',
      '/usr/local/go/pkg/linux_amd64/go/internal',
      '/usr/local/go/pkg/linux_amd64/go/internal/gccgoimporter.a',
      '/usr/local/go/pkg/linux_amd64/go/internal/gcimporter.a',
      '/usr/local/go/pkg/linux_amd64/go/internal/srcimporter.a',
      '/usr/local/go/pkg/linux_amd64/go/parser.a',
      '/usr/local/go/pkg/linux_amd64/go/printer.a',
      '/usr/local/go/pkg/linux_amd64/go/scanner.a',
      '/usr/local/go/pkg/linux_amd64/go/token.a',
      '/usr/local/go/pkg/linux_amd64/go/types.a',
      '/usr/local/go/pkg/linux_amd64/hash',
      '/usr/local/go/pkg/linux_amd64/hash/adler32.a',
      '/usr/local/go/pkg/linux_amd64/hash/crc32.a',
      '/usr/local/go/pkg/linux_amd64/hash/crc64.a',
      '/usr/local/go/pkg/linux_amd64/hash/fnv.a',
      '/usr/local/go/pkg/linux_amd64/hash.a',
      '/usr/local/go/pkg/linux_amd64/html',
      '/usr/local/go/pkg/linux_amd64/html/template.a',
      '/usr/local/go/pkg/linux_amd64/html.a',
      '/usr/local/go/pkg/linux_amd64/image',
      '/usr/local/go/pkg/linux_amd64/image/color',
      '/usr/local/go/pkg/linux_amd64/image/color/palette.a',
      '/usr/local/go/pkg/linux_amd64/image/color.a',
      '/usr/local/go/pkg/linux_amd64/image/draw.a',
      '/usr/local/go/pkg/linux_amd64/image/gif.a',
      '/usr/local/go/pkg/linux_amd64/image/internal',
      '/usr/local/go/pkg/linux_amd64/image/internal/imageutil.a',
      '/usr/local/go/pkg/linux_amd64/image/jpeg.a',
      '/usr/local/go/pkg/linux_amd64/image/png.a',
      '/usr/local/go/pkg/linux_amd64/image.a',
      '/usr/local/go/pkg/linux_amd64/index',
      '/usr/local/go/pkg/linux_amd64/index/suffixarray.a',
      '/usr/local/go/pkg/linux_amd64/internal',
      '/usr/local/go/pkg/linux_amd64/internal/cpu.a',
      '/usr/local/go/pkg/linux_amd64/internal/nettrace.a',
      '/usr/local/go/pkg/linux_amd64/internal/poll.a',
      '/usr/local/go/pkg/linux_amd64/internal/race.a',
      '/usr/local/go/pkg/linux_amd64/internal/singleflight.a',
      '/usr/local/go/pkg/linux_amd64/internal/syscall',
      '/usr/local/go/pkg/linux_amd64/internal/syscall/unix.a',
      '/usr/local/go/pkg/linux_amd64/internal/syscall/windows',
      '/usr/local/go/pkg/linux_amd64/internal/syscall/windows/registry.a',
      '/usr/local/go/pkg/linux_amd64/internal/syscall/windows/sysdll.a',
      '/usr/local/go/pkg/linux_amd64/internal/syscall/windows.a',
      '/usr/local/go/pkg/linux_amd64/internal/testenv.a',
      '/usr/local/go/pkg/linux_amd64/internal/trace.a',
      '/usr/local/go/pkg/linux_amd64/io',
      '/usr/local/go/pkg/linux_amd64/io/ioutil.a',
      '/usr/local/go/pkg/linux_amd64/io.a',
      '/usr/local/go/pkg/linux_amd64/log',
      '/usr/local/go/pkg/linux_amd64/log/syslog.a',
      '/usr/local/go/pkg/linux_amd64/log.a',
      '/usr/local/go/pkg/linux_amd64/math',
      '/usr/local/go/pkg/linux_amd64/math/big.a',
      '/usr/local/go/pkg/linux_amd64/math/bits.a',
      '/usr/local/go/pkg/linux_amd64/math/cmplx.a',
      '/usr/local/go/pkg/linux_amd64/math/rand.a',
      '/usr/local/go/pkg/linux_amd64/math.a',
      '/usr/local/go/pkg/linux_amd64/mime',
      '/usr/local/go/pkg/linux_amd64/mime/multipart.a',
      '/usr/local/go/pkg/linux_amd64/mime/quotedprintable.a',
      '/usr/local/go/pkg/linux_amd64/mime.a',
      '/usr/local/go/pkg/linux_amd64/net',
      '/usr/local/go/pkg/linux_amd64/net/http',
      '/usr/local/go/pkg/linux_amd64/net/http/cgi.a',
      '/usr/local/go/pkg/linux_amd64/net/http/cookiejar.a',
      '/usr/local/go/pkg/linux_amd64/net/http/fcgi.a',
      '/usr/local/go/pkg/linux_amd64/net/http/httptest.a',
      '/usr/local/go/pkg/linux_amd64/net/http/httptrace.a',
      '/usr/local/go/pkg/linux_amd64/net/http/httputil.a',
      '/usr/local/go/pkg/linux_amd64/net/http/internal.a',
      '/usr/local/go/pkg/linux_amd64/net/http/pprof.a',
      '/usr/local/go/pkg/linux_amd64/net/http.a',
      '/usr/local/go/pkg/linux_amd64/net/internal',
      '/usr/local/go/pkg/linux_amd64/net/internal/socktest.a',
      '/usr/local/go/pkg/linux_amd64/net/mail.a',
      '/usr/local/go/pkg/linux_amd64/net/rpc',
      '/usr/local/go/pkg/linux_amd64/net/rpc/jsonrpc.a',
      '/usr/local/go/pkg/linux_amd64/net/rpc.a',
      '/usr/local/go/pkg/linux_amd64/net/smtp.a',
      '/usr/local/go/pkg/linux_amd64/net/textproto.a',
      '/usr/local/go/pkg/linux_amd64/net/url.a',
      '/usr/local/go/pkg/linux_amd64/net.a',
      '/usr/local/go/pkg/linux_amd64/os',
      '/usr/local/go/pkg/linux_amd64/os/exec.a',
      '/usr/local/go/pkg/linux_amd64/os/signal.a',
      '/usr/local/go/pkg/linux_amd64/os/user.a',
      '/usr/local/go/pkg/linux_amd64/os.a',
      '/usr/local/go/pkg/linux_amd64/path',
      '/usr/local/go/pkg/linux_amd64/path/filepath.a',
      '/usr/local/go/pkg/linux_amd64/path.a',
      '/usr/local/go/pkg/linux_amd64/plugin.a',
      '/usr/local/go/pkg/linux_amd64/reflect.a',
      '/usr/local/go/pkg/linux_amd64/regexp',
      '/usr/local/go/pkg/linux_amd64/regexp/syntax.a',
      '/usr/local/go/pkg/linux_amd64/regexp.a',
      '/usr/local/go/pkg/linux_amd64/runtime',
      '/usr/local/go/pkg/linux_amd64/runtime/cgo.a',
      '/usr/local/go/pkg/linux_amd64/runtime/debug.a',
      '/usr/local/go/pkg/linux_amd64/runtime/internal',
      '/usr/local/go/pkg/linux_amd64/runtime/internal/atomic.a',
      '/usr/local/go/pkg/linux_amd64/runtime/internal/sys.a',
      '/usr/local/go/pkg/linux_amd64/runtime/pprof',
      '/usr/local/go/pkg/linux_amd64/runtime/pprof/internal',
      '/usr/local/go/pkg/linux_amd64/runtime/pprof/internal/profile.a',
      '/usr/local/go/pkg/linux_amd64/runtime/pprof.a',
      '/usr/local/go/pkg/linux_amd64/runtime/race.a',
      '/usr/local/go/pkg/linux_amd64/runtime/trace.a',
      '/usr/local/go/pkg/linux_amd64/runtime.a',
      '/usr/local/go/pkg/linux_amd64/sort.a',
      '/usr/local/go/pkg/linux_amd64/strconv.a',
      '/usr/local/go/pkg/linux_amd64/strings.a',
      '/usr/local/go/pkg/linux_amd64/sync',
      '/usr/local/go/pkg/linux_amd64/sync/atomic.a',
      '/usr/local/go/pkg/linux_amd64/sync.a',
      '/usr/local/go/pkg/linux_amd64/syscall.a',
      '/usr/local/go/pkg/linux_amd64/testing',
      '/usr/local/go/pkg/linux_amd64/testing/internal',
      '/usr/local/go/pkg/linux_amd64/testing/internal/testdeps.a',
      '/usr/local/go/pkg/linux_amd64/testing/iotest.a',
      '/usr/local/go/pkg/linux_amd64/testing/quick.a',
      '/usr/local/go/pkg/linux_amd64/testing.a',
      '/usr/local/go/pkg/linux_amd64/text',
      '/usr/local/go/pkg/linux_amd64/text/scanner.a',
      '/usr/local/go/pkg/linux_amd64/text/tabwriter.a',
      '/usr/local/go/pkg/linux_amd64/text/template',
      '/usr/local/go/pkg/linux_amd64/text/template/parse.a',
      '/usr/local/go/pkg/linux_amd64/text/template.a',
      '/usr/local/go/pkg/linux_amd64/time.a',
      '/usr/local/go/pkg/linux_amd64/unicode',
      '/usr/local/go/pkg/linux_amd64/unicode/utf16.a',
      '/usr/local/go/pkg/linux_amd64/unicode/utf8.a',
      '/usr/local/go/pkg/linux_amd64/unicode.a',
      '/usr/local/go/pkg/linux_amd64/vendor',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/crypto',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/crypto/chacha20poly1305',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/crypto/chacha20poly1305/internal',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/crypto/chacha20poly1305/internal/chacha20.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/crypto/chacha20poly1305.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/crypto/curve25519.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/crypto/poly1305.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/net',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/net/http2',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/net/http2/hpack.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/net/idna.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/net/lex',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/net/lex/httplex.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/net/nettest.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/net/proxy.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/text',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/text/secure',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/text/secure/bidirule.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/text/secure.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/text/transform.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/text/unicode',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/text/unicode/bidi.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/text/unicode/norm.a',
      '/usr/local/go/pkg/linux_amd64/vendor/golang_org/x/text/unicode.a',
      '/usr/local/go/pkg/linux_amd64_race',
      '/usr/local/go/pkg/linux_amd64_race/archive',
      '/usr/local/go/pkg/linux_amd64_race/archive/tar.a',
      '/usr/local/go/pkg/linux_amd64_race/archive/zip.a',
      '/usr/local/go/pkg/linux_amd64_race/bufio.a',
      '/usr/local/go/pkg/linux_amd64_race/bytes.a',
      '/usr/local/go/pkg/linux_amd64_race/compress',
      '/usr/local/go/pkg/linux_amd64_race/compress/bzip2.a',
      '/usr/local/go/pkg/linux_amd64_race/compress/flate.a',
      '/usr/local/go/pkg/linux_amd64_race/compress/gzip.a',
      '/usr/local/go/pkg/linux_amd64_race/compress/lzw.a',
      '/usr/local/go/pkg/linux_amd64_race/compress/zlib.a',
      '/usr/local/go/pkg/linux_amd64_race/container',
      '/usr/local/go/pkg/linux_amd64_race/container/heap.a',
      '/usr/local/go/pkg/linux_amd64_race/container/list.a',
      '/usr/local/go/pkg/linux_amd64_race/container/ring.a',
      '/usr/local/go/pkg/linux_amd64_race/context.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto',
      '/usr/local/go/pkg/linux_amd64_race/crypto/aes.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/cipher.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/des.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/dsa.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/ecdsa.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/elliptic.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/hmac.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/internal',
      '/usr/local/go/pkg/linux_amd64_race/crypto/internal/cipherhw.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/md5.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/rand.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/rc4.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/rsa.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/sha1.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/sha256.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/sha512.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/subtle.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/tls.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/x509',
      '/usr/local/go/pkg/linux_amd64_race/crypto/x509/pkix.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto/x509.a',
      '/usr/local/go/pkg/linux_amd64_race/crypto.a',
      '/usr/local/go/pkg/linux_amd64_race/database',
      '/usr/local/go/pkg/linux_amd64_race/database/sql',
      '/usr/local/go/pkg/linux_amd64_race/database/sql/driver.a',
      '/usr/local/go/pkg/linux_amd64_race/database/sql.a',
      '/usr/local/go/pkg/linux_amd64_race/debug',
      '/usr/local/go/pkg/linux_amd64_race/debug/dwarf.a',
      '/usr/local/go/pkg/linux_amd64_race/debug/elf.a',
      '/usr/local/go/pkg/linux_amd64_race/debug/gosym.a',
      '/usr/local/go/pkg/linux_amd64_race/debug/macho.a',
      '/usr/local/go/pkg/linux_amd64_race/debug/pe.a',
      '/usr/local/go/pkg/linux_amd64_race/debug/plan9obj.a',
      '/usr/local/go/pkg/linux_amd64_race/encoding',
      '/usr/local/go/pkg/linux_amd64_race/encoding/ascii85.a',
      '/usr/local/go/pkg/linux_amd64_race/encoding/asn1.a',
      '/usr/local/go/pkg/linux_amd64_race/encoding/base32.a',
      '/usr/local/go/pkg/linux_amd64_race/encoding/base64.a',
      '/usr/local/go/pkg/linux_amd64_race/encoding/binary.a',
      '/usr/local/go/pkg/linux_amd64_race/encoding/csv.a',
      '/usr/local/go/pkg/linux_amd64_race/encoding/gob.a',
      '/usr/local/go/pkg/linux_amd64_race/encoding/hex.a',
      '/usr/local/go/pkg/linux_amd64_race/encoding/json.a',
      '/usr/local/go/pkg/linux_amd64_race/encoding/pem.a',
      '/usr/local/go/pkg/linux_amd64_race/encoding/xml.a',
      '/usr/local/go/pkg/linux_amd64_race/encoding.a',
      '/usr/local/go/pkg/linux_amd64_race/errors.a',
      '/usr/local/go/pkg/linux_amd64_race/expvar.a',
      '/usr/local/go/pkg/linux_amd64_race/flag.a',
      '/usr/local/go/pkg/linux_amd64_race/fmt.a',
      '/usr/local/go/pkg/linux_amd64_race/go',
      '/usr/local/go/pkg/linux_amd64_race/go/ast.a',
      '/usr/local/go/pkg/linux_amd64_race/go/build.a',
      '/usr/local/go/pkg/linux_amd64_race/go/constant.a',
      '/usr/local/go/pkg/linux_amd64_race/go/doc.a',
      '/usr/local/go/pkg/linux_amd64_race/go/format.a',
      '/usr/local/go/pkg/linux_amd64_race/go/importer.a',
      '/usr/local/go/pkg/linux_amd64_race/go/internal',
      '/usr/local/go/pkg/linux_amd64_race/go/internal/gccgoimporter.a',
      '/usr/local/go/pkg/linux_amd64_race/go/internal/gcimporter.a',
      '/usr/local/go/pkg/linux_amd64_race/go/internal/srcimporter.a',
      '/usr/local/go/pkg/linux_amd64_race/go/parser.a',
      '/usr/local/go/pkg/linux_amd64_race/go/printer.a',
      '/usr/local/go/pkg/linux_amd64_race/go/scanner.a',
      '/usr/local/go/pkg/linux_amd64_race/go/token.a',
      '/usr/local/go/pkg/linux_amd64_race/go/types.a',
      '/usr/local/go/pkg/linux_amd64_race/hash',
      '/usr/local/go/pkg/linux_amd64_race/hash/adler32.a',
      '/usr/local/go/pkg/linux_amd64_race/hash/crc32.a',
      '/usr/local/go/pkg/linux_amd64_race/hash/crc64.a',
      '/usr/local/go/pkg/linux_amd64_race/hash/fnv.a',
      '/usr/local/go/pkg/linux_amd64_race/hash.a',
      '/usr/local/go/pkg/linux_amd64_race/html',
      '/usr/local/go/pkg/linux_amd64_race/html/template.a',
      '/usr/local/go/pkg/linux_amd64_race/html.a',
      '/usr/local/go/pkg/linux_amd64_race/image',
      '/usr/local/go/pkg/linux_amd64_race/image/color',
      '/usr/local/go/pkg/linux_amd64_race/image/color/palette.a',
      '/usr/local/go/pkg/linux_amd64_race/image/color.a',
      '/usr/local/go/pkg/linux_amd64_race/image/draw.a',
      '/usr/local/go/pkg/linux_amd64_race/image/gif.a',
      '/usr/local/go/pkg/linux_amd64_race/image/internal',
      '/usr/local/go/pkg/linux_amd64_race/image/internal/imageutil.a',
      '/usr/local/go/pkg/linux_amd64_race/image/jpeg.a',
      '/usr/local/go/pkg/linux_amd64_race/image/png.a',
      '/usr/local/go/pkg/linux_amd64_race/image.a',
      '/usr/local/go/pkg/linux_amd64_race/index',
      '/usr/local/go/pkg/linux_amd64_race/index/suffixarray.a',
      '/usr/local/go/pkg/linux_amd64_race/internal',
      '/usr/local/go/pkg/linux_amd64_race/internal/cpu.a',
      '/usr/local/go/pkg/linux_amd64_race/internal/nettrace.a',
      '/usr/local/go/pkg/linux_amd64_race/internal/poll.a',
      '/usr/local/go/pkg/linux_amd64_race/internal/race.a',
      '/usr/local/go/pkg/linux_amd64_race/internal/singleflight.a',
      '/usr/local/go/pkg/linux_amd64_race/internal/syscall',
      '/usr/local/go/pkg/linux_amd64_race/internal/syscall/unix.a',
      '/usr/local/go/pkg/linux_amd64_race/internal/syscall/windows',
      '/usr/local/go/pkg/linux_amd64_race/internal/syscall/windows/registry.a',
      '/usr/local/go/pkg/linux_amd64_race/internal/syscall/windows/sysdll.a',
      '/usr/local/go/pkg/linux_amd64_race/internal/syscall/windows.a',
      '/usr/local/go/pkg/linux_amd64_race/internal/testenv.a',
      '/usr/local/go/pkg/linux_amd64_race/internal/trace.a',
      '/usr/local/go/pkg/linux_amd64_race/io',
      '/usr/local/go/pkg/linux_amd64_race/io/ioutil.a',
      '/usr/local/go/pkg/linux_amd64_race/io.a',
      '/usr/local/go/pkg/linux_amd64_race/log',
      '/usr/local/go/pkg/linux_amd64_race/log/syslog.a',
      '/usr/local/go/pkg/linux_amd64_race/log.a',
      '/usr/local/go/pkg/linux_amd64_race/math',
      '/usr/local/go/pkg/linux_amd64_race/math/big.a',
      '/usr/local/go/pkg/linux_amd64_race/math/bits.a',
      '/usr/local/go/pkg/linux_amd64_race/math/cmplx.a',
      '/usr/local/go/pkg/linux_amd64_race/math/rand.a',
      '/usr/local/go/pkg/linux_amd64_race/math.a',
      '/usr/local/go/pkg/linux_amd64_race/mime',
      '/usr/local/go/pkg/linux_amd64_race/mime/multipart.a',
      '/usr/local/go/pkg/linux_amd64_race/mime/quotedprintable.a',
      '/usr/local/go/pkg/linux_amd64_race/mime.a',
      '/usr/local/go/pkg/linux_amd64_race/net',
      '/usr/local/go/pkg/linux_amd64_race/net/http',
      '/usr/local/go/pkg/linux_amd64_race/net/http/cgi.a',
      '/usr/local/go/pkg/linux_amd64_race/net/http/cookiejar.a',
      '/usr/local/go/pkg/linux_amd64_race/net/http/fcgi.a',
      '/usr/local/go/pkg/linux_amd64_race/net/http/httptest.a',
      '/usr/local/go/pkg/linux_amd64_race/net/http/httptrace.a',
      '/usr/local/go/pkg/linux_amd64_race/net/http/httputil.a',
      '/usr/local/go/pkg/linux_amd64_race/net/http/internal.a',
      '/usr/local/go/pkg/linux_amd64_race/net/http/pprof.a',
      '/usr/local/go/pkg/linux_amd64_race/net/http.a',
      '/usr/local/go/pkg/linux_amd64_race/net/internal',
      '/usr/local/go/pkg/linux_amd64_race/net/internal/socktest.a',
      '/usr/local/go/pkg/linux_amd64_race/net/mail.a',
      '/usr/local/go/pkg/linux_amd64_race/net/rpc',
      '/usr/local/go/pkg/linux_amd64_race/net/rpc/jsonrpc.a',
      '/usr/local/go/pkg/linux_amd64_race/net/rpc.a',
      '/usr/local/go/pkg/linux_amd64_race/net/smtp.a',
      '/usr/local/go/pkg/linux_amd64_race/net/textproto.a',
      '/usr/local/go/pkg/linux_amd64_race/net/url.a',
      '/usr/local/go/pkg/linux_amd64_race/net.a',
      '/usr/local/go/pkg/linux_amd64_race/os',
      '/usr/local/go/pkg/linux_amd64_race/os/exec.a',
      '/usr/local/go/pkg/linux_amd64_race/os/signal.a',
      '/usr/local/go/pkg/linux_amd64_race/os/user.a',
      '/usr/local/go/pkg/linux_amd64_race/os.a',
      '/usr/local/go/pkg/linux_amd64_race/path',
      '/usr/local/go/pkg/linux_amd64_race/path/filepath.a',
      '/usr/local/go/pkg/linux_amd64_race/path.a',
      '/usr/local/go/pkg/linux_amd64_race/plugin.a',
      '/usr/local/go/pkg/linux_amd64_race/reflect.a',
      '/usr/local/go/pkg/linux_amd64_race/regexp',
      '/usr/local/go/pkg/linux_amd64_race/regexp/syntax.a',
      '/usr/local/go/pkg/linux_amd64_race/regexp.a',
      '/usr/local/go/pkg/linux_amd64_race/runtime',
      '/usr/local/go/pkg/linux_amd64_race/runtime/cgo.a',
      '/usr/local/go/pkg/linux_amd64_race/runtime/debug.a',
      '/usr/local/go/pkg/linux_amd64_race/runtime/internal',
      '/usr/local/go/pkg/linux_amd64_race/runtime/internal/atomic.a',
      '/usr/local/go/pkg/linux_amd64_race/runtime/internal/sys.a',
      '/usr/local/go/pkg/linux_amd64_race/runtime/pprof',
      '/usr/local/go/pkg/linux_amd64_race/runtime/pprof/internal',
      '/usr/local/go/pkg/linux_amd64_race/runtime/pprof/internal/profile.a',
      '/usr/local/go/pkg/linux_amd64_race/runtime/pprof.a',
      '/usr/local/go/pkg/linux_amd64_race/runtime/race.a',
      '/usr/local/go/pkg/linux_amd64_race/runtime/trace.a',
      '/usr/local/go/pkg/linux_amd64_race/runtime.a',
      '/usr/local/go/pkg/linux_amd64_race/sort.a',
      '/usr/local/go/pkg/linux_amd64_race/strconv.a',
      '/usr/local/go/pkg/linux_amd64_race/strings.a',
      '/usr/local/go/pkg/linux_amd64_race/sync',
      '/usr/local/go/pkg/linux_amd64_race/sync/atomic.a',
      '/usr/local/go/pkg/linux_amd64_race/sync.a',
      '/usr/local/go/pkg/linux_amd64_race/syscall.a',
      '/usr/local/go/pkg/linux_amd64_race/testing',
      '/usr/local/go/pkg/linux_amd64_race/testing/internal',
      '/usr/local/go/pkg/linux_amd64_race/testing/internal/testdeps.a',
      '/usr/local/go/pkg/linux_amd64_race/testing/iotest.a',
      '/usr/local/go/pkg/linux_amd64_race/testing/quick.a',
      '/usr/local/go/pkg/linux_amd64_race/testing.a',
      '/usr/local/go/pkg/linux_amd64_race/text',
      '/usr/local/go/pkg/linux_amd64_race/text/scanner.a',
      '/usr/local/go/pkg/linux_amd64_race/text/tabwriter.a',
      '/usr/local/go/pkg/linux_amd64_race/text/template',
      '/usr/local/go/pkg/linux_amd64_race/text/template/parse.a',
      '/usr/local/go/pkg/linux_amd64_race/text/template.a',
      '/usr/local/go/pkg/linux_amd64_race/time.a',
      '/usr/local/go/pkg/linux_amd64_race/unicode',
      '/usr/local/go/pkg/linux_amd64_race/unicode/utf16.a',
      '/usr/local/go/pkg/linux_amd64_race/unicode/utf8.a',
      '/usr/local/go/pkg/linux_amd64_race/unicode.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/crypto',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/crypto/chacha20poly1305',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/crypto/chacha20poly1305/internal',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/crypto/chacha20poly1305/internal/chacha20.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/crypto/chacha20poly1305.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/crypto/curve25519.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/crypto/poly1305.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/net',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/net/http2',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/net/http2/hpack.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/net/idna.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/net/lex',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/net/lex/httplex.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/net/nettest.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/net/proxy.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/text',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/text/secure',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/text/secure/bidirule.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/text/secure.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/text/transform.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/text/unicode',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/text/unicode/bidi.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/text/unicode/norm.a',
      '/usr/local/go/pkg/linux_amd64_race/vendor/golang_org/x/text/unicode.a',
      '/usr/local/go/pkg/linux_amd64_shared',
      '/usr/local/go/pkg/linux_amd64_shared/errors.a',
      '/usr/local/go/pkg/linux_amd64_shared/fmt.a',
      '/usr/local/go/pkg/linux_amd64_shared/internal',
      '/usr/local/go/pkg/linux_amd64_shared/internal/cpu.a',
      '/usr/local/go/pkg/linux_amd64_shared/internal/poll.a',
      '/usr/local/go/pkg/linux_amd64_shared/internal/race.a',
      '/usr/local/go/pkg/linux_amd64_shared/io.a',
      '/usr/local/go/pkg/linux_amd64_shared/math.a',
      '/usr/local/go/pkg/linux_amd64_shared/os.a',
      '/usr/local/go/pkg/linux_amd64_shared/reflect.a',
      '/usr/local/go/pkg/linux_amd64_shared/runtime',
      '/usr/local/go/pkg/linux_amd64_shared/runtime/cgo.a',
      '/usr/local/go/pkg/linux_amd64_shared/runtime/internal',
      '/usr/local/go/pkg/linux_amd64_shared/runtime/internal/atomic.a',
      '/usr/local/go/pkg/linux_amd64_shared/runtime/internal/sys.a',
      '/usr/local/go/pkg/linux_amd64_shared/runtime.a',
      '/usr/local/go/pkg/linux_amd64_shared/strconv.a',
      '/usr/local/go/pkg/linux_amd64_shared/sync',
      '/usr/local/go/pkg/linux_amd64_shared/sync/atomic.a',
      '/usr/local/go/pkg/linux_amd64_shared/sync.a',
      '/usr/local/go/pkg/linux_amd64_shared/syscall.a',
      '/usr/local/go/pkg/linux_amd64_shared/time.a',
      '/usr/local/go/pkg/linux_amd64_shared/unicode',
      '/usr/local/go/pkg/linux_amd64_shared/unicode/utf8.a',
      '/usr/local/go/pkg/linux_amd64_shared/unicode.a',
      '/usr/local/go/pkg/obj',
      '/usr/local/go/pkg/obj/linux_amd64',
      '/usr/local/go/pkg/tool',
      '/usr/local/go/pkg/tool/linux_amd64',
      '/usr/local/go/pkg/tool/linux_amd64/addr2line',
      '/usr/local/go/pkg/tool/linux_amd64/asm',
      '/usr/local/go/pkg/tool/linux_amd64/cgo',
      '/usr/local/go/pkg/tool/linux_amd64/compile',
      '/usr/local/go/pkg/tool/linux_amd64/cover',
      '/usr/local/go/pkg/tool/linux_amd64/dist',
      '/usr/local/go/pkg/tool/linux_amd64/doc',
      '/usr/local/go/pkg/tool/linux_amd64/fix',
      '/usr/local/go/pkg/tool/linux_amd64/link',
      '/usr/local/go/pkg/tool/linux_amd64/nm',
      '/usr/local/go/pkg/tool/linux_amd64/objdump',
      '/usr/local/go/pkg/tool/linux_amd64/pack',
      '/usr/local/go/pkg/tool/linux_amd64/pprof',
      '/usr/local/go/pkg/tool/linux_amd64/tour',
      '/usr/local/go/pkg/tool/linux_amd64/trace',
      '/usr/local/go/pkg/tool/linux_amd64/vet',
      '/usr/local/go/README.md',
      '/usr/local/go/robots.txt',
      '/usr/local/go/src',
      '/usr/local/go/src/all.bash',
      '/usr/local/go/src/all.bat',
      '/usr/local/go/src/all.rc',
      '/usr/local/go/src/androidtest.bash',
      '/usr/local/go/src/archive',
      '/usr/local/go/src/archive/tar',
      '/usr/local/go/src/archive/tar/common.go',
      '/usr/local/go/src/archive/tar/example_test.go',
      '/usr/local/go/src/archive/tar/format.go',
      '/usr/local/go/src/archive/tar/reader.go',
      '/usr/local/go/src/archive/tar/reader_test.go',
      '/usr/local/go/src/archive/tar/stat_atimespec.go',
      '/usr/local/go/src/archive/tar/stat_atim.go',
      '/usr/local/go/src/archive/tar/stat_unix.go',
      '/usr/local/go/src/archive/tar/strconv.go',
      '/usr/local/go/src/archive/tar/strconv_test.go',
      '/usr/local/go/src/archive/tar/tar_test.go',
      '/usr/local/go/src/archive/tar/testdata',
      '/usr/local/go/src/archive/tar/testdata/gnu-incremental.tar',
      '/usr/local/go/src/archive/tar/testdata/gnu-multi-hdrs.tar',
      '/usr/local/go/src/archive/tar/testdata/gnu.tar',
      '/usr/local/go/src/archive/tar/testdata/hardlink.tar',
      '/usr/local/go/src/archive/tar/testdata/hdr-only.tar',
      '/usr/local/go/src/archive/tar/testdata/issue10968.tar',
      '/usr/local/go/src/archive/tar/testdata/issue11169.tar',
      '/usr/local/go/src/archive/tar/testdata/issue12435.tar',
      '/usr/local/go/src/archive/tar/testdata/neg-size.tar',
      '/usr/local/go/src/archive/tar/testdata/nil-uid.tar',
      '/usr/local/go/src/archive/tar/testdata/pax-bad-hdr-file.tar',
      '/usr/local/go/src/archive/tar/testdata/pax-bad-mtime-file.tar',
      '/usr/local/go/src/archive/tar/testdata/pax-multi-hdrs.tar',
      '/usr/local/go/src/archive/tar/testdata/pax-path-hdr.tar',
      '/usr/local/go/src/archive/tar/testdata/pax-pos-size-file.tar',
      '/usr/local/go/src/archive/tar/testdata/pax.tar',
      '/usr/local/go/src/archive/tar/testdata/small2.txt',
      '/usr/local/go/src/archive/tar/testdata/small.txt',
      '/usr/local/go/src/archive/tar/testdata/sparse-formats.tar',
      '/usr/local/go/src/archive/tar/testdata/star.tar',
      '/usr/local/go/src/archive/tar/testdata/ustar-file-reg.tar',
      '/usr/local/go/src/archive/tar/testdata/ustar.issue12594.tar',
      '/usr/local/go/src/archive/tar/testdata/ustar.tar',
      '/usr/local/go/src/archive/tar/testdata/v7.tar',
      '/usr/local/go/src/archive/tar/testdata/writer-big-long.tar',
      '/usr/local/go/src/archive/tar/testdata/writer-big.tar',
      '/usr/local/go/src/archive/tar/testdata/writer.tar',
      '/usr/local/go/src/archive/tar/testdata/xattrs.tar',
      '/usr/local/go/src/archive/tar/writer.go',
      '/usr/local/go/src/archive/tar/writer_test.go',
      '/usr/local/go/src/archive/zip',
      '/usr/local/go/src/archive/zip/example_test.go',
      '/usr/local/go/src/archive/zip/reader.go',
      '/usr/local/go/src/archive/zip/reader_test.go',
      '/usr/local/go/src/archive/zip/register.go',
      '/usr/local/go/src/archive/zip/struct.go',
      '/usr/local/go/src/archive/zip/testdata',
      '/usr/local/go/src/archive/zip/testdata/crc32-not-streamed.zip',
      '/usr/local/go/src/archive/zip/testdata/dd.zip',
      '/usr/local/go/src/archive/zip/testdata/go-no-datadesc-sig.zip',
      '/usr/local/go/src/archive/zip/testdata/gophercolor16x16.png',
      '/usr/local/go/src/archive/zip/testdata/go-with-datadesc-sig.zip',
      '/usr/local/go/src/archive/zip/testdata/readme.notzip',
      '/usr/local/go/src/archive/zip/testdata/readme.zip',
      '/usr/local/go/src/archive/zip/testdata/symlink.zip',
      '/usr/local/go/src/archive/zip/testdata/test-trailing-junk.zip',
      '/usr/local/go/src/archive/zip/testdata/test.zip',
      '/usr/local/go/src/archive/zip/testdata/unix.zip',
      '/usr/local/go/src/archive/zip/testdata/winxp.zip',
      '/usr/local/go/src/archive/zip/testdata/zip64-2.zip',
      '/usr/local/go/src/archive/zip/testdata/zip64.zip',
      '/usr/local/go/src/archive/zip/writer.go',
      '/usr/local/go/src/archive/zip/writer_test.go',
      '/usr/local/go/src/archive/zip/zip_test.go',
      '/usr/local/go/src/bootstrap.bash',
      '/usr/local/go/src/bufio',
      '/usr/local/go/src/bufio/bufio.go',
      '/usr/local/go/src/bufio/bufio_test.go',
      '/usr/local/go/src/bufio/example_test.go',
      '/usr/local/go/src/bufio/export_test.go',
      '/usr/local/go/src/bufio/scan.go',
      '/usr/local/go/src/bufio/scan_test.go',
      '/usr/local/go/src/buildall.bash',
      '/usr/local/go/src/builtin',
      '/usr/local/go/src/builtin/builtin.go',
      '/usr/local/go/src/bytes',
      '/usr/local/go/src/bytes/buffer.go',
      '/usr/local/go/src/bytes/buffer_test.go',
      '/usr/local/go/src/bytes/bytes_amd64.go',
      '/usr/local/go/src/bytes/bytes_decl.go',
      '/usr/local/go/src/bytes/bytes_generic.go',
      '/usr/local/go/src/bytes/bytes.go',
      '/usr/local/go/src/bytes/bytes_s390x.go',
      '/usr/local/go/src/bytes/bytes_test.go',
      '/usr/local/go/src/bytes/compare_test.go',
      '/usr/local/go/src/bytes/equal_test.go',
      '/usr/local/go/src/bytes/example_test.go',
      '/usr/local/go/src/bytes/export_test.go',
      '/usr/local/go/src/bytes/reader.go',
      '/usr/local/go/src/bytes/reader_test.go',
      '/usr/local/go/src/clean.bash',
      '/usr/local/go/src/clean.bat',
      '/usr/local/go/src/clean.rc',
      '/usr/local/go/src/cmd',
      '/usr/local/go/src/cmd/addr2line',
      '/usr/local/go/src/cmd/addr2line/addr2line_test.go',
      '/usr/local/go/src/cmd/addr2line/main.go',
      '/usr/local/go/src/cmd/api',
      '/usr/local/go/src/cmd/api/goapi.go',
      '/usr/local/go/src/cmd/api/goapi_test.go',
      '/usr/local/go/src/cmd/api/run.go',
      '/usr/local/go/src/cmd/api/testdata',
      '/usr/local/go/src/cmd/api/testdata/src',
      '/usr/local/go/src/cmd/api/testdata/src/pkg',
      '/usr/local/go/src/cmd/api/testdata/src/pkg/p1',
      '/usr/local/go/src/cmd/api/testdata/src/pkg/p1/golden.txt',
      '/usr/local/go/src/cmd/api/testdata/src/pkg/p1/p1.go',
      '/usr/local/go/src/cmd/api/testdata/src/pkg/p2',
      '/usr/local/go/src/cmd/api/testdata/src/pkg/p2/golden.txt',
      '/usr/local/go/src/cmd/api/testdata/src/pkg/p2/p2.go',
      '/usr/local/go/src/cmd/api/testdata/src/pkg/p3',
      '/usr/local/go/src/cmd/api/testdata/src/pkg/p3/golden.txt',
      '/usr/local/go/src/cmd/api/testdata/src/pkg/p3/p3.go',
      '/usr/local/go/src/cmd/asm',
      '/usr/local/go/src/cmd/asm/doc.go',
      '/usr/local/go/src/cmd/asm/internal',
      '/usr/local/go/src/cmd/asm/internal/arch',
      '/usr/local/go/src/cmd/asm/internal/arch/amd64.go',
      '/usr/local/go/src/cmd/asm/internal/arch/arch.go',
      '/usr/local/go/src/cmd/asm/internal/arch/arm64.go',
      '/usr/local/go/src/cmd/asm/internal/arch/arm.go',
      '/usr/local/go/src/cmd/asm/internal/arch/mips.go',
      '/usr/local/go/src/cmd/asm/internal/arch/ppc64.go',
      '/usr/local/go/src/cmd/asm/internal/arch/s390x.go',
      '/usr/local/go/src/cmd/asm/internal/asm',
      '/usr/local/go/src/cmd/asm/internal/asm/asm.go',
      '/usr/local/go/src/cmd/asm/internal/asm/endtoend_test.go',
      '/usr/local/go/src/cmd/asm/internal/asm/expr_test.go',
      '/usr/local/go/src/cmd/asm/internal/asm/operand_test.go',
      '/usr/local/go/src/cmd/asm/internal/asm/parse.go',
      '/usr/local/go/src/cmd/asm/internal/asm/pseudo_test.go',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/386.s',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/amd64enc.s',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/amd64error.s',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/amd64.s',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/arm64enc.s',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/arm64.s',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/armerror.s',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/arm.s',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/armv6.s',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/mips64.s',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/mips.s',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/ppc64.s',
      '/usr/local/go/src/cmd/asm/internal/asm/testdata/s390x.s',
      '/usr/local/go/src/cmd/asm/internal/flags',
      '/usr/local/go/src/cmd/asm/internal/flags/flags.go',
      '/usr/local/go/src/cmd/asm/internal/lex',
      '/usr/local/go/src/cmd/asm/internal/lex/input.go',
      '/usr/local/go/src/cmd/asm/internal/lex/lex.go',
      '/usr/local/go/src/cmd/asm/internal/lex/lex_test.go',
      '/usr/local/go/src/cmd/asm/internal/lex/slice.go',
      '/usr/local/go/src/cmd/asm/internal/lex/stack.go',
      '/usr/local/go/src/cmd/asm/internal/lex/tokenizer.go',
      '/usr/local/go/src/cmd/asm/main.go',
      '/usr/local/go/src/cmd/cgo',
      '/usr/local/go/src/cmd/cgo/ast.go',
      '/usr/local/go/src/cmd/cgo/doc.go',
      '/usr/local/go/src/cmd/cgo/gcc.go',
      '/usr/local/go/src/cmd/cgo/godefs.go',
      '/usr/local/go/src/cmd/cgo/main.go',
      '/usr/local/go/src/cmd/cgo/out.go',
      '/usr/local/go/src/cmd/cgo/util.go',
      '/usr/local/go/src/cmd/cgo/zdefaultcc.go',
      '/usr/local/go/src/cmd/compile',
      '/usr/local/go/src/cmd/compile/doc.go',
      '/usr/local/go/src/cmd/compile/fmt_test.go',
      '/usr/local/go/src/cmd/compile/internal',
      '/usr/local/go/src/cmd/compile/internal/amd64',
      '/usr/local/go/src/cmd/compile/internal/amd64/galign.go',
      '/usr/local/go/src/cmd/compile/internal/amd64/ggen.go',
      '/usr/local/go/src/cmd/compile/internal/amd64/ssa.go',
      '/usr/local/go/src/cmd/compile/internal/arm',
      '/usr/local/go/src/cmd/compile/internal/arm/galign.go',
      '/usr/local/go/src/cmd/compile/internal/arm/ggen.go',
      '/usr/local/go/src/cmd/compile/internal/arm/ssa.go',
      '/usr/local/go/src/cmd/compile/internal/arm64',
      '/usr/local/go/src/cmd/compile/internal/arm64/galign.go',
      '/usr/local/go/src/cmd/compile/internal/arm64/ggen.go',
      '/usr/local/go/src/cmd/compile/internal/arm64/ssa.go',
      '/usr/local/go/src/cmd/compile/internal/gc',
      '/usr/local/go/src/cmd/compile/internal/gc/alg.go',
      '/usr/local/go/src/cmd/compile/internal/gc/align.go',
      '/usr/local/go/src/cmd/compile/internal/gc/asm_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/bexport.go',
      '/usr/local/go/src/cmd/compile/internal/gc/bimport.go',
      '/usr/local/go/src/cmd/compile/internal/gc/bitset.go',
      '/usr/local/go/src/cmd/compile/internal/gc/bootstrap.go',
      '/usr/local/go/src/cmd/compile/internal/gc/builtin',
      '/usr/local/go/src/cmd/compile/internal/gc/builtin/runtime.go',
      '/usr/local/go/src/cmd/compile/internal/gc/builtin.go',
      '/usr/local/go/src/cmd/compile/internal/gc/builtin_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/bv.go',
      '/usr/local/go/src/cmd/compile/internal/gc/class_string.go',
      '/usr/local/go/src/cmd/compile/internal/gc/closure.go',
      '/usr/local/go/src/cmd/compile/internal/gc/constFold_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/const.go',
      '/usr/local/go/src/cmd/compile/internal/gc/dcl.go',
      '/usr/local/go/src/cmd/compile/internal/gc/esc.go',
      '/usr/local/go/src/cmd/compile/internal/gc/export.go',
      '/usr/local/go/src/cmd/compile/internal/gc/fixedbugs_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/float_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/fmt.go',
      '/usr/local/go/src/cmd/compile/internal/gc/gen.go',
      '/usr/local/go/src/cmd/compile/internal/gc/global_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/go.go',
      '/usr/local/go/src/cmd/compile/internal/gc/gsubr.go',
      '/usr/local/go/src/cmd/compile/internal/gc/iface_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/init.go',
      '/usr/local/go/src/cmd/compile/internal/gc/inl.go',
      '/usr/local/go/src/cmd/compile/internal/gc/lex.go',
      '/usr/local/go/src/cmd/compile/internal/gc/lex_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/logic_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/main.go',
      '/usr/local/go/src/cmd/compile/internal/gc/mkbuiltin.go',
      '/usr/local/go/src/cmd/compile/internal/gc/mpfloat.go',
      '/usr/local/go/src/cmd/compile/internal/gc/mpint.go',
      '/usr/local/go/src/cmd/compile/internal/gc/noder.go',
      '/usr/local/go/src/cmd/compile/internal/gc/norace.go',
      '/usr/local/go/src/cmd/compile/internal/gc/obj.go',
      '/usr/local/go/src/cmd/compile/internal/gc/opnames.go',
      '/usr/local/go/src/cmd/compile/internal/gc/order.go',
      '/usr/local/go/src/cmd/compile/internal/gc/pgen.go',
      '/usr/local/go/src/cmd/compile/internal/gc/pgen_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/phi.go',
      '/usr/local/go/src/cmd/compile/internal/gc/plive.go',
      '/usr/local/go/src/cmd/compile/internal/gc/pprof.go',
      '/usr/local/go/src/cmd/compile/internal/gc/race.go',
      '/usr/local/go/src/cmd/compile/internal/gc/racewalk.go',
      '/usr/local/go/src/cmd/compile/internal/gc/range.go',
      '/usr/local/go/src/cmd/compile/internal/gc/reflect.go',
      '/usr/local/go/src/cmd/compile/internal/gc/reflect_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/reproduciblebuilds_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/scope.go',
      '/usr/local/go/src/cmd/compile/internal/gc/scope_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/select.go',
      '/usr/local/go/src/cmd/compile/internal/gc/shift_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/sinit.go',
      '/usr/local/go/src/cmd/compile/internal/gc/sizeof_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/ssa.go',
      '/usr/local/go/src/cmd/compile/internal/gc/ssa_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/subr.go',
      '/usr/local/go/src/cmd/compile/internal/gc/swt.go',
      '/usr/local/go/src/cmd/compile/internal/gc/swt_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/syntax.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/addressed.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/append.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/arithBoundary.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/arithConst.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/arith.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/array.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/assert.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/break.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/chan.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/closure.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/cmpConst.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/cmp.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/compound.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/copy.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/ctl.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/deferNoReturn.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/divbyzero.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/dupLoad.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/fp.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/gen',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/gen/arithBoundaryGen.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/gen/arithConstGen.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/gen/cmpConstGen.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/gen/constFoldGen.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/gen/copyGen.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/gen/zeroGen.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/loadstore.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/map.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/namedReturn.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/phi.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/regalloc.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/reproducible',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/reproducible/issue20272.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/short.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/slice.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/sqrt_const.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/string.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/unsafe.go',
      '/usr/local/go/src/cmd/compile/internal/gc/testdata/zero.go',
      '/usr/local/go/src/cmd/compile/internal/gc/timings.go',
      '/usr/local/go/src/cmd/compile/internal/gc/trace.go',
      '/usr/local/go/src/cmd/compile/internal/gc/truncconst_test.go',
      '/usr/local/go/src/cmd/compile/internal/gc/typecheck.go',
      '/usr/local/go/src/cmd/compile/internal/gc/types_acc.go',
      '/usr/local/go/src/cmd/compile/internal/gc/types.go',
      '/usr/local/go/src/cmd/compile/internal/gc/universe.go',
      '/usr/local/go/src/cmd/compile/internal/gc/unsafe.go',
      '/usr/local/go/src/cmd/compile/internal/gc/util.go',
      '/usr/local/go/src/cmd/compile/internal/gc/walk.go',
      '/usr/local/go/src/cmd/compile/internal/mips',
      '/usr/local/go/src/cmd/compile/internal/mips/galign.go',
      '/usr/local/go/src/cmd/compile/internal/mips/ggen.go',
      '/usr/local/go/src/cmd/compile/internal/mips/ssa.go',
      '/usr/local/go/src/cmd/compile/internal/mips64',
      '/usr/local/go/src/cmd/compile/internal/mips64/galign.go',
      '/usr/local/go/src/cmd/compile/internal/mips64/ggen.go',
      '/usr/local/go/src/cmd/compile/internal/mips64/ssa.go',
      '/usr/local/go/src/cmd/compile/internal/ppc64',
      '/usr/local/go/src/cmd/compile/internal/ppc64/galign.go',
      '/usr/local/go/src/cmd/compile/internal/ppc64/ggen.go',
      '/usr/local/go/src/cmd/compile/internal/ppc64/opt.go',
      '/usr/local/go/src/cmd/compile/internal/ppc64/ssa.go',
      '/usr/local/go/src/cmd/compile/internal/s390x',
      '/usr/local/go/src/cmd/compile/internal/s390x/galign.go',
      '/usr/local/go/src/cmd/compile/internal/s390x/ggen.go',
      '/usr/local/go/src/cmd/compile/internal/s390x/ssa.go',
      '/usr/local/go/src/cmd/compile/internal/ssa',
      '/usr/local/go/src/cmd/compile/internal/ssa/block.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/cache.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/checkbce.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/check.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/compile.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/config.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/copyelim.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/copyelim_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/critical.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/cse.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/cse_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/deadcode.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/deadcode_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/deadstore.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/deadstore_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/decompose.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/dom.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/dom_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/export_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/flagalloc.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/func.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/func_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/fuse.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/fuse_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/386Ops.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/386.rules',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/AMD64Ops.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/AMD64.rules',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/ARM64Ops.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/ARM64.rules',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/ARMOps.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/ARM.rules',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/dec64Ops.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/dec64.rules',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/decOps.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/dec.rules',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/genericOps.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/generic.rules',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/main.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/MIPS64Ops.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/MIPS64.rules',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/MIPSOps.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/MIPS.rules',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/PPC64Ops.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/PPC64.rules',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/README',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/rulegen.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/S390XOps.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/gen/S390X.rules',
      '/usr/local/go/src/cmd/compile/internal/ssa/html.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/id.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/layout.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/lca.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/lca_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/likelyadjust.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/location.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/loopbce.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/loopreschedchecks.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/looprotate.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/loop_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/lower.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/magic.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/magic_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/nilcheck.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/nilcheck_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/opGen.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/op.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/opt.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/passbm_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/phielim.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/phiopt.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/print.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/prove.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/redblack32.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/redblack32_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/regalloc.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/regalloc_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewrite386.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewriteAMD64.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewriteARM64.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewriteARM.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewritedec64.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewritedec.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewritegeneric.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewrite.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewriteMIPS64.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewriteMIPS.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewritePPC64.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewriteS390X.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/rewrite_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/schedule.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/schedule_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/shift_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/shortcircuit.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/shortcircuit_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/sizeof_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/sparsemap.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/sparseset.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/sparsetree.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/sparsetreemap.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/stackalloc.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/stackframe.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/tighten.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/TODO',
      '/usr/local/go/src/cmd/compile/internal/ssa/trim.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/value.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/writebarrier.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/writebarrier_test.go',
      '/usr/local/go/src/cmd/compile/internal/ssa/zcse.go',
      '/usr/local/go/src/cmd/compile/internal/syntax',
      '/usr/local/go/src/cmd/compile/internal/syntax/branches.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/dumper.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/dumper_test.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/nodes.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/nodes_test.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/parser.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/parser_test.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/printer.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/printer_test.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/scanner.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/scanner_test.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/source.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/syntax.go',
      '/usr/local/go/src/cmd/compile/internal/syntax/tokens.go',
      '/usr/local/go/src/cmd/compile/internal/test',
      '/usr/local/go/src/cmd/compile/internal/test/divconst_test.go',
      '/usr/local/go/src/cmd/compile/internal/test/README',
      '/usr/local/go/src/cmd/compile/internal/test/test.go',
      '/usr/local/go/src/cmd/compile/internal/types',
      '/usr/local/go/src/cmd/compile/internal/types/pkg.go',
      '/usr/local/go/src/cmd/compile/internal/types/scope.go',
      '/usr/local/go/src/cmd/compile/internal/types/sizeof_test.go',
      '/usr/local/go/src/cmd/compile/internal/types/sym.go',
      '/usr/local/go/src/cmd/compile/internal/types/type.go',
      '/usr/local/go/src/cmd/compile/internal/types/utils.go',
      '/usr/local/go/src/cmd/compile/internal/x86',
      '/usr/local/go/src/cmd/compile/internal/x86/387.go',
      '/usr/local/go/src/cmd/compile/internal/x86/galign.go',
      '/usr/local/go/src/cmd/compile/internal/x86/ggen.go',
      '/usr/local/go/src/cmd/compile/internal/x86/ssa.go',
      '/usr/local/go/src/cmd/compile/main.go',
      '/usr/local/go/src/cmd/cover',
      '/usr/local/go/src/cmd/cover/cover.go',
      '/usr/local/go/src/cmd/cover/cover_test.go',
      '/usr/local/go/src/cmd/cover/doc.go',
      '/usr/local/go/src/cmd/cover/func.go',
      '/usr/local/go/src/cmd/cover/html.go',
      '/usr/local/go/src/cmd/cover/profile.go',
      '/usr/local/go/src/cmd/cover/testdata',
      '/usr/local/go/src/cmd/cover/testdata/main.go',
      '/usr/local/go/src/cmd/cover/testdata/p.go',
      '/usr/local/go/src/cmd/cover/testdata/profile.cov',
      '/usr/local/go/src/cmd/cover/testdata/test.go',
      '/usr/local/go/src/cmd/dist',
      '/usr/local/go/src/cmd/dist/build.go',
      '/usr/local/go/src/cmd/dist/buildgo.go',
      '/usr/local/go/src/cmd/dist/buildruntime.go',
      '/usr/local/go/src/cmd/dist/buildtool.go',
      '/usr/local/go/src/cmd/dist/cpuid_386.s',
      '/usr/local/go/src/cmd/dist/cpuid_amd64.s',
      '/usr/local/go/src/cmd/dist/cpuid_default.s',
      '/usr/local/go/src/cmd/dist/deps.go',
      '/usr/local/go/src/cmd/dist/main.go',
      '/usr/local/go/src/cmd/dist/mkdeps.bash',
      '/usr/local/go/src/cmd/dist/README',
      '/usr/local/go/src/cmd/dist/sys_default.go',
      '/usr/local/go/src/cmd/dist/sys_windows.go',
      '/usr/local/go/src/cmd/dist/test.go',
      '/usr/local/go/src/cmd/dist/test_linux.go',
      '/usr/local/go/src/cmd/dist/util_gccgo.go',
      '/usr/local/go/src/cmd/dist/util_gc.go',
      '/usr/local/go/src/cmd/dist/util.go',
      '/usr/local/go/src/cmd/dist/vfp_arm.s',
      '/usr/local/go/src/cmd/dist/vfp_default.s',
      '/usr/local/go/src/cmd/doc',
      '/usr/local/go/src/cmd/doc/dirs.go',
      '/usr/local/go/src/cmd/doc/doc_test.go',
      '/usr/local/go/src/cmd/doc/main.go',
      '/usr/local/go/src/cmd/doc/pkg.go',
      '/usr/local/go/src/cmd/doc/testdata',
      '/usr/local/go/src/cmd/doc/testdata/pkg.go',
      '/usr/local/go/src/cmd/fix',
      '/usr/local/go/src/cmd/fix/context.go',
      '/usr/local/go/src/cmd/fix/context_test.go',
      '/usr/local/go/src/cmd/fix/doc.go',
      '/usr/local/go/src/cmd/fix/fix.go',
      '/usr/local/go/src/cmd/fix/gotypes.go',
      '/usr/local/go/src/cmd/fix/gotypes_test.go',
      '/usr/local/go/src/cmd/fix/import_test.go',
      '/usr/local/go/src/cmd/fix/main.go',
      '/usr/local/go/src/cmd/fix/main_test.go',
      '/usr/local/go/src/cmd/fix/netipv6zone.go',
      '/usr/local/go/src/cmd/fix/netipv6zone_test.go',
      '/usr/local/go/src/cmd/fix/printerconfig.go',
      '/usr/local/go/src/cmd/fix/printerconfig_test.go',
      '/usr/local/go/src/cmd/fix/typecheck.go',
      '/usr/local/go/src/cmd/go',
      '/usr/local/go/src/cmd/go/alldocs.go',
      '/usr/local/go/src/cmd/go/go11.go',
      '/usr/local/go/src/cmd/go/go_test.go',
      '/usr/local/go/src/cmd/go/go_unix_test.go',
      '/usr/local/go/src/cmd/go/go_windows_test.go',
      '/usr/local/go/src/cmd/go/internal',
      '/usr/local/go/src/cmd/go/internal/base',
      '/usr/local/go/src/cmd/go/internal/base/base.go',
      '/usr/local/go/src/cmd/go/internal/base/env.go',
      '/usr/local/go/src/cmd/go/internal/base/flag.go',
      '/usr/local/go/src/cmd/go/internal/base/path.go',
      '/usr/local/go/src/cmd/go/internal/base/signal.go',
      '/usr/local/go/src/cmd/go/internal/base/signal_notunix.go',
      '/usr/local/go/src/cmd/go/internal/base/signal_unix.go',
      '/usr/local/go/src/cmd/go/internal/base/tool.go',
      '/usr/local/go/src/cmd/go/internal/bug',
      '/usr/local/go/src/cmd/go/internal/bug/bug.go',
      '/usr/local/go/src/cmd/go/internal/buildid',
      '/usr/local/go/src/cmd/go/internal/buildid/buildid.go',
      '/usr/local/go/src/cmd/go/internal/buildid/note.go',
      '/usr/local/go/src/cmd/go/internal/cfg',
      '/usr/local/go/src/cmd/go/internal/cfg/cfg.go',
      '/usr/local/go/src/cmd/go/internal/cfg/zdefaultcc.go',
      '/usr/local/go/src/cmd/go/internal/cfg/zosarch.go',
      '/usr/local/go/src/cmd/go/internal/clean',
      '/usr/local/go/src/cmd/go/internal/clean/clean.go',
      '/usr/local/go/src/cmd/go/internal/cmdflag',
      '/usr/local/go/src/cmd/go/internal/cmdflag/flag.go',
      '/usr/local/go/src/cmd/go/internal/doc',
      '/usr/local/go/src/cmd/go/internal/doc/doc.go',
      '/usr/local/go/src/cmd/go/internal/envcmd',
      '/usr/local/go/src/cmd/go/internal/envcmd/env.go',
      '/usr/local/go/src/cmd/go/internal/fix',
      '/usr/local/go/src/cmd/go/internal/fix/fix.go',
      '/usr/local/go/src/cmd/go/internal/fmtcmd',
      '/usr/local/go/src/cmd/go/internal/fmtcmd/fmt.go',
      '/usr/local/go/src/cmd/go/internal/generate',
      '/usr/local/go/src/cmd/go/internal/generate/generate.go',
      '/usr/local/go/src/cmd/go/internal/generate/generate_test.go',
      '/usr/local/go/src/cmd/go/internal/get',
      '/usr/local/go/src/cmd/go/internal/get/discovery.go',
      '/usr/local/go/src/cmd/go/internal/get/get.go',
      '/usr/local/go/src/cmd/go/internal/get/pkg_test.go',
      '/usr/local/go/src/cmd/go/internal/get/tag_test.go',
      '/usr/local/go/src/cmd/go/internal/get/vcs.go',
      '/usr/local/go/src/cmd/go/internal/get/vcs_test.go',
      '/usr/local/go/src/cmd/go/internal/help',
      '/usr/local/go/src/cmd/go/internal/help/helpdoc.go',
      '/usr/local/go/src/cmd/go/internal/help/help.go',
      '/usr/local/go/src/cmd/go/internal/list',
      '/usr/local/go/src/cmd/go/internal/list/context.go',
      '/usr/local/go/src/cmd/go/internal/list/list.go',
      '/usr/local/go/src/cmd/go/internal/load',
      '/usr/local/go/src/cmd/go/internal/load/match_test.go',
      '/usr/local/go/src/cmd/go/internal/load/path.go',
      '/usr/local/go/src/cmd/go/internal/load/pkg.go',
      '/usr/local/go/src/cmd/go/internal/load/search.go',
      '/usr/local/go/src/cmd/go/internal/load/testgo.go',
      '/usr/local/go/src/cmd/go/internal/run',
      '/usr/local/go/src/cmd/go/internal/run/run.go',
      '/usr/local/go/src/cmd/go/internal/str',
      '/usr/local/go/src/cmd/go/internal/str/str.go',
      '/usr/local/go/src/cmd/go/internal/test',
      '/usr/local/go/src/cmd/go/internal/test/testflag.go',
      '/usr/local/go/src/cmd/go/internal/test/test.go',
      '/usr/local/go/src/cmd/go/internal/tool',
      '/usr/local/go/src/cmd/go/internal/tool/tool.go',
      '/usr/local/go/src/cmd/go/internal/version',
      '/usr/local/go/src/cmd/go/internal/version/version.go',
      '/usr/local/go/src/cmd/go/internal/vet',
      '/usr/local/go/src/cmd/go/internal/vet/vetflag.go',
      '/usr/local/go/src/cmd/go/internal/vet/vet.go',
      '/usr/local/go/src/cmd/go/internal/web',
      '/usr/local/go/src/cmd/go/internal/web/bootstrap.go',
      '/usr/local/go/src/cmd/go/internal/web/http.go',
      '/usr/local/go/src/cmd/go/internal/web/security.go',
      '/usr/local/go/src/cmd/go/internal/work',
      '/usr/local/go/src/cmd/go/internal/work/build.go',
      '/usr/local/go/src/cmd/go/internal/work/build_test.go',
      '/usr/local/go/src/cmd/go/internal/work/testgo.go',
      '/usr/local/go/src/cmd/go/main.go',
      '/usr/local/go/src/cmd/go/mkalldocs.sh',
      '/usr/local/go/src/cmd/go/note_test.go',
      '/usr/local/go/src/cmd/go/testdata',
      '/usr/local/go/src/cmd/go/testdata/dep_test.go',
      '/usr/local/go/src/cmd/go/testdata/example1_test.go',
      '/usr/local/go/src/cmd/go/testdata/example2_test.go',
      '/usr/local/go/src/cmd/go/testdata/failssh',
      '/usr/local/go/src/cmd/go/testdata/failssh/ssh',
      '/usr/local/go/src/cmd/go/testdata/flag_test.go',
      '/usr/local/go/src/cmd/go/testdata/generate',
      '/usr/local/go/src/cmd/go/testdata/generate/test1.go',
      '/usr/local/go/src/cmd/go/testdata/generate/test2.go',
      '/usr/local/go/src/cmd/go/testdata/generate/test3.go',
      '/usr/local/go/src/cmd/go/testdata/generate/test4.go',
      '/usr/local/go/src/cmd/go/testdata/importcom',
      '/usr/local/go/src/cmd/go/testdata/importcom/bad.go',
      '/usr/local/go/src/cmd/go/testdata/importcom/conflict.go',
      '/usr/local/go/src/cmd/go/testdata/importcom/src',
      '/usr/local/go/src/cmd/go/testdata/importcom/src/bad',
      '/usr/local/go/src/cmd/go/testdata/importcom/src/bad/bad.go',
      '/usr/local/go/src/cmd/go/testdata/importcom/src/conflict',
      '/usr/local/go/src/cmd/go/testdata/importcom/src/conflict/a.go',
      '/usr/local/go/src/cmd/go/testdata/importcom/src/conflict/b.go',
      '/usr/local/go/src/cmd/go/testdata/importcom/src/works',
      '/usr/local/go/src/cmd/go/testdata/importcom/src/works/x',
      '/usr/local/go/src/cmd/go/testdata/importcom/src/works/x/x1.go',
      '/usr/local/go/src/cmd/go/testdata/importcom/src/works/x/x.go',
      '/usr/local/go/src/cmd/go/testdata/importcom/src/wrongplace',
      '/usr/local/go/src/cmd/go/testdata/importcom/src/wrongplace/x.go',
      '/usr/local/go/src/cmd/go/testdata/importcom/works.go',
      '/usr/local/go/src/cmd/go/testdata/importcom/wrongplace.go',
      '/usr/local/go/src/cmd/go/testdata/local',
      '/usr/local/go/src/cmd/go/testdata/local/easy.go',
      '/usr/local/go/src/cmd/go/testdata/local/easysub',
      '/usr/local/go/src/cmd/go/testdata/local/easysub/easysub.go',
      '/usr/local/go/src/cmd/go/testdata/local/easysub/main.go',
      '/usr/local/go/src/cmd/go/testdata/local/hard.go',
      '/usr/local/go/src/cmd/go/testdata/local/sub',
      '/usr/local/go/src/cmd/go/testdata/local/sub/sub',
      '/usr/local/go/src/cmd/go/testdata/local/sub/sub/subsub.go',
      '/usr/local/go/src/cmd/go/testdata/local/sub/sub.go',
      '/usr/local/go/src/cmd/go/testdata/norunexample',
      '/usr/local/go/src/cmd/go/testdata/norunexample/example_test.go',
      '/usr/local/go/src/cmd/go/testdata/norunexample/test_test.go',
      '/usr/local/go/src/cmd/go/testdata/rundir',
      '/usr/local/go/src/cmd/go/testdata/rundir/sub',
      '/usr/local/go/src/cmd/go/testdata/rundir/sub/sub.go',
      '/usr/local/go/src/cmd/go/testdata/rundir/x.go',
      '/usr/local/go/src/cmd/go/testdata/shadow',
      '/usr/local/go/src/cmd/go/testdata/shadow/root1',
      '/usr/local/go/src/cmd/go/testdata/shadow/root1/src',
      '/usr/local/go/src/cmd/go/testdata/shadow/root1/src/foo',
      '/usr/local/go/src/cmd/go/testdata/shadow/root1/src/foo/foo.go',
      '/usr/local/go/src/cmd/go/testdata/shadow/root1/src/math',
      '/usr/local/go/src/cmd/go/testdata/shadow/root1/src/math/math.go',
      '/usr/local/go/src/cmd/go/testdata/shadow/root2',
      '/usr/local/go/src/cmd/go/testdata/shadow/root2/src',
      '/usr/local/go/src/cmd/go/testdata/shadow/root2/src/foo',
      '/usr/local/go/src/cmd/go/testdata/shadow/root2/src/foo/foo.go',
      '/usr/local/go/src/cmd/go/testdata/src',
      '/usr/local/go/src/cmd/go/testdata/src/badc',
      '/usr/local/go/src/cmd/go/testdata/src/badc/x.c',
      '/usr/local/go/src/cmd/go/testdata/src/badc/x.go',
      '/usr/local/go/src/cmd/go/testdata/src/badpkg',
      '/usr/local/go/src/cmd/go/testdata/src/badpkg/x.go',
      '/usr/local/go/src/cmd/go/testdata/src/badtest',
      '/usr/local/go/src/cmd/go/testdata/src/badtest/badexec',
      '/usr/local/go/src/cmd/go/testdata/src/badtest/badexec/x_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/badtest/badsyntax',
      '/usr/local/go/src/cmd/go/testdata/src/badtest/badsyntax/x.go',
      '/usr/local/go/src/cmd/go/testdata/src/badtest/badsyntax/x_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/badtest/badvar',
      '/usr/local/go/src/cmd/go/testdata/src/badtest/badvar/x.go',
      '/usr/local/go/src/cmd/go/testdata/src/badtest/badvar/x_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/bench',
      '/usr/local/go/src/cmd/go/testdata/src/bench/x_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/benchfatal',
      '/usr/local/go/src/cmd/go/testdata/src/benchfatal/x_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/canonical',
      '/usr/local/go/src/cmd/go/testdata/src/canonical/a',
      '/usr/local/go/src/cmd/go/testdata/src/canonical/a/a.go',
      '/usr/local/go/src/cmd/go/testdata/src/canonical/a/vendor',
      '/usr/local/go/src/cmd/go/testdata/src/canonical/a/vendor/c',
      '/usr/local/go/src/cmd/go/testdata/src/canonical/a/vendor/c/c.go',
      '/usr/local/go/src/cmd/go/testdata/src/canonical/b',
      '/usr/local/go/src/cmd/go/testdata/src/canonical/b/b.go',
      '/usr/local/go/src/cmd/go/testdata/src/canonical/d',
      '/usr/local/go/src/cmd/go/testdata/src/canonical/d/d.go',
      '/usr/local/go/src/cmd/go/testdata/src/cgoasm',
      '/usr/local/go/src/cmd/go/testdata/src/cgoasm/p.go',
      '/usr/local/go/src/cmd/go/testdata/src/cgoasm/p.s',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover/p.go',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover/p_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover2',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover2/p.go',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover2/x_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover3',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover3/p.go',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover3/p_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover3/x_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover4',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover4/notcgo.go',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover4/p.go',
      '/usr/local/go/src/cmd/go/testdata/src/cgocover4/x_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/cgotest',
      '/usr/local/go/src/cmd/go/testdata/src/cgotest/m.go',
      '/usr/local/go/src/cmd/go/testdata/src/dupload',
      '/usr/local/go/src/cmd/go/testdata/src/dupload/dupload.go',
      '/usr/local/go/src/cmd/go/testdata/src/dupload/p',
      '/usr/local/go/src/cmd/go/testdata/src/dupload/p/p.go',
      '/usr/local/go/src/cmd/go/testdata/src/dupload/p2',
      '/usr/local/go/src/cmd/go/testdata/src/dupload/p2/p2.go',
      '/usr/local/go/src/cmd/go/testdata/src/dupload/vendor',
      '/usr/local/go/src/cmd/go/testdata/src/dupload/vendor/p',
      '/usr/local/go/src/cmd/go/testdata/src/dupload/vendor/p/p.go',
      '/usr/local/go/src/cmd/go/testdata/src/empty',
      '/usr/local/go/src/cmd/go/testdata/src/empty/pkg',
      '/usr/local/go/src/cmd/go/testdata/src/empty/pkg/pkg.go',
      '/usr/local/go/src/cmd/go/testdata/src/empty/pkgtest',
      '/usr/local/go/src/cmd/go/testdata/src/empty/pkgtest/pkg.go',
      '/usr/local/go/src/cmd/go/testdata/src/empty/pkgtest/test_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/empty/pkgtestxtest',
      '/usr/local/go/src/cmd/go/testdata/src/empty/pkgtestxtest/pkg.go',
      '/usr/local/go/src/cmd/go/testdata/src/empty/pkgtestxtest/test_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/empty/pkgtestxtest/xtest_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/empty/pkgxtest',
      '/usr/local/go/src/cmd/go/testdata/src/empty/pkgxtest/pkg.go',
      '/usr/local/go/src/cmd/go/testdata/src/empty/pkgxtest/xtest_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/empty/test',
      '/usr/local/go/src/cmd/go/testdata/src/empty/test/test_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/empty/testxtest',
      '/usr/local/go/src/cmd/go/testdata/src/empty/testxtest/test_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/empty/testxtest/xtest_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/empty/xtest',
      '/usr/local/go/src/cmd/go/testdata/src/empty/xtest/xtest_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/exclude',
      '/usr/local/go/src/cmd/go/testdata/src/exclude/empty',
      '/usr/local/go/src/cmd/go/testdata/src/exclude/empty/x.txt',
      '/usr/local/go/src/cmd/go/testdata/src/exclude/ignore',
      '/usr/local/go/src/cmd/go/testdata/src/exclude/ignore/_x.go',
      '/usr/local/go/src/cmd/go/testdata/src/exclude/x.go',
      '/usr/local/go/src/cmd/go/testdata/src/exclude/x_linux.go',
      '/usr/local/go/src/cmd/go/testdata/src/gencycle',
      '/usr/local/go/src/cmd/go/testdata/src/gencycle/gencycle.go',
      '/usr/local/go/src/cmd/go/testdata/src/go-cmd-test',
      '/usr/local/go/src/cmd/go/testdata/src/go-cmd-test/helloworld.go',
      '/usr/local/go/src/cmd/go/testdata/src/importmain',
      '/usr/local/go/src/cmd/go/testdata/src/importmain/ismain',
      '/usr/local/go/src/cmd/go/testdata/src/importmain/ismain/main.go',
      '/usr/local/go/src/cmd/go/testdata/src/importmain/test',
      '/usr/local/go/src/cmd/go/testdata/src/importmain/test/test.go',
      '/usr/local/go/src/cmd/go/testdata/src/importmain/test/test_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/main_test',
      '/usr/local/go/src/cmd/go/testdata/src/main_test/m.go',
      '/usr/local/go/src/cmd/go/testdata/src/main_test/m_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/my.pkg',
      '/usr/local/go/src/cmd/go/testdata/src/my.pkg/main',
      '/usr/local/go/src/cmd/go/testdata/src/my.pkg/main/main.go',
      '/usr/local/go/src/cmd/go/testdata/src/my.pkg/pkg.go',
      '/usr/local/go/src/cmd/go/testdata/src/notest',
      '/usr/local/go/src/cmd/go/testdata/src/notest/hello.go',
      '/usr/local/go/src/cmd/go/testdata/src/run',
      '/usr/local/go/src/cmd/go/testdata/src/run/bad.go',
      '/usr/local/go/src/cmd/go/testdata/src/run/good.go',
      '/usr/local/go/src/cmd/go/testdata/src/run/internal',
      '/usr/local/go/src/cmd/go/testdata/src/run/internal/internal.go',
      '/usr/local/go/src/cmd/go/testdata/src/run/subdir',
      '/usr/local/go/src/cmd/go/testdata/src/run/subdir/internal',
      '/usr/local/go/src/cmd/go/testdata/src/run/subdir/internal/private',
      '/usr/local/go/src/cmd/go/testdata/src/run/subdir/internal/private/private.go',
      '/usr/local/go/src/cmd/go/testdata/src/syntaxerror',
      '/usr/local/go/src/cmd/go/testdata/src/syntaxerror/x.go',
      '/usr/local/go/src/cmd/go/testdata/src/syntaxerror/x_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/testcycle',
      '/usr/local/go/src/cmd/go/testdata/src/testcycle/p1',
      '/usr/local/go/src/cmd/go/testdata/src/testcycle/p1/p1.go',
      '/usr/local/go/src/cmd/go/testdata/src/testcycle/p1/p1_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/testcycle/p2',
      '/usr/local/go/src/cmd/go/testdata/src/testcycle/p2/p2.go',
      '/usr/local/go/src/cmd/go/testdata/src/testcycle/p3',
      '/usr/local/go/src/cmd/go/testdata/src/testcycle/p3/p3.go',
      '/usr/local/go/src/cmd/go/testdata/src/testcycle/p3/p3_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/testcycle/q1',
      '/usr/local/go/src/cmd/go/testdata/src/testcycle/q1/q1.go',
      '/usr/local/go/src/cmd/go/testdata/src/testcycle/q1/q1_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/testdep',
      '/usr/local/go/src/cmd/go/testdata/src/testdep/p1',
      '/usr/local/go/src/cmd/go/testdata/src/testdep/p1/p1.go',
      '/usr/local/go/src/cmd/go/testdata/src/testdep/p1/p1_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/testdep/p2',
      '/usr/local/go/src/cmd/go/testdata/src/testdep/p2/p2.go',
      '/usr/local/go/src/cmd/go/testdata/src/testdep/p3',
      '/usr/local/go/src/cmd/go/testdata/src/testdep/p3/p3.go',
      '/usr/local/go/src/cmd/go/testdata/src/testlist',
      '/usr/local/go/src/cmd/go/testdata/src/testlist/bench_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/testlist/example_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/testlist/test_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/testrace',
      '/usr/local/go/src/cmd/go/testdata/src/testrace/race_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/testregexp',
      '/usr/local/go/src/cmd/go/testdata/src/testregexp/x_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/testregexp/z_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend',
      '/usr/local/go/src/cmd/go/testdata/src/vend/bad.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/dir1',
      '/usr/local/go/src/cmd/go/testdata/src/vend/dir1/dir1.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/good.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/hello',
      '/usr/local/go/src/cmd/go/testdata/src/vend/hello/hello.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/hello/hello_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/hello/hellox_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/subdir',
      '/usr/local/go/src/cmd/go/testdata/src/vend/subdir/bad.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/subdir/good.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/vendor',
      '/usr/local/go/src/cmd/go/testdata/src/vend/vendor/p',
      '/usr/local/go/src/cmd/go/testdata/src/vend/vendor/p/p.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/vendor/q',
      '/usr/local/go/src/cmd/go/testdata/src/vend/vendor/q/q.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/vendor/strings',
      '/usr/local/go/src/cmd/go/testdata/src/vend/vendor/strings/msg.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/vendor/vend',
      '/usr/local/go/src/cmd/go/testdata/src/vend/vendor/vend/dir1',
      '/usr/local/go/src/cmd/go/testdata/src/vend/vendor/vend/dir1/dir2',
      '/usr/local/go/src/cmd/go/testdata/src/vend/vendor/vend/dir1/dir2/dir2.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/x',
      '/usr/local/go/src/cmd/go/testdata/src/vend/x/invalid',
      '/usr/local/go/src/cmd/go/testdata/src/vend/x/invalid/invalid.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/x/vendor',
      '/usr/local/go/src/cmd/go/testdata/src/vend/x/vendor/p',
      '/usr/local/go/src/cmd/go/testdata/src/vend/x/vendor/p/p',
      '/usr/local/go/src/cmd/go/testdata/src/vend/x/vendor/p/p/p.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/x/vendor/p/p.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/x/vendor/r',
      '/usr/local/go/src/cmd/go/testdata/src/vend/x/vendor/r/r.go',
      '/usr/local/go/src/cmd/go/testdata/src/vend/x/x.go',
      '/usr/local/go/src/cmd/go/testdata/src/vetpkg',
      '/usr/local/go/src/cmd/go/testdata/src/vetpkg/a_test.go',
      '/usr/local/go/src/cmd/go/testdata/src/vetpkg/b.go',
      '/usr/local/go/src/cmd/go/testdata/src/vetpkg/c.go',
      '/usr/local/go/src/cmd/go/testdata/src/xtestonly',
      '/usr/local/go/src/cmd/go/testdata/src/xtestonly/f.go',
      '/usr/local/go/src/cmd/go/testdata/src/xtestonly/f_test.go',
      '/usr/local/go/src/cmd/go/testdata/standalone_benchmark_test.go',
      '/usr/local/go/src/cmd/go/testdata/standalone_fail_sub_test.go',
      '/usr/local/go/src/cmd/go/testdata/standalone_parallel_sub_test.go',
      '/usr/local/go/src/cmd/go/testdata/standalone_sub_test.go',
      '/usr/local/go/src/cmd/go/testdata/standalone_test.go',
      '/usr/local/go/src/cmd/go/testdata/testimport',
      '/usr/local/go/src/cmd/go/testdata/testimport/p1',
      '/usr/local/go/src/cmd/go/testdata/testimport/p1/p1.go',
      '/usr/local/go/src/cmd/go/testdata/testimport/p2',
      '/usr/local/go/src/cmd/go/testdata/testimport/p2/p2.go',
      '/usr/local/go/src/cmd/go/testdata/testimport/p.go',
      '/usr/local/go/src/cmd/go/testdata/testimport/p_test.go',
      '/usr/local/go/src/cmd/go/testdata/testimport/x_test.go',
      '/usr/local/go/src/cmd/go/testdata/testinternal',
      '/usr/local/go/src/cmd/go/testdata/testinternal/p.go',
      '/usr/local/go/src/cmd/go/testdata/testinternal2',
      '/usr/local/go/src/cmd/go/testdata/testinternal2/p.go',
      '/usr/local/go/src/cmd/go/testdata/testinternal2/x',
      '/usr/local/go/src/cmd/go/testdata/testinternal2/x/y',
      '/usr/local/go/src/cmd/go/testdata/testinternal2/x/y/z',
      '/usr/local/go/src/cmd/go/testdata/testinternal2/x/y/z/internal',
      '/usr/local/go/src/cmd/go/testdata/testinternal2/x/y/z/internal/w',
      '/usr/local/go/src/cmd/go/testdata/testinternal2/x/y/z/internal/w/w.go',
      '/usr/local/go/src/cmd/go/testdata/testinternal3',
      '/usr/local/go/src/cmd/go/testdata/testinternal3/t.go',
      '/usr/local/go/src/cmd/go/testdata/testinternal4',
      '/usr/local/go/src/cmd/go/testdata/testinternal4/src',
      '/usr/local/go/src/cmd/go/testdata/testinternal4/src/p',
      '/usr/local/go/src/cmd/go/testdata/testinternal4/src/p/p.go',
      '/usr/local/go/src/cmd/go/testdata/testinternal4/src/q',
      '/usr/local/go/src/cmd/go/testdata/testinternal4/src/q/internal',
      '/usr/local/go/src/cmd/go/testdata/testinternal4/src/q/internal/x',
      '/usr/local/go/src/cmd/go/testdata/testinternal4/src/q/internal/x/x.go',
      '/usr/local/go/src/cmd/go/testdata/testinternal4/src/q/j',
      '/usr/local/go/src/cmd/go/testdata/testinternal4/src/q/j/j.go',
      '/usr/local/go/src/cmd/go/testdata/testonly',
      '/usr/local/go/src/cmd/go/testdata/testonly/p_test.go',
      '/usr/local/go/src/cmd/go/testdata/testterminal18153',
      '/usr/local/go/src/cmd/go/testdata/testterminal18153/terminal_test.go',
      '/usr/local/go/src/cmd/go/testdata/testvendor',
      '/usr/local/go/src/cmd/go/testdata/testvendor/src',
      '/usr/local/go/src/cmd/go/testdata/testvendor/src/p',
      '/usr/local/go/src/cmd/go/testdata/testvendor/src/p/p.go',
      '/usr/local/go/src/cmd/go/testdata/testvendor/src/q',
      '/usr/local/go/src/cmd/go/testdata/testvendor/src/q/vendor',
      '/usr/local/go/src/cmd/go/testdata/testvendor/src/q/vendor/x',
      '/usr/local/go/src/cmd/go/testdata/testvendor/src/q/vendor/x/x.go',
      '/usr/local/go/src/cmd/go/testdata/testvendor/src/q/y',
      '/usr/local/go/src/cmd/go/testdata/testvendor/src/q/y/y.go',
      '/usr/local/go/src/cmd/go/testdata/testvendor/src/q/z',
      '/usr/local/go/src/cmd/go/testdata/testvendor/src/q/z/z.go',
      '/usr/local/go/src/cmd/go/testdata/testvendor2',
      '/usr/local/go/src/cmd/go/testdata/testvendor2/src',
      '/usr/local/go/src/cmd/go/testdata/testvendor2/src/p',
      '/usr/local/go/src/cmd/go/testdata/testvendor2/src/p/p.go',
      '/usr/local/go/src/cmd/go/testdata/testvendor2/vendor',
      '/usr/local/go/src/cmd/go/testdata/testvendor2/vendor/x',
      '/usr/local/go/src/cmd/go/testdata/testvendor2/vendor/x/x.go',
      '/usr/local/go/src/cmd/go/testdata/timeoutbench_test.go',
      '/usr/local/go/src/cmd/go/vendor_test.go',
      '/usr/local/go/src/cmd/gofmt',
      '/usr/local/go/src/cmd/gofmt/doc.go',
      '/usr/local/go/src/cmd/gofmt/gofmt.go',
      '/usr/local/go/src/cmd/gofmt/gofmt_test.go',
      '/usr/local/go/src/cmd/gofmt/internal.go',
      '/usr/local/go/src/cmd/gofmt/long_test.go',
      '/usr/local/go/src/cmd/gofmt/rewrite.go',
      '/usr/local/go/src/cmd/gofmt/simplify.go',
      '/usr/local/go/src/cmd/gofmt/testdata',
      '/usr/local/go/src/cmd/gofmt/testdata/comments.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/comments.input',
      '/usr/local/go/src/cmd/gofmt/testdata/composites.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/composites.input',
      '/usr/local/go/src/cmd/gofmt/testdata/crlf.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/crlf.input',
      '/usr/local/go/src/cmd/gofmt/testdata/emptydecl.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/emptydecl.input',
      '/usr/local/go/src/cmd/gofmt/testdata/import.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/import.input',
      '/usr/local/go/src/cmd/gofmt/testdata/ranges.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/ranges.input',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite1.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite1.input',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite2.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite2.input',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite3.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite3.input',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite4.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite4.input',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite5.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite5.input',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite6.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite6.input',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite7.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite7.input',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite8.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite8.input',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite9.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/rewrite9.input',
      '/usr/local/go/src/cmd/gofmt/testdata/slices1.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/slices1.input',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin1.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin1.input',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin2.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin2.input',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin3.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin3.input',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin4.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin4.input',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin5.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin5.input',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin6.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin6.input',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin7.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/stdin7.input',
      '/usr/local/go/src/cmd/gofmt/testdata/typealias.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/typealias.input',
      '/usr/local/go/src/cmd/gofmt/testdata/typeswitch.golden',
      '/usr/local/go/src/cmd/gofmt/testdata/typeswitch.input',
      '/usr/local/go/src/cmd/internal',
      '/usr/local/go/src/cmd/internal/bio',
      '/usr/local/go/src/cmd/internal/bio/buf.go',
      '/usr/local/go/src/cmd/internal/bio/must.go',
      '/usr/local/go/src/cmd/internal/browser',
      '/usr/local/go/src/cmd/internal/browser/browser.go',
      '/usr/local/go/src/cmd/internal/dwarf',
      '/usr/local/go/src/cmd/internal/dwarf/dwarf_defs.go',
      '/usr/local/go/src/cmd/internal/dwarf/dwarf.go',
      '/usr/local/go/src/cmd/internal/dwarf/dwarf_test.go',
      '/usr/local/go/src/cmd/internal/gcprog',
      '/usr/local/go/src/cmd/internal/gcprog/gcprog.go',
      '/usr/local/go/src/cmd/internal/goobj',
      '/usr/local/go/src/cmd/internal/goobj/read.go',
      '/usr/local/go/src/cmd/internal/obj',
      '/usr/local/go/src/cmd/internal/obj/addrtype_string.go',
      '/usr/local/go/src/cmd/internal/obj/arm',
      '/usr/local/go/src/cmd/internal/obj/arm/anames5.go',
      '/usr/local/go/src/cmd/internal/obj/arm/anames.go',
      '/usr/local/go/src/cmd/internal/obj/arm/a.out.go',
      '/usr/local/go/src/cmd/internal/obj/arm/asm5.go',
      '/usr/local/go/src/cmd/internal/obj/arm/list5.go',
      '/usr/local/go/src/cmd/internal/obj/arm/obj5.go',
      '/usr/local/go/src/cmd/internal/obj/arm64',
      '/usr/local/go/src/cmd/internal/obj/arm64/anames7.go',
      '/usr/local/go/src/cmd/internal/obj/arm64/anames.go',
      '/usr/local/go/src/cmd/internal/obj/arm64/a.out.go',
      '/usr/local/go/src/cmd/internal/obj/arm64/asm7.go',
      '/usr/local/go/src/cmd/internal/obj/arm64/asm_test.go',
      '/usr/local/go/src/cmd/internal/obj/arm64/list7.go',
      '/usr/local/go/src/cmd/internal/obj/arm64/obj7.go',
      '/usr/local/go/src/cmd/internal/obj/bootstrap.go',
      '/usr/local/go/src/cmd/internal/obj/data.go',
      '/usr/local/go/src/cmd/internal/obj/go.go',
      '/usr/local/go/src/cmd/internal/obj/inl.go',
      '/usr/local/go/src/cmd/internal/obj/ld.go',
      '/usr/local/go/src/cmd/internal/obj/line.go',
      '/usr/local/go/src/cmd/internal/obj/line_test.go',
      '/usr/local/go/src/cmd/internal/obj/link.go',
      '/usr/local/go/src/cmd/internal/obj/mips',
      '/usr/local/go/src/cmd/internal/obj/mips/anames0.go',
      '/usr/local/go/src/cmd/internal/obj/mips/anames.go',
      '/usr/local/go/src/cmd/internal/obj/mips/a.out.go',
      '/usr/local/go/src/cmd/internal/obj/mips/asm0.go',
      '/usr/local/go/src/cmd/internal/obj/mips/list0.go',
      '/usr/local/go/src/cmd/internal/obj/mips/obj0.go',
      '/usr/local/go/src/cmd/internal/obj/objfile.go',
      '/usr/local/go/src/cmd/internal/obj/pass.go',
      '/usr/local/go/src/cmd/internal/obj/pcln.go',
      '/usr/local/go/src/cmd/internal/obj/plist.go',
      '/usr/local/go/src/cmd/internal/obj/ppc64',
      '/usr/local/go/src/cmd/internal/obj/ppc64/anames9.go',
      '/usr/local/go/src/cmd/internal/obj/ppc64/anames.go',
      '/usr/local/go/src/cmd/internal/obj/ppc64/a.out.go',
      '/usr/local/go/src/cmd/internal/obj/ppc64/asm9.go',
      '/usr/local/go/src/cmd/internal/obj/ppc64/list9.go',
      '/usr/local/go/src/cmd/internal/obj/ppc64/obj9.go',
      '/usr/local/go/src/cmd/internal/obj/s390x',
      '/usr/local/go/src/cmd/internal/obj/s390x/anames.go',
      '/usr/local/go/src/cmd/internal/obj/s390x/anamesz.go',
      '/usr/local/go/src/cmd/internal/obj/s390x/a.out.go',
      '/usr/local/go/src/cmd/internal/obj/s390x/asmz.go',
      '/usr/local/go/src/cmd/internal/obj/s390x/listz.go',
      '/usr/local/go/src/cmd/internal/obj/s390x/objz.go',
      '/usr/local/go/src/cmd/internal/obj/s390x/vector.go',
      '/usr/local/go/src/cmd/internal/obj/sizeof_test.go',
      '/usr/local/go/src/cmd/internal/obj/sort.go',
      '/usr/local/go/src/cmd/internal/obj/stringer.go',
      '/usr/local/go/src/cmd/internal/obj/sym.go',
      '/usr/local/go/src/cmd/internal/obj/textflag.go',
      '/usr/local/go/src/cmd/internal/obj/util.go',
      '/usr/local/go/src/cmd/internal/obj/x86',
      '/usr/local/go/src/cmd/internal/obj/x86/anames.go',
      '/usr/local/go/src/cmd/internal/obj/x86/a.out.go',
      '/usr/local/go/src/cmd/internal/obj/x86/asm6.go',
      '/usr/local/go/src/cmd/internal/obj/x86/issue19518_test.go',
      '/usr/local/go/src/cmd/internal/obj/x86/list6.go',
      '/usr/local/go/src/cmd/internal/obj/x86/obj6.go',
      '/usr/local/go/src/cmd/internal/obj/x86/obj6_test.go',
      '/usr/local/go/src/cmd/internal/objabi',
      '/usr/local/go/src/cmd/internal/objabi/autotype.go',
      '/usr/local/go/src/cmd/internal/objabi/doc.go',
      '/usr/local/go/src/cmd/internal/objabi/flag.go',
      '/usr/local/go/src/cmd/internal/objabi/funcdata.go',
      '/usr/local/go/src/cmd/internal/objabi/head.go',
      '/usr/local/go/src/cmd/internal/objabi/line.go',
      '/usr/local/go/src/cmd/internal/objabi/path.go',
      '/usr/local/go/src/cmd/internal/objabi/path_test.go',
      '/usr/local/go/src/cmd/internal/objabi/reloctype.go',
      '/usr/local/go/src/cmd/internal/objabi/reloctype_string.go',
      '/usr/local/go/src/cmd/internal/objabi/stack.go',
      '/usr/local/go/src/cmd/internal/objabi/symkind.go',
      '/usr/local/go/src/cmd/internal/objabi/symkind_string.go',
      '/usr/local/go/src/cmd/internal/objabi/typekind.go',
      '/usr/local/go/src/cmd/internal/objabi/util.go',
      '/usr/local/go/src/cmd/internal/objabi/zbootstrap.go',
      '/usr/local/go/src/cmd/internal/objfile',
      '/usr/local/go/src/cmd/internal/objfile/disasm.go',
      '/usr/local/go/src/cmd/internal/objfile/elf.go',
      '/usr/local/go/src/cmd/internal/objfile/goobj.go',
      '/usr/local/go/src/cmd/internal/objfile/macho.go',
      '/usr/local/go/src/cmd/internal/objfile/objfile.go',
      '/usr/local/go/src/cmd/internal/objfile/pe.go',
      '/usr/local/go/src/cmd/internal/objfile/plan9obj.go',
      '/usr/local/go/src/cmd/internal/src',
      '/usr/local/go/src/cmd/internal/src/pos.go',
      '/usr/local/go/src/cmd/internal/src/pos_test.go',
      '/usr/local/go/src/cmd/internal/src/xpos.go',
      '/usr/local/go/src/cmd/internal/src/xpos_test.go',
      '/usr/local/go/src/cmd/internal/sys',
      '/usr/local/go/src/cmd/internal/sys/arch.go',
      '/usr/local/go/src/cmd/link',
      '/usr/local/go/src/cmd/link/doc.go',
      '/usr/local/go/src/cmd/link/dwarf_test.go',
      '/usr/local/go/src/cmd/link/internal',
      '/usr/local/go/src/cmd/link/internal/amd64',
      '/usr/local/go/src/cmd/link/internal/amd64/asm.go',
      '/usr/local/go/src/cmd/link/internal/amd64/l.go',
      '/usr/local/go/src/cmd/link/internal/amd64/obj.go',
      '/usr/local/go/src/cmd/link/internal/arm',
      '/usr/local/go/src/cmd/link/internal/arm/asm.go',
      '/usr/local/go/src/cmd/link/internal/arm/l.go',
      '/usr/local/go/src/cmd/link/internal/arm/obj.go',
      '/usr/local/go/src/cmd/link/internal/arm64',
      '/usr/local/go/src/cmd/link/internal/arm64/asm.go',
      '/usr/local/go/src/cmd/link/internal/arm64/l.go',
      '/usr/local/go/src/cmd/link/internal/arm64/obj.go',
      '/usr/local/go/src/cmd/link/internal/ld',
      '/usr/local/go/src/cmd/link/internal/ld/ar.go',
      '/usr/local/go/src/cmd/link/internal/ld/config.go',
      '/usr/local/go/src/cmd/link/internal/ld/data.go',
      '/usr/local/go/src/cmd/link/internal/ld/deadcode.go',
      '/usr/local/go/src/cmd/link/internal/ld/decodesym.go',
      '/usr/local/go/src/cmd/link/internal/ld/dwarf.go',
      '/usr/local/go/src/cmd/link/internal/ld/dwarf_test.go',
      '/usr/local/go/src/cmd/link/internal/ld/elf.go',
      '/usr/local/go/src/cmd/link/internal/ld/go.go',
      '/usr/local/go/src/cmd/link/internal/ld/ldelf.go',
      '/usr/local/go/src/cmd/link/internal/ld/ld.go',
      '/usr/local/go/src/cmd/link/internal/ld/ldmacho.go',
      '/usr/local/go/src/cmd/link/internal/ld/ldpe.go',
      '/usr/local/go/src/cmd/link/internal/ld/lib.go',
      '/usr/local/go/src/cmd/link/internal/ld/link.go',
      '/usr/local/go/src/cmd/link/internal/ld/macho_combine_dwarf.go',
      '/usr/local/go/src/cmd/link/internal/ld/macho.go',
      '/usr/local/go/src/cmd/link/internal/ld/main.go',
      '/usr/local/go/src/cmd/link/internal/ld/nooptcgolink_test.go',
      '/usr/local/go/src/cmd/link/internal/ld/objfile.go',
      '/usr/local/go/src/cmd/link/internal/ld/pcln.go',
      '/usr/local/go/src/cmd/link/internal/ld/pe.go',
      '/usr/local/go/src/cmd/link/internal/ld/symbols.go',
      '/usr/local/go/src/cmd/link/internal/ld/sym.go',
      '/usr/local/go/src/cmd/link/internal/ld/symkind.go',
      '/usr/local/go/src/cmd/link/internal/ld/symkind_string.go',
      '/usr/local/go/src/cmd/link/internal/ld/symtab.go',
      '/usr/local/go/src/cmd/link/internal/ld/typelink.go',
      '/usr/local/go/src/cmd/link/internal/ld/util.go',
      '/usr/local/go/src/cmd/link/internal/mips',
      '/usr/local/go/src/cmd/link/internal/mips/asm.go',
      '/usr/local/go/src/cmd/link/internal/mips/l.go',
      '/usr/local/go/src/cmd/link/internal/mips/obj.go',
      '/usr/local/go/src/cmd/link/internal/mips64',
      '/usr/local/go/src/cmd/link/internal/mips64/asm.go',
      '/usr/local/go/src/cmd/link/internal/mips64/l.go',
      '/usr/local/go/src/cmd/link/internal/mips64/obj.go',
      '/usr/local/go/src/cmd/link/internal/ppc64',
      '/usr/local/go/src/cmd/link/internal/ppc64/asm.go',
      '/usr/local/go/src/cmd/link/internal/ppc64/l.go',
      '/usr/local/go/src/cmd/link/internal/ppc64/obj.go',
      '/usr/local/go/src/cmd/link/internal/s390x',
      '/usr/local/go/src/cmd/link/internal/s390x/asm.go',
      '/usr/local/go/src/cmd/link/internal/s390x/l.go',
      '/usr/local/go/src/cmd/link/internal/s390x/obj.go',
      '/usr/local/go/src/cmd/link/internal/x86',
      '/usr/local/go/src/cmd/link/internal/x86/asm.go',
      '/usr/local/go/src/cmd/link/internal/x86/l.go',
      '/usr/local/go/src/cmd/link/internal/x86/obj.go',
      '/usr/local/go/src/cmd/link/linkbig_test.go',
      '/usr/local/go/src/cmd/link/link_test.go',
      '/usr/local/go/src/cmd/link/main.go',
      '/usr/local/go/src/cmd/nm',
      '/usr/local/go/src/cmd/nm/doc.go',
      '/usr/local/go/src/cmd/nm/nm_cgo_test.go',
      '/usr/local/go/src/cmd/nm/nm.go',
      '/usr/local/go/src/cmd/nm/nm_test.go',
      '/usr/local/go/src/cmd/objdump',
      '/usr/local/go/src/cmd/objdump/main.go',
      '/usr/local/go/src/cmd/objdump/objdump_test.go',
      '/usr/local/go/src/cmd/objdump/testdata',
      '/usr/local/go/src/cmd/objdump/testdata/fmthello.go',
      '/usr/local/go/src/cmd/pack',
      '/usr/local/go/src/cmd/pack/doc.go',
      '/usr/local/go/src/cmd/pack/pack.go',
      '/usr/local/go/src/cmd/pack/pack_test.go',
      '/usr/local/go/src/cmd/pprof',
      '/usr/local/go/src/cmd/pprof/doc.go',
      '/usr/local/go/src/cmd/pprof/pprof.go',
      '/usr/local/go/src/cmd/pprof/README',
      '/usr/local/go/src/cmd/trace',
      '/usr/local/go/src/cmd/trace/doc.go',
      '/usr/local/go/src/cmd/trace/goroutines.go',
      '/usr/local/go/src/cmd/trace/main.go',
      '/usr/local/go/src/cmd/trace/pprof.go',
      '/usr/local/go/src/cmd/trace/trace.go',
      '/usr/local/go/src/cmd/trace/trace_test.go',
      '/usr/local/go/src/cmd/vendor',
      '/usr/local/go/src/cmd/vendor/github.com',
      '/usr/local/go/src/cmd/vendor/github.com/google',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/AUTHORS',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/CONTRIBUTING',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/CONTRIBUTORS',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/doc',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/doc/developer',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/doc/developer/pprof.dev.md',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/doc/developer/profile.proto.md',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/doc/pprof.md',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/driver',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/driver/driver.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/binutils',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/binutils/addr2liner.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/binutils/addr2liner_llvm.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/binutils/addr2liner_nm.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/binutils/binutils.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/binutils/binutils_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/binutils/disasm.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/binutils/disasm_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/cli.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/commands.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/driver_focus.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/driver.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/driver_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/fetch.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/fetch_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/interactive.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/interactive_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/options.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/tempfile.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/cppbench.cpu',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/file1000.src',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/file2000.src',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/file3000.src',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/go.crc32.cpu',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/go.nomappings.crash',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.contention.cum.files.dot',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.contention.flat.addresses.dot.focus.ignore',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.callgrind',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.comments',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.cum.lines.text.hide',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.cum.lines.text.show',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.cum.lines.topproto.hide',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.flat.addresses.disasm',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.flat.addresses.weblist',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.flat.functions.dot',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.flat.functions.text',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.peek',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpusmall.flat.addresses.tree',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.tags',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.tags.focus.ignore',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.cpu.traces',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap_alloc.flat.alloc_objects.text',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap_alloc.flat.alloc_space.dot.focus',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap_alloc.flat.alloc_space.dot.hide',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap.callgrind',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap.comments',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap.cum.lines.tree.focus',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap.cum.relative_percentages.tree.focus',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap.flat.files.seconds.text',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap.flat.files.text',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap.flat.inuse_objects.text',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap.flat.inuse_space.dot.focus',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap.flat.inuse_space.dot.focus.ignore',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap.flat.lines.dot.focus',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap.tags',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.heap.tags.unit',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/driver/testdata/pprof.unknown.flat.functions.text',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/elfexec',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/elfexec/elfexec.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/elfexec/elfexec_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/graph',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/graph/dotgraph.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/graph/dotgraph_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/graph/graph.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/graph/graph_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/graph/testdata',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/graph/testdata/compose1.dot',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/graph/testdata/compose2.dot',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/graph/testdata/compose3.dot',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/graph/testdata/compose4.dot',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/graph/testdata/compose5.dot',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/measurement',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/measurement/measurement.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/plugin',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/plugin/plugin.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/proftest',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/proftest/proftest.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/report',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/report/report.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/report/report_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/report/source.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/report/source_html.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/report/testdata',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/report/testdata/source1',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/report/testdata/source2',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/report/testdata/source.dot',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/report/testdata/source.rpt',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/symbolizer',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/symbolizer/symbolizer.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/symbolizer/symbolizer_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/symbolz',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/symbolz/symbolz.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/internal/symbolz/symbolz_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/LICENSE',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/pprof.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/encode.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/filter.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/index.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/index_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/legacy_java_profile.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/legacy_profile.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/legacy_profile_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/merge.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/profile.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/profile_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/proto.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/proto_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/prune.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/prune_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.contention',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.contention.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.cpu',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.cpu.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.growth',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.growth.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.heap',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.heap.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.thread',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.thread.all',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.thread.all.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.thread.none',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.thread.none.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/cppbench.thread.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/gobench.cpu',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/gobench.cpu.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/gobench.heap',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/gobench.heap.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/go.crc32.cpu',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/go.crc32.cpu.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/go.godoc.thread',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/go.godoc.thread.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/java.contention',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/java.contention.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/java.cpu',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/java.cpu.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/java.heap',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/profile/testdata/java.heap.string',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/proto',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/proto/profile.proto',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/README.md',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/third_party',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/third_party/svg',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/third_party/svg/svg.go',
      '/usr/local/go/src/cmd/vendor/github.com/google/pprof/third_party/svg/svgpan.go',
      '/usr/local/go/src/cmd/vendor/github.com/ianlancetaylor',
      '/usr/local/go/src/cmd/vendor/github.com/ianlancetaylor/demangle',
      '/usr/local/go/src/cmd/vendor/github.com/ianlancetaylor/demangle/ast.go',
      '/usr/local/go/src/cmd/vendor/github.com/ianlancetaylor/demangle/ast_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/ianlancetaylor/demangle/c++filt.go',
      '/usr/local/go/src/cmd/vendor/github.com/ianlancetaylor/demangle/demangle.go',
      '/usr/local/go/src/cmd/vendor/github.com/ianlancetaylor/demangle/demangle_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/ianlancetaylor/demangle/expected_test.go',
      '/usr/local/go/src/cmd/vendor/github.com/ianlancetaylor/demangle/LICENSE',
      '/usr/local/go/src/cmd/vendor/github.com/ianlancetaylor/demangle/README.md',
      '/usr/local/go/src/cmd/vendor/github.com/ianlancetaylor/demangle/testdata',
      '/usr/local/go/src/cmd/vendor/github.com/ianlancetaylor/demangle/testdata/demangle-expected',
      '/usr/local/go/src/cmd/vendor/golang.org',
      '/usr/local/go/src/cmd/vendor/golang.org/x',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/decode.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/decode_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/ext_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/gnu.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/inst.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/Makefile',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/objdumpext_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/objdump_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/plan9x.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/tables.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/testdata',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/testdata/decode.txt',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/arm/armasm/testdata/Makefile',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/decode.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/decode_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/doc.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/ext_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/field.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/field_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/gnu.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/inst.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/objdumpext_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/objdump_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/plan9.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/tables.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/testdata',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/ppc64/ppc64asm/testdata/decode.txt',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/decode.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/decode_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/ext_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/gnu.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/inst.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/inst_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/intel.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/Makefile',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/objdumpext_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/objdump_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/plan9ext_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/plan9x.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/plan9x_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/tables.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/testdata',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/testdata/decode.txt',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/testdata/libmach8db.c',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/testdata/Makefile',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/xedext_test.go',
      '/usr/local/go/src/cmd/vendor/golang.org/x/arch/x86/x86asm/xed_test.go',
      '/usr/local/go/src/cmd/vendor/vendor.json',
      '/usr/local/go/src/cmd/vet',
      '/usr/local/go/src/cmd/vet/all',
      '/usr/local/go/src/cmd/vet/all/main.go',
      '/usr/local/go/src/cmd/vet/all/whitelist',
      '/usr/local/go/src/cmd/vet/all/whitelist/386.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/all.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/amd64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/android_386.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/android_amd64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/android_arm.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/arm64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/arm.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/darwin_386.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/darwin_amd64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/darwin_arm64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/darwin_arm.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/dragonfly_amd64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/freebsd_386.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/freebsd_amd64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/freebsd_arm.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/linux_386.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/linux_amd64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/linux_arm64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/linux_arm.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/linux_ppc64x.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/mips64x.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/mipsle.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/mips.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/mipsx.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/nacl_386.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/nacl_amd64p32.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/nacl_arm.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/netbsd_386.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/netbsd_amd64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/netbsd_arm.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/netbsd.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/openbsd_386.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/openbsd_amd64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/openbsd_arm.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/plan9_386.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/plan9_amd64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/plan9_arm.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/ppc64x.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/readme.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/s390x.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/solaris_amd64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/windows_386.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/windows_amd64.txt',
      '/usr/local/go/src/cmd/vet/all/whitelist/windows.txt',
      '/usr/local/go/src/cmd/vet/asmdecl.go',
      '/usr/local/go/src/cmd/vet/assign.go',
      '/usr/local/go/src/cmd/vet/atomic.go',
      '/usr/local/go/src/cmd/vet/bool.go',
      '/usr/local/go/src/cmd/vet/buildtag.go',
      '/usr/local/go/src/cmd/vet/cgo.go',
      '/usr/local/go/src/cmd/vet/composite.go',
      '/usr/local/go/src/cmd/vet/copylock.go',
      '/usr/local/go/src/cmd/vet/deadcode.go',
      '/usr/local/go/src/cmd/vet/dead.go',
      '/usr/local/go/src/cmd/vet/doc.go',
      '/usr/local/go/src/cmd/vet/httpresponse.go',
      '/usr/local/go/src/cmd/vet/internal',
      '/usr/local/go/src/cmd/vet/internal/cfg',
      '/usr/local/go/src/cmd/vet/internal/cfg/builder.go',
      '/usr/local/go/src/cmd/vet/internal/cfg/cfg.go',
      '/usr/local/go/src/cmd/vet/internal/cfg/cfg_test.go',
      '/usr/local/go/src/cmd/vet/internal/whitelist',
      '/usr/local/go/src/cmd/vet/internal/whitelist/whitelist.go',
      '/usr/local/go/src/cmd/vet/lostcancel.go',
      '/usr/local/go/src/cmd/vet/main.go',
      '/usr/local/go/src/cmd/vet/method.go',
      '/usr/local/go/src/cmd/vet/nilfunc.go',
      '/usr/local/go/src/cmd/vet/print.go',
      '/usr/local/go/src/cmd/vet/rangeloop.go',
      '/usr/local/go/src/cmd/vet/README',
      '/usr/local/go/src/cmd/vet/shadow.go',
      '/usr/local/go/src/cmd/vet/shift.go',
      '/usr/local/go/src/cmd/vet/structtag.go',
      '/usr/local/go/src/cmd/vet/testdata',
      '/usr/local/go/src/cmd/vet/testdata/asm',
      '/usr/local/go/src/cmd/vet/testdata/asm/asm1.s',
      '/usr/local/go/src/cmd/vet/testdata/asm/asm2.s',
      '/usr/local/go/src/cmd/vet/testdata/asm/asm3.s',
      '/usr/local/go/src/cmd/vet/testdata/asm/asm4.s',
      '/usr/local/go/src/cmd/vet/testdata/asm/asm5.s',
      '/usr/local/go/src/cmd/vet/testdata/asm/asm6.s',
      '/usr/local/go/src/cmd/vet/testdata/asm/asm7.s',
      '/usr/local/go/src/cmd/vet/testdata/asm/asm.go',
      '/usr/local/go/src/cmd/vet/testdata/asm8.s',
      '/usr/local/go/src/cmd/vet/testdata/assign.go',
      '/usr/local/go/src/cmd/vet/testdata/atomic.go',
      '/usr/local/go/src/cmd/vet/testdata/bool.go',
      '/usr/local/go/src/cmd/vet/testdata/buildtag',
      '/usr/local/go/src/cmd/vet/testdata/buildtag/buildtag_bad.go',
      '/usr/local/go/src/cmd/vet/testdata/buildtag/buildtag.go',
      '/usr/local/go/src/cmd/vet/testdata/cgo',
      '/usr/local/go/src/cmd/vet/testdata/cgo/cgo2.go',
      '/usr/local/go/src/cmd/vet/testdata/cgo/cgo3.go',
      '/usr/local/go/src/cmd/vet/testdata/cgo/cgo.go',
      '/usr/local/go/src/cmd/vet/testdata/composite.go',
      '/usr/local/go/src/cmd/vet/testdata/copylock_func.go',
      '/usr/local/go/src/cmd/vet/testdata/copylock.go',
      '/usr/local/go/src/cmd/vet/testdata/copylock_range.go',
      '/usr/local/go/src/cmd/vet/testdata/deadcode.go',
      '/usr/local/go/src/cmd/vet/testdata/divergent',
      '/usr/local/go/src/cmd/vet/testdata/divergent/buf.go',
      '/usr/local/go/src/cmd/vet/testdata/divergent/buf_test.go',
      '/usr/local/go/src/cmd/vet/testdata/httpresponse.go',
      '/usr/local/go/src/cmd/vet/testdata/incomplete',
      '/usr/local/go/src/cmd/vet/testdata/incomplete/examples_test.go',
      '/usr/local/go/src/cmd/vet/testdata/lostcancel.go',
      '/usr/local/go/src/cmd/vet/testdata/method.go',
      '/usr/local/go/src/cmd/vet/testdata/nilfunc.go',
      '/usr/local/go/src/cmd/vet/testdata/print.go',
      '/usr/local/go/src/cmd/vet/testdata/rangeloop.go',
      '/usr/local/go/src/cmd/vet/testdata/shadow.go',
      '/usr/local/go/src/cmd/vet/testdata/shift.go',
      '/usr/local/go/src/cmd/vet/testdata/structtag.go',
      '/usr/local/go/src/cmd/vet/testdata/tagtest',
      '/usr/local/go/src/cmd/vet/testdata/tagtest/file1.go',
      '/usr/local/go/src/cmd/vet/testdata/tagtest/file2.go',
      '/usr/local/go/src/cmd/vet/testdata/testingpkg',
      '/usr/local/go/src/cmd/vet/testdata/testingpkg/tests.go',
      '/usr/local/go/src/cmd/vet/testdata/testingpkg/tests_test.go',
      '/usr/local/go/src/cmd/vet/testdata/unsafeptr.go',
      '/usr/local/go/src/cmd/vet/testdata/unused.go',
      '/usr/local/go/src/cmd/vet/tests.go',
      '/usr/local/go/src/cmd/vet/types.go',
      '/usr/local/go/src/cmd/vet/unsafeptr.go',
      '/usr/local/go/src/cmd/vet/unused.go',
      '/usr/local/go/src/cmd/vet/vet_test.go',
      '/usr/local/go/src/cmp.bash',
      '/usr/local/go/src/compress',
      '/usr/local/go/src/compress/bzip2',
      '/usr/local/go/src/compress/bzip2/bit_reader.go',
      '/usr/local/go/src/compress/bzip2/bzip2.go',
      '/usr/local/go/src/compress/bzip2/bzip2_test.go',
      '/usr/local/go/src/compress/bzip2/huffman.go',
      '/usr/local/go/src/compress/bzip2/move_to_front.go',
      '/usr/local/go/src/compress/bzip2/testdata',
      '/usr/local/go/src/compress/bzip2/testdata/e.txt.bz2',
      '/usr/local/go/src/compress/bzip2/testdata/fail-issue5747.bz2',
      '/usr/local/go/src/compress/bzip2/testdata/Mark.Twain-Tom.Sawyer.txt.bz2',
      '/usr/local/go/src/compress/bzip2/testdata/pass-random1.bin',
      '/usr/local/go/src/compress/bzip2/testdata/pass-random1.bz2',
      '/usr/local/go/src/compress/bzip2/testdata/pass-random2.bin',
      '/usr/local/go/src/compress/bzip2/testdata/pass-random2.bz2',
      '/usr/local/go/src/compress/bzip2/testdata/pass-sawtooth.bz2',
      '/usr/local/go/src/compress/bzip2/testdata/random.data.bz2',
      '/usr/local/go/src/compress/flate',
      '/usr/local/go/src/compress/flate/deflatefast.go',
      '/usr/local/go/src/compress/flate/deflate.go',
      '/usr/local/go/src/compress/flate/deflate_test.go',
      '/usr/local/go/src/compress/flate/dict_decoder.go',
      '/usr/local/go/src/compress/flate/dict_decoder_test.go',
      '/usr/local/go/src/compress/flate/example_test.go',
      '/usr/local/go/src/compress/flate/flate_test.go',
      '/usr/local/go/src/compress/flate/huffman_bit_writer.go',
      '/usr/local/go/src/compress/flate/huffman_bit_writer_test.go',
      '/usr/local/go/src/compress/flate/huffman_code.go',
      '/usr/local/go/src/compress/flate/inflate.go',
      '/usr/local/go/src/compress/flate/inflate_test.go',
      '/usr/local/go/src/compress/flate/reader_test.go',
      '/usr/local/go/src/compress/flate/testdata',
      '/usr/local/go/src/compress/flate/testdata/huffman-null-max.dyn.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-null-max.dyn.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-null-max.golden',
      '/usr/local/go/src/compress/flate/testdata/huffman-null-max.in',
      '/usr/local/go/src/compress/flate/testdata/huffman-null-max.wb.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-null-max.wb.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-pi.dyn.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-pi.dyn.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-pi.golden',
      '/usr/local/go/src/compress/flate/testdata/huffman-pi.in',
      '/usr/local/go/src/compress/flate/testdata/huffman-pi.wb.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-pi.wb.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-1k.dyn.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-1k.dyn.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-1k.golden',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-1k.in',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-1k.wb.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-1k.wb.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-limit.dyn.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-limit.dyn.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-limit.golden',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-limit.in',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-limit.wb.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-limit.wb.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-max.golden',
      '/usr/local/go/src/compress/flate/testdata/huffman-rand-max.in',
      '/usr/local/go/src/compress/flate/testdata/huffman-shifts.dyn.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-shifts.dyn.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-shifts.golden',
      '/usr/local/go/src/compress/flate/testdata/huffman-shifts.in',
      '/usr/local/go/src/compress/flate/testdata/huffman-shifts.wb.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-shifts.wb.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-text.dyn.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-text.dyn.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-text.golden',
      '/usr/local/go/src/compress/flate/testdata/huffman-text.in',
      '/usr/local/go/src/compress/flate/testdata/huffman-text-shift.dyn.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-text-shift.dyn.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-text-shift.golden',
      '/usr/local/go/src/compress/flate/testdata/huffman-text-shift.in',
      '/usr/local/go/src/compress/flate/testdata/huffman-text-shift.wb.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-text-shift.wb.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-text.wb.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-text.wb.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-zero.dyn.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-zero.dyn.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/huffman-zero.golden',
      '/usr/local/go/src/compress/flate/testdata/huffman-zero.in',
      '/usr/local/go/src/compress/flate/testdata/huffman-zero.wb.expect',
      '/usr/local/go/src/compress/flate/testdata/huffman-zero.wb.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/null-long-match.dyn.expect-noinput',
      '/usr/local/go/src/compress/flate/testdata/null-long-match.wb.expect-noinput',
      '/usr/local/go/src/compress/flate/token.go',
      '/usr/local/go/src/compress/flate/writer_test.go',
      '/usr/local/go/src/compress/gzip',
      '/usr/local/go/src/compress/gzip/example_test.go',
      '/usr/local/go/src/compress/gzip/gunzip.go',
      '/usr/local/go/src/compress/gzip/gunzip_test.go',
      '/usr/local/go/src/compress/gzip/gzip.go',
      '/usr/local/go/src/compress/gzip/gzip_test.go',
      '/usr/local/go/src/compress/gzip/issue14937_test.go',
      '/usr/local/go/src/compress/gzip/testdata',
      '/usr/local/go/src/compress/gzip/testdata/issue6550.gz',
      '/usr/local/go/src/compress/lzw',
      '/usr/local/go/src/compress/lzw/reader.go',
      '/usr/local/go/src/compress/lzw/reader_test.go',
      '/usr/local/go/src/compress/lzw/writer.go',
      '/usr/local/go/src/compress/lzw/writer_test.go',
      '/usr/local/go/src/compress/testdata',
      '/usr/local/go/src/compress/testdata/e.txt',
      '/usr/local/go/src/compress/testdata/gettysburg.txt',
      '/usr/local/go/src/compress/testdata/Mark.Twain-Tom.Sawyer.txt',
      '/usr/local/go/src/compress/testdata/pi.txt',
      '/usr/local/go/src/compress/zlib',
      '/usr/local/go/src/compress/zlib/example_test.go',
      '/usr/local/go/src/compress/zlib/reader.go',
      '/usr/local/go/src/compress/zlib/reader_test.go',
      '/usr/local/go/src/compress/zlib/writer.go',
      '/usr/local/go/src/compress/zlib/writer_test.go',
      '/usr/local/go/src/container',
      '/usr/local/go/src/container/heap',
      '/usr/local/go/src/container/heap/example_intheap_test.go',
      '/usr/local/go/src/container/heap/example_pq_test.go',
      '/usr/local/go/src/container/heap/heap.go',
      '/usr/local/go/src/container/heap/heap_test.go',
      '/usr/local/go/src/container/list',
      '/usr/local/go/src/container/list/example_test.go',
      '/usr/local/go/src/container/list/list.go',
      '/usr/local/go/src/container/list/list_test.go',
      '/usr/local/go/src/container/ring',
      '/usr/local/go/src/container/ring/ring.go',
      '/usr/local/go/src/container/ring/ring_test.go',
      '/usr/local/go/src/context',
      '/usr/local/go/src/context/benchmark_test.go',
      '/usr/local/go/src/context/context.go',
      '/usr/local/go/src/context/context_test.go',
      '/usr/local/go/src/context/example_test.go',
      '/usr/local/go/src/context/net_test.go',
      '/usr/local/go/src/context/x_test.go',
      '/usr/local/go/src/crypto',
      '/usr/local/go/src/crypto/aes',
      '/usr/local/go/src/crypto/aes/aes_gcm.go',
      '/usr/local/go/src/crypto/aes/aes_test.go',
      '/usr/local/go/src/crypto/aes/asm_amd64.s',
      '/usr/local/go/src/crypto/aes/asm_ppc64le.s',
      '/usr/local/go/src/crypto/aes/asm_s390x.s',
      '/usr/local/go/src/crypto/aes/block.go',
      '/usr/local/go/src/crypto/aes/cbc_s390x.go',
      '/usr/local/go/src/crypto/aes/cipher_amd64.go',
      '/usr/local/go/src/crypto/aes/cipher_generic.go',
      '/usr/local/go/src/crypto/aes/cipher.go',
      '/usr/local/go/src/crypto/aes/cipher_ppc64le.go',
      '/usr/local/go/src/crypto/aes/cipher_s390x.go',
      '/usr/local/go/src/crypto/aes/const.go',
      '/usr/local/go/src/crypto/aes/ctr_s390x.go',
      '/usr/local/go/src/crypto/aes/gcm_amd64.s',
      '/usr/local/go/src/crypto/aes/gcm_s390x.go',
      '/usr/local/go/src/crypto/aes/modes.go',
      '/usr/local/go/src/crypto/aes/modes_test.go',
      '/usr/local/go/src/crypto/cipher',
      '/usr/local/go/src/crypto/cipher/benchmark_test.go',
      '/usr/local/go/src/crypto/cipher/cbc_aes_test.go',
      '/usr/local/go/src/crypto/cipher/cbc.go',
      '/usr/local/go/src/crypto/cipher/cfb.go',
      '/usr/local/go/src/crypto/cipher/cfb_test.go',
      '/usr/local/go/src/crypto/cipher/cipher.go',
      '/usr/local/go/src/crypto/cipher/cipher_test.go',
      '/usr/local/go/src/crypto/cipher/common_test.go',
      '/usr/local/go/src/crypto/cipher/ctr_aes_test.go',
      '/usr/local/go/src/crypto/cipher/ctr.go',
      '/usr/local/go/src/crypto/cipher/ctr_test.go',
      '/usr/local/go/src/crypto/cipher/example_test.go',
      '/usr/local/go/src/crypto/cipher/gcm.go',
      '/usr/local/go/src/crypto/cipher/gcm_test.go',
      '/usr/local/go/src/crypto/cipher/io.go',
      '/usr/local/go/src/crypto/cipher/ofb.go',
      '/usr/local/go/src/crypto/cipher/ofb_test.go',
      '/usr/local/go/src/crypto/cipher/xor.go',
      '/usr/local/go/src/crypto/cipher/xor_test.go',
      '/usr/local/go/src/crypto/crypto.go',
      '/usr/local/go/src/crypto/des',
      '/usr/local/go/src/crypto/des/block.go',
      '/usr/local/go/src/crypto/des/cipher.go',
      '/usr/local/go/src/crypto/des/const.go',
      '/usr/local/go/src/crypto/des/des_test.go',
      '/usr/local/go/src/crypto/des/example_test.go',
      '/usr/local/go/src/crypto/dsa',
      '/usr/local/go/src/crypto/dsa/dsa.go',
      '/usr/local/go/src/crypto/dsa/dsa_test.go',
      '/usr/local/go/src/crypto/ecdsa',
      '/usr/local/go/src/crypto/ecdsa/ecdsa.go',
      '/usr/local/go/src/crypto/ecdsa/ecdsa_test.go',
      '/usr/local/go/src/crypto/ecdsa/testdata',
      '/usr/local/go/src/crypto/ecdsa/testdata/SigVer.rsp.bz2',
      '/usr/local/go/src/crypto/elliptic',
      '/usr/local/go/src/crypto/elliptic/elliptic.go',
      '/usr/local/go/src/crypto/elliptic/elliptic_test.go',
      '/usr/local/go/src/crypto/elliptic/p224.go',
      '/usr/local/go/src/crypto/elliptic/p224_test.go',
      '/usr/local/go/src/crypto/elliptic/p256_amd64.go',
      '/usr/local/go/src/crypto/elliptic/p256_asm_amd64.s',
      '/usr/local/go/src/crypto/elliptic/p256_asm_s390x.s',
      '/usr/local/go/src/crypto/elliptic/p256_generic.go',
      '/usr/local/go/src/crypto/elliptic/p256.go',
      '/usr/local/go/src/crypto/elliptic/p256_s390x.go',
      '/usr/local/go/src/crypto/hmac',
      '/usr/local/go/src/crypto/hmac/hmac.go',
      '/usr/local/go/src/crypto/hmac/hmac_test.go',
      '/usr/local/go/src/crypto/internal',
      '/usr/local/go/src/crypto/internal/cipherhw',
      '/usr/local/go/src/crypto/internal/cipherhw/asm_amd64.s',
      '/usr/local/go/src/crypto/internal/cipherhw/asm_s390x.s',
      '/usr/local/go/src/crypto/internal/cipherhw/cipherhw_amd64.go',
      '/usr/local/go/src/crypto/internal/cipherhw/cipherhw_s390x.go',
      '/usr/local/go/src/crypto/internal/cipherhw/doc.go',
      '/usr/local/go/src/crypto/internal/cipherhw/generic.go',
      '/usr/local/go/src/crypto/md5',
      '/usr/local/go/src/crypto/md5/example_test.go',
      '/usr/local/go/src/crypto/md5/gen.go',
      '/usr/local/go/src/crypto/md5/md5block_386.s',
      '/usr/local/go/src/crypto/md5/md5block_amd64p32.s',
      '/usr/local/go/src/crypto/md5/md5block_amd64.s',
      '/usr/local/go/src/crypto/md5/md5block_arm.s',
      '/usr/local/go/src/crypto/md5/md5block_decl.go',
      '/usr/local/go/src/crypto/md5/md5block_generic.go',
      '/usr/local/go/src/crypto/md5/md5block.go',
      '/usr/local/go/src/crypto/md5/md5block_ppc64le.s',
      '/usr/local/go/src/crypto/md5/md5block_s390x.s',
      '/usr/local/go/src/crypto/md5/md5.go',
      '/usr/local/go/src/crypto/md5/md5_test.go',
      '/usr/local/go/src/crypto/rand',
      '/usr/local/go/src/crypto/rand/eagain.go',
      '/usr/local/go/src/crypto/rand/example_test.go',
      '/usr/local/go/src/crypto/rand/rand.go',
      '/usr/local/go/src/crypto/rand/rand_linux.go',
      '/usr/local/go/src/crypto/rand/rand_openbsd.go',
      '/usr/local/go/src/crypto/rand/rand_test.go',
      '/usr/local/go/src/crypto/rand/rand_unix.go',
      '/usr/local/go/src/crypto/rand/rand_windows.go',
      '/usr/local/go/src/crypto/rand/util.go',
      '/usr/local/go/src/crypto/rand/util_test.go',
      '/usr/local/go/src/crypto/rc4',
      '/usr/local/go/src/crypto/rc4/rc4_386.s',
      '/usr/local/go/src/crypto/rc4/rc4_amd64p32.s',
      '/usr/local/go/src/crypto/rc4/rc4_amd64.s',
      '/usr/local/go/src/crypto/rc4/rc4_arm.s',
      '/usr/local/go/src/crypto/rc4/rc4_asm.go',
      '/usr/local/go/src/crypto/rc4/rc4.go',
      '/usr/local/go/src/crypto/rc4/rc4_ref.go',
      '/usr/local/go/src/crypto/rc4/rc4_test.go',
      '/usr/local/go/src/crypto/rsa',
      '/usr/local/go/src/crypto/rsa/example_test.go',
      '/usr/local/go/src/crypto/rsa/pkcs1v15.go',
      '/usr/local/go/src/crypto/rsa/pkcs1v15_test.go',
      '/usr/local/go/src/crypto/rsa/pss.go',
      '/usr/local/go/src/crypto/rsa/pss_test.go',
      '/usr/local/go/src/crypto/rsa/rsa.go',
      '/usr/local/go/src/crypto/rsa/rsa_test.go',
      '/usr/local/go/src/crypto/rsa/testdata',
      '/usr/local/go/src/crypto/rsa/testdata/pss-vect.txt.bz2',
      '/usr/local/go/src/crypto/sha1',
      '/usr/local/go/src/crypto/sha1/example_test.go',
      '/usr/local/go/src/crypto/sha1/fallback_test.go',
      '/usr/local/go/src/crypto/sha1/issue15617_test.go',
      '/usr/local/go/src/crypto/sha1/sha1block_386.s',
      '/usr/local/go/src/crypto/sha1/sha1block_amd64.go',
      '/usr/local/go/src/crypto/sha1/sha1block_amd64p32.s',
      '/usr/local/go/src/crypto/sha1/sha1block_amd64.s',
      '/usr/local/go/src/crypto/sha1/sha1block_arm.s',
      '/usr/local/go/src/crypto/sha1/sha1block_decl.go',
      '/usr/local/go/src/crypto/sha1/sha1block_generic.go',
      '/usr/local/go/src/crypto/sha1/sha1block.go',
      '/usr/local/go/src/crypto/sha1/sha1block_s390x.go',
      '/usr/local/go/src/crypto/sha1/sha1block_s390x.s',
      '/usr/local/go/src/crypto/sha1/sha1.go',
      '/usr/local/go/src/crypto/sha1/sha1_test.go',
      '/usr/local/go/src/crypto/sha256',
      '/usr/local/go/src/crypto/sha256/example_test.go',
      '/usr/local/go/src/crypto/sha256/fallback_test.go',
      '/usr/local/go/src/crypto/sha256/sha256block_386.s',
      '/usr/local/go/src/crypto/sha256/sha256block_amd64.go',
      '/usr/local/go/src/crypto/sha256/sha256block_amd64.s',
      '/usr/local/go/src/crypto/sha256/sha256block_decl.go',
      '/usr/local/go/src/crypto/sha256/sha256block_generic.go',
      '/usr/local/go/src/crypto/sha256/sha256block.go',
      '/usr/local/go/src/crypto/sha256/sha256block_ppc64le.s',
      '/usr/local/go/src/crypto/sha256/sha256block_s390x.go',
      '/usr/local/go/src/crypto/sha256/sha256block_s390x.s',
      '/usr/local/go/src/crypto/sha256/sha256.go',
      '/usr/local/go/src/crypto/sha256/sha256_test.go',
      '/usr/local/go/src/crypto/sha512',
      '/usr/local/go/src/crypto/sha512/fallback_test.go',
      '/usr/local/go/src/crypto/sha512/sha512block_amd64.go',
      '/usr/local/go/src/crypto/sha512/sha512block_amd64.s',
      '/usr/local/go/src/crypto/sha512/sha512block_decl.go',
      '/usr/local/go/src/crypto/sha512/sha512block_generic.go',
      '/usr/local/go/src/crypto/sha512/sha512block.go',
      '/usr/local/go/src/crypto/sha512/sha512block_ppc64le.s',
      '/usr/local/go/src/crypto/sha512/sha512block_s390x.go',
      '/usr/local/go/src/crypto/sha512/sha512block_s390x.s',
      '/usr/local/go/src/crypto/sha512/sha512.go',
      '/usr/local/go/src/crypto/sha512/sha512_test.go',
      '/usr/local/go/src/crypto/subtle',
      '/usr/local/go/src/crypto/subtle/constant_time.go',
      '/usr/local/go/src/crypto/subtle/constant_time_test.go',
      '/usr/local/go/src/crypto/tls',
      '/usr/local/go/src/crypto/tls/alert.go',
      '/usr/local/go/src/crypto/tls/cipher_suites.go',
      '/usr/local/go/src/crypto/tls/common.go',
      '/usr/local/go/src/crypto/tls/conn.go',
      '/usr/local/go/src/crypto/tls/conn_test.go',
      '/usr/local/go/src/crypto/tls/example_test.go',
      '/usr/local/go/src/crypto/tls/generate_cert.go',
      '/usr/local/go/src/crypto/tls/handshake_client.go',
      '/usr/local/go/src/crypto/tls/handshake_client_test.go',
      '/usr/local/go/src/crypto/tls/handshake_messages.go',
      '/usr/local/go/src/crypto/tls/handshake_messages_test.go',
      '/usr/local/go/src/crypto/tls/handshake_server.go',
      '/usr/local/go/src/crypto/tls/handshake_server_test.go',
      '/usr/local/go/src/crypto/tls/handshake_test.go',
      '/usr/local/go/src/crypto/tls/key_agreement.go',
      '/usr/local/go/src/crypto/tls/prf.go',
      '/usr/local/go/src/crypto/tls/prf_test.go',
      '/usr/local/go/src/crypto/tls/testdata',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv10-ClientCert-ECDSA-ECDSA',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv10-ClientCert-ECDSA-RSA',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv10-ClientCert-RSA-ECDSA',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv10-ClientCert-RSA-RSA',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv10-ECDHE-ECDSA-AES',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv10-ECDHE-RSA-AES',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv10-RSA-RC4',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv11-ECDHE-ECDSA-AES',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv11-ECDHE-RSA-AES',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv11-RSA-RC4',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-AES128-GCM-SHA256',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-AES128-SHA256',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-AES256-GCM-SHA384',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ALPN',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ALPN-NoMatch',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ClientCert-ECDSA-ECDSA',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ClientCert-ECDSA-RSA',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ClientCert-RSA-AES256-GCM-SHA384',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ClientCert-RSA-ECDSA',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ClientCert-RSA-RSA',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ECDHE-ECDSA-AES',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ECDHE-ECDSA-AES128-SHA256',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ECDHE-ECDSA-AES256-GCM-SHA384',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ECDHE-ECDSA-AES-GCM',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ECDHE-ECDSA-CHACHA20-POLY1305',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ECDHE-RSA-AES',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ECDHE-RSA-AES128-SHA256',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-ECDHE-RSA-CHACHA20-POLY1305',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-RenegotiateOnce',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-RenegotiateTwice',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-RenegotiateTwiceRejected',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-RenegotiationRejected',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-RSA-RC4',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-SCT',
      '/usr/local/go/src/crypto/tls/testdata/Client-TLSv12-X25519-ECDHE-RSA-AES-GCM',
      '/usr/local/go/src/crypto/tls/testdata/Server-SSLv3-RSA-3DES',
      '/usr/local/go/src/crypto/tls/testdata/Server-SSLv3-RSA-AES',
      '/usr/local/go/src/crypto/tls/testdata/Server-SSLv3-RSA-RC4',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv10-ECDHE-ECDSA-AES',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv10-RSA-3DES',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv10-RSA-AES',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv10-RSA-RC4',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv11-FallbackSCSV',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv11-RSA-RC4',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-ALPN',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-ALPN-NoMatch',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-CipherSuiteCertPreferenceECDSA',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-CipherSuiteCertPreferenceRSA',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-ClientAuthRequestedAndECDSAGiven',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-ClientAuthRequestedAndGiven',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-ClientAuthRequestedNotGiven',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-ECDHE-ECDSA-AES',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-IssueTicket',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-IssueTicketPreDisable',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-Resume',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-ResumeDisabled',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-RSA-3DES',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-RSA-AES',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-RSA-AES256-GCM-SHA384',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-RSA-AES-GCM',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-RSA-RC4',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-SNI',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-SNI-GetCertificate',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-SNI-GetCertificateNotFound',
      '/usr/local/go/src/crypto/tls/testdata/Server-TLSv12-X25519-ECDHE-RSA-AES-GCM',
      '/usr/local/go/src/crypto/tls/ticket.go',
      '/usr/local/go/src/crypto/tls/tls.go',
      '/usr/local/go/src/crypto/tls/tls_test.go',
      '/usr/local/go/src/crypto/x509',
      '/usr/local/go/src/crypto/x509/cert_pool.go',
      '/usr/local/go/src/crypto/x509/example_test.go',
      '/usr/local/go/src/crypto/x509/pem_decrypt.go',
      '/usr/local/go/src/crypto/x509/pem_decrypt_test.go',
      '/usr/local/go/src/crypto/x509/pkcs1.go',
      '/usr/local/go/src/crypto/x509/pkcs8.go',
      '/usr/local/go/src/crypto/x509/pkcs8_test.go',
      '/usr/local/go/src/crypto/x509/pkix',
      '/usr/local/go/src/crypto/x509/pkix/pkix.go',
      '/usr/local/go/src/crypto/x509/root_bsd.go',
      '/usr/local/go/src/crypto/x509/root_cgo_darwin.go',
      '/usr/local/go/src/crypto/x509/root_darwin_arm_gen.go',
      '/usr/local/go/src/crypto/x509/root_darwin_armx.go',
      '/usr/local/go/src/crypto/x509/root_darwin.go',
      '/usr/local/go/src/crypto/x509/root_darwin_test.go',
      '/usr/local/go/src/crypto/x509/root.go',
      '/usr/local/go/src/crypto/x509/root_linux.go',
      '/usr/local/go/src/crypto/x509/root_nacl.go',
      '/usr/local/go/src/crypto/x509/root_nocgo_darwin.go',
      '/usr/local/go/src/crypto/x509/root_plan9.go',
      '/usr/local/go/src/crypto/x509/root_solaris.go',
      '/usr/local/go/src/crypto/x509/root_unix.go',
      '/usr/local/go/src/crypto/x509/root_unix_test.go',
      '/usr/local/go/src/crypto/x509/root_windows.go',
      '/usr/local/go/src/crypto/x509/sec1.go',
      '/usr/local/go/src/crypto/x509/sec1_test.go',
      '/usr/local/go/src/crypto/x509/sha2_windows_test.go',
      '/usr/local/go/src/crypto/x509/testdata',
      '/usr/local/go/src/crypto/x509/testdata/test-dir.crt',
      '/usr/local/go/src/crypto/x509/test-file.crt',
      '/usr/local/go/src/crypto/x509/verify.go',
      '/usr/local/go/src/crypto/x509/verify_test.go',
      '/usr/local/go/src/crypto/x509/x509.go',
      '/usr/local/go/src/crypto/x509/x509_test.go',
      '/usr/local/go/src/crypto/x509/x509_test_import.go',
      '/usr/local/go/src/database',
      '/usr/local/go/src/database/sql',
      '/usr/local/go/src/database/sql/convert.go',
      '/usr/local/go/src/database/sql/convert_test.go',
      '/usr/local/go/src/database/sql/ctxutil.go',
      '/usr/local/go/src/database/sql/doc.txt',
      '/usr/local/go/src/database/sql/driver',
      '/usr/local/go/src/database/sql/driver/driver.go',
      '/usr/local/go/src/database/sql/driver/types.go',
      '/usr/local/go/src/database/sql/driver/types_test.go',
      '/usr/local/go/src/database/sql/example_test.go',
      '/usr/local/go/src/database/sql/fakedb_test.go',
      '/usr/local/go/src/database/sql/sql.go',
      '/usr/local/go/src/database/sql/sql_test.go',
      '/usr/local/go/src/debug',
      '/usr/local/go/src/debug/dwarf',
      '/usr/local/go/src/debug/dwarf/buf.go',
      '/usr/local/go/src/debug/dwarf/class_string.go',
      '/usr/local/go/src/debug/dwarf/const.go',
      '/usr/local/go/src/debug/dwarf/entry.go',
      '/usr/local/go/src/debug/dwarf/entry_test.go',
      '/usr/local/go/src/debug/dwarf/export_test.go',
      '/usr/local/go/src/debug/dwarf/line.go',
      '/usr/local/go/src/debug/dwarf/line_test.go',
      '/usr/local/go/src/debug/dwarf/open.go',
      '/usr/local/go/src/debug/dwarf/testdata',
      '/usr/local/go/src/debug/dwarf/testdata/cycle.c',
      '/usr/local/go/src/debug/dwarf/testdata/cycle.elf',
      '/usr/local/go/src/debug/dwarf/testdata/line1.c',
      '/usr/local/go/src/debug/dwarf/testdata/line1.h',
      '/usr/local/go/src/debug/dwarf/testdata/line2.c',
      '/usr/local/go/src/debug/dwarf/testdata/line-clang.elf',
      '/usr/local/go/src/debug/dwarf/testdata/line-gcc.elf',
      '/usr/local/go/src/debug/dwarf/testdata/line-gcc-win.bin',
      '/usr/local/go/src/debug/dwarf/testdata/ranges.c',
      '/usr/local/go/src/debug/dwarf/testdata/ranges.elf',
      '/usr/local/go/src/debug/dwarf/testdata/split.c',
      '/usr/local/go/src/debug/dwarf/testdata/split.elf',
      '/usr/local/go/src/debug/dwarf/testdata/typedef.c',
      '/usr/local/go/src/debug/dwarf/testdata/typedef.elf',
      '/usr/local/go/src/debug/dwarf/testdata/typedef.elf4',
      '/usr/local/go/src/debug/dwarf/testdata/typedef.macho',
      '/usr/local/go/src/debug/dwarf/type.go',
      '/usr/local/go/src/debug/dwarf/type_test.go',
      '/usr/local/go/src/debug/dwarf/typeunit.go',
      '/usr/local/go/src/debug/dwarf/unit.go',
      '/usr/local/go/src/debug/elf',
      '/usr/local/go/src/debug/elf/elf.go',
      '/usr/local/go/src/debug/elf/elf_test.go',
      '/usr/local/go/src/debug/elf/file.go',
      '/usr/local/go/src/debug/elf/file_test.go',
      '/usr/local/go/src/debug/elf/reader.go',
      '/usr/local/go/src/debug/elf/symbols_test.go',
      '/usr/local/go/src/debug/elf/testdata',
      '/usr/local/go/src/debug/elf/testdata/compressed-32.obj',
      '/usr/local/go/src/debug/elf/testdata/compressed-64.obj',
      '/usr/local/go/src/debug/elf/testdata/gcc-386-freebsd-exec',
      '/usr/local/go/src/debug/elf/testdata/gcc-amd64-linux-exec',
      '/usr/local/go/src/debug/elf/testdata/gcc-amd64-openbsd-debug-with-rela.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-clang-arm.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-clang-x86.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc424-x86-64.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc441-x86-64.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc441-x86.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc482-aarch64.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc482-ppc64le.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc492-arm.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc492-mips64.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc492-mipsle.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc493-mips64le.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc531-s390x.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc540-mips.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc5-ppc.obj',
      '/usr/local/go/src/debug/elf/testdata/go-relocation-test-gcc620-sparc64.obj',
      '/usr/local/go/src/debug/elf/testdata/hello.c',
      '/usr/local/go/src/debug/elf/testdata/hello-world-core.gz',
      '/usr/local/go/src/debug/elf/testdata/zdebug-test-gcc484-x86-64.obj',
      '/usr/local/go/src/debug/gosym',
      '/usr/local/go/src/debug/gosym/pclinetest.asm',
      '/usr/local/go/src/debug/gosym/pclinetest.h',
      '/usr/local/go/src/debug/gosym/pclntab.go',
      '/usr/local/go/src/debug/gosym/pclntab_test.go',
      '/usr/local/go/src/debug/gosym/symtab.go',
      '/usr/local/go/src/debug/gosym/symtab_test.go',
      '/usr/local/go/src/debug/macho',
      '/usr/local/go/src/debug/macho/fat.go',
      '/usr/local/go/src/debug/macho/file.go',
      '/usr/local/go/src/debug/macho/file_test.go',
      '/usr/local/go/src/debug/macho/macho.go',
      '/usr/local/go/src/debug/macho/testdata',
      '/usr/local/go/src/debug/macho/testdata/fat-gcc-386-amd64-darwin-exec',
      '/usr/local/go/src/debug/macho/testdata/gcc-386-darwin-exec',
      '/usr/local/go/src/debug/macho/testdata/gcc-amd64-darwin-exec',
      '/usr/local/go/src/debug/macho/testdata/gcc-amd64-darwin-exec-debug',
      '/usr/local/go/src/debug/macho/testdata/hello.c',
      '/usr/local/go/src/debug/pe',
      '/usr/local/go/src/debug/pe/file_cgo_test.go',
      '/usr/local/go/src/debug/pe/file.go',
      '/usr/local/go/src/debug/pe/file_test.go',
      '/usr/local/go/src/debug/pe/pe.go',
      '/usr/local/go/src/debug/pe/section.go',
      '/usr/local/go/src/debug/pe/string.go',
      '/usr/local/go/src/debug/pe/symbol.go',
      '/usr/local/go/src/debug/pe/testdata',
      '/usr/local/go/src/debug/pe/testdata/gcc-386-mingw-exec',
      '/usr/local/go/src/debug/pe/testdata/gcc-386-mingw-no-symbols-exec',
      '/usr/local/go/src/debug/pe/testdata/gcc-386-mingw-obj',
      '/usr/local/go/src/debug/pe/testdata/gcc-amd64-mingw-exec',
      '/usr/local/go/src/debug/pe/testdata/gcc-amd64-mingw-obj',
      '/usr/local/go/src/debug/pe/testdata/hello.c',
      '/usr/local/go/src/debug/plan9obj',
      '/usr/local/go/src/debug/plan9obj/file.go',
      '/usr/local/go/src/debug/plan9obj/file_test.go',
      '/usr/local/go/src/debug/plan9obj/plan9obj.go',
      '/usr/local/go/src/debug/plan9obj/testdata',
      '/usr/local/go/src/debug/plan9obj/testdata/386-plan9-exec',
      '/usr/local/go/src/debug/plan9obj/testdata/amd64-plan9-exec',
      '/usr/local/go/src/debug/plan9obj/testdata/hello.c',
      '/usr/local/go/src/encoding',
      '/usr/local/go/src/encoding/ascii85',
      '/usr/local/go/src/encoding/ascii85/ascii85.go',
      '/usr/local/go/src/encoding/ascii85/ascii85_test.go',
      '/usr/local/go/src/encoding/asn1',
      '/usr/local/go/src/encoding/asn1/asn1.go',
      '/usr/local/go/src/encoding/asn1/asn1_test.go',
      '/usr/local/go/src/encoding/asn1/common.go',
      '/usr/local/go/src/encoding/asn1/marshal.go',
      '/usr/local/go/src/encoding/asn1/marshal_test.go',
      '/usr/local/go/src/encoding/base32',
      '/usr/local/go/src/encoding/base32/base32.go',
      '/usr/local/go/src/encoding/base32/base32_test.go',
      '/usr/local/go/src/encoding/base32/example_test.go',
      '/usr/local/go/src/encoding/base64',
      '/usr/local/go/src/encoding/base64/base64.go',
      '/usr/local/go/src/encoding/base64/base64_test.go',
      '/usr/local/go/src/encoding/base64/example_test.go',
      '/usr/local/go/src/encoding/binary',
      '/usr/local/go/src/encoding/binary/binary.go',
      '/usr/local/go/src/encoding/binary/binary_test.go',
      '/usr/local/go/src/encoding/binary/example_test.go',
      '/usr/local/go/src/encoding/binary/varint.go',
      '/usr/local/go/src/encoding/binary/varint_test.go',
      '/usr/local/go/src/encoding/csv',
      '/usr/local/go/src/encoding/csv/example_test.go',
      '/usr/local/go/src/encoding/csv/reader.go',
      '/usr/local/go/src/encoding/csv/reader_test.go',
      '/usr/local/go/src/encoding/csv/writer.go',
      '/usr/local/go/src/encoding/csv/writer_test.go',
      '/usr/local/go/src/encoding/encoding.go',
      '/usr/local/go/src/encoding/gob',
      '/usr/local/go/src/encoding/gob/codec_test.go',
      '/usr/local/go/src/encoding/gob/debug.go',
      '/usr/local/go/src/encoding/gob/decgen.go',
      '/usr/local/go/src/encoding/gob/dec_helpers.go',
      '/usr/local/go/src/encoding/gob/decode.go',
      '/usr/local/go/src/encoding/gob/decoder.go',
      '/usr/local/go/src/encoding/gob/doc.go',
      '/usr/local/go/src/encoding/gob/dump.go',
      '/usr/local/go/src/encoding/gob/encgen.go',
      '/usr/local/go/src/encoding/gob/enc_helpers.go',
      '/usr/local/go/src/encoding/gob/encode.go',
      '/usr/local/go/src/encoding/gob/encoder.go',
      '/usr/local/go/src/encoding/gob/encoder_test.go',
      '/usr/local/go/src/encoding/gob/error.go',
      '/usr/local/go/src/encoding/gob/example_encdec_test.go',
      '/usr/local/go/src/encoding/gob/example_interface_test.go',
      '/usr/local/go/src/encoding/gob/example_test.go',
      '/usr/local/go/src/encoding/gob/gobencdec_test.go',
      '/usr/local/go/src/encoding/gob/timing_test.go',
      '/usr/local/go/src/encoding/gob/type.go',
      '/usr/local/go/src/encoding/gob/type_test.go',
      '/usr/local/go/src/encoding/hex',
      '/usr/local/go/src/encoding/hex/example_test.go',
      '/usr/local/go/src/encoding/hex/hex.go',
      '/usr/local/go/src/encoding/hex/hex_test.go',
      '/usr/local/go/src/encoding/json',
      '/usr/local/go/src/encoding/json/bench_test.go',
      '/usr/local/go/src/encoding/json/decode.go',
      '/usr/local/go/src/encoding/json/decode_test.go',
      '/usr/local/go/src/encoding/json/encode.go',
      '/usr/local/go/src/encoding/json/encode_test.go',
      '/usr/local/go/src/encoding/json/example_marshaling_test.go',
      '/usr/local/go/src/encoding/json/example_test.go',
      '/usr/local/go/src/encoding/json/fold.go',
      '/usr/local/go/src/encoding/json/fold_test.go',
      '/usr/local/go/src/encoding/json/indent.go',
      '/usr/local/go/src/encoding/json/number_test.go',
      '/usr/local/go/src/encoding/json/scanner.go',
      '/usr/local/go/src/encoding/json/scanner_test.go',
      '/usr/local/go/src/encoding/json/stream.go',
      '/usr/local/go/src/encoding/json/stream_test.go',
      '/usr/local/go/src/encoding/json/tables.go',
      '/usr/local/go/src/encoding/json/tagkey_test.go',
      '/usr/local/go/src/encoding/json/tags.go',
      '/usr/local/go/src/encoding/json/tags_test.go',
      '/usr/local/go/src/encoding/json/testdata',
      '/usr/local/go/src/encoding/json/testdata/code.json.gz',
      '/usr/local/go/src/encoding/pem',
      '/usr/local/go/src/encoding/pem/example_test.go',
      '/usr/local/go/src/encoding/pem/pem.go',
      '/usr/local/go/src/encoding/pem/pem_test.go',
      '/usr/local/go/src/encoding/xml',
      '/usr/local/go/src/encoding/xml/atom_test.go',
      '/usr/local/go/src/encoding/xml/example_test.go',
      '/usr/local/go/src/encoding/xml/marshal.go',
      '/usr/local/go/src/encoding/xml/marshal_test.go',
      '/usr/local/go/src/encoding/xml/read.go',
      '/usr/local/go/src/encoding/xml/read_test.go',
      '/usr/local/go/src/encoding/xml/typeinfo.go',
      '/usr/local/go/src/encoding/xml/xml.go',
      '/usr/local/go/src/encoding/xml/xml_test.go',
      '/usr/local/go/src/errors',
      '/usr/local/go/src/errors/errors.go',
      '/usr/local/go/src/errors/errors_test.go',
      '/usr/local/go/src/errors/example_test.go',
      '/usr/local/go/src/expvar',
      '/usr/local/go/src/expvar/expvar.go',
      '/usr/local/go/src/expvar/expvar_test.go',
      '/usr/local/go/src/flag',
      '/usr/local/go/src/flag/example_test.go',
      '/usr/local/go/src/flag/export_test.go',
      '/usr/local/go/src/flag/flag.go',
      '/usr/local/go/src/flag/flag_test.go',
      '/usr/local/go/src/fmt',
      '/usr/local/go/src/fmt/doc.go',
      '/usr/local/go/src/fmt/export_test.go',
      '/usr/local/go/src/fmt/fmt_test.go',
      '/usr/local/go/src/fmt/format.go',
      '/usr/local/go/src/fmt/print.go',
      '/usr/local/go/src/fmt/scan.go',
      '/usr/local/go/src/fmt/scan_test.go',
      '/usr/local/go/src/fmt/stringer_test.go',
      '/usr/local/go/src/go',
      '/usr/local/go/src/go/ast',
      '/usr/local/go/src/go/ast/ast.go',
      '/usr/local/go/src/go/ast/ast_test.go',
      '/usr/local/go/src/go/ast/commentmap.go',
      '/usr/local/go/src/go/ast/commentmap_test.go',
      '/usr/local/go/src/go/ast/example_test.go',
      '/usr/local/go/src/go/ast/filter.go',
      '/usr/local/go/src/go/ast/filter_test.go',
      '/usr/local/go/src/go/ast/import.go',
      '/usr/local/go/src/go/ast/print.go',
      '/usr/local/go/src/go/ast/print_test.go',
      '/usr/local/go/src/go/ast/resolve.go',
      '/usr/local/go/src/go/ast/scope.go',
      '/usr/local/go/src/go/ast/walk.go',
      '/usr/local/go/src/go/build',
      '/usr/local/go/src/go/build/build.go',
      '/usr/local/go/src/go/build/build_test.go',
      '/usr/local/go/src/go/build/deps_test.go',
      '/usr/local/go/src/go/build/doc.go',
      '/usr/local/go/src/go/build/read.go',
      '/usr/local/go/src/go/build/read_test.go',
      '/usr/local/go/src/go/build/syslist.go',
      '/usr/local/go/src/go/build/syslist_test.go',
      '/usr/local/go/src/go/build/testdata',
      '/usr/local/go/src/go/build/testdata/empty',
      '/usr/local/go/src/go/build/testdata/empty/dummy',
      '/usr/local/go/src/go/build/testdata/multi',
      '/usr/local/go/src/go/build/testdata/multi/file_appengine.go',
      '/usr/local/go/src/go/build/testdata/multi/file.go',
      '/usr/local/go/src/go/build/testdata/other',
      '/usr/local/go/src/go/build/testdata/other/file',
      '/usr/local/go/src/go/build/testdata/other/file/file.go',
      '/usr/local/go/src/go/build/testdata/other/main.go',
      '/usr/local/go/src/go/build/zcgo.go',
      '/usr/local/go/src/go/constant',
      '/usr/local/go/src/go/constant/value.go',
      '/usr/local/go/src/go/constant/value_test.go',
      '/usr/local/go/src/go/doc',
      '/usr/local/go/src/go/doc/comment.go',
      '/usr/local/go/src/go/doc/comment_test.go',
      '/usr/local/go/src/go/doc/doc.go',
      '/usr/local/go/src/go/doc/doc_test.go',
      '/usr/local/go/src/go/doc/example.go',
      '/usr/local/go/src/go/doc/example_test.go',
      '/usr/local/go/src/go/doc/exports.go',
      '/usr/local/go/src/go/doc/filter.go',
      '/usr/local/go/src/go/doc/headscan.go',
      '/usr/local/go/src/go/doc/Makefile',
      '/usr/local/go/src/go/doc/reader.go',
      '/usr/local/go/src/go/doc/synopsis.go',
      '/usr/local/go/src/go/doc/synopsis_test.go',
      '/usr/local/go/src/go/doc/testdata',
      '/usr/local/go/src/go/doc/testdata/a0.go',
      '/usr/local/go/src/go/doc/testdata/a.0.golden',
      '/usr/local/go/src/go/doc/testdata/a1.go',
      '/usr/local/go/src/go/doc/testdata/a.1.golden',
      '/usr/local/go/src/go/doc/testdata/a.2.golden',
      '/usr/local/go/src/go/doc/testdata/b.0.golden',
      '/usr/local/go/src/go/doc/testdata/b.1.golden',
      '/usr/local/go/src/go/doc/testdata/b.2.golden',
      '/usr/local/go/src/go/doc/testdata/benchmark.go',
      '/usr/local/go/src/go/doc/testdata/b.go',
      '/usr/local/go/src/go/doc/testdata/blank.0.golden',
      '/usr/local/go/src/go/doc/testdata/blank.1.golden',
      '/usr/local/go/src/go/doc/testdata/blank.2.golden',
      '/usr/local/go/src/go/doc/testdata/blank.go',
      '/usr/local/go/src/go/doc/testdata/bugpara.0.golden',
      '/usr/local/go/src/go/doc/testdata/bugpara.1.golden',
      '/usr/local/go/src/go/doc/testdata/bugpara.2.golden',
      '/usr/local/go/src/go/doc/testdata/bugpara.go',
      '/usr/local/go/src/go/doc/testdata/c.0.golden',
      '/usr/local/go/src/go/doc/testdata/c.1.golden',
      '/usr/local/go/src/go/doc/testdata/c.2.golden',
      '/usr/local/go/src/go/doc/testdata/c.go',
      '/usr/local/go/src/go/doc/testdata/d.0.golden',
      '/usr/local/go/src/go/doc/testdata/d1.go',
      '/usr/local/go/src/go/doc/testdata/d.1.golden',
      '/usr/local/go/src/go/doc/testdata/d2.go',
      '/usr/local/go/src/go/doc/testdata/d.2.golden',
      '/usr/local/go/src/go/doc/testdata/e.0.golden',
      '/usr/local/go/src/go/doc/testdata/e.1.golden',
      '/usr/local/go/src/go/doc/testdata/e.2.golden',
      '/usr/local/go/src/go/doc/testdata/e.go',
      '/usr/local/go/src/go/doc/testdata/error1.0.golden',
      '/usr/local/go/src/go/doc/testdata/error1.1.golden',
      '/usr/local/go/src/go/doc/testdata/error1.2.golden',
      '/usr/local/go/src/go/doc/testdata/error1.go',
      '/usr/local/go/src/go/doc/testdata/error2.0.golden',
      '/usr/local/go/src/go/doc/testdata/error2.1.golden',
      '/usr/local/go/src/go/doc/testdata/error2.2.golden',
      '/usr/local/go/src/go/doc/testdata/error2.go',
      '/usr/local/go/src/go/doc/testdata/example.go',
      '/usr/local/go/src/go/doc/testdata/f.0.golden',
      '/usr/local/go/src/go/doc/testdata/f.1.golden',
      '/usr/local/go/src/go/doc/testdata/f.2.golden',
      '/usr/local/go/src/go/doc/testdata/f.go',
      '/usr/local/go/src/go/doc/testdata/issue13742.0.golden',
      '/usr/local/go/src/go/doc/testdata/issue13742.1.golden',
      '/usr/local/go/src/go/doc/testdata/issue13742.2.golden',
      '/usr/local/go/src/go/doc/testdata/issue13742.go',
      '/usr/local/go/src/go/doc/testdata/issue17788.0.golden',
      '/usr/local/go/src/go/doc/testdata/issue17788.1.golden',
      '/usr/local/go/src/go/doc/testdata/issue17788.2.golden',
      '/usr/local/go/src/go/doc/testdata/issue17788.go',
      '/usr/local/go/src/go/doc/testdata/predeclared.0.golden',
      '/usr/local/go/src/go/doc/testdata/predeclared.1.golden',
      '/usr/local/go/src/go/doc/testdata/predeclared.2.golden',
      '/usr/local/go/src/go/doc/testdata/predeclared.go',
      '/usr/local/go/src/go/doc/testdata/template.txt',
      '/usr/local/go/src/go/doc/testdata/testing.0.golden',
      '/usr/local/go/src/go/doc/testdata/testing.1.golden',
      '/usr/local/go/src/go/doc/testdata/testing.2.golden',
      '/usr/local/go/src/go/doc/testdata/testing.go',
      '/usr/local/go/src/go/format',
      '/usr/local/go/src/go/format/format.go',
      '/usr/local/go/src/go/format/format_test.go',
      '/usr/local/go/src/go/format/internal.go',
      '/usr/local/go/src/go/importer',
      '/usr/local/go/src/go/importer/importer.go',
      '/usr/local/go/src/go/internal',
      '/usr/local/go/src/go/internal/gccgoimporter',
      '/usr/local/go/src/go/internal/gccgoimporter/gccgoinstallation.go',
      '/usr/local/go/src/go/internal/gccgoimporter/gccgoinstallation_test.go',
      '/usr/local/go/src/go/internal/gccgoimporter/importer.go',
      '/usr/local/go/src/go/internal/gccgoimporter/importer_test.go',
      '/usr/local/go/src/go/internal/gccgoimporter/parser.go',
      '/usr/local/go/src/go/internal/gccgoimporter/parser_test.go',
      '/usr/local/go/src/go/internal/gccgoimporter/testdata',
      '/usr/local/go/src/go/internal/gccgoimporter/testdata/alias.gox',
      '/usr/local/go/src/go/internal/gccgoimporter/testdata/complexnums.go',
      '/usr/local/go/src/go/internal/gccgoimporter/testdata/complexnums.gox',
      '/usr/local/go/src/go/internal/gccgoimporter/testdata/conversions.go',
      '/usr/local/go/src/go/internal/gccgoimporter/testdata/conversions.gox',
      '/usr/local/go/src/go/internal/gccgoimporter/testdata/imports.go',
      '/usr/local/go/src/go/internal/gccgoimporter/testdata/imports.gox',
      '/usr/local/go/src/go/internal/gccgoimporter/testdata/pointer.go',
      '/usr/local/go/src/go/internal/gccgoimporter/testdata/pointer.gox',
      '/usr/local/go/src/go/internal/gccgoimporter/testdata/time.gox',
      '/usr/local/go/src/go/internal/gccgoimporter/testdata/unicode.gox',
      '/usr/local/go/src/go/internal/gcimporter',
      '/usr/local/go/src/go/internal/gcimporter/bimport.go',
      '/usr/local/go/src/go/internal/gcimporter/exportdata.go',
      '/usr/local/go/src/go/internal/gcimporter/gcimporter.go',
      '/usr/local/go/src/go/internal/gcimporter/gcimporter_test.go',
      '/usr/local/go/src/go/internal/gcimporter/testdata',
      '/usr/local/go/src/go/internal/gcimporter/testdata/a.go',
      '/usr/local/go/src/go/internal/gcimporter/testdata/b.go',
      '/usr/local/go/src/go/internal/gcimporter/testdata/exports.go',
      '/usr/local/go/src/go/internal/gcimporter/testdata/issue15920.go',
      '/usr/local/go/src/go/internal/gcimporter/testdata/issue20046.go',
      '/usr/local/go/src/go/internal/gcimporter/testdata/p.go',
      '/usr/local/go/src/go/internal/gcimporter/testdata/versions',
      '/usr/local/go/src/go/internal/gcimporter/testdata/versions/test.go',
      '/usr/local/go/src/go/internal/gcimporter/testdata/versions/test_go1.7_0.a',
      '/usr/local/go/src/go/internal/gcimporter/testdata/versions/test_go1.7_1.a',
      '/usr/local/go/src/go/internal/gcimporter/testdata/versions/test_go1.8_4.a',
      '/usr/local/go/src/go/internal/gcimporter/testdata/versions/test_go1.8_5.a',
      '/usr/local/go/src/go/internal/srcimporter',
      '/usr/local/go/src/go/internal/srcimporter/srcimporter.go',
      '/usr/local/go/src/go/internal/srcimporter/srcimporter_test.go',
      '/usr/local/go/src/go/parser',
      '/usr/local/go/src/go/parser/error_test.go',
      '/usr/local/go/src/go/parser/example_test.go',
      '/usr/local/go/src/go/parser/interface.go',
      '/usr/local/go/src/go/parser/parser.go',
      '/usr/local/go/src/go/parser/parser_test.go',
      '/usr/local/go/src/go/parser/performance_test.go',
      '/usr/local/go/src/go/parser/short_test.go',
      '/usr/local/go/src/go/parser/testdata',
      '/usr/local/go/src/go/parser/testdata/commas.src',
      '/usr/local/go/src/go/parser/testdata/issue3106.src',
      '/usr/local/go/src/go/printer',
      '/usr/local/go/src/go/printer/example_test.go',
      '/usr/local/go/src/go/printer/nodes.go',
      '/usr/local/go/src/go/printer/performance_test.go',
      '/usr/local/go/src/go/printer/printer.go',
      '/usr/local/go/src/go/printer/printer_test.go',
      '/usr/local/go/src/go/printer/testdata',
      '/usr/local/go/src/go/printer/testdata/comments2.golden',
      '/usr/local/go/src/go/printer/testdata/comments2.input',
      '/usr/local/go/src/go/printer/testdata/comments.golden',
      '/usr/local/go/src/go/printer/testdata/comments.input',
      '/usr/local/go/src/go/printer/testdata/comments.x',
      '/usr/local/go/src/go/printer/testdata/declarations.golden',
      '/usr/local/go/src/go/printer/testdata/declarations.input',
      '/usr/local/go/src/go/printer/testdata/empty.golden',
      '/usr/local/go/src/go/printer/testdata/empty.input',
      '/usr/local/go/src/go/printer/testdata/expressions.golden',
      '/usr/local/go/src/go/printer/testdata/expressions.input',
      '/usr/local/go/src/go/printer/testdata/expressions.raw',
      '/usr/local/go/src/go/printer/testdata/linebreaks.golden',
      '/usr/local/go/src/go/printer/testdata/linebreaks.input',
      '/usr/local/go/src/go/printer/testdata/parser.go',
      '/usr/local/go/src/go/printer/testdata/slow.golden',
      '/usr/local/go/src/go/printer/testdata/slow.input',
      '/usr/local/go/src/go/printer/testdata/statements.golden',
      '/usr/local/go/src/go/printer/testdata/statements.input',
      '/usr/local/go/src/go/scanner',
      '/usr/local/go/src/go/scanner/errors.go',
      '/usr/local/go/src/go/scanner/example_test.go',
      '/usr/local/go/src/go/scanner/scanner.go',
      '/usr/local/go/src/go/scanner/scanner_test.go',
      '/usr/local/go/src/go/token',
      '/usr/local/go/src/go/token/position.go',
      '/usr/local/go/src/go/token/position_test.go',
      '/usr/local/go/src/go/token/serialize.go',
      '/usr/local/go/src/go/token/serialize_test.go',
      '/usr/local/go/src/go/token/token.go',
      '/usr/local/go/src/go/types',
      '/usr/local/go/src/go/types/api.go',
      '/usr/local/go/src/go/types/api_test.go',
      '/usr/local/go/src/go/types/assignments.go',
      '/usr/local/go/src/go/types/builtins.go',
      '/usr/local/go/src/go/types/builtins_test.go',
      '/usr/local/go/src/go/types/call.go',
      '/usr/local/go/src/go/types/check.go',
      '/usr/local/go/src/go/types/check_test.go',
      '/usr/local/go/src/go/types/conversions.go',
      '/usr/local/go/src/go/types/decl.go',
      '/usr/local/go/src/go/types/errors.go',
      '/usr/local/go/src/go/types/eval.go',
      '/usr/local/go/src/go/types/eval_test.go',
      '/usr/local/go/src/go/types/example_test.go',
      '/usr/local/go/src/go/types/expr.go',
      '/usr/local/go/src/go/types/exprstring.go',
      '/usr/local/go/src/go/types/exprstring_test.go',
      '/usr/local/go/src/go/types/gotype.go',
      '/usr/local/go/src/go/types/hilbert_test.go',
      '/usr/local/go/src/go/types/initorder.go',
      '/usr/local/go/src/go/types/issues_test.go',
      '/usr/local/go/src/go/types/labels.go',
      '/usr/local/go/src/go/types/lookup.go',
      '/usr/local/go/src/go/types/methodset.go',
      '/usr/local/go/src/go/types/object.go',
      '/usr/local/go/src/go/types/object_test.go',
      '/usr/local/go/src/go/types/objset.go',
      '/usr/local/go/src/go/types/operand.go',
      '/usr/local/go/src/go/types/ordering.go',
      '/usr/local/go/src/go/types/package.go',
      '/usr/local/go/src/go/types/predicates.go',
      '/usr/local/go/src/go/types/resolver.go',
      '/usr/local/go/src/go/types/resolver_test.go',
      '/usr/local/go/src/go/types/return.go',
      '/usr/local/go/src/go/types/scope.go',
      '/usr/local/go/src/go/types/selection.go',
      '/usr/local/go/src/go/types/self_test.go',
      '/usr/local/go/src/go/types/sizes.go',
      '/usr/local/go/src/go/types/sizes_test.go',
      '/usr/local/go/src/go/types/stdlib_test.go',
      '/usr/local/go/src/go/types/stmt.go',
      '/usr/local/go/src/go/types/testdata',
      '/usr/local/go/src/go/types/testdata/blank.src',
      '/usr/local/go/src/go/types/testdata/builtins.src',
      '/usr/local/go/src/go/types/testdata/const0.src',
      '/usr/local/go/src/go/types/testdata/const1.src',
      '/usr/local/go/src/go/types/testdata/constdecl.src',
      '/usr/local/go/src/go/types/testdata/conversions2.src',
      '/usr/local/go/src/go/types/testdata/conversions.src',
      '/usr/local/go/src/go/types/testdata/cycles1.src',
      '/usr/local/go/src/go/types/testdata/cycles2.src',
      '/usr/local/go/src/go/types/testdata/cycles3.src',
      '/usr/local/go/src/go/types/testdata/cycles4.src',
      '/usr/local/go/src/go/types/testdata/cycles.src',
      '/usr/local/go/src/go/types/testdata/decls0.src',
      '/usr/local/go/src/go/types/testdata/decls1.src',
      '/usr/local/go/src/go/types/testdata/decls2a.src',
      '/usr/local/go/src/go/types/testdata/decls2b.src',
      '/usr/local/go/src/go/types/testdata/decls3.src',
      '/usr/local/go/src/go/types/testdata/decls4.src',
      '/usr/local/go/src/go/types/testdata/errors.src',
      '/usr/local/go/src/go/types/testdata/expr0.src',
      '/usr/local/go/src/go/types/testdata/expr1.src',
      '/usr/local/go/src/go/types/testdata/expr2.src',
      '/usr/local/go/src/go/types/testdata/expr3.src',
      '/usr/local/go/src/go/types/testdata/gotos.src',
      '/usr/local/go/src/go/types/testdata/importC.src',
      '/usr/local/go/src/go/types/testdata/importdecl0a.src',
      '/usr/local/go/src/go/types/testdata/importdecl0b.src',
      '/usr/local/go/src/go/types/testdata/importdecl1a.src',
      '/usr/local/go/src/go/types/testdata/importdecl1b.src',
      '/usr/local/go/src/go/types/testdata/init0.src',
      '/usr/local/go/src/go/types/testdata/init1.src',
      '/usr/local/go/src/go/types/testdata/init2.src',
      '/usr/local/go/src/go/types/testdata/issues.src',
      '/usr/local/go/src/go/types/testdata/labels.src',
      '/usr/local/go/src/go/types/testdata/methodsets.src',
      '/usr/local/go/src/go/types/testdata/shifts.src',
      '/usr/local/go/src/go/types/testdata/stmt0.src',
      '/usr/local/go/src/go/types/testdata/stmt1.src',
      '/usr/local/go/src/go/types/testdata/vardecl.src',
      '/usr/local/go/src/go/types/token_test.go',
      '/usr/local/go/src/go/types/type.go',
      '/usr/local/go/src/go/types/typestring.go',
      '/usr/local/go/src/go/types/typestring_test.go',
      '/usr/local/go/src/go/types/typexpr.go',
      '/usr/local/go/src/go/types/universe.go',
      '/usr/local/go/src/hash',
      '/usr/local/go/src/hash/adler32',
      '/usr/local/go/src/hash/adler32/adler32.go',
      '/usr/local/go/src/hash/adler32/adler32_test.go',
      '/usr/local/go/src/hash/crc32',
      '/usr/local/go/src/hash/crc32/crc32_amd64.go',
      '/usr/local/go/src/hash/crc32/crc32_amd64p32.go',
      '/usr/local/go/src/hash/crc32/crc32_amd64p32.s',
      '/usr/local/go/src/hash/crc32/crc32_amd64.s',
      '/usr/local/go/src/hash/crc32/crc32_arm64.go',
      '/usr/local/go/src/hash/crc32/crc32_arm64.s',
      '/usr/local/go/src/hash/crc32/crc32_generic.go',
      '/usr/local/go/src/hash/crc32/crc32.go',
      '/usr/local/go/src/hash/crc32/crc32_otherarch.go',
      '/usr/local/go/src/hash/crc32/crc32_ppc64le.go',
      '/usr/local/go/src/hash/crc32/crc32_ppc64le.s',
      '/usr/local/go/src/hash/crc32/crc32_s390x.go',
      '/usr/local/go/src/hash/crc32/crc32_s390x.s',
      '/usr/local/go/src/hash/crc32/crc32_table_ppc64le.s',
      '/usr/local/go/src/hash/crc32/crc32_test.go',
      '/usr/local/go/src/hash/crc32/example_test.go',
      '/usr/local/go/src/hash/crc32/gen_const_ppc64le.go',
      '/usr/local/go/src/hash/crc64',
      '/usr/local/go/src/hash/crc64/crc64.go',
      '/usr/local/go/src/hash/crc64/crc64_test.go',
      '/usr/local/go/src/hash/fnv',
      '/usr/local/go/src/hash/fnv/fnv.go',
      '/usr/local/go/src/hash/fnv/fnv_test.go',
      '/usr/local/go/src/hash/hash.go',
      '/usr/local/go/src/hash/test_cases.txt',
      '/usr/local/go/src/hash/test_gen.awk',
      '/usr/local/go/src/html',
      '/usr/local/go/src/html/entity.go',
      '/usr/local/go/src/html/entity_test.go',
      '/usr/local/go/src/html/escape.go',
      '/usr/local/go/src/html/escape_test.go',
      '/usr/local/go/src/html/example_test.go',
      '/usr/local/go/src/html/template',
      '/usr/local/go/src/html/template/attr.go',
      '/usr/local/go/src/html/template/clone_test.go',
      '/usr/local/go/src/html/template/content.go',
      '/usr/local/go/src/html/template/content_test.go',
      '/usr/local/go/src/html/template/context.go',
      '/usr/local/go/src/html/template/css.go',
      '/usr/local/go/src/html/template/css_test.go',
      '/usr/local/go/src/html/template/doc.go',
      '/usr/local/go/src/html/template/error.go',
      '/usr/local/go/src/html/template/escape.go',
      '/usr/local/go/src/html/template/escape_test.go',
      '/usr/local/go/src/html/template/examplefiles_test.go',
      '/usr/local/go/src/html/template/example_test.go',
      '/usr/local/go/src/html/template/html.go',
      '/usr/local/go/src/html/template/html_test.go',
      '/usr/local/go/src/html/template/js.go',
      '/usr/local/go/src/html/template/js_test.go',
      '/usr/local/go/src/html/template/template.go',
      '/usr/local/go/src/html/template/template_test.go',
      '/usr/local/go/src/html/template/transition.go',
      '/usr/local/go/src/html/template/transition_test.go',
      '/usr/local/go/src/html/template/url.go',
      '/usr/local/go/src/html/template/url_test.go',
      '/usr/local/go/src/image',
      '/usr/local/go/src/image/color',
      '/usr/local/go/src/image/color/color.go',
      '/usr/local/go/src/image/color/palette',
      '/usr/local/go/src/image/color/palette/generate.go',
      '/usr/local/go/src/image/color/palette/gen.go',
      '/usr/local/go/src/image/color/palette/palette.go',
      '/usr/local/go/src/image/color/ycbcr.go',
      '/usr/local/go/src/image/color/ycbcr_test.go',
      '/usr/local/go/src/image/decode_example_test.go',
      '/usr/local/go/src/image/decode_test.go',
      '/usr/local/go/src/image/draw',
      '/usr/local/go/src/image/draw/bench_test.go',
      '/usr/local/go/src/image/draw/clip_test.go',
      '/usr/local/go/src/image/draw/draw.go',
      '/usr/local/go/src/image/draw/draw_test.go',
      '/usr/local/go/src/image/draw/example_test.go',
      '/usr/local/go/src/image/format.go',
      '/usr/local/go/src/image/geom.go',
      '/usr/local/go/src/image/geom_test.go',
      '/usr/local/go/src/image/gif',
      '/usr/local/go/src/image/gif/reader.go',
      '/usr/local/go/src/image/gif/reader_test.go',
      '/usr/local/go/src/image/gif/writer.go',
      '/usr/local/go/src/image/gif/writer_test.go',
      '/usr/local/go/src/image/image.go',
      '/usr/local/go/src/image/image_test.go',
      '/usr/local/go/src/image/internal',
      '/usr/local/go/src/image/internal/imageutil',
      '/usr/local/go/src/image/internal/imageutil/gen.go',
      '/usr/local/go/src/image/internal/imageutil/imageutil.go',
      '/usr/local/go/src/image/internal/imageutil/impl.go',
      '/usr/local/go/src/image/jpeg',
      '/usr/local/go/src/image/jpeg/dct_test.go',
      '/usr/local/go/src/image/jpeg/fdct.go',
      '/usr/local/go/src/image/jpeg/huffman.go',
      '/usr/local/go/src/image/jpeg/idct.go',
      '/usr/local/go/src/image/jpeg/reader.go',
      '/usr/local/go/src/image/jpeg/reader_test.go',
      '/usr/local/go/src/image/jpeg/scan.go',
      '/usr/local/go/src/image/jpeg/writer.go',
      '/usr/local/go/src/image/jpeg/writer_test.go',
      '/usr/local/go/src/image/names.go',
      '/usr/local/go/src/image/png',
      '/usr/local/go/src/image/png/example_test.go',
      '/usr/local/go/src/image/png/paeth.go',
      '/usr/local/go/src/image/png/paeth_test.go',
      '/usr/local/go/src/image/png/reader.go',
      '/usr/local/go/src/image/png/reader_test.go',
      '/usr/local/go/src/image/png/testdata',
      '/usr/local/go/src/image/png/testdata/benchGray.png',
      '/usr/local/go/src/image/png/testdata/benchNRGBA-gradient.png',
      '/usr/local/go/src/image/png/testdata/benchNRGBA-opaque.png',
      '/usr/local/go/src/image/png/testdata/benchPaletted.png',
      '/usr/local/go/src/image/png/testdata/benchRGB-interlace.png',
      '/usr/local/go/src/image/png/testdata/benchRGB.png',
      '/usr/local/go/src/image/png/testdata/gray-gradient.interlaced.png',
      '/usr/local/go/src/image/png/testdata/gray-gradient.png',
      '/usr/local/go/src/image/png/testdata/invalid-crc32.png',
      '/usr/local/go/src/image/png/testdata/invalid-noend.png',
      '/usr/local/go/src/image/png/testdata/invalid-trunc.png',
      '/usr/local/go/src/image/png/testdata/invalid-zlib.png',
      '/usr/local/go/src/image/png/testdata/pngsuite',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g01-30.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g01-30.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g01.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g01.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g02-29.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g02-29.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g02.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g02.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g04-31.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g04-31.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g04.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g04.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g16.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn0g16.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn2c08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn2c08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn2c16.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn2c16.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn3p01.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn3p01.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn3p02.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn3p02.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn3p04-31i.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn3p04-31i.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn3p04.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn3p04.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn3p08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn3p08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn3p08-trns.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn3p08-trns.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn4a08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn4a08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn4a16.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn4a16.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn6a08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn6a08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn6a16.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/basn6a16.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbbn0g01.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbbn0g01.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbbn0g02.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbbn0g02.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbbn0g04.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbbn0g04.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbbn2c16.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbbn2c16.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbbn3p08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbbn3p08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbgn2c16.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbgn2c16.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbgn3p08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbgn3p08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbrn2c08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbrn2c08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbwn0g16.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbwn0g16.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbwn3p08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbwn3p08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbyn3p08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftbyn3p08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftp0n0g08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftp0n0g08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftp0n2c08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftp0n2c08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftp0n3p08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftp0n3p08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftp1n3p08.png',
      '/usr/local/go/src/image/png/testdata/pngsuite/ftp1n3p08.sng',
      '/usr/local/go/src/image/png/testdata/pngsuite/README',
      '/usr/local/go/src/image/png/testdata/pngsuite/README.original',
      '/usr/local/go/src/image/png/writer.go',
      '/usr/local/go/src/image/png/writer_test.go',
      '/usr/local/go/src/image/testdata',
      '/usr/local/go/src/image/testdata/video-001.221212.jpeg',
      '/usr/local/go/src/image/testdata/video-001.221212.png',
      '/usr/local/go/src/image/testdata/video-001.5bpp.gif',
      '/usr/local/go/src/image/testdata/video-001.cmyk.jpeg',
      '/usr/local/go/src/image/testdata/video-001.cmyk.png',
      '/usr/local/go/src/image/testdata/video-001.gif',
      '/usr/local/go/src/image/testdata/video-001.interlaced.gif',
      '/usr/local/go/src/image/testdata/video-001.jpeg',
      '/usr/local/go/src/image/testdata/video-001.png',
      '/usr/local/go/src/image/testdata/video-001.progressive.jpeg',
      '/usr/local/go/src/image/testdata/video-001.progressive.truncated.jpeg',
      '/usr/local/go/src/image/testdata/video-001.progressive.truncated.png',
      '/usr/local/go/src/image/testdata/video-001.q50.410.jpeg',
      '/usr/local/go/src/image/testdata/video-001.q50.410.progressive.jpeg',
      '/usr/local/go/src/image/testdata/video-001.q50.411.jpeg',
      '/usr/local/go/src/image/testdata/video-001.q50.411.progressive.jpeg',
      '/usr/local/go/src/image/testdata/video-001.q50.420.jpeg',
      '/usr/local/go/src/image/testdata/video-001.q50.420.progressive.jpeg',
      '/usr/local/go/src/image/testdata/video-001.q50.422.jpeg',
      '/usr/local/go/src/image/testdata/video-001.q50.422.progressive.jpeg',
      '/usr/local/go/src/image/testdata/video-001.q50.440.jpeg',
      '/usr/local/go/src/image/testdata/video-001.q50.440.progressive.jpeg',
      '/usr/local/go/src/image/testdata/video-001.q50.444.jpeg',
      '/usr/local/go/src/image/testdata/video-001.q50.444.progressive.jpeg',
      '/usr/local/go/src/image/testdata/video-001.rgb.jpeg',
      '/usr/local/go/src/image/testdata/video-001.rgb.png',
      '/usr/local/go/src/image/testdata/video-001.separate.dc.progression.jpeg',
      '/usr/local/go/src/image/testdata/video-001.separate.dc.progression.progressive.jpeg',
      '/usr/local/go/src/image/testdata/video-005.gray.gif',
      '/usr/local/go/src/image/testdata/video-005.gray.jpeg',
      '/usr/local/go/src/image/testdata/video-005.gray.png',
      '/usr/local/go/src/image/testdata/video-005.gray.q50.2x2.jpeg',
      '/usr/local/go/src/image/testdata/video-005.gray.q50.2x2.progressive.jpeg',
      '/usr/local/go/src/image/testdata/video-005.gray.q50.jpeg',
      '/usr/local/go/src/image/testdata/video-005.gray.q50.progressive.jpeg',
      '/usr/local/go/src/image/ycbcr.go',
      '/usr/local/go/src/image/ycbcr_test.go',
      '/usr/local/go/src/index',
      '/usr/local/go/src/index/suffixarray',
      '/usr/local/go/src/index/suffixarray/example_test.go',
      '/usr/local/go/src/index/suffixarray/qsufsort.go',
      '/usr/local/go/src/index/suffixarray/suffixarray.go',
      '/usr/local/go/src/index/suffixarray/suffixarray_test.go',
      '/usr/local/go/src/internal',
      '/usr/local/go/src/internal/cpu',
      '/usr/local/go/src/internal/cpu/cpu_arm64.go',
      '/usr/local/go/src/internal/cpu/cpu_arm.go',
      '/usr/local/go/src/internal/cpu/cpu.go',
      '/usr/local/go/src/internal/cpu/cpu_mips64.go',
      '/usr/local/go/src/internal/cpu/cpu_mips64le.go',
      '/usr/local/go/src/internal/cpu/cpu_mips.go',
      '/usr/local/go/src/internal/cpu/cpu_mipsle.go',
      '/usr/local/go/src/internal/cpu/cpu_ppc64.go',
      '/usr/local/go/src/internal/cpu/cpu_ppc64le.go',
      '/usr/local/go/src/internal/cpu/cpu_s390x.go',
      '/usr/local/go/src/internal/cpu/cpu_test.go',
      '/usr/local/go/src/internal/cpu/cpu_x86.go',
      '/usr/local/go/src/internal/cpu/cpu_x86.s',
      '/usr/local/go/src/internal/nettrace',
      '/usr/local/go/src/internal/nettrace/nettrace.go',
      '/usr/local/go/src/internal/poll',
      '/usr/local/go/src/internal/poll/export_posix_test.go',
      '/usr/local/go/src/internal/poll/export_test.go',
      '/usr/local/go/src/internal/poll/export_windows_test.go',
      '/usr/local/go/src/internal/poll/fd.go',
      '/usr/local/go/src/internal/poll/fd_io_plan9.go',
      '/usr/local/go/src/internal/poll/fd_mutex.go',
      '/usr/local/go/src/internal/poll/fd_mutex_test.go',
      '/usr/local/go/src/internal/poll/fd_plan9.go',
      '/usr/local/go/src/internal/poll/fd_poll_nacl.go',
      '/usr/local/go/src/internal/poll/fd_poll_runtime.go',
      '/usr/local/go/src/internal/poll/fd_posix.go',
      '/usr/local/go/src/internal/poll/fd_posix_test.go',
      '/usr/local/go/src/internal/poll/fd_unix.go',
      '/usr/local/go/src/internal/poll/fd_windows.go',
      '/usr/local/go/src/internal/poll/fd_windows_test.go',
      '/usr/local/go/src/internal/poll/hook_cloexec.go',
      '/usr/local/go/src/internal/poll/hook_unix.go',
      '/usr/local/go/src/internal/poll/hook_windows.go',
      '/usr/local/go/src/internal/poll/sendfile_bsd.go',
      '/usr/local/go/src/internal/poll/sendfile_linux.go',
      '/usr/local/go/src/internal/poll/sendfile_solaris.go',
      '/usr/local/go/src/internal/poll/sendfile_windows.go',
      '/usr/local/go/src/internal/poll/sock_cloexec.go',
      '/usr/local/go/src/internal/poll/sockopt.go',
      '/usr/local/go/src/internal/poll/sockoptip.go',
      '/usr/local/go/src/internal/poll/sockopt_linux.go',
      '/usr/local/go/src/internal/poll/sockopt_unix.go',
      '/usr/local/go/src/internal/poll/sockopt_windows.go',
      '/usr/local/go/src/internal/poll/strconv.go',
      '/usr/local/go/src/internal/poll/sys_cloexec.go',
      '/usr/local/go/src/internal/poll/writev.go',
      '/usr/local/go/src/internal/poll/writev_test.go',
      '/usr/local/go/src/internal/race',
      '/usr/local/go/src/internal/race/doc.go',
      '/usr/local/go/src/internal/race/norace.go',
      '/usr/local/go/src/internal/race/race.go',
      '/usr/local/go/src/internal/singleflight',
      '/usr/local/go/src/internal/singleflight/singleflight.go',
      '/usr/local/go/src/internal/singleflight/singleflight_test.go',
      '/usr/local/go/src/internal/syscall',
      '/usr/local/go/src/internal/syscall/unix',
      '/usr/local/go/src/internal/syscall/unix/getentropy_openbsd.go',
      '/usr/local/go/src/internal/syscall/unix/getrandom_linux_386.go',
      '/usr/local/go/src/internal/syscall/unix/getrandom_linux_amd64.go',
      '/usr/local/go/src/internal/syscall/unix/getrandom_linux_arm.go',
      '/usr/local/go/src/internal/syscall/unix/getrandom_linux_generic.go',
      '/usr/local/go/src/internal/syscall/unix/getrandom_linux.go',
      '/usr/local/go/src/internal/syscall/unix/getrandom_linux_mips64x.go',
      '/usr/local/go/src/internal/syscall/unix/getrandom_linux_mipsx.go',
      '/usr/local/go/src/internal/syscall/unix/getrandom_linux_ppc64x.go',
      '/usr/local/go/src/internal/syscall/unix/getrandom_linux_s390x.go',
      '/usr/local/go/src/internal/syscall/windows',
      '/usr/local/go/src/internal/syscall/windows/mksyscall.go',
      '/usr/local/go/src/internal/syscall/windows/registry',
      '/usr/local/go/src/internal/syscall/windows/registry/export_test.go',
      '/usr/local/go/src/internal/syscall/windows/registry/key.go',
      '/usr/local/go/src/internal/syscall/windows/registry/mksyscall.go',
      '/usr/local/go/src/internal/syscall/windows/registry/registry_test.go',
      '/usr/local/go/src/internal/syscall/windows/registry/syscall.go',
      '/usr/local/go/src/internal/syscall/windows/registry/value.go',
      '/usr/local/go/src/internal/syscall/windows/registry/zsyscall_windows.go',
      '/usr/local/go/src/internal/syscall/windows/reparse_windows.go',
      '/usr/local/go/src/internal/syscall/windows/security_windows.go',
      '/usr/local/go/src/internal/syscall/windows/syscall_windows.go',
      '/usr/local/go/src/internal/syscall/windows/sysdll',
      '/usr/local/go/src/internal/syscall/windows/sysdll/sysdll.go',
      '/usr/local/go/src/internal/syscall/windows/zsyscall_windows.go',
      '/usr/local/go/src/internal/testenv',
      '/usr/local/go/src/internal/testenv/testenv_cgo.go',
      '/usr/local/go/src/internal/testenv/testenv.go',
      '/usr/local/go/src/internal/testenv/testenv_notwin.go',
      '/usr/local/go/src/internal/testenv/testenv_windows.go',
      '/usr/local/go/src/internal/trace',
      '/usr/local/go/src/internal/trace/goroutines.go',
      '/usr/local/go/src/internal/trace/mkcanned.bash',
      '/usr/local/go/src/internal/trace/order.go',
      '/usr/local/go/src/internal/trace/parser.go',
      '/usr/local/go/src/internal/trace/parser_test.go',
      '/usr/local/go/src/internal/trace/testdata',
      '/usr/local/go/src/internal/trace/testdata/http_1_5_good',
      '/usr/local/go/src/internal/trace/testdata/http_1_7_good',
      '/usr/local/go/src/internal/trace/testdata/http_1_9_good',
      '/usr/local/go/src/internal/trace/testdata/stress_1_5_good',
      '/usr/local/go/src/internal/trace/testdata/stress_1_5_unordered',
      '/usr/local/go/src/internal/trace/testdata/stress_1_7_good',
      '/usr/local/go/src/internal/trace/testdata/stress_1_9_good',
      '/usr/local/go/src/internal/trace/testdata/stress_start_stop_1_5_good',
      '/usr/local/go/src/internal/trace/testdata/stress_start_stop_1_7_good',
      '/usr/local/go/src/internal/trace/testdata/stress_start_stop_1_9_good',
      '/usr/local/go/src/internal/trace/writer.go',
      '/usr/local/go/src/io',
      '/usr/local/go/src/io/example_test.go',
      '/usr/local/go/src/io/io.go',
      '/usr/local/go/src/io/io_test.go',
      '/usr/local/go/src/io/ioutil',
      '/usr/local/go/src/io/ioutil/example_test.go',
      '/usr/local/go/src/io/ioutil/ioutil.go',
      '/usr/local/go/src/io/ioutil/ioutil_test.go',
      '/usr/local/go/src/io/ioutil/tempfile.go',
      '/usr/local/go/src/io/ioutil/tempfile_test.go',
      '/usr/local/go/src/io/ioutil/testdata',
      '/usr/local/go/src/io/ioutil/testdata/hello',
      '/usr/local/go/src/io/multi.go',
      '/usr/local/go/src/io/multi_test.go',
      '/usr/local/go/src/io/pipe.go',
      '/usr/local/go/src/io/pipe_test.go',
      '/usr/local/go/src/iostest.bash',
      '/usr/local/go/src/log',
      '/usr/local/go/src/log/example_test.go',
      '/usr/local/go/src/log/log.go',
      '/usr/local/go/src/log/log_test.go',
      '/usr/local/go/src/log/syslog',
      '/usr/local/go/src/log/syslog/doc.go',
      '/usr/local/go/src/log/syslog/example_test.go',
      '/usr/local/go/src/log/syslog/syslog.go',
      '/usr/local/go/src/log/syslog/syslog_test.go',
      '/usr/local/go/src/log/syslog/syslog_unix.go',
      '/usr/local/go/src/make.bash',
      '/usr/local/go/src/make.bat',
      '/usr/local/go/src/Make.dist',
      '/usr/local/go/src/make.rc',
      '/usr/local/go/src/math',
      '/usr/local/go/src/math/abs.go',
      '/usr/local/go/src/math/acosh.go',
      '/usr/local/go/src/math/acosh_s390x.s',
      '/usr/local/go/src/math/acos_s390x.s',
      '/usr/local/go/src/math/all_test.go',
      '/usr/local/go/src/math/arith_s390x.go',
      '/usr/local/go/src/math/arith_s390x_test.go',
      '/usr/local/go/src/math/asin_386.s',
      '/usr/local/go/src/math/asin_amd64p32.s',
      '/usr/local/go/src/math/asin_amd64.s',
      '/usr/local/go/src/math/asin_arm.s',
      '/usr/local/go/src/math/asin.go',
      '/usr/local/go/src/math/asinh.go',
      '/usr/local/go/src/math/asinh_s390x.s',
      '/usr/local/go/src/math/asinh_stub.s',
      '/usr/local/go/src/math/asin_s390x.s',
      '/usr/local/go/src/math/atan2_386.s',
      '/usr/local/go/src/math/atan2_amd64p32.s',
      '/usr/local/go/src/math/atan2_amd64.s',
      '/usr/local/go/src/math/atan2_arm.s',
      '/usr/local/go/src/math/atan2.go',
      '/usr/local/go/src/math/atan2_s390x.s',
      '/usr/local/go/src/math/atan_386.s',
      '/usr/local/go/src/math/atan_amd64p32.s',
      '/usr/local/go/src/math/atan_amd64.s',
      '/usr/local/go/src/math/atan_arm.s',
      '/usr/local/go/src/math/atan.go',
      '/usr/local/go/src/math/atanh.go',
      '/usr/local/go/src/math/atanh_s390x.s',
      '/usr/local/go/src/math/atan_s390x.s',
      '/usr/local/go/src/math/big',
      '/usr/local/go/src/math/big/accuracy_string.go',
      '/usr/local/go/src/math/big/arith_386.s',
      '/usr/local/go/src/math/big/arith_amd64p32.s',
      '/usr/local/go/src/math/big/arith_amd64.s',
      '/usr/local/go/src/math/big/arith_arm64.s',
      '/usr/local/go/src/math/big/arith_arm.s',
      '/usr/local/go/src/math/big/arith_decl.go',
      '/usr/local/go/src/math/big/arith_decl_pure.go',
      '/usr/local/go/src/math/big/arith_decl_s390x.go',
      '/usr/local/go/src/math/big/arith.go',
      '/usr/local/go/src/math/big/arith_mips64x.s',
      '/usr/local/go/src/math/big/arith_mipsx.s',
      '/usr/local/go/src/math/big/arith_ppc64x.s',
      '/usr/local/go/src/math/big/arith_s390x.s',
      '/usr/local/go/src/math/big/arith_s390x_test.go',
      '/usr/local/go/src/math/big/arith_test.go',
      '/usr/local/go/src/math/big/bits_test.go',
      '/usr/local/go/src/math/big/calibrate_test.go',
      '/usr/local/go/src/math/big/decimal.go',
      '/usr/local/go/src/math/big/decimal_test.go',
      '/usr/local/go/src/math/big/doc.go',
      '/usr/local/go/src/math/big/example_rat_test.go',
      '/usr/local/go/src/math/big/example_test.go',
      '/usr/local/go/src/math/big/floatconv.go',
      '/usr/local/go/src/math/big/floatconv_test.go',
      '/usr/local/go/src/math/big/floatexample_test.go',
      '/usr/local/go/src/math/big/float.go',
      '/usr/local/go/src/math/big/floatmarsh.go',
      '/usr/local/go/src/math/big/floatmarsh_test.go',
      '/usr/local/go/src/math/big/float_test.go',
      '/usr/local/go/src/math/big/ftoa.go',
      '/usr/local/go/src/math/big/gcd_test.go',
      '/usr/local/go/src/math/big/hilbert_test.go',
      '/usr/local/go/src/math/big/intconv.go',
      '/usr/local/go/src/math/big/intconv_test.go',
      '/usr/local/go/src/math/big/int.go',
      '/usr/local/go/src/math/big/intmarsh.go',
      '/usr/local/go/src/math/big/intmarsh_test.go',
      '/usr/local/go/src/math/big/int_test.go',
      '/usr/local/go/src/math/big/natconv.go',
      '/usr/local/go/src/math/big/natconv_test.go',
      '/usr/local/go/src/math/big/nat.go',
      '/usr/local/go/src/math/big/nat_test.go',
      '/usr/local/go/src/math/big/prime.go',
      '/usr/local/go/src/math/big/prime_test.go',
      '/usr/local/go/src/math/big/ratconv.go',
      '/usr/local/go/src/math/big/ratconv_test.go',
      '/usr/local/go/src/math/big/rat.go',
      '/usr/local/go/src/math/big/ratmarsh.go',
      '/usr/local/go/src/math/big/ratmarsh_test.go',
      '/usr/local/go/src/math/big/rat_test.go',
      '/usr/local/go/src/math/big/roundingmode_string.go',
      '/usr/local/go/src/math/bits',
      '/usr/local/go/src/math/bits/bits.go',
      '/usr/local/go/src/math/bits/bits_tables.go',
      '/usr/local/go/src/math/bits/bits_test.go',
      '/usr/local/go/src/math/bits/example_test.go',
      '/usr/local/go/src/math/bits/make_tables.go',
      '/usr/local/go/src/math/bits.go',
      '/usr/local/go/src/math/cbrt.go',
      '/usr/local/go/src/math/cbrt_s390x.s',
      '/usr/local/go/src/math/cbrt_stub.s',
      '/usr/local/go/src/math/cmplx',
      '/usr/local/go/src/math/cmplx/abs.go',
      '/usr/local/go/src/math/cmplx/asin.go',
      '/usr/local/go/src/math/cmplx/cmath_test.go',
      '/usr/local/go/src/math/cmplx/conj.go',
      '/usr/local/go/src/math/cmplx/example_test.go',
      '/usr/local/go/src/math/cmplx/exp.go',
      '/usr/local/go/src/math/cmplx/isinf.go',
      '/usr/local/go/src/math/cmplx/isnan.go',
      '/usr/local/go/src/math/cmplx/log.go',
      '/usr/local/go/src/math/cmplx/phase.go',
      '/usr/local/go/src/math/cmplx/polar.go',
      '/usr/local/go/src/math/cmplx/pow.go',
      '/usr/local/go/src/math/cmplx/rect.go',
      '/usr/local/go/src/math/cmplx/sin.go',
      '/usr/local/go/src/math/cmplx/sqrt.go',
      '/usr/local/go/src/math/cmplx/tan.go',
      '/usr/local/go/src/math/const.go',
      '/usr/local/go/src/math/copysign.go',
      '/usr/local/go/src/math/cosh_s390x.s',
      '/usr/local/go/src/math/dim_386.s',
      '/usr/local/go/src/math/dim_amd64p32.s',
      '/usr/local/go/src/math/dim_amd64.s',
      '/usr/local/go/src/math/dim_arm64.s',
      '/usr/local/go/src/math/dim_arm.s',
      '/usr/local/go/src/math/dim.go',
      '/usr/local/go/src/math/dim_s390x.s',
      '/usr/local/go/src/math/erfc_s390x.s',
      '/usr/local/go/src/math/erf.go',
      '/usr/local/go/src/math/erf_s390x.s',
      '/usr/local/go/src/math/erf_stub.s',
      '/usr/local/go/src/math/example_test.go',
      '/usr/local/go/src/math/exp2_386.s',
      '/usr/local/go/src/math/exp2_amd64p32.s',
      '/usr/local/go/src/math/exp2_amd64.s',
      '/usr/local/go/src/math/exp2_arm.s',
      '/usr/local/go/src/math/exp_386.s',
      '/usr/local/go/src/math/exp_amd64p32.s',
      '/usr/local/go/src/math/exp_amd64.s',
      '/usr/local/go/src/math/exp_arm.s',
      '/usr/local/go/src/math/exp.go',
      '/usr/local/go/src/math/expm1_386.s',
      '/usr/local/go/src/math/expm1_amd64p32.s',
      '/usr/local/go/src/math/expm1_amd64.s',
      '/usr/local/go/src/math/expm1_arm.s',
      '/usr/local/go/src/math/expm1.go',
      '/usr/local/go/src/math/expm1_s390x.s',
      '/usr/local/go/src/math/export_s390x_test.go',
      '/usr/local/go/src/math/export_test.go',
      '/usr/local/go/src/math/exp_s390x.s',
      '/usr/local/go/src/math/floor_386.s',
      '/usr/local/go/src/math/floor_amd64p32.s',
      '/usr/local/go/src/math/floor_amd64.s',
      '/usr/local/go/src/math/floor_arm64.s',
      '/usr/local/go/src/math/floor_arm.s',
      '/usr/local/go/src/math/floor_asm.go',
      '/usr/local/go/src/math/floor.go',
      '/usr/local/go/src/math/floor_ppc64x.s',
      '/usr/local/go/src/math/floor_s390x.s',
      '/usr/local/go/src/math/frexp_386.s',
      '/usr/local/go/src/math/frexp_amd64p32.s',
      '/usr/local/go/src/math/frexp_amd64.s',
      '/usr/local/go/src/math/frexp_arm.s',
      '/usr/local/go/src/math/frexp.go',
      '/usr/local/go/src/math/gamma.go',
      '/usr/local/go/src/math/hypot_386.s',
      '/usr/local/go/src/math/hypot_amd64p32.s',
      '/usr/local/go/src/math/hypot_amd64.s',
      '/usr/local/go/src/math/hypot_arm.s',
      '/usr/local/go/src/math/hypot.go',
      '/usr/local/go/src/math/j0.go',
      '/usr/local/go/src/math/j1.go',
      '/usr/local/go/src/math/jn.go',
      '/usr/local/go/src/math/ldexp_386.s',
      '/usr/local/go/src/math/ldexp_amd64p32.s',
      '/usr/local/go/src/math/ldexp_amd64.s',
      '/usr/local/go/src/math/ldexp_arm.s',
      '/usr/local/go/src/math/ldexp.go',
      '/usr/local/go/src/math/lgamma.go',
      '/usr/local/go/src/math/log10_386.s',
      '/usr/local/go/src/math/log10_amd64p32.s',
      '/usr/local/go/src/math/log10_amd64.s',
      '/usr/local/go/src/math/log10_arm.s',
      '/usr/local/go/src/math/log10.go',
      '/usr/local/go/src/math/log10_s390x.s',
      '/usr/local/go/src/math/log1p_386.s',
      '/usr/local/go/src/math/log1p_amd64p32.s',
      '/usr/local/go/src/math/log1p_amd64.s',
      '/usr/local/go/src/math/log1p_arm.s',
      '/usr/local/go/src/math/log1p.go',
      '/usr/local/go/src/math/log1p_s390x.s',
      '/usr/local/go/src/math/log_386.s',
      '/usr/local/go/src/math/log_amd64p32.s',
      '/usr/local/go/src/math/log_amd64.s',
      '/usr/local/go/src/math/log_arm.s',
      '/usr/local/go/src/math/logb.go',
      '/usr/local/go/src/math/log.go',
      '/usr/local/go/src/math/log_s390x.s',
      '/usr/local/go/src/math/mod_386.s',
      '/usr/local/go/src/math/mod_amd64p32.s',
      '/usr/local/go/src/math/mod_amd64.s',
      '/usr/local/go/src/math/mod_arm.s',
      '/usr/local/go/src/math/modf_386.s',
      '/usr/local/go/src/math/modf_amd64p32.s',
      '/usr/local/go/src/math/modf_amd64.s',
      '/usr/local/go/src/math/modf_arm64.s',
      '/usr/local/go/src/math/modf_arm.s',
      '/usr/local/go/src/math/modf.go',
      '/usr/local/go/src/math/mod.go',
      '/usr/local/go/src/math/nextafter.go',
      '/usr/local/go/src/math/pow10.go',
      '/usr/local/go/src/math/pow.go',
      '/usr/local/go/src/math/pow_s390x.s',
      '/usr/local/go/src/math/pow_stub.s',
      '/usr/local/go/src/math/rand',
      '/usr/local/go/src/math/rand/example_test.go',
      '/usr/local/go/src/math/rand/exp.go',
      '/usr/local/go/src/math/rand/gen_cooked.go',
      '/usr/local/go/src/math/rand/normal.go',
      '/usr/local/go/src/math/rand/race_test.go',
      '/usr/local/go/src/math/rand/rand.go',
      '/usr/local/go/src/math/rand/rand_test.go',
      '/usr/local/go/src/math/rand/regress_test.go',
      '/usr/local/go/src/math/rand/rng.go',
      '/usr/local/go/src/math/rand/zipf.go',
      '/usr/local/go/src/math/remainder_386.s',
      '/usr/local/go/src/math/remainder_amd64p32.s',
      '/usr/local/go/src/math/remainder_amd64.s',
      '/usr/local/go/src/math/remainder_arm.s',
      '/usr/local/go/src/math/remainder.go',
      '/usr/local/go/src/math/signbit.go',
      '/usr/local/go/src/math/sin_386.s',
      '/usr/local/go/src/math/sin_amd64p32.s',
      '/usr/local/go/src/math/sin_amd64.s',
      '/usr/local/go/src/math/sin_arm.s',
      '/usr/local/go/src/math/sincos_386.go',
      '/usr/local/go/src/math/sincos_386.s',
      '/usr/local/go/src/math/sincos.go',
      '/usr/local/go/src/math/sin.go',
      '/usr/local/go/src/math/sinh.go',
      '/usr/local/go/src/math/sinh_s390x.s',
      '/usr/local/go/src/math/sinh_stub.s',
      '/usr/local/go/src/math/sin_s390x.s',
      '/usr/local/go/src/math/sqrt_386.s',
      '/usr/local/go/src/math/sqrt_amd64p32.s',
      '/usr/local/go/src/math/sqrt_amd64.s',
      '/usr/local/go/src/math/sqrt_arm64.s',
      '/usr/local/go/src/math/sqrt_arm.s',
      '/usr/local/go/src/math/sqrt.go',
      '/usr/local/go/src/math/sqrt_mipsx.s',
      '/usr/local/go/src/math/sqrt_ppc64x.s',
      '/usr/local/go/src/math/sqrt_s390x.s',
      '/usr/local/go/src/math/stubs_arm64.s',
      '/usr/local/go/src/math/stubs_mips64x.s',
      '/usr/local/go/src/math/stubs_mipsx.s',
      '/usr/local/go/src/math/stubs_ppc64x.s',
      '/usr/local/go/src/math/stubs_s390x.s',
      '/usr/local/go/src/math/tan_386.s',
      '/usr/local/go/src/math/tan_amd64p32.s',
      '/usr/local/go/src/math/tan_amd64.s',
      '/usr/local/go/src/math/tan_arm.s',
      '/usr/local/go/src/math/tan.go',
      '/usr/local/go/src/math/tanh.go',
      '/usr/local/go/src/math/tanh_s390x.s',
      '/usr/local/go/src/math/tan_s390x.s',
      '/usr/local/go/src/math/unsafe.go',
      '/usr/local/go/src/mime',
      '/usr/local/go/src/mime/encodedword.go',
      '/usr/local/go/src/mime/encodedword_test.go',
      '/usr/local/go/src/mime/example_test.go',
      '/usr/local/go/src/mime/grammar.go',
      '/usr/local/go/src/mime/mediatype.go',
      '/usr/local/go/src/mime/mediatype_test.go',
      '/usr/local/go/src/mime/multipart',
      '/usr/local/go/src/mime/multipart/example_test.go',
      '/usr/local/go/src/mime/multipart/formdata.go',
      '/usr/local/go/src/mime/multipart/formdata_test.go',
      '/usr/local/go/src/mime/multipart/multipart.go',
      '/usr/local/go/src/mime/multipart/multipart_test.go',
      '/usr/local/go/src/mime/multipart/testdata',
      '/usr/local/go/src/mime/multipart/testdata/nested-mime',
      '/usr/local/go/src/mime/multipart/writer.go',
      '/usr/local/go/src/mime/multipart/writer_test.go',
      '/usr/local/go/src/mime/quotedprintable',
      '/usr/local/go/src/mime/quotedprintable/example_test.go',
      '/usr/local/go/src/mime/quotedprintable/reader.go',
      '/usr/local/go/src/mime/quotedprintable/reader_test.go',
      '/usr/local/go/src/mime/quotedprintable/writer.go',
      '/usr/local/go/src/mime/quotedprintable/writer_test.go',
      '/usr/local/go/src/mime/testdata',
      '/usr/local/go/src/mime/testdata/test.types',
      '/usr/local/go/src/mime/testdata/test.types.plan9',
      '/usr/local/go/src/mime/type_dragonfly.go',
      '/usr/local/go/src/mime/type_freebsd.go',
      '/usr/local/go/src/mime/type.go',
      '/usr/local/go/src/mime/type_openbsd.go',
      '/usr/local/go/src/mime/type_plan9.go',
      '/usr/local/go/src/mime/type_test.go',
      '/usr/local/go/src/mime/type_unix.go',
      '/usr/local/go/src/mime/type_windows.go',
      '/usr/local/go/src/naclmake.bash',
      '/usr/local/go/src/nacltest.bash',
      '/usr/local/go/src/net',
      '/usr/local/go/src/net/addrselect.go',
      '/usr/local/go/src/net/addrselect_test.go',
      '/usr/local/go/src/net/cgo_android.go',
      '/usr/local/go/src/net/cgo_bsd.go',
      '/usr/local/go/src/net/cgo_linux.go',
      '/usr/local/go/src/net/cgo_netbsd.go',
      '/usr/local/go/src/net/cgo_openbsd.go',
      '/usr/local/go/src/net/cgo_resnew.go',
      '/usr/local/go/src/net/cgo_resold.go',
      '/usr/local/go/src/net/cgo_socknew.go',
      '/usr/local/go/src/net/cgo_sockold.go',
      '/usr/local/go/src/net/cgo_solaris.go',
      '/usr/local/go/src/net/cgo_stub.go',
      '/usr/local/go/src/net/cgo_unix.go',
      '/usr/local/go/src/net/cgo_unix_test.go',
      '/usr/local/go/src/net/cgo_windows.go',
      '/usr/local/go/src/net/conf.go',
      '/usr/local/go/src/net/conf_netcgo.go',
      '/usr/local/go/src/net/conf_test.go',
      '/usr/local/go/src/net/conn_test.go',
      '/usr/local/go/src/net/dial.go',
      '/usr/local/go/src/net/dial_test.go',
      '/usr/local/go/src/net/dial_unix_test.go',
      '/usr/local/go/src/net/dnsclient.go',
      '/usr/local/go/src/net/dnsclient_test.go',
      '/usr/local/go/src/net/dnsclient_unix.go',
      '/usr/local/go/src/net/dnsclient_unix_test.go',
      '/usr/local/go/src/net/dnsconfig_unix.go',
      '/usr/local/go/src/net/dnsconfig_unix_test.go',
      '/usr/local/go/src/net/dnsmsg.go',
      '/usr/local/go/src/net/dnsmsg_test.go',
      '/usr/local/go/src/net/dnsname_test.go',
      '/usr/local/go/src/net/error_plan9_test.go',
      '/usr/local/go/src/net/error_posix.go',
      '/usr/local/go/src/net/error_posix_test.go',
      '/usr/local/go/src/net/error_test.go',
      '/usr/local/go/src/net/error_unix_test.go',
      '/usr/local/go/src/net/error_windows_test.go',
      '/usr/local/go/src/net/example_test.go',
      '/usr/local/go/src/net/external_test.go',
      '/usr/local/go/src/net/fd_plan9.go',
      '/usr/local/go/src/net/fd_unix.go',
      '/usr/local/go/src/net/fd_windows.go',
      '/usr/local/go/src/net/file.go',
      '/usr/local/go/src/net/file_plan9.go',
      '/usr/local/go/src/net/file_stub.go',
      '/usr/local/go/src/net/file_test.go',
      '/usr/local/go/src/net/file_unix.go',
      '/usr/local/go/src/net/file_windows.go',
      '/usr/local/go/src/net/hook.go',
      '/usr/local/go/src/net/hook_plan9.go',
      '/usr/local/go/src/net/hook_unix.go',
      '/usr/local/go/src/net/hook_windows.go',
      '/usr/local/go/src/net/hosts.go',
      '/usr/local/go/src/net/hosts_test.go',
      '/usr/local/go/src/net/http',
      '/usr/local/go/src/net/http/cgi',
      '/usr/local/go/src/net/http/cgi/child.go',
      '/usr/local/go/src/net/http/cgi/child_test.go',
      '/usr/local/go/src/net/http/cgi/host.go',
      '/usr/local/go/src/net/http/cgi/host_test.go',
      '/usr/local/go/src/net/http/cgi/matryoshka_test.go',
      '/usr/local/go/src/net/http/cgi/plan9_test.go',
      '/usr/local/go/src/net/http/cgi/posix_test.go',
      '/usr/local/go/src/net/http/cgi/testdata',
      '/usr/local/go/src/net/http/cgi/testdata/test.cgi',
      '/usr/local/go/src/net/http/client.go',
      '/usr/local/go/src/net/http/clientserver_test.go',
      '/usr/local/go/src/net/http/client_test.go',
      '/usr/local/go/src/net/http/cookie.go',
      '/usr/local/go/src/net/http/cookiejar',
      '/usr/local/go/src/net/http/cookiejar/dummy_publicsuffix_test.go',
      '/usr/local/go/src/net/http/cookiejar/example_test.go',
      '/usr/local/go/src/net/http/cookiejar/jar.go',
      '/usr/local/go/src/net/http/cookiejar/jar_test.go',
      '/usr/local/go/src/net/http/cookiejar/punycode.go',
      '/usr/local/go/src/net/http/cookiejar/punycode_test.go',
      '/usr/local/go/src/net/http/cookie_test.go',
      '/usr/local/go/src/net/http/doc.go',
      '/usr/local/go/src/net/http/example_test.go',
      '/usr/local/go/src/net/http/export_test.go',
      '/usr/local/go/src/net/http/fcgi',
      '/usr/local/go/src/net/http/fcgi/child.go',
      '/usr/local/go/src/net/http/fcgi/fcgi.go',
      '/usr/local/go/src/net/http/fcgi/fcgi_test.go',
      '/usr/local/go/src/net/http/filetransport.go',
      '/usr/local/go/src/net/http/filetransport_test.go',
      '/usr/local/go/src/net/http/fs.go',
      '/usr/local/go/src/net/http/fs_test.go',
      '/usr/local/go/src/net/http/h2_bundle.go',
      '/usr/local/go/src/net/http/header.go',
      '/usr/local/go/src/net/http/header_test.go',
      '/usr/local/go/src/net/http/http.go',
      '/usr/local/go/src/net/http/httptest',
      '/usr/local/go/src/net/http/httptest/example_test.go',
      '/usr/local/go/src/net/http/httptest/httptest.go',
      '/usr/local/go/src/net/http/httptest/httptest_test.go',
      '/usr/local/go/src/net/http/httptest/recorder.go',
      '/usr/local/go/src/net/http/httptest/recorder_test.go',
      '/usr/local/go/src/net/http/httptest/server.go',
      '/usr/local/go/src/net/http/httptest/server_test.go',
      '/usr/local/go/src/net/http/http_test.go',
      '/usr/local/go/src/net/http/httptrace',
      '/usr/local/go/src/net/http/httptrace/example_test.go',
      '/usr/local/go/src/net/http/httptrace/trace.go',
      '/usr/local/go/src/net/http/httptrace/trace_test.go',
      '/usr/local/go/src/net/http/httputil',
      '/usr/local/go/src/net/http/httputil/dump.go',
      '/usr/local/go/src/net/http/httputil/dump_test.go',
      '/usr/local/go/src/net/http/httputil/example_test.go',
      '/usr/local/go/src/net/http/httputil/httputil.go',
      '/usr/local/go/src/net/http/httputil/persist.go',
      '/usr/local/go/src/net/http/httputil/reverseproxy.go',
      '/usr/local/go/src/net/http/httputil/reverseproxy_test.go',
      '/usr/local/go/src/net/http/internal',
      '/usr/local/go/src/net/http/internal/chunked.go',
      '/usr/local/go/src/net/http/internal/chunked_test.go',
      '/usr/local/go/src/net/http/internal/testcert.go',
      '/usr/local/go/src/net/http/jar.go',
      '/usr/local/go/src/net/http/main_test.go',
      '/usr/local/go/src/net/http/method.go',
      '/usr/local/go/src/net/http/npn_test.go',
      '/usr/local/go/src/net/http/pprof',
      '/usr/local/go/src/net/http/pprof/pprof.go',
      '/usr/local/go/src/net/http/proxy_test.go',
      '/usr/local/go/src/net/http/race.go',
      '/usr/local/go/src/net/http/range_test.go',
      '/usr/local/go/src/net/http/readrequest_test.go',
      '/usr/local/go/src/net/http/request.go',
      '/usr/local/go/src/net/http/request_test.go',
      '/usr/local/go/src/net/http/requestwrite_test.go',
      '/usr/local/go/src/net/http/response.go',
      '/usr/local/go/src/net/http/response_test.go',
      '/usr/local/go/src/net/http/responsewrite_test.go',
      '/usr/local/go/src/net/http/server.go',
      '/usr/local/go/src/net/http/serve_test.go',
      '/usr/local/go/src/net/http/sniff.go',
      '/usr/local/go/src/net/http/sniff_test.go',
      '/usr/local/go/src/net/http/status.go',
      '/usr/local/go/src/net/http/testdata',
      '/usr/local/go/src/net/http/testdata/file',
      '/usr/local/go/src/net/http/testdata/index.html',
      '/usr/local/go/src/net/http/testdata/style.css',
      '/usr/local/go/src/net/http/transfer.go',
      '/usr/local/go/src/net/http/transfer_test.go',
      '/usr/local/go/src/net/http/transport.go',
      '/usr/local/go/src/net/http/transport_internal_test.go',
      '/usr/local/go/src/net/http/transport_test.go',
      '/usr/local/go/src/net/http/triv.go',
      '/usr/local/go/src/net/interface_bsd.go',
      '/usr/local/go/src/net/interface_bsd_test.go',
      '/usr/local/go/src/net/interface_bsdvar.go',
      '/usr/local/go/src/net/interface_darwin.go',
      '/usr/local/go/src/net/interface_freebsd.go',
      '/usr/local/go/src/net/interface.go',
      '/usr/local/go/src/net/interface_linux.go',
      '/usr/local/go/src/net/interface_linux_test.go',
      '/usr/local/go/src/net/interface_plan9.go',
      '/usr/local/go/src/net/interface_solaris.go',
      '/usr/local/go/src/net/interface_stub.go',
      '/usr/local/go/src/net/interface_test.go',
      '/usr/local/go/src/net/interface_unix_test.go',
      '/usr/local/go/src/net/interface_windows.go',
      '/usr/local/go/src/net/interface_windows_test.go',
      '/usr/local/go/src/net/internal',
      '/usr/local/go/src/net/internal/socktest',
      '/usr/local/go/src/net/internal/socktest/main_test.go',
      '/usr/local/go/src/net/internal/socktest/main_unix_test.go',
      '/usr/local/go/src/net/internal/socktest/main_windows_test.go',
      '/usr/local/go/src/net/internal/socktest/switch.go',
      '/usr/local/go/src/net/internal/socktest/switch_posix.go',
      '/usr/local/go/src/net/internal/socktest/switch_stub.go',
      '/usr/local/go/src/net/internal/socktest/switch_unix.go',
      '/usr/local/go/src/net/internal/socktest/switch_windows.go',
      '/usr/local/go/src/net/internal/socktest/sys_cloexec.go',
      '/usr/local/go/src/net/internal/socktest/sys_unix.go',
      '/usr/local/go/src/net/internal/socktest/sys_windows.go',
      '/usr/local/go/src/net/ip.go',
      '/usr/local/go/src/net/iprawsock.go',
      '/usr/local/go/src/net/iprawsock_plan9.go',
      '/usr/local/go/src/net/iprawsock_posix.go',
      '/usr/local/go/src/net/iprawsock_test.go',
      '/usr/local/go/src/net/ipsock.go',
      '/usr/local/go/src/net/ipsock_plan9.go',
      '/usr/local/go/src/net/ipsock_posix.go',
      '/usr/local/go/src/net/ipsock_test.go',
      '/usr/local/go/src/net/ip_test.go',
      '/usr/local/go/src/net/listen_test.go',
      '/usr/local/go/src/net/lookup.go',
      '/usr/local/go/src/net/lookup_nacl.go',
      '/usr/local/go/src/net/lookup_plan9.go',
      '/usr/local/go/src/net/lookup_test.go',
      '/usr/local/go/src/net/lookup_unix.go',
      '/usr/local/go/src/net/lookup_windows.go',
      '/usr/local/go/src/net/lookup_windows_test.go',
      '/usr/local/go/src/net/mac.go',
      '/usr/local/go/src/net/mac_test.go',
      '/usr/local/go/src/net/mail',
      '/usr/local/go/src/net/mail/example_test.go',
      '/usr/local/go/src/net/mail/message.go',
      '/usr/local/go/src/net/mail/message_test.go',
      '/usr/local/go/src/net/main_cloexec_test.go',
      '/usr/local/go/src/net/main_conf_test.go',
      '/usr/local/go/src/net/main_noconf_test.go',
      '/usr/local/go/src/net/main_plan9_test.go',
      '/usr/local/go/src/net/main_posix_test.go',
      '/usr/local/go/src/net/main_test.go',
      '/usr/local/go/src/net/main_unix_test.go',
      '/usr/local/go/src/net/main_windows_test.go',
      '/usr/local/go/src/net/mockserver_test.go',
      '/usr/local/go/src/net/net.go',
      '/usr/local/go/src/net/netgo_unix_test.go',
      '/usr/local/go/src/net/net_test.go',
      '/usr/local/go/src/net/net_windows_test.go',
      '/usr/local/go/src/net/nss.go',
      '/usr/local/go/src/net/nss_test.go',
      '/usr/local/go/src/net/packetconn_test.go',
      '/usr/local/go/src/net/parse.go',
      '/usr/local/go/src/net/parse_test.go',
      '/usr/local/go/src/net/pipe.go',
      '/usr/local/go/src/net/pipe_test.go',
      '/usr/local/go/src/net/platform_test.go',
      '/usr/local/go/src/net/port.go',
      '/usr/local/go/src/net/port_test.go',
      '/usr/local/go/src/net/port_unix.go',
      '/usr/local/go/src/net/protoconn_test.go',
      '/usr/local/go/src/net/rawconn.go',
      '/usr/local/go/src/net/rawconn_unix_test.go',
      '/usr/local/go/src/net/rawconn_windows_test.go',
      '/usr/local/go/src/net/rpc',
      '/usr/local/go/src/net/rpc/client.go',
      '/usr/local/go/src/net/rpc/client_test.go',
      '/usr/local/go/src/net/rpc/debug.go',
      '/usr/local/go/src/net/rpc/jsonrpc',
      '/usr/local/go/src/net/rpc/jsonrpc/all_test.go',
      '/usr/local/go/src/net/rpc/jsonrpc/client.go',
      '/usr/local/go/src/net/rpc/jsonrpc/server.go',
      '/usr/local/go/src/net/rpc/server.go',
      '/usr/local/go/src/net/rpc/server_test.go',
      '/usr/local/go/src/net/sendfile_bsd.go',
      '/usr/local/go/src/net/sendfile_linux.go',
      '/usr/local/go/src/net/sendfile_solaris.go',
      '/usr/local/go/src/net/sendfile_stub.go',
      '/usr/local/go/src/net/sendfile_test.go',
      '/usr/local/go/src/net/sendfile_windows.go',
      '/usr/local/go/src/net/server_test.go',
      '/usr/local/go/src/net/smtp',
      '/usr/local/go/src/net/smtp/auth.go',
      '/usr/local/go/src/net/smtp/example_test.go',
      '/usr/local/go/src/net/smtp/smtp.go',
      '/usr/local/go/src/net/smtp/smtp_test.go',
      '/usr/local/go/src/net/sock_bsd.go',
      '/usr/local/go/src/net/sock_cloexec.go',
      '/usr/local/go/src/net/sock_linux.go',
      '/usr/local/go/src/net/sockopt_bsd.go',
      '/usr/local/go/src/net/sockoptip_bsd.go',
      '/usr/local/go/src/net/sockoptip_linux.go',
      '/usr/local/go/src/net/sockoptip_posix.go',
      '/usr/local/go/src/net/sockoptip_stub.go',
      '/usr/local/go/src/net/sockoptip_windows.go',
      '/usr/local/go/src/net/sockopt_linux.go',
      '/usr/local/go/src/net/sockopt_plan9.go',
      '/usr/local/go/src/net/sockopt_posix.go',
      '/usr/local/go/src/net/sockopt_solaris.go',
      '/usr/local/go/src/net/sockopt_stub.go',
      '/usr/local/go/src/net/sockopt_windows.go',
      '/usr/local/go/src/net/sock_plan9.go',
      '/usr/local/go/src/net/sock_posix.go',
      '/usr/local/go/src/net/sock_stub.go',
      '/usr/local/go/src/net/sock_windows.go',
      '/usr/local/go/src/net/sys_cloexec.go',
      '/usr/local/go/src/net/tcpsock.go',
      '/usr/local/go/src/net/tcpsockopt_darwin.go',
      '/usr/local/go/src/net/tcpsockopt_dragonfly.go',
      '/usr/local/go/src/net/tcpsockopt_openbsd.go',
      '/usr/local/go/src/net/tcpsockopt_plan9.go',
      '/usr/local/go/src/net/tcpsockopt_posix.go',
      '/usr/local/go/src/net/tcpsockopt_solaris.go',
      '/usr/local/go/src/net/tcpsockopt_stub.go',
      '/usr/local/go/src/net/tcpsockopt_unix.go',
      '/usr/local/go/src/net/tcpsockopt_windows.go',
      '/usr/local/go/src/net/tcpsock_plan9.go',
      '/usr/local/go/src/net/tcpsock_posix.go',
      '/usr/local/go/src/net/tcpsock_test.go',
      '/usr/local/go/src/net/tcpsock_unix_test.go',
      '/usr/local/go/src/net/testdata',
      '/usr/local/go/src/net/testdata/case-hosts',
      '/usr/local/go/src/net/testdata/domain-resolv.conf',
      '/usr/local/go/src/net/testdata/empty-resolv.conf',
      '/usr/local/go/src/net/testdata/hosts',
      '/usr/local/go/src/net/testdata/igmp',
      '/usr/local/go/src/net/testdata/igmp6',
      '/usr/local/go/src/net/testdata/invalid-ndots-resolv.conf',
      '/usr/local/go/src/net/testdata/ipv4-hosts',
      '/usr/local/go/src/net/testdata/ipv6-hosts',
      '/usr/local/go/src/net/testdata/large-ndots-resolv.conf',
      '/usr/local/go/src/net/testdata/Mark.Twain-Tom.Sawyer.txt',
      '/usr/local/go/src/net/testdata/negative-ndots-resolv.conf',
      '/usr/local/go/src/net/testdata/openbsd-resolv.conf',
      '/usr/local/go/src/net/testdata/resolv.conf',
      '/usr/local/go/src/net/testdata/search-resolv.conf',
      '/usr/local/go/src/net/testdata/singleline-hosts',
      '/usr/local/go/src/net/textproto',
      '/usr/local/go/src/net/textproto/header.go',
      '/usr/local/go/src/net/textproto/pipeline.go',
      '/usr/local/go/src/net/textproto/reader.go',
      '/usr/local/go/src/net/textproto/reader_test.go',
      '/usr/local/go/src/net/textproto/textproto.go',
      '/usr/local/go/src/net/textproto/writer.go',
      '/usr/local/go/src/net/textproto/writer_test.go',
      '/usr/local/go/src/net/timeout_test.go',
      '/usr/local/go/src/net/udpsock.go',
      '/usr/local/go/src/net/udpsock_plan9.go',
      '/usr/local/go/src/net/udpsock_plan9_test.go',
      '/usr/local/go/src/net/udpsock_posix.go',
      '/usr/local/go/src/net/udpsock_test.go',
      '/usr/local/go/src/net/unixsock.go',
      '/usr/local/go/src/net/unixsock_plan9.go',
      '/usr/local/go/src/net/unixsock_posix.go',
      '/usr/local/go/src/net/unixsock_test.go',
      '/usr/local/go/src/net/url',
      '/usr/local/go/src/net/url/example_test.go',
      '/usr/local/go/src/net/url/url.go',
      '/usr/local/go/src/net/url/url_test.go',
      '/usr/local/go/src/net/writev_test.go',
      '/usr/local/go/src/net/writev_unix.go',
      '/usr/local/go/src/os',
      '/usr/local/go/src/os/dir.go',
      '/usr/local/go/src/os/dir_plan9.go',
      '/usr/local/go/src/os/dir_unix.go',
      '/usr/local/go/src/os/dir_windows.go',
      '/usr/local/go/src/os/env.go',
      '/usr/local/go/src/os/env_test.go',
      '/usr/local/go/src/os/env_unix_test.go',
      '/usr/local/go/src/os/error.go',
      '/usr/local/go/src/os/error_plan9.go',
      '/usr/local/go/src/os/error_posix.go',
      '/usr/local/go/src/os/error_test.go',
      '/usr/local/go/src/os/error_unix.go',
      '/usr/local/go/src/os/error_unix_test.go',
      '/usr/local/go/src/os/error_windows.go',
      '/usr/local/go/src/os/error_windows_test.go',
      '/usr/local/go/src/os/example_test.go',
      '/usr/local/go/src/os/exec',
      '/usr/local/go/src/os/exec/env_test.go',
      '/usr/local/go/src/os/exec/example_test.go',
      '/usr/local/go/src/os/exec/exec.go',
      '/usr/local/go/src/os/exec/exec_posix_test.go',
      '/usr/local/go/src/os/exec/exec_test.go',
      '/usr/local/go/src/os/exec/exec_unix.go',
      '/usr/local/go/src/os/exec/exec_windows.go',
      '/usr/local/go/src/os/exec/internal_test.go',
      '/usr/local/go/src/os/exec/lp_plan9.go',
      '/usr/local/go/src/os/exec/lp_test.go',
      '/usr/local/go/src/os/exec/lp_unix.go',
      '/usr/local/go/src/os/exec/lp_unix_test.go',
      '/usr/local/go/src/os/exec/lp_windows.go',
      '/usr/local/go/src/os/exec/lp_windows_test.go',
      '/usr/local/go/src/os/exec.go',
      '/usr/local/go/src/os/exec_plan9.go',
      '/usr/local/go/src/os/exec_posix.go',
      '/usr/local/go/src/os/exec_unix.go',
      '/usr/local/go/src/os/executable_darwin.go',
      '/usr/local/go/src/os/executable_freebsd.go',
      '/usr/local/go/src/os/executable.go',
      '/usr/local/go/src/os/executable_path.go',
      '/usr/local/go/src/os/executable_plan9.go',
      '/usr/local/go/src/os/executable_procfs.go',
      '/usr/local/go/src/os/executable_solaris.go',
      '/usr/local/go/src/os/executable_test.go',
      '/usr/local/go/src/os/executable_windows.go',
      '/usr/local/go/src/os/exec_windows.go',
      '/usr/local/go/src/os/export_test.go',
      '/usr/local/go/src/os/export_windows_test.go',
      '/usr/local/go/src/os/file.go',
      '/usr/local/go/src/os/file_plan9.go',
      '/usr/local/go/src/os/file_posix.go',
      '/usr/local/go/src/os/file_unix.go',
      '/usr/local/go/src/os/file_windows.go',
      '/usr/local/go/src/os/getwd_darwin.go',
      '/usr/local/go/src/os/getwd.go',
      '/usr/local/go/src/os/os_test.go',
      '/usr/local/go/src/os/os_unix_test.go',
      '/usr/local/go/src/os/os_windows_test.go',
      '/usr/local/go/src/os/path.go',
      '/usr/local/go/src/os/path_plan9.go',
      '/usr/local/go/src/os/path_test.go',
      '/usr/local/go/src/os/path_unix.go',
      '/usr/local/go/src/os/path_windows.go',
      '/usr/local/go/src/os/path_windows_test.go',
      '/usr/local/go/src/os/pipe_bsd.go',
      '/usr/local/go/src/os/pipe_freebsd.go',
      '/usr/local/go/src/os/pipe_linux.go',
      '/usr/local/go/src/os/pipe_test.go',
      '/usr/local/go/src/os/proc.go',
      '/usr/local/go/src/os/signal',
      '/usr/local/go/src/os/signal/doc.go',
      '/usr/local/go/src/os/signal/example_test.go',
      '/usr/local/go/src/os/signal/signal.go',
      '/usr/local/go/src/os/signal/signal_plan9.go',
      '/usr/local/go/src/os/signal/signal_plan9_test.go',
      '/usr/local/go/src/os/signal/signal_test.go',
      '/usr/local/go/src/os/signal/signal_unix.go',
      '/usr/local/go/src/os/signal/signal_windows_test.go',
      '/usr/local/go/src/os/signal/sig.s',
      '/usr/local/go/src/os/stat_darwin.go',
      '/usr/local/go/src/os/stat_dragonfly.go',
      '/usr/local/go/src/os/stat_freebsd.go',
      '/usr/local/go/src/os/stat_linux.go',
      '/usr/local/go/src/os/stat_nacl.go',
      '/usr/local/go/src/os/stat_netbsd.go',
      '/usr/local/go/src/os/stat_openbsd.go',
      '/usr/local/go/src/os/stat_plan9.go',
      '/usr/local/go/src/os/stat_solaris.go',
      '/usr/local/go/src/os/stat_unix.go',
      '/usr/local/go/src/os/stat_windows.go',
      '/usr/local/go/src/os/sticky_bsd.go',
      '/usr/local/go/src/os/sticky_notbsd.go',
      '/usr/local/go/src/os/str.go',
      '/usr/local/go/src/os/sys_bsd.go',
      '/usr/local/go/src/os/sys_darwin.go',
      '/usr/local/go/src/os/sys_freebsd.go',
      '/usr/local/go/src/os/sys.go',
      '/usr/local/go/src/os/sys_linux.go',
      '/usr/local/go/src/os/sys_nacl.go',
      '/usr/local/go/src/os/sys_plan9.go',
      '/usr/local/go/src/os/sys_solaris.go',
      '/usr/local/go/src/os/sys_unix.go',
      '/usr/local/go/src/os/sys_windows.go',
      '/usr/local/go/src/os/types.go',
      '/usr/local/go/src/os/types_plan9.go',
      '/usr/local/go/src/os/types_unix.go',
      '/usr/local/go/src/os/types_windows.go',
      '/usr/local/go/src/os/user',
      '/usr/local/go/src/os/user/cgo_lookup_unix.go',
      '/usr/local/go/src/os/user/getgrouplist_darwin.go',
      '/usr/local/go/src/os/user/getgrouplist_unix.go',
      '/usr/local/go/src/os/user/listgroups_solaris.go',
      '/usr/local/go/src/os/user/listgroups_unix.go',
      '/usr/local/go/src/os/user/lookup_android.go',
      '/usr/local/go/src/os/user/lookup.go',
      '/usr/local/go/src/os/user/lookup_plan9.go',
      '/usr/local/go/src/os/user/lookup_stubs.go',
      '/usr/local/go/src/os/user/lookup_unix.go',
      '/usr/local/go/src/os/user/lookup_unix_test.go',
      '/usr/local/go/src/os/user/lookup_windows.go',
      '/usr/local/go/src/os/user/user.go',
      '/usr/local/go/src/os/user/user_test.go',
      '/usr/local/go/src/os/wait_unimp.go',
      '/usr/local/go/src/os/wait_wait6.go',
      '/usr/local/go/src/os/wait_waitid.go',
      '/usr/local/go/src/path',
      '/usr/local/go/src/path/example_test.go',
      '/usr/local/go/src/path/filepath',
      '/usr/local/go/src/path/filepath/example_unix_test.go',
      '/usr/local/go/src/path/filepath/export_test.go',
      '/usr/local/go/src/path/filepath/export_windows_test.go',
      '/usr/local/go/src/path/filepath/match.go',
      '/usr/local/go/src/path/filepath/match_test.go',
      '/usr/local/go/src/path/filepath/path.go',
      '/usr/local/go/src/path/filepath/path_plan9.go',
      '/usr/local/go/src/path/filepath/path_test.go',
      '/usr/local/go/src/path/filepath/path_unix.go',
      '/usr/local/go/src/path/filepath/path_windows.go',
      '/usr/local/go/src/path/filepath/path_windows_test.go',
      '/usr/local/go/src/path/filepath/symlink.go',
      '/usr/local/go/src/path/filepath/symlink_unix.go',
      '/usr/local/go/src/path/filepath/symlink_windows.go',
      '/usr/local/go/src/path/match.go',
      '/usr/local/go/src/path/match_test.go',
      '/usr/local/go/src/path/path.go',
      '/usr/local/go/src/path/path_test.go',
      '/usr/local/go/src/plugin',
      '/usr/local/go/src/plugin/plugin_dlopen.go',
      '/usr/local/go/src/plugin/plugin.go',
      '/usr/local/go/src/plugin/plugin_stubs.go',
      '/usr/local/go/src/race.bash',
      '/usr/local/go/src/race.bat',
      '/usr/local/go/src/reflect',
      '/usr/local/go/src/reflect/all_test.go',
      '/usr/local/go/src/reflect/asm_386.s',
      '/usr/local/go/src/reflect/asm_amd64p32.s',
      '/usr/local/go/src/reflect/asm_amd64.s',
      '/usr/local/go/src/reflect/asm_arm64.s',
      '/usr/local/go/src/reflect/asm_arm.s',
      '/usr/local/go/src/reflect/asm_mips64x.s',
      '/usr/local/go/src/reflect/asm_mipsx.s',
      '/usr/local/go/src/reflect/asm_ppc64x.s',
      '/usr/local/go/src/reflect/asm_s390x.s',
      '/usr/local/go/src/reflect/deepequal.go',
      '/usr/local/go/src/reflect/example_test.go',
      '/usr/local/go/src/reflect/export_test.go',
      '/usr/local/go/src/reflect/makefunc.go',
      '/usr/local/go/src/reflect/set_test.go',
      '/usr/local/go/src/reflect/swapper.go',
      '/usr/local/go/src/reflect/tostring_test.go',
      '/usr/local/go/src/reflect/type.go',
      '/usr/local/go/src/reflect/value.go',
      '/usr/local/go/src/regexp',
      '/usr/local/go/src/regexp/all_test.go',
      '/usr/local/go/src/regexp/backtrack.go',
      '/usr/local/go/src/regexp/example_test.go',
      '/usr/local/go/src/regexp/exec2_test.go',
      '/usr/local/go/src/regexp/exec.go',
      '/usr/local/go/src/regexp/exec_test.go',
      '/usr/local/go/src/regexp/find_test.go',
      '/usr/local/go/src/regexp/onepass.go',
      '/usr/local/go/src/regexp/onepass_test.go',
      '/usr/local/go/src/regexp/regexp.go',
      '/usr/local/go/src/regexp/syntax',
      '/usr/local/go/src/regexp/syntax/compile.go',
      '/usr/local/go/src/regexp/syntax/doc.go',
      '/usr/local/go/src/regexp/syntax/make_perl_groups.pl',
      '/usr/local/go/src/regexp/syntax/parse.go',
      '/usr/local/go/src/regexp/syntax/parse_test.go',
      '/usr/local/go/src/regexp/syntax/perl_groups.go',
      '/usr/local/go/src/regexp/syntax/prog.go',
      '/usr/local/go/src/regexp/syntax/prog_test.go',
      '/usr/local/go/src/regexp/syntax/regexp.go',
      '/usr/local/go/src/regexp/syntax/simplify.go',
      '/usr/local/go/src/regexp/syntax/simplify_test.go',
      '/usr/local/go/src/regexp/testdata',
      '/usr/local/go/src/regexp/testdata/basic.dat',
      '/usr/local/go/src/regexp/testdata/nullsubexpr.dat',
      '/usr/local/go/src/regexp/testdata/re2-exhaustive.txt.bz2',
      '/usr/local/go/src/regexp/testdata/re2-search.txt',
      '/usr/local/go/src/regexp/testdata/README',
      '/usr/local/go/src/regexp/testdata/repetition.dat',
      '/usr/local/go/src/regexp/testdata/testregex.c',
      '/usr/local/go/src/run.bash',
      '/usr/local/go/src/run.bat',
      '/usr/local/go/src/run.rc',
      '/usr/local/go/src/runtime',
      '/usr/local/go/src/runtime/alg.go',
      '/usr/local/go/src/runtime/append_test.go',
      '/usr/local/go/src/runtime/asm_386.s',
      '/usr/local/go/src/runtime/asm_amd64p32.s',
      '/usr/local/go/src/runtime/asm_amd64.s',
      '/usr/local/go/src/runtime/asm_arm64.s',
      '/usr/local/go/src/runtime/asm_arm.s',
      '/usr/local/go/src/runtime/asm_mips64x.s',
      '/usr/local/go/src/runtime/asm_mipsx.s',
      '/usr/local/go/src/runtime/asm_ppc64x.h',
      '/usr/local/go/src/runtime/asm_ppc64x.s',
      '/usr/local/go/src/runtime/asm.s',
      '/usr/local/go/src/runtime/asm_s390x.s',
      '/usr/local/go/src/runtime/atomic_arm64.s',
      '/usr/local/go/src/runtime/atomic_mips64x.s',
      '/usr/local/go/src/runtime/atomic_mipsx.s',
      '/usr/local/go/src/runtime/atomic_pointer.go',
      '/usr/local/go/src/runtime/atomic_ppc64x.s',
      '/usr/local/go/src/runtime/callers_test.go',
      '/usr/local/go/src/runtime/cgo',
      '/usr/local/go/src/runtime/cgo/asm_386.s',
      '/usr/local/go/src/runtime/cgo/asm_amd64.s',
      '/usr/local/go/src/runtime/cgo/asm_arm64.s',
      '/usr/local/go/src/runtime/cgo/asm_arm.s',
      '/usr/local/go/src/runtime/cgo/asm_mips64x.s',
      '/usr/local/go/src/runtime/cgo/asm_mipsx.s',
      '/usr/local/go/src/runtime/cgo/asm_nacl_amd64p32.s',
      '/usr/local/go/src/runtime/cgo/asm_ppc64x.s',
      '/usr/local/go/src/runtime/cgo/asm_s390x.s',
      '/usr/local/go/src/runtime/cgo/callbacks.go',
      '/usr/local/go/src/runtime/cgo/callbacks_traceback.go',
      '/usr/local/go/src/runtime/cgo/cgo.go',
      '/usr/local/go/src/runtime/cgo/dragonfly.go',
      '/usr/local/go/src/runtime/cgo/freebsd.go',
      '/usr/local/go/src/runtime/cgo/gcc_386.S',
      '/usr/local/go/src/runtime/cgo/gcc_amd64.S',
      '/usr/local/go/src/runtime/cgo/gcc_android_386.c',
      '/usr/local/go/src/runtime/cgo/gcc_android_amd64.c',
      '/usr/local/go/src/runtime/cgo/gcc_android_arm64.c',
      '/usr/local/go/src/runtime/cgo/gcc_android_arm.c',
      '/usr/local/go/src/runtime/cgo/gcc_android.c',
      '/usr/local/go/src/runtime/cgo/gcc_arm64.S',
      '/usr/local/go/src/runtime/cgo/gcc_arm.S',
      '/usr/local/go/src/runtime/cgo/gcc_context.c',
      '/usr/local/go/src/runtime/cgo/gcc_darwin_386.c',
      '/usr/local/go/src/runtime/cgo/gcc_darwin_amd64.c',
      '/usr/local/go/src/runtime/cgo/gcc_darwin_arm64.c',
      '/usr/local/go/src/runtime/cgo/gcc_darwin_arm.c',
      '/usr/local/go/src/runtime/cgo/gcc_dragonfly_amd64.c',
      '/usr/local/go/src/runtime/cgo/gcc_fatalf.c',
      '/usr/local/go/src/runtime/cgo/gcc_freebsd_386.c',
      '/usr/local/go/src/runtime/cgo/gcc_freebsd_amd64.c',
      '/usr/local/go/src/runtime/cgo/gcc_freebsd_arm.c',
      '/usr/local/go/src/runtime/cgo/gcc_libinit.c',
      '/usr/local/go/src/runtime/cgo/gcc_libinit_windows.c',
      '/usr/local/go/src/runtime/cgo/gcc_linux_386.c',
      '/usr/local/go/src/runtime/cgo/gcc_linux_amd64.c',
      '/usr/local/go/src/runtime/cgo/gcc_linux_arm64.c',
      '/usr/local/go/src/runtime/cgo/gcc_linux_arm.c',
      '/usr/local/go/src/runtime/cgo/gcc_linux_mips64x.c',
      '/usr/local/go/src/runtime/cgo/gcc_linux_mipsx.c',
      '/usr/local/go/src/runtime/cgo/gcc_linux_ppc64x.c',
      '/usr/local/go/src/runtime/cgo/gcc_linux_s390x.c',
      '/usr/local/go/src/runtime/cgo/gcc_mips64x.S',
      '/usr/local/go/src/runtime/cgo/gcc_mipsx.S',
      '/usr/local/go/src/runtime/cgo/gcc_mmap.c',
      '/usr/local/go/src/runtime/cgo/gcc_netbsd_386.c',
      '/usr/local/go/src/runtime/cgo/gcc_netbsd_amd64.c',
      '/usr/local/go/src/runtime/cgo/gcc_netbsd_arm.c',
      '/usr/local/go/src/runtime/cgo/gcc_openbsd_386.c',
      '/usr/local/go/src/runtime/cgo/gcc_openbsd_amd64.c',
      '/usr/local/go/src/runtime/cgo/gcc_ppc64x.S',
      '/usr/local/go/src/runtime/cgo/gcc_s390x.S',
      '/usr/local/go/src/runtime/cgo/gcc_setenv.c',
      '/usr/local/go/src/runtime/cgo/gcc_sigaction.c',
      '/usr/local/go/src/runtime/cgo/gcc_signal_darwin_armx.c',
      '/usr/local/go/src/runtime/cgo/gcc_signal_darwin_lldb.c',
      '/usr/local/go/src/runtime/cgo/gcc_solaris_amd64.c',
      '/usr/local/go/src/runtime/cgo/gcc_traceback.c',
      '/usr/local/go/src/runtime/cgo/gcc_util.c',
      '/usr/local/go/src/runtime/cgo/gcc_windows_386.c',
      '/usr/local/go/src/runtime/cgo/gcc_windows_amd64.c',
      '/usr/local/go/src/runtime/cgo/iscgo.go',
      '/usr/local/go/src/runtime/cgo/libcgo.h',
      '/usr/local/go/src/runtime/cgo/libcgo_unix.h',
      '/usr/local/go/src/runtime/cgo/mmap.go',
      '/usr/local/go/src/runtime/cgo/netbsd.go',
      '/usr/local/go/src/runtime/cgo/openbsd.go',
      '/usr/local/go/src/runtime/cgo/setenv.go',
      '/usr/local/go/src/runtime/cgo/sigaction.go',
      '/usr/local/go/src/runtime/cgo/signal_darwin_arm64.s',
      '/usr/local/go/src/runtime/cgo/signal_darwin_arm.s',
      '/usr/local/go/src/runtime/cgo/signal_darwin_armx.go',
      '/usr/local/go/src/runtime/cgocallback.go',
      '/usr/local/go/src/runtime/cgocall.go',
      '/usr/local/go/src/runtime/cgocheck.go',
      '/usr/local/go/src/runtime/cgo.go',
      '/usr/local/go/src/runtime/cgo_mmap.go',
      '/usr/local/go/src/runtime/cgo_ppc64x.go',
      '/usr/local/go/src/runtime/cgo_sigaction.go',
      '/usr/local/go/src/runtime/chanbarrier_test.go',
      '/usr/local/go/src/runtime/chan.go',
      '/usr/local/go/src/runtime/chan_test.go',
      '/usr/local/go/src/runtime/closure_test.go',
      '/usr/local/go/src/runtime/compiler.go',
      '/usr/local/go/src/runtime/complex.go',
      '/usr/local/go/src/runtime/complex_test.go',
      '/usr/local/go/src/runtime/cpuflags_amd64.go',
      '/usr/local/go/src/runtime/cpuprof.go',
      '/usr/local/go/src/runtime/cputicks.go',
      '/usr/local/go/src/runtime/crash_cgo_test.go',
      '/usr/local/go/src/runtime/crash_nonunix_test.go',
      '/usr/local/go/src/runtime/crash_test.go',
      '/usr/local/go/src/runtime/crash_unix_test.go',
      '/usr/local/go/src/runtime/debug',
      '/usr/local/go/src/runtime/debug/debug.s',
      '/usr/local/go/src/runtime/debug/garbage.go',
      '/usr/local/go/src/runtime/debug/garbage_test.go',
      '/usr/local/go/src/runtime/debug/heapdump_test.go',
      '/usr/local/go/src/runtime/debug/stack.go',
      '/usr/local/go/src/runtime/debug/stack_test.go',
      '/usr/local/go/src/runtime/debug/stubs.go',
      '/usr/local/go/src/runtime/debug.go',
      '/usr/local/go/src/runtime/defs1_linux.go',
      '/usr/local/go/src/runtime/defs1_netbsd_386.go',
      '/usr/local/go/src/runtime/defs1_netbsd_amd64.go',
      '/usr/local/go/src/runtime/defs1_netbsd_arm.go',
      '/usr/local/go/src/runtime/defs1_solaris_amd64.go',
      '/usr/local/go/src/runtime/defs2_linux.go',
      '/usr/local/go/src/runtime/defs3_linux.go',
      '/usr/local/go/src/runtime/defs_arm_linux.go',
      '/usr/local/go/src/runtime/defs_darwin_386.go',
      '/usr/local/go/src/runtime/defs_darwin_amd64.go',
      '/usr/local/go/src/runtime/defs_darwin_arm64.go',
      '/usr/local/go/src/runtime/defs_darwin_arm.go',
      '/usr/local/go/src/runtime/defs_darwin.go',
      '/usr/local/go/src/runtime/defs_dragonfly_amd64.go',
      '/usr/local/go/src/runtime/defs_dragonfly.go',
      '/usr/local/go/src/runtime/defs_freebsd_386.go',
      '/usr/local/go/src/runtime/defs_freebsd_amd64.go',
      '/usr/local/go/src/runtime/defs_freebsd_arm.go',
      '/usr/local/go/src/runtime/defs_freebsd.go',
      '/usr/local/go/src/runtime/defs_linux_386.go',
      '/usr/local/go/src/runtime/defs_linux_amd64.go',
      '/usr/local/go/src/runtime/defs_linux_arm64.go',
      '/usr/local/go/src/runtime/defs_linux_arm.go',
      '/usr/local/go/src/runtime/defs_linux.go',
      '/usr/local/go/src/runtime/defs_linux_mips64x.go',
      '/usr/local/go/src/runtime/defs_linux_mipsx.go',
      '/usr/local/go/src/runtime/defs_linux_ppc64.go',
      '/usr/local/go/src/runtime/defs_linux_ppc64le.go',
      '/usr/local/go/src/runtime/defs_linux_s390x.go',
      '/usr/local/go/src/runtime/defs_nacl_386.go',
      '/usr/local/go/src/runtime/defs_nacl_amd64p32.go',
      '/usr/local/go/src/runtime/defs_nacl_arm.go',
      '/usr/local/go/src/runtime/defs_netbsd_386.go',
      '/usr/local/go/src/runtime/defs_netbsd_amd64.go',
      '/usr/local/go/src/runtime/defs_netbsd_arm.go',
      '/usr/local/go/src/runtime/defs_netbsd.go',
      '/usr/local/go/src/runtime/defs_openbsd_386.go',
      '/usr/local/go/src/runtime/defs_openbsd_amd64.go',
      '/usr/local/go/src/runtime/defs_openbsd_arm.go',
      '/usr/local/go/src/runtime/defs_openbsd.go',
      '/usr/local/go/src/runtime/defs_plan9_386.go',
      '/usr/local/go/src/runtime/defs_plan9_amd64.go',
      '/usr/local/go/src/runtime/defs_plan9_arm.go',
      '/usr/local/go/src/runtime/defs_solaris_amd64.go',
      '/usr/local/go/src/runtime/defs_solaris.go',
      '/usr/local/go/src/runtime/defs_windows_386.go',
      '/usr/local/go/src/runtime/defs_windows_amd64.go',
      '/usr/local/go/src/runtime/defs_windows.go',
      '/usr/local/go/src/runtime/duff_386.s',
      '/usr/local/go/src/runtime/duff_amd64.s',
      '/usr/local/go/src/runtime/duff_arm64.s',
      '/usr/local/go/src/runtime/duff_arm.s',
      '/usr/local/go/src/runtime/duff_mips64x.s',
      '/usr/local/go/src/runtime/duff_ppc64x.s',
      '/usr/local/go/src/runtime/env_plan9.go',
      '/usr/local/go/src/runtime/env_posix.go',
      '/usr/local/go/src/runtime/env_test.go',
      '/usr/local/go/src/runtime/error.go',
      '/usr/local/go/src/runtime/example_test.go',
      '/usr/local/go/src/runtime/export_arm_test.go',
      '/usr/local/go/src/runtime/export_futex_test.go',
      '/usr/local/go/src/runtime/export_linux_test.go',
      '/usr/local/go/src/runtime/export_mmap_test.go',
      '/usr/local/go/src/runtime/export_test.go',
      '/usr/local/go/src/runtime/export_unix_test.go',
      '/usr/local/go/src/runtime/export_windows_test.go',
      '/usr/local/go/src/runtime/extern.go',
      '/usr/local/go/src/runtime/fastlog2.go',
      '/usr/local/go/src/runtime/fastlog2table.go',
      '/usr/local/go/src/runtime/fastlog2_test.go',
      '/usr/local/go/src/runtime/float.go',
      '/usr/local/go/src/runtime/funcdata.h',
      '/usr/local/go/src/runtime/futex_test.go',
      '/usr/local/go/src/runtime/gcinfo_test.go',
      '/usr/local/go/src/runtime/gc_test.go',
      '/usr/local/go/src/runtime/go_tls.h',
      '/usr/local/go/src/runtime/HACKING.md',
      '/usr/local/go/src/runtime/hash32.go',
      '/usr/local/go/src/runtime/hash64.go',
      '/usr/local/go/src/runtime/hashmap_fast.go',
      '/usr/local/go/src/runtime/hashmap.go',
      '/usr/local/go/src/runtime/hash_test.go',
      '/usr/local/go/src/runtime/heapdump.go',
      '/usr/local/go/src/runtime/iface.go',
      '/usr/local/go/src/runtime/iface_test.go',
      '/usr/local/go/src/runtime/internal',
      '/usr/local/go/src/runtime/internal/atomic',
      '/usr/local/go/src/runtime/internal/atomic/asm_386.s',
      '/usr/local/go/src/runtime/internal/atomic/asm_amd64p32.s',
      '/usr/local/go/src/runtime/internal/atomic/asm_amd64.s',
      '/usr/local/go/src/runtime/internal/atomic/asm_arm64.s',
      '/usr/local/go/src/runtime/internal/atomic/asm_arm.s',
      '/usr/local/go/src/runtime/internal/atomic/asm_mips64x.s',
      '/usr/local/go/src/runtime/internal/atomic/asm_mipsx.s',
      '/usr/local/go/src/runtime/internal/atomic/asm_ppc64x.s',
      '/usr/local/go/src/runtime/internal/atomic/asm_s390x.s',
      '/usr/local/go/src/runtime/internal/atomic/atomic_386.go',
      '/usr/local/go/src/runtime/internal/atomic/atomic_amd64x.go',
      '/usr/local/go/src/runtime/internal/atomic/atomic_arm64.go',
      '/usr/local/go/src/runtime/internal/atomic/atomic_arm64.s',
      '/usr/local/go/src/runtime/internal/atomic/atomic_arm.go',
      '/usr/local/go/src/runtime/internal/atomic/atomic_mips64x.go',
      '/usr/local/go/src/runtime/internal/atomic/atomic_mips64x.s',
      '/usr/local/go/src/runtime/internal/atomic/atomic_mipsx.go',
      '/usr/local/go/src/runtime/internal/atomic/atomic_mipsx.s',
      '/usr/local/go/src/runtime/internal/atomic/atomic_ppc64x.go',
      '/usr/local/go/src/runtime/internal/atomic/atomic_ppc64x.s',
      '/usr/local/go/src/runtime/internal/atomic/atomic_s390x.go',
      '/usr/local/go/src/runtime/internal/atomic/atomic_test.go',
      '/usr/local/go/src/runtime/internal/atomic/bench_test.go',
      '/usr/local/go/src/runtime/internal/atomic/stubs.go',
      '/usr/local/go/src/runtime/internal/atomic/sys_darwin_arm.s',
      '/usr/local/go/src/runtime/internal/atomic/sys_freebsd_arm.s',
      '/usr/local/go/src/runtime/internal/atomic/sys_linux_arm.s',
      '/usr/local/go/src/runtime/internal/atomic/sys_nacl_arm.s',
      '/usr/local/go/src/runtime/internal/atomic/sys_netbsd_arm.s',
      '/usr/local/go/src/runtime/internal/atomic/sys_openbsd_arm.s',
      '/usr/local/go/src/runtime/internal/atomic/sys_plan9_arm.s',
      '/usr/local/go/src/runtime/internal/sys',
      '/usr/local/go/src/runtime/internal/sys/arch_386.go',
      '/usr/local/go/src/runtime/internal/sys/arch_amd64.go',
      '/usr/local/go/src/runtime/internal/sys/arch_amd64p32.go',
      '/usr/local/go/src/runtime/internal/sys/arch_arm64.go',
      '/usr/local/go/src/runtime/internal/sys/arch_arm.go',
      '/usr/local/go/src/runtime/internal/sys/arch.go',
      '/usr/local/go/src/runtime/internal/sys/arch_mips64.go',
      '/usr/local/go/src/runtime/internal/sys/arch_mips64le.go',
      '/usr/local/go/src/runtime/internal/sys/arch_mips.go',
      '/usr/local/go/src/runtime/internal/sys/arch_mipsle.go',
      '/usr/local/go/src/runtime/internal/sys/arch_ppc64.go',
      '/usr/local/go/src/runtime/internal/sys/arch_ppc64le.go',
      '/usr/local/go/src/runtime/internal/sys/arch_s390x.go',
      '/usr/local/go/src/runtime/internal/sys/gengoos.go',
      '/usr/local/go/src/runtime/internal/sys/intrinsics_386.s',
      '/usr/local/go/src/runtime/internal/sys/intrinsics.go',
      '/usr/local/go/src/runtime/internal/sys/intrinsics_stubs.go',
      '/usr/local/go/src/runtime/internal/sys/intrinsics_test.go',
      '/usr/local/go/src/runtime/internal/sys/stubs.go',
      '/usr/local/go/src/runtime/internal/sys/sys.go',
      '/usr/local/go/src/runtime/internal/sys/zgoarch_386.go',
      '/usr/local/go/src/runtime/internal/sys/zgoarch_amd64.go',
      '/usr/local/go/src/runtime/internal/sys/zgoarch_amd64p32.go',
      '/usr/local/go/src/runtime/internal/sys/zgoarch_arm64.go',
      '/usr/local/go/src/runtime/internal/sys/zgoarch_arm.go',
      '/usr/local/go/src/runtime/internal/sys/zgoarch_mips64.go',
      '/usr/local/go/src/runtime/internal/sys/zgoarch_mips64le.go',
      '/usr/local/go/src/runtime/internal/sys/zgoarch_mips.go',
      '/usr/local/go/src/runtime/internal/sys/zgoarch_mipsle.go',
      '/usr/local/go/src/runtime/internal/sys/zgoarch_ppc64.go',
      '/usr/local/go/src/runtime/internal/sys/zgoarch_ppc64le.go',
      '/usr/local/go/src/runtime/internal/sys/zgoarch_s390x.go',
      '/usr/local/go/src/runtime/internal/sys/zgoos_android.go',
      '/usr/local/go/src/runtime/internal/sys/zgoos_darwin.go',
      '/usr/local/go/src/runtime/internal/sys/zgoos_dragonfly.go',
      '/usr/local/go/src/runtime/internal/sys/zgoos_freebsd.go',
      '/usr/local/go/src/runtime/internal/sys/zgoos_linux.go',
      '/usr/local/go/src/runtime/internal/sys/zgoos_nacl.go',
      '/usr/local/go/src/runtime/internal/sys/zgoos_netbsd.go',
      '/usr/local/go/src/runtime/internal/sys/zgoos_openbsd.go',
      '/usr/local/go/src/runtime/internal/sys/zgoos_plan9.go',
      '/usr/local/go/src/runtime/internal/sys/zgoos_solaris.go',
      '/usr/local/go/src/runtime/internal/sys/zgoos_windows.go',
      '/usr/local/go/src/runtime/internal/sys/zversion.go',
      '/usr/local/go/src/runtime/lfstack_32bit.go',
      '/usr/local/go/src/runtime/lfstack_64bit.go',
      '/usr/local/go/src/runtime/lfstack.go',
      '/usr/local/go/src/runtime/lfstack_test.go',
      '/usr/local/go/src/runtime/lock_futex.go',
      '/usr/local/go/src/runtime/lock_sema.go',
      '/usr/local/go/src/runtime/Makefile',
      '/usr/local/go/src/runtime/malloc.go',
      '/usr/local/go/src/runtime/malloc_test.go',
      '/usr/local/go/src/runtime/mapspeed_test.go',
      '/usr/local/go/src/runtime/map_test.go',
      '/usr/local/go/src/runtime/mbarrier.go',
      '/usr/local/go/src/runtime/mbitmap.go',
      '/usr/local/go/src/runtime/mcache.go',
      '/usr/local/go/src/runtime/mcentral.go',
      '/usr/local/go/src/runtime/mem_bsd.go',
      '/usr/local/go/src/runtime/memclr_386.s',
      '/usr/local/go/src/runtime/memclr_amd64.s',
      '/usr/local/go/src/runtime/memclr_arm64.s',
      '/usr/local/go/src/runtime/memclr_arm.s',
      '/usr/local/go/src/runtime/memclr_mips64x.s',
      '/usr/local/go/src/runtime/memclr_mipsx.s',
      '/usr/local/go/src/runtime/memclr_plan9_386.s',
      '/usr/local/go/src/runtime/memclr_plan9_amd64.s',
      '/usr/local/go/src/runtime/memclr_ppc64x.s',
      '/usr/local/go/src/runtime/memclr_s390x.s',
      '/usr/local/go/src/runtime/mem_darwin.go',
      '/usr/local/go/src/runtime/mem_linux.go',
      '/usr/local/go/src/runtime/memmove_386.s',
      '/usr/local/go/src/runtime/memmove_amd64.s',
      '/usr/local/go/src/runtime/memmove_arm64.s',
      '/usr/local/go/src/runtime/memmove_arm.s',
      '/usr/local/go/src/runtime/memmove_linux_amd64_test.go',
      '/usr/local/go/src/runtime/memmove_mips64x.s',
      '/usr/local/go/src/runtime/memmove_mipsx.s',
      '/usr/local/go/src/runtime/memmove_nacl_amd64p32.s',
      '/usr/local/go/src/runtime/memmove_plan9_386.s',
      '/usr/local/go/src/runtime/memmove_plan9_amd64.s',
      '/usr/local/go/src/runtime/memmove_ppc64x.s',
      '/usr/local/go/src/runtime/memmove_s390x.s',
      '/usr/local/go/src/runtime/memmove_test.go',
      '/usr/local/go/src/runtime/mem_plan9.go',
      '/usr/local/go/src/runtime/mem_windows.go',
      '/usr/local/go/src/runtime/mfinal.go',
      '/usr/local/go/src/runtime/mfinal_test.go',
      '/usr/local/go/src/runtime/mfixalloc.go',
      '/usr/local/go/src/runtime/mgc.go',
      '/usr/local/go/src/runtime/mgclarge.go',
      '/usr/local/go/src/runtime/mgcmark.go',
      '/usr/local/go/src/runtime/mgcsweepbuf.go',
      '/usr/local/go/src/runtime/mgcsweep.go',
      '/usr/local/go/src/runtime/mgcwork.go',
      '/usr/local/go/src/runtime/mheap.go',
      '/usr/local/go/src/runtime/mkduff.go',
      '/usr/local/go/src/runtime/mkfastlog2table.go',
      '/usr/local/go/src/runtime/mknacl.sh',
      '/usr/local/go/src/runtime/mksizeclasses.go',
      '/usr/local/go/src/runtime/mmap.go',
      '/usr/local/go/src/runtime/mprof.go',
      '/usr/local/go/src/runtime/msan',
      '/usr/local/go/src/runtime/msan/msan.go',
      '/usr/local/go/src/runtime/msan0.go',
      '/usr/local/go/src/runtime/msan_amd64.s',
      '/usr/local/go/src/runtime/msan.go',
      '/usr/local/go/src/runtime/msize.go',
      '/usr/local/go/src/runtime/mstats.go',
      '/usr/local/go/src/runtime/net_plan9.go',
      '/usr/local/go/src/runtime/netpoll_epoll.go',
      '/usr/local/go/src/runtime/netpoll.go',
      '/usr/local/go/src/runtime/netpoll_kqueue.go',
      '/usr/local/go/src/runtime/netpoll_nacl.go',
      '/usr/local/go/src/runtime/netpoll_solaris.go',
      '/usr/local/go/src/runtime/netpoll_stub.go',
      '/usr/local/go/src/runtime/netpoll_windows.go',
      '/usr/local/go/src/runtime/noasm.go',
      '/usr/local/go/src/runtime/norace_linux_test.go',
      '/usr/local/go/src/runtime/norace_test.go',
      '/usr/local/go/src/runtime/numcpu_freebsd_test.go',
      '/usr/local/go/src/runtime/os2_freebsd.go',
      '/usr/local/go/src/runtime/os2_nacl.go',
      '/usr/local/go/src/runtime/os2_openbsd.go',
      '/usr/local/go/src/runtime/os2_plan9.go',
      '/usr/local/go/src/runtime/os2_solaris.go',
      '/usr/local/go/src/runtime/os3_plan9.go',
      '/usr/local/go/src/runtime/os3_solaris.go',
      '/usr/local/go/src/runtime/os_android.go',
      '/usr/local/go/src/runtime/os_darwin_arm64.go',
      '/usr/local/go/src/runtime/os_darwin_arm.go',
      '/usr/local/go/src/runtime/os_darwin.go',
      '/usr/local/go/src/runtime/os_dragonfly.go',
      '/usr/local/go/src/runtime/os_freebsd_arm.go',
      '/usr/local/go/src/runtime/os_freebsd.go',
      '/usr/local/go/src/runtime/os_linux_arm64.go',
      '/usr/local/go/src/runtime/os_linux_arm.go',
      '/usr/local/go/src/runtime/os_linux_be64.go',
      '/usr/local/go/src/runtime/os_linux_generic.go',
      '/usr/local/go/src/runtime/os_linux.go',
      '/usr/local/go/src/runtime/os_linux_mips64x.go',
      '/usr/local/go/src/runtime/os_linux_mipsx.go',
      '/usr/local/go/src/runtime/os_linux_noauxv.go',
      '/usr/local/go/src/runtime/os_linux_ppc64x.go',
      '/usr/local/go/src/runtime/os_linux_s390x.go',
      '/usr/local/go/src/runtime/os_nacl_arm.go',
      '/usr/local/go/src/runtime/os_nacl.go',
      '/usr/local/go/src/runtime/os_netbsd_386.go',
      '/usr/local/go/src/runtime/os_netbsd_amd64.go',
      '/usr/local/go/src/runtime/os_netbsd_arm.go',
      '/usr/local/go/src/runtime/os_netbsd.go',
      '/usr/local/go/src/runtime/os_openbsd_arm.go',
      '/usr/local/go/src/runtime/os_openbsd.go',
      '/usr/local/go/src/runtime/os_plan9_arm.go',
      '/usr/local/go/src/runtime/os_plan9.go',
      '/usr/local/go/src/runtime/os_solaris.go',
      '/usr/local/go/src/runtime/os_windows.go',
      '/usr/local/go/src/runtime/panic.go',
      '/usr/local/go/src/runtime/plugin.go',
      '/usr/local/go/src/runtime/pprof',
      '/usr/local/go/src/runtime/pprof/elf.go',
      '/usr/local/go/src/runtime/pprof/internal',
      '/usr/local/go/src/runtime/pprof/internal/profile',
      '/usr/local/go/src/runtime/pprof/internal/profile/encode.go',
      '/usr/local/go/src/runtime/pprof/internal/profile/filter.go',
      '/usr/local/go/src/runtime/pprof/internal/profile/legacy_profile.go',
      '/usr/local/go/src/runtime/pprof/internal/profile/profile.go',
      '/usr/local/go/src/runtime/pprof/internal/profile/profile_test.go',
      '/usr/local/go/src/runtime/pprof/internal/profile/proto.go',
      '/usr/local/go/src/runtime/pprof/internal/profile/proto_test.go',
      '/usr/local/go/src/runtime/pprof/internal/profile/prune.go',
      '/usr/local/go/src/runtime/pprof/label.go',
      '/usr/local/go/src/runtime/pprof/label_test.go',
      '/usr/local/go/src/runtime/pprof/map.go',
      '/usr/local/go/src/runtime/pprof/mprof_test.go',
      '/usr/local/go/src/runtime/pprof/pprof.go',
      '/usr/local/go/src/runtime/pprof/pprof_test.go',
      '/usr/local/go/src/runtime/pprof/protobuf.go',
      '/usr/local/go/src/runtime/pprof/proto.go',
      '/usr/local/go/src/runtime/pprof/protomem.go',
      '/usr/local/go/src/runtime/pprof/protomem_test.go',
      '/usr/local/go/src/runtime/pprof/proto_test.go',
      '/usr/local/go/src/runtime/pprof/runtime.go',
      '/usr/local/go/src/runtime/pprof/runtime_test.go',
      '/usr/local/go/src/runtime/pprof/testdata',
      '/usr/local/go/src/runtime/pprof/testdata/README',
      '/usr/local/go/src/runtime/pprof/testdata/test32',
      '/usr/local/go/src/runtime/pprof/testdata/test32be',
      '/usr/local/go/src/runtime/pprof/testdata/test64',
      '/usr/local/go/src/runtime/pprof/testdata/test64be',
      '/usr/local/go/src/runtime/print.go',
      '/usr/local/go/src/runtime/proc.go',
      '/usr/local/go/src/runtime/proc_runtime_test.go',
      '/usr/local/go/src/runtime/proc_test.go',
      '/usr/local/go/src/runtime/profbuf.go',
      '/usr/local/go/src/runtime/profbuf_test.go',
      '/usr/local/go/src/runtime/proflabel.go',
      '/usr/local/go/src/runtime/race',
      '/usr/local/go/src/runtime/race/doc.go',
      '/usr/local/go/src/runtime/race/output_test.go',
      '/usr/local/go/src/runtime/race/race_darwin_amd64.syso',
      '/usr/local/go/src/runtime/race/race_freebsd_amd64.syso',
      '/usr/local/go/src/runtime/race/race.go',
      '/usr/local/go/src/runtime/race/race_linux_amd64.syso',
      '/usr/local/go/src/runtime/race/race_linux_test.go',
      '/usr/local/go/src/runtime/race/race_test.go',
      '/usr/local/go/src/runtime/race/race_unix_test.go',
      '/usr/local/go/src/runtime/race/race_windows_amd64.syso',
      '/usr/local/go/src/runtime/race/race_windows_test.go',
      '/usr/local/go/src/runtime/race/README',
      '/usr/local/go/src/runtime/race/sched_test.go',
      '/usr/local/go/src/runtime/race/testdata',
      '/usr/local/go/src/runtime/race/testdata/atomic_test.go',
      '/usr/local/go/src/runtime/race/testdata/cgo_test.go',
      '/usr/local/go/src/runtime/race/testdata/cgo_test_main.go',
      '/usr/local/go/src/runtime/race/testdata/chan_test.go',
      '/usr/local/go/src/runtime/race/testdata/comp_test.go',
      '/usr/local/go/src/runtime/race/testdata/finalizer_test.go',
      '/usr/local/go/src/runtime/race/testdata/io_test.go',
      '/usr/local/go/src/runtime/race/testdata/issue12225_test.go',
      '/usr/local/go/src/runtime/race/testdata/issue12664_test.go',
      '/usr/local/go/src/runtime/race/testdata/issue13264_test.go',
      '/usr/local/go/src/runtime/race/testdata/map_test.go',
      '/usr/local/go/src/runtime/race/testdata/mop_test.go',
      '/usr/local/go/src/runtime/race/testdata/mutex_test.go',
      '/usr/local/go/src/runtime/race/testdata/pool_test.go',
      '/usr/local/go/src/runtime/race/testdata/reflect_test.go',
      '/usr/local/go/src/runtime/race/testdata/regression_test.go',
      '/usr/local/go/src/runtime/race/testdata/rwmutex_test.go',
      '/usr/local/go/src/runtime/race/testdata/select_test.go',
      '/usr/local/go/src/runtime/race/testdata/slice_test.go',
      '/usr/local/go/src/runtime/race/testdata/sync_test.go',
      '/usr/local/go/src/runtime/race/testdata/waitgroup_test.go',
      '/usr/local/go/src/runtime/race0.go',
      '/usr/local/go/src/runtime/race_amd64.s',
      '/usr/local/go/src/runtime/race.go',
      '/usr/local/go/src/runtime/rand_test.go',
      '/usr/local/go/src/runtime/rdebug.go',
      '/usr/local/go/src/runtime/relax_stub.go',
      '/usr/local/go/src/runtime/rt0_android_386.s',
      '/usr/local/go/src/runtime/rt0_android_amd64.s',
      '/usr/local/go/src/runtime/rt0_android_arm64.s',
      '/usr/local/go/src/runtime/rt0_android_arm.s',
      '/usr/local/go/src/runtime/rt0_darwin_386.s',
      '/usr/local/go/src/runtime/rt0_darwin_amd64.s',
      '/usr/local/go/src/runtime/rt0_darwin_arm64.s',
      '/usr/local/go/src/runtime/rt0_darwin_arm.s',
      '/usr/local/go/src/runtime/rt0_dragonfly_amd64.s',
      '/usr/local/go/src/runtime/rt0_freebsd_386.s',
      '/usr/local/go/src/runtime/rt0_freebsd_amd64.s',
      '/usr/local/go/src/runtime/rt0_freebsd_arm.s',
      '/usr/local/go/src/runtime/rt0_linux_386.s',
      '/usr/local/go/src/runtime/rt0_linux_amd64.s',
      '/usr/local/go/src/runtime/rt0_linux_arm64.s',
      '/usr/local/go/src/runtime/rt0_linux_arm.s',
      '/usr/local/go/src/runtime/rt0_linux_mips64x.s',
      '/usr/local/go/src/runtime/rt0_linux_mipsx.s',
      '/usr/local/go/src/runtime/rt0_linux_ppc64le.s',
      '/usr/local/go/src/runtime/rt0_linux_ppc64.s',
      '/usr/local/go/src/runtime/rt0_linux_s390x.s',
      '/usr/local/go/src/runtime/rt0_nacl_386.s',
      '/usr/local/go/src/runtime/rt0_nacl_amd64p32.s',
      '/usr/local/go/src/runtime/rt0_nacl_arm.s',
      '/usr/local/go/src/runtime/rt0_netbsd_386.s',
      '/usr/local/go/src/runtime/rt0_netbsd_amd64.s',
      '/usr/local/go/src/runtime/rt0_netbsd_arm.s',
      '/usr/local/go/src/runtime/rt0_openbsd_386.s',
      '/usr/local/go/src/runtime/rt0_openbsd_amd64.s',
      '/usr/local/go/src/runtime/rt0_openbsd_arm.s',
      '/usr/local/go/src/runtime/rt0_plan9_386.s',
      '/usr/local/go/src/runtime/rt0_plan9_amd64.s',
      '/usr/local/go/src/runtime/rt0_plan9_arm.s',
      '/usr/local/go/src/runtime/rt0_solaris_amd64.s',
      '/usr/local/go/src/runtime/rt0_windows_386.s',
      '/usr/local/go/src/runtime/rt0_windows_amd64.s',
      '/usr/local/go/src/runtime/runtime1.go',
      '/usr/local/go/src/runtime/runtime2.go',
      '/usr/local/go/src/runtime/runtime-gdb.py',
      '/usr/local/go/src/runtime/runtime-gdb_test.go',
      '/usr/local/go/src/runtime/runtime.go',
      '/usr/local/go/src/runtime/runtime_linux_test.go',
      '/usr/local/go/src/runtime/runtime-lldb_test.go',
      '/usr/local/go/src/runtime/runtime_mmap_test.go',
      '/usr/local/go/src/runtime/runtime_test.go',
      '/usr/local/go/src/runtime/runtime_unix_test.go',
      '/usr/local/go/src/runtime/rwmutex.go',
      '/usr/local/go/src/runtime/rwmutex_test.go',
      '/usr/local/go/src/runtime/select.go',
      '/usr/local/go/src/runtime/sema.go',
      '/usr/local/go/src/runtime/sigaction_linux.go',
      '/usr/local/go/src/runtime/signal_386.go',
      '/usr/local/go/src/runtime/signal_amd64x.go',
      '/usr/local/go/src/runtime/signal_arm64.go',
      '/usr/local/go/src/runtime/signal_arm.go',
      '/usr/local/go/src/runtime/signal_darwin_386.go',
      '/usr/local/go/src/runtime/signal_darwin_amd64.go',
      '/usr/local/go/src/runtime/signal_darwin_arm64.go',
      '/usr/local/go/src/runtime/signal_darwin_arm.go',
      '/usr/local/go/src/runtime/signal_darwin.go',
      '/usr/local/go/src/runtime/signal_dragonfly_amd64.go',
      '/usr/local/go/src/runtime/signal_dragonfly.go',
      '/usr/local/go/src/runtime/signal_freebsd_386.go',
      '/usr/local/go/src/runtime/signal_freebsd_amd64.go',
      '/usr/local/go/src/runtime/signal_freebsd_arm.go',
      '/usr/local/go/src/runtime/signal_freebsd.go',
      '/usr/local/go/src/runtime/signal_linux_386.go',
      '/usr/local/go/src/runtime/signal_linux_amd64.go',
      '/usr/local/go/src/runtime/signal_linux_arm64.go',
      '/usr/local/go/src/runtime/signal_linux_arm.go',
      '/usr/local/go/src/runtime/signal_linux_mips64x.go',
      '/usr/local/go/src/runtime/signal_linux_mipsx.go',
      '/usr/local/go/src/runtime/signal_linux_ppc64x.go',
      '/usr/local/go/src/runtime/signal_linux_s390x.go',
      '/usr/local/go/src/runtime/signal_mips64x.go',
      '/usr/local/go/src/runtime/signal_mipsx.go',
      '/usr/local/go/src/runtime/signal_nacl_386.go',
      '/usr/local/go/src/runtime/signal_nacl_amd64p32.go',
      '/usr/local/go/src/runtime/signal_nacl_arm.go',
      '/usr/local/go/src/runtime/signal_nacl.go',
      '/usr/local/go/src/runtime/signal_netbsd_386.go',
      '/usr/local/go/src/runtime/signal_netbsd_amd64.go',
      '/usr/local/go/src/runtime/signal_netbsd_arm.go',
      '/usr/local/go/src/runtime/signal_netbsd.go',
      '/usr/local/go/src/runtime/signal_openbsd_386.go',
      '/usr/local/go/src/runtime/signal_openbsd_amd64.go',
      '/usr/local/go/src/runtime/signal_openbsd_arm.go',
      '/usr/local/go/src/runtime/signal_openbsd.go',
      '/usr/local/go/src/runtime/signal_plan9.go',
      '/usr/local/go/src/runtime/signal_ppc64x.go',
      '/usr/local/go/src/runtime/signal_sighandler.go',
      '/usr/local/go/src/runtime/signal_solaris_amd64.go',
      '/usr/local/go/src/runtime/signal_solaris.go',
      '/usr/local/go/src/runtime/signal_unix.go',
      '/usr/local/go/src/runtime/signal_windows.go',
      '/usr/local/go/src/runtime/sigqueue.go',
      '/usr/local/go/src/runtime/sigqueue_plan9.go',
      '/usr/local/go/src/runtime/sigtab_linux_generic.go',
      '/usr/local/go/src/runtime/sigtab_linux_mipsx.go',
      '/usr/local/go/src/runtime/sizeclasses.go',
      '/usr/local/go/src/runtime/slice.go',
      '/usr/local/go/src/runtime/softfloat64.go',
      '/usr/local/go/src/runtime/softfloat64_test.go',
      '/usr/local/go/src/runtime/softfloat_arm.go',
      '/usr/local/go/src/runtime/sqrt.go',
      '/usr/local/go/src/runtime/sqrt_test.go',
      '/usr/local/go/src/runtime/stack.go',
      '/usr/local/go/src/runtime/stack_test.go',
      '/usr/local/go/src/runtime/string.go',
      '/usr/local/go/src/runtime/string_test.go',
      '/usr/local/go/src/runtime/stubs2.go',
      '/usr/local/go/src/runtime/stubs32.go',
      '/usr/local/go/src/runtime/stubs_android.go',
      '/usr/local/go/src/runtime/stubs_asm.go',
      '/usr/local/go/src/runtime/stubs.go',
      '/usr/local/go/src/runtime/stubs_linux.go',
      '/usr/local/go/src/runtime/stubs_nonlinux.go',
      '/usr/local/go/src/runtime/symtab.go',
      '/usr/local/go/src/runtime/symtab_test.go',
      '/usr/local/go/src/runtime/sys_arm64.go',
      '/usr/local/go/src/runtime/sys_arm.go',
      '/usr/local/go/src/runtime/syscall2_solaris.go',
      '/usr/local/go/src/runtime/syscall_nacl.h',
      '/usr/local/go/src/runtime/syscall_solaris.go',
      '/usr/local/go/src/runtime/syscall_windows.go',
      '/usr/local/go/src/runtime/syscall_windows_test.go',
      '/usr/local/go/src/runtime/sys_darwin_386.s',
      '/usr/local/go/src/runtime/sys_darwin_amd64.s',
      '/usr/local/go/src/runtime/sys_darwin_arm64.s',
      '/usr/local/go/src/runtime/sys_darwin_arm.s',
      '/usr/local/go/src/runtime/sys_dragonfly_amd64.s',
      '/usr/local/go/src/runtime/sys_freebsd_386.s',
      '/usr/local/go/src/runtime/sys_freebsd_amd64.s',
      '/usr/local/go/src/runtime/sys_freebsd_arm.s',
      '/usr/local/go/src/runtime/sys_linux_386.s',
      '/usr/local/go/src/runtime/sys_linux_amd64.s',
      '/usr/local/go/src/runtime/sys_linux_arm64.s',
      '/usr/local/go/src/runtime/sys_linux_arm.s',
      '/usr/local/go/src/runtime/sys_linux_mips64x.s',
      '/usr/local/go/src/runtime/sys_linux_mipsx.s',
      '/usr/local/go/src/runtime/sys_linux_ppc64x.s',
      '/usr/local/go/src/runtime/sys_linux_s390x.s',
      '/usr/local/go/src/runtime/sys_mips64x.go',
      '/usr/local/go/src/runtime/sys_mipsx.go',
      '/usr/local/go/src/runtime/sys_nacl_386.s',
      '/usr/local/go/src/runtime/sys_nacl_amd64p32.s',
      '/usr/local/go/src/runtime/sys_nacl_arm.s',
      '/usr/local/go/src/runtime/sys_netbsd_386.s',
      '/usr/local/go/src/runtime/sys_netbsd_amd64.s',
      '/usr/local/go/src/runtime/sys_netbsd_arm.s',
      '/usr/local/go/src/runtime/sys_nonppc64x.go',
      '/usr/local/go/src/runtime/sys_openbsd_386.s',
      '/usr/local/go/src/runtime/sys_openbsd_amd64.s',
      '/usr/local/go/src/runtime/sys_openbsd_arm.s',
      '/usr/local/go/src/runtime/sys_plan9_386.s',
      '/usr/local/go/src/runtime/sys_plan9_amd64.s',
      '/usr/local/go/src/runtime/sys_plan9_arm.s',
      '/usr/local/go/src/runtime/sys_ppc64x.go',
      '/usr/local/go/src/runtime/sys_s390x.go',
      '/usr/local/go/src/runtime/sys_solaris_amd64.s',
      '/usr/local/go/src/runtime/sys_windows_386.s',
      '/usr/local/go/src/runtime/sys_windows_amd64.s',
      '/usr/local/go/src/runtime/sys_x86.go',
      '/usr/local/go/src/runtime/testdata',
      '/usr/local/go/src/runtime/testdata/testprog',
      '/usr/local/go/src/runtime/testdata/testprog/crash.go',
      '/usr/local/go/src/runtime/testdata/testprog/deadlock.go',
      '/usr/local/go/src/runtime/testdata/testprog/gc.go',
      '/usr/local/go/src/runtime/testdata/testprog/main.go',
      '/usr/local/go/src/runtime/testdata/testprog/map.go',
      '/usr/local/go/src/runtime/testdata/testprog/memprof.go',
      '/usr/local/go/src/runtime/testdata/testprog/misc.go',
      '/usr/local/go/src/runtime/testdata/testprog/numcpu_freebsd.go',
      '/usr/local/go/src/runtime/testdata/testprog/panicrace.go',
      '/usr/local/go/src/runtime/testdata/testprog/signal.go',
      '/usr/local/go/src/runtime/testdata/testprog/stringconcat.go',
      '/usr/local/go/src/runtime/testdata/testprog/syscall_windows.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo',
      '/usr/local/go/src/runtime/testdata/testprogcgo/aprof.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/callback.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/cgo.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/crash.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/deadlock.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/dll_windows.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/dropm.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/dropm_stub.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/exec.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/main.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/numgoroutine.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/pprof.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/raceprof.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/racesig.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/threadpanic.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/threadpanic_unix.c',
      '/usr/local/go/src/runtime/testdata/testprogcgo/threadpanic_windows.c',
      '/usr/local/go/src/runtime/testdata/testprogcgo/threadpprof.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/threadprof.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/tracebackctxt_c.c',
      '/usr/local/go/src/runtime/testdata/testprogcgo/tracebackctxt.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/traceback.go',
      '/usr/local/go/src/runtime/testdata/testprogcgo/windows',
      '/usr/local/go/src/runtime/testdata/testprogcgo/windows/win.go',
      '/usr/local/go/src/runtime/testdata/testprognet',
      '/usr/local/go/src/runtime/testdata/testprognet/main.go',
      '/usr/local/go/src/runtime/testdata/testprognet/net.go',
      '/usr/local/go/src/runtime/testdata/testprognet/signalexec.go',
      '/usr/local/go/src/runtime/testdata/testprognet/signal.go',
      '/usr/local/go/src/runtime/textflag.h',
      '/usr/local/go/src/runtime/timeasm.go',
      '/usr/local/go/src/runtime/time.go',
      '/usr/local/go/src/runtime/timestub.go',
      '/usr/local/go/src/runtime/tls_arm64.h',
      '/usr/local/go/src/runtime/tls_arm64.s',
      '/usr/local/go/src/runtime/tls_arm.s',
      '/usr/local/go/src/runtime/tls_mips64x.s',
      '/usr/local/go/src/runtime/tls_mipsx.s',
      '/usr/local/go/src/runtime/tls_ppc64x.s',
      '/usr/local/go/src/runtime/tls_s390x.s',
      '/usr/local/go/src/runtime/trace',
      '/usr/local/go/src/runtime/trace/trace.go',
      '/usr/local/go/src/runtime/trace/trace_stack_test.go',
      '/usr/local/go/src/runtime/trace/trace_test.go',
      '/usr/local/go/src/runtime/traceback.go',
      '/usr/local/go/src/runtime/trace.go',
      '/usr/local/go/src/runtime/type.go',
      '/usr/local/go/src/runtime/typekind.go',
      '/usr/local/go/src/runtime/unaligned1.go',
      '/usr/local/go/src/runtime/unaligned2.go',
      '/usr/local/go/src/runtime/utf8.go',
      '/usr/local/go/src/runtime/vdso_linux_amd64.go',
      '/usr/local/go/src/runtime/vdso_none.go',
      '/usr/local/go/src/runtime/vlop_386.s',
      '/usr/local/go/src/runtime/vlop_arm.s',
      '/usr/local/go/src/runtime/vlop_arm_test.go',
      '/usr/local/go/src/runtime/vlrt.go',
      '/usr/local/go/src/runtime/wincallback.go',
      '/usr/local/go/src/runtime/write_err_android.go',
      '/usr/local/go/src/runtime/write_err.go',
      '/usr/local/go/src/runtime/zcallback_windows.go',
      '/usr/local/go/src/runtime/zcallback_windows.s',
      '/usr/local/go/src/sort',
      '/usr/local/go/src/sort/example_interface_test.go',
      '/usr/local/go/src/sort/example_keys_test.go',
      '/usr/local/go/src/sort/example_multi_test.go',
      '/usr/local/go/src/sort/example_search_test.go',
      '/usr/local/go/src/sort/example_test.go',
      '/usr/local/go/src/sort/example_wrapper_test.go',
      '/usr/local/go/src/sort/export_test.go',
      '/usr/local/go/src/sort/genzfunc.go',
      '/usr/local/go/src/sort/search.go',
      '/usr/local/go/src/sort/search_test.go',
      '/usr/local/go/src/sort/sort.go',
      '/usr/local/go/src/sort/sort_test.go',
      '/usr/local/go/src/sort/zfuncversion.go',
      '/usr/local/go/src/strconv',
      '/usr/local/go/src/strconv/atob.go',
      '/usr/local/go/src/strconv/atob_test.go',
      '/usr/local/go/src/strconv/atof.go',
      '/usr/local/go/src/strconv/atof_test.go',
      '/usr/local/go/src/strconv/atoi.go',
      '/usr/local/go/src/strconv/atoi_test.go',
      '/usr/local/go/src/strconv/decimal.go',
      '/usr/local/go/src/strconv/decimal_test.go',
      '/usr/local/go/src/strconv/doc.go',
      '/usr/local/go/src/strconv/example_test.go',
      '/usr/local/go/src/strconv/extfloat.go',
      '/usr/local/go/src/strconv/fp_test.go',
      '/usr/local/go/src/strconv/ftoa.go',
      '/usr/local/go/src/strconv/ftoa_test.go',
      '/usr/local/go/src/strconv/internal_test.go',
      '/usr/local/go/src/strconv/isprint.go',
      '/usr/local/go/src/strconv/itoa.go',
      '/usr/local/go/src/strconv/itoa_test.go',
      '/usr/local/go/src/strconv/makeisprint.go',
      '/usr/local/go/src/strconv/quote.go',
      '/usr/local/go/src/strconv/quote_test.go',
      '/usr/local/go/src/strconv/strconv_test.go',
      '/usr/local/go/src/strconv/testdata',
      '/usr/local/go/src/strconv/testdata/testfp.txt',
      '/usr/local/go/src/strings',
      '/usr/local/go/src/strings/compare.go',
      '/usr/local/go/src/strings/compare_test.go',
      '/usr/local/go/src/strings/example_test.go',
      '/usr/local/go/src/strings/export_test.go',
      '/usr/local/go/src/strings/reader.go',
      '/usr/local/go/src/strings/reader_test.go',
      '/usr/local/go/src/strings/replace.go',
      '/usr/local/go/src/strings/replace_test.go',
      '/usr/local/go/src/strings/search.go',
      '/usr/local/go/src/strings/search_test.go',
      '/usr/local/go/src/strings/strings_amd64.go',
      '/usr/local/go/src/strings/strings_decl.go',
      '/usr/local/go/src/strings/strings_generic.go',
      '/usr/local/go/src/strings/strings.go',
      '/usr/local/go/src/strings/strings.s',
      '/usr/local/go/src/strings/strings_s390x.go',
      '/usr/local/go/src/strings/strings_test.go',
      '/usr/local/go/src/sync',
      '/usr/local/go/src/sync/atomic',
      '/usr/local/go/src/sync/atomic/64bit_arm.go',
      '/usr/local/go/src/sync/atomic/asm_386.s',
      '/usr/local/go/src/sync/atomic/asm_amd64p32.s',
      '/usr/local/go/src/sync/atomic/asm_amd64.s',
      '/usr/local/go/src/sync/atomic/asm_arm64.s',
      '/usr/local/go/src/sync/atomic/asm_arm.s',
      '/usr/local/go/src/sync/atomic/asm_darwin_arm.s',
      '/usr/local/go/src/sync/atomic/asm_freebsd_arm.s',
      '/usr/local/go/src/sync/atomic/asm_linux_arm.s',
      '/usr/local/go/src/sync/atomic/asm_mips64x.s',
      '/usr/local/go/src/sync/atomic/asm_mipsx.s',
      '/usr/local/go/src/sync/atomic/asm_nacl_arm.s',
      '/usr/local/go/src/sync/atomic/asm_netbsd_arm.s',
      '/usr/local/go/src/sync/atomic/asm_openbsd_arm.s',
      '/usr/local/go/src/sync/atomic/asm_plan9_arm.s',
      '/usr/local/go/src/sync/atomic/asm_ppc64x.s',
      '/usr/local/go/src/sync/atomic/asm_s390x.s',
      '/usr/local/go/src/sync/atomic/atomic_linux_arm_test.go',
      '/usr/local/go/src/sync/atomic/atomic_test.go',
      '/usr/local/go/src/sync/atomic/doc.go',
      '/usr/local/go/src/sync/atomic/export_linux_arm_test.go',
      '/usr/local/go/src/sync/atomic/race.s',
      '/usr/local/go/src/sync/atomic/value.go',
      '/usr/local/go/src/sync/atomic/value_test.go',
      '/usr/local/go/src/sync/cond.go',
      '/usr/local/go/src/sync/cond_test.go',
      '/usr/local/go/src/sync/example_pool_test.go',
      '/usr/local/go/src/sync/example_test.go',
      '/usr/local/go/src/sync/export_test.go',
      '/usr/local/go/src/sync/map_bench_test.go',
      '/usr/local/go/src/sync/map.go',
      '/usr/local/go/src/sync/map_reference_test.go',
      '/usr/local/go/src/sync/map_test.go',
      '/usr/local/go/src/sync/mutex.go',
      '/usr/local/go/src/sync/mutex_test.go',
      '/usr/local/go/src/sync/once.go',
      '/usr/local/go/src/sync/once_test.go',
      '/usr/local/go/src/sync/pool.go',
      '/usr/local/go/src/sync/pool_test.go',
      '/usr/local/go/src/sync/runtime.go',
      '/usr/local/go/src/sync/runtime_sema_test.go',
      '/usr/local/go/src/sync/rwmutex.go',
      '/usr/local/go/src/sync/rwmutex_test.go',
      '/usr/local/go/src/sync/waitgroup.go',
      '/usr/local/go/src/sync/waitgroup_test.go',
      '/usr/local/go/src/syscall',
      '/usr/local/go/src/syscall/asm9_unix1_amd64.s',
      '/usr/local/go/src/syscall/asm9_unix2_amd64.s',
      '/usr/local/go/src/syscall/asm_darwin_386.s',
      '/usr/local/go/src/syscall/asm_darwin_amd64.s',
      '/usr/local/go/src/syscall/asm_darwin_arm64.s',
      '/usr/local/go/src/syscall/asm_darwin_arm.s',
      '/usr/local/go/src/syscall/asm_freebsd_arm.s',
      '/usr/local/go/src/syscall/asm_linux_386.s',
      '/usr/local/go/src/syscall/asm_linux_amd64.s',
      '/usr/local/go/src/syscall/asm_linux_arm64.s',
      '/usr/local/go/src/syscall/asm_linux_arm.s',
      '/usr/local/go/src/syscall/asm_linux_mips64x.s',
      '/usr/local/go/src/syscall/asm_linux_mipsx.s',
      '/usr/local/go/src/syscall/asm_linux_ppc64x.s',
      '/usr/local/go/src/syscall/asm_linux_s390x.s',
      '/usr/local/go/src/syscall/asm_nacl_386.s',
      '/usr/local/go/src/syscall/asm_nacl_amd64p32.s',
      '/usr/local/go/src/syscall/asm_nacl_arm.s',
      '/usr/local/go/src/syscall/asm_netbsd_arm.s',
      '/usr/local/go/src/syscall/asm_openbsd_arm.s',
      '/usr/local/go/src/syscall/asm_plan9_386.s',
      '/usr/local/go/src/syscall/asm_plan9_amd64.s',
      '/usr/local/go/src/syscall/asm_plan9_arm.s',
      '/usr/local/go/src/syscall/asm_solaris_amd64.s',
      '/usr/local/go/src/syscall/asm_unix_386.s',
      '/usr/local/go/src/syscall/asm_unix_amd64.s',
      '/usr/local/go/src/syscall/bpf_bsd.go',
      '/usr/local/go/src/syscall/const_plan9.go',
      '/usr/local/go/src/syscall/creds_test.go',
      '/usr/local/go/src/syscall/dirent.go',
      '/usr/local/go/src/syscall/dir_plan9.go',
      '/usr/local/go/src/syscall/dll_windows.go',
      '/usr/local/go/src/syscall/endian_big.go',
      '/usr/local/go/src/syscall/endian_little.go',
      '/usr/local/go/src/syscall/env_plan9.go',
      '/usr/local/go/src/syscall/env_unix.go',
      '/usr/local/go/src/syscall/env_windows.go',
      '/usr/local/go/src/syscall/errors_plan9.go',
      '/usr/local/go/src/syscall/exec_bsd.go',
      '/usr/local/go/src/syscall/exec_freebsd.go',
      '/usr/local/go/src/syscall/exec_linux.go',
      '/usr/local/go/src/syscall/exec_linux_test.go',
      '/usr/local/go/src/syscall/exec_plan9.go',
      '/usr/local/go/src/syscall/exec_solaris.go',
      '/usr/local/go/src/syscall/exec_solaris_test.go',
      '/usr/local/go/src/syscall/exec_unix.go',
      '/usr/local/go/src/syscall/exec_unix_test.go',
      '/usr/local/go/src/syscall/exec_windows.go',
      '/usr/local/go/src/syscall/export_test.go',
      '/usr/local/go/src/syscall/export_unix_test.go',
      '/usr/local/go/src/syscall/fd_nacl.go',
      '/usr/local/go/src/syscall/flock.go',
      '/usr/local/go/src/syscall/flock_linux_32bit.go',
      '/usr/local/go/src/syscall/forkpipe_bsd.go',
      '/usr/local/go/src/syscall/fs_nacl.go',
      '/usr/local/go/src/syscall/lsf_linux.go',
      '/usr/local/go/src/syscall/mkall.sh',
      '/usr/local/go/src/syscall/mkerrors.sh',
      '/usr/local/go/src/syscall/mkpost.go',
      '/usr/local/go/src/syscall/mksyscall.pl',
      '/usr/local/go/src/syscall/mksyscall_solaris.pl',
      '/usr/local/go/src/syscall/mksyscall_windows.go',
      '/usr/local/go/src/syscall/mksysctl_openbsd.pl',
      '/usr/local/go/src/syscall/mksysnum_darwin.pl',
      '/usr/local/go/src/syscall/mksysnum_dragonfly.pl',
      '/usr/local/go/src/syscall/mksysnum_freebsd.pl',
      '/usr/local/go/src/syscall/mksysnum_linux.pl',
      '/usr/local/go/src/syscall/mksysnum_netbsd.pl',
      '/usr/local/go/src/syscall/mksysnum_openbsd.pl',
      '/usr/local/go/src/syscall/mksysnum_plan9.sh',
      '/usr/local/go/src/syscall/mmap_unix_test.go',
      '/usr/local/go/src/syscall/msan0.go',
      '/usr/local/go/src/syscall/msan.go',
      '/usr/local/go/src/syscall/net.go',
      '/usr/local/go/src/syscall/netlink_linux.go',
      '/usr/local/go/src/syscall/net_nacl.go',
      '/usr/local/go/src/syscall/pwd_plan9.go',
      '/usr/local/go/src/syscall/route_bsd.go',
      '/usr/local/go/src/syscall/route_darwin.go',
      '/usr/local/go/src/syscall/route_dragonfly.go',
      '/usr/local/go/src/syscall/route_freebsd_32bit.go',
      '/usr/local/go/src/syscall/route_freebsd_64bit.go',
      '/usr/local/go/src/syscall/route_freebsd.go',
      '/usr/local/go/src/syscall/route_netbsd.go',
      '/usr/local/go/src/syscall/route_openbsd.go',
      '/usr/local/go/src/syscall/security_windows.go',
      '/usr/local/go/src/syscall/setuidgid_32_linux.go',
      '/usr/local/go/src/syscall/setuidgid_linux.go',
      '/usr/local/go/src/syscall/sockcmsg_linux.go',
      '/usr/local/go/src/syscall/sockcmsg_unix.go',
      '/usr/local/go/src/syscall/str.go',
      '/usr/local/go/src/syscall/syscall_bsd.go',
      '/usr/local/go/src/syscall/syscall_bsd_test.go',
      '/usr/local/go/src/syscall/syscall_darwin_386.go',
      '/usr/local/go/src/syscall/syscall_darwin_amd64.go',
      '/usr/local/go/src/syscall/syscall_darwin_arm64.go',
      '/usr/local/go/src/syscall/syscall_darwin_arm.go',
      '/usr/local/go/src/syscall/syscall_darwin.go',
      '/usr/local/go/src/syscall/syscall_dragonfly_amd64.go',
      '/usr/local/go/src/syscall/syscall_dragonfly.go',
      '/usr/local/go/src/syscall/syscall_freebsd_386.go',
      '/usr/local/go/src/syscall/syscall_freebsd_amd64.go',
      '/usr/local/go/src/syscall/syscall_freebsd_arm.go',
      '/usr/local/go/src/syscall/syscall_freebsd.go',
      '/usr/local/go/src/syscall/syscall.go',
      '/usr/local/go/src/syscall/syscall_linux_386.go',
      '/usr/local/go/src/syscall/syscall_linux_amd64.go',
      '/usr/local/go/src/syscall/syscall_linux_arm64.go',
      '/usr/local/go/src/syscall/syscall_linux_arm.go',
      '/usr/local/go/src/syscall/syscall_linux.go',
      '/usr/local/go/src/syscall/syscall_linux_mips64x.go',
      '/usr/local/go/src/syscall/syscall_linux_mipsx.go',
      '/usr/local/go/src/syscall/syscall_linux_ppc64x.go',
      '/usr/local/go/src/syscall/syscall_linux_s390x.go',
      '/usr/local/go/src/syscall/syscall_linux_test.go',
      '/usr/local/go/src/syscall/syscall_nacl_386.go',
      '/usr/local/go/src/syscall/syscall_nacl_amd64p32.go',
      '/usr/local/go/src/syscall/syscall_nacl_arm.go',
      '/usr/local/go/src/syscall/syscall_nacl.go',
      '/usr/local/go/src/syscall/syscall_netbsd_386.go',
      '/usr/local/go/src/syscall/syscall_netbsd_amd64.go',
      '/usr/local/go/src/syscall/syscall_netbsd_arm.go',
      '/usr/local/go/src/syscall/syscall_netbsd.go',
      '/usr/local/go/src/syscall/syscall_no_getwd.go',
      '/usr/local/go/src/syscall/syscall_openbsd_386.go',
      '/usr/local/go/src/syscall/syscall_openbsd_amd64.go',
      '/usr/local/go/src/syscall/syscall_openbsd_arm.go',
      '/usr/local/go/src/syscall/syscall_openbsd.go',
      '/usr/local/go/src/syscall/syscall_plan9.go',
      '/usr/local/go/src/syscall/syscall_solaris_amd64.go',
      '/usr/local/go/src/syscall/syscall_solaris.go',
      '/usr/local/go/src/syscall/syscall_test.go',
      '/usr/local/go/src/syscall/syscall_unix.go',
      '/usr/local/go/src/syscall/syscall_unix_test.go',
      '/usr/local/go/src/syscall/syscall_windows_386.go',
      '/usr/local/go/src/syscall/syscall_windows_amd64.go',
      '/usr/local/go/src/syscall/syscall_windows.go',
      '/usr/local/go/src/syscall/syscall_windows_test.go',
      '/usr/local/go/src/syscall/tables_nacl.go',
      '/usr/local/go/src/syscall/time_nacl_386.s',
      '/usr/local/go/src/syscall/time_nacl_amd64p32.s',
      '/usr/local/go/src/syscall/time_nacl_arm.s',
      '/usr/local/go/src/syscall/timestruct.go',
      '/usr/local/go/src/syscall/types_darwin.go',
      '/usr/local/go/src/syscall/types_dragonfly.go',
      '/usr/local/go/src/syscall/types_freebsd.go',
      '/usr/local/go/src/syscall/types_linux.go',
      '/usr/local/go/src/syscall/types_netbsd.go',
      '/usr/local/go/src/syscall/types_openbsd.go',
      '/usr/local/go/src/syscall/types_solaris.go',
      '/usr/local/go/src/syscall/unzip_nacl.go',
      '/usr/local/go/src/syscall/zerrors_darwin_386.go',
      '/usr/local/go/src/syscall/zerrors_darwin_amd64.go',
      '/usr/local/go/src/syscall/zerrors_darwin_arm64.go',
      '/usr/local/go/src/syscall/zerrors_darwin_arm.go',
      '/usr/local/go/src/syscall/zerrors_dragonfly_amd64.go',
      '/usr/local/go/src/syscall/zerrors_freebsd_386.go',
      '/usr/local/go/src/syscall/zerrors_freebsd_amd64.go',
      '/usr/local/go/src/syscall/zerrors_freebsd_arm.go',
      '/usr/local/go/src/syscall/zerrors_linux_386.go',
      '/usr/local/go/src/syscall/zerrors_linux_amd64.go',
      '/usr/local/go/src/syscall/zerrors_linux_arm64.go',
      '/usr/local/go/src/syscall/zerrors_linux_arm.go',
      '/usr/local/go/src/syscall/zerrors_linux_mips64.go',
      '/usr/local/go/src/syscall/zerrors_linux_mips64le.go',
      '/usr/local/go/src/syscall/zerrors_linux_mips.go',
      '/usr/local/go/src/syscall/zerrors_linux_mipsle.go',
      '/usr/local/go/src/syscall/zerrors_linux_ppc64.go',
      '/usr/local/go/src/syscall/zerrors_linux_ppc64le.go',
      '/usr/local/go/src/syscall/zerrors_linux_s390x.go',
      '/usr/local/go/src/syscall/zerrors_netbsd_386.go',
      '/usr/local/go/src/syscall/zerrors_netbsd_amd64.go',
      '/usr/local/go/src/syscall/zerrors_netbsd_arm.go',
      '/usr/local/go/src/syscall/zerrors_openbsd_386.go',
      '/usr/local/go/src/syscall/zerrors_openbsd_amd64.go',
      '/usr/local/go/src/syscall/zerrors_openbsd_arm.go',
      '/usr/local/go/src/syscall/zerrors_solaris_amd64.go',
      '/usr/local/go/src/syscall/zerrors_windows_386.go',
      '/usr/local/go/src/syscall/zerrors_windows_amd64.go',
      '/usr/local/go/src/syscall/zerrors_windows.go',
      '/usr/local/go/src/syscall/zsyscall_darwin_386.go',
      '/usr/local/go/src/syscall/zsyscall_darwin_amd64.go',
      '/usr/local/go/src/syscall/zsyscall_darwin_arm64.go',
      '/usr/local/go/src/syscall/zsyscall_darwin_arm.go',
      '/usr/local/go/src/syscall/zsyscall_dragonfly_amd64.go',
      '/usr/local/go/src/syscall/zsyscall_freebsd_386.go',
      '/usr/local/go/src/syscall/zsyscall_freebsd_amd64.go',
      '/usr/local/go/src/syscall/zsyscall_freebsd_arm.go',
      '/usr/local/go/src/syscall/zsyscall_linux_386.go',
      '/usr/local/go/src/syscall/zsyscall_linux_amd64.go',
      '/usr/local/go/src/syscall/zsyscall_linux_arm64.go',
      '/usr/local/go/src/syscall/zsyscall_linux_arm.go',
      '/usr/local/go/src/syscall/zsyscall_linux_mips64.go',
      '/usr/local/go/src/syscall/zsyscall_linux_mips64le.go',
      '/usr/local/go/src/syscall/zsyscall_linux_mips.go',
      '/usr/local/go/src/syscall/zsyscall_linux_mipsle.go',
      '/usr/local/go/src/syscall/zsyscall_linux_ppc64.go',
      '/usr/local/go/src/syscall/zsyscall_linux_ppc64le.go',
      '/usr/local/go/src/syscall/zsyscall_linux_s390x.go',
      '/usr/local/go/src/syscall/zsyscall_nacl_386.go',
      '/usr/local/go/src/syscall/zsyscall_nacl_amd64p32.go',
      '/usr/local/go/src/syscall/zsyscall_nacl_arm.go',
      '/usr/local/go/src/syscall/zsyscall_netbsd_386.go',
      '/usr/local/go/src/syscall/zsyscall_netbsd_amd64.go',
      '/usr/local/go/src/syscall/zsyscall_netbsd_arm.go',
      '/usr/local/go/src/syscall/zsyscall_openbsd_386.go',
      '/usr/local/go/src/syscall/zsyscall_openbsd_amd64.go',
      '/usr/local/go/src/syscall/zsyscall_openbsd_arm.go',
      '/usr/local/go/src/syscall/zsyscall_plan9_386.go',
      '/usr/local/go/src/syscall/zsyscall_plan9_amd64.go',
      '/usr/local/go/src/syscall/zsyscall_plan9_arm.go',
      '/usr/local/go/src/syscall/zsyscall_solaris_amd64.go',
      '/usr/local/go/src/syscall/zsyscall_windows.go',
      '/usr/local/go/src/syscall/zsysctl_openbsd.go',
      '/usr/local/go/src/syscall/zsysnum_darwin_386.go',
      '/usr/local/go/src/syscall/zsysnum_darwin_amd64.go',
      '/usr/local/go/src/syscall/zsysnum_darwin_arm64.go',
      '/usr/local/go/src/syscall/zsysnum_darwin_arm.go',
      '/usr/local/go/src/syscall/zsysnum_dragonfly_amd64.go',
      '/usr/local/go/src/syscall/zsysnum_freebsd_386.go',
      '/usr/local/go/src/syscall/zsysnum_freebsd_amd64.go',
      '/usr/local/go/src/syscall/zsysnum_freebsd_arm.go',
      '/usr/local/go/src/syscall/zsysnum_linux_386.go',
      '/usr/local/go/src/syscall/zsysnum_linux_amd64.go',
      '/usr/local/go/src/syscall/zsysnum_linux_arm64.go',
      '/usr/local/go/src/syscall/zsysnum_linux_arm.go',
      '/usr/local/go/src/syscall/zsysnum_linux_mips64.go',
      '/usr/local/go/src/syscall/zsysnum_linux_mips64le.go',
      '/usr/local/go/src/syscall/zsysnum_linux_mips.go',
      '/usr/local/go/src/syscall/zsysnum_linux_mipsle.go',
      '/usr/local/go/src/syscall/zsysnum_linux_ppc64.go',
      '/usr/local/go/src/syscall/zsysnum_linux_ppc64le.go',
      '/usr/local/go/src/syscall/zsysnum_linux_s390x.go',
      '/usr/local/go/src/syscall/zsysnum_netbsd_386.go',
      '/usr/local/go/src/syscall/zsysnum_netbsd_amd64.go',
      '/usr/local/go/src/syscall/zsysnum_netbsd_arm.go',
      '/usr/local/go/src/syscall/zsysnum_openbsd_386.go',
      '/usr/local/go/src/syscall/zsysnum_openbsd_amd64.go',
      '/usr/local/go/src/syscall/zsysnum_openbsd_arm.go',
      '/usr/local/go/src/syscall/zsysnum_plan9.go',
      '/usr/local/go/src/syscall/zsysnum_solaris_amd64.go',
      '/usr/local/go/src/syscall/zsysnum_windows_386.go',
      '/usr/local/go/src/syscall/zsysnum_windows_amd64.go',
      '/usr/local/go/src/syscall/ztypes_darwin_386.go',
      '/usr/local/go/src/syscall/ztypes_darwin_amd64.go',
      '/usr/local/go/src/syscall/ztypes_darwin_arm64.go',
      '/usr/local/go/src/syscall/ztypes_darwin_arm.go',
      '/usr/local/go/src/syscall/ztypes_dragonfly_amd64.go',
      '/usr/local/go/src/syscall/ztypes_freebsd_386.go',
      '/usr/local/go/src/syscall/ztypes_freebsd_amd64.go',
      '/usr/local/go/src/syscall/ztypes_freebsd_arm.go',
      '/usr/local/go/src/syscall/ztypes_linux_386.go',
      '/usr/local/go/src/syscall/ztypes_linux_amd64.go',
      '/usr/local/go/src/syscall/ztypes_linux_arm64.go',
      '/usr/local/go/src/syscall/ztypes_linux_arm.go',
      '/usr/local/go/src/syscall/ztypes_linux_mips64.go',
      '/usr/local/go/src/syscall/ztypes_linux_mips64le.go',
      '/usr/local/go/src/syscall/ztypes_linux_mips.go',
      '/usr/local/go/src/syscall/ztypes_linux_mipsle.go',
      '/usr/local/go/src/syscall/ztypes_linux_ppc64.go',
      '/usr/local/go/src/syscall/ztypes_linux_ppc64le.go',
      '/usr/local/go/src/syscall/ztypes_linux_s390x.go',
      '/usr/local/go/src/syscall/ztypes_netbsd_386.go',
      '/usr/local/go/src/syscall/ztypes_netbsd_amd64.go',
      '/usr/local/go/src/syscall/ztypes_netbsd_arm.go',
      '/usr/local/go/src/syscall/ztypes_openbsd_386.go',
      '/usr/local/go/src/syscall/ztypes_openbsd_amd64.go',
      '/usr/local/go/src/syscall/ztypes_openbsd_arm.go',
      '/usr/local/go/src/syscall/ztypes_solaris_amd64.go',
      '/usr/local/go/src/syscall/ztypes_windows_386.go',
      '/usr/local/go/src/syscall/ztypes_windows_amd64.go',
      '/usr/local/go/src/syscall/ztypes_windows.go',
      '/usr/local/go/src/testing',
      '/usr/local/go/src/testing/allocs.go',
      '/usr/local/go/src/testing/allocs_test.go',
      '/usr/local/go/src/testing/benchmark.go',
      '/usr/local/go/src/testing/benchmark_test.go',
      '/usr/local/go/src/testing/cover.go',
      '/usr/local/go/src/testing/example.go',
      '/usr/local/go/src/testing/export_test.go',
      '/usr/local/go/src/testing/helperfuncs_test.go',
      '/usr/local/go/src/testing/helper_test.go',
      '/usr/local/go/src/testing/internal',
      '/usr/local/go/src/testing/internal/testdeps',
      '/usr/local/go/src/testing/internal/testdeps/deps.go',
      '/usr/local/go/src/testing/iotest',
      '/usr/local/go/src/testing/iotest/logger.go',
      '/usr/local/go/src/testing/iotest/reader.go',
      '/usr/local/go/src/testing/iotest/writer.go',
      '/usr/local/go/src/testing/match.go',
      '/usr/local/go/src/testing/match_test.go',
      '/usr/local/go/src/testing/quick',
      '/usr/local/go/src/testing/quick/quick.go',
      '/usr/local/go/src/testing/quick/quick_test.go',
      '/usr/local/go/src/testing/sub_test.go',
      '/usr/local/go/src/testing/testing.go',
      '/usr/local/go/src/testing/testing_test.go',
      '/usr/local/go/src/text',
      '/usr/local/go/src/text/scanner',
      '/usr/local/go/src/text/scanner/example_test.go',
      '/usr/local/go/src/text/scanner/scanner.go',
      '/usr/local/go/src/text/scanner/scanner_test.go',
      '/usr/local/go/src/text/tabwriter',
      '/usr/local/go/src/text/tabwriter/example_test.go',
      '/usr/local/go/src/text/tabwriter/tabwriter.go',
      '/usr/local/go/src/text/tabwriter/tabwriter_test.go',
      '/usr/local/go/src/text/template',
      '/usr/local/go/src/text/template/doc.go',
      '/usr/local/go/src/text/template/examplefiles_test.go',
      '/usr/local/go/src/text/template/examplefunc_test.go',
      '/usr/local/go/src/text/template/example_test.go',
      '/usr/local/go/src/text/template/exec.go',
      '/usr/local/go/src/text/template/exec_test.go',
      '/usr/local/go/src/text/template/funcs.go',
      '/usr/local/go/src/text/template/helper.go',
      '/usr/local/go/src/text/template/multi_test.go',
      '/usr/local/go/src/text/template/option.go',
      '/usr/local/go/src/text/template/parse',
      '/usr/local/go/src/text/template/parse/lex.go',
      '/usr/local/go/src/text/template/parse/lex_test.go',
      '/usr/local/go/src/text/template/parse/node.go',
      '/usr/local/go/src/text/template/parse/parse.go',
      '/usr/local/go/src/text/template/parse/parse_test.go',
      '/usr/local/go/src/text/template/template.go',
      '/usr/local/go/src/text/template/testdata',
      '/usr/local/go/src/text/template/testdata/file1.tmpl',
      '/usr/local/go/src/text/template/testdata/file2.tmpl',
      '/usr/local/go/src/text/template/testdata/tmpl1.tmpl',
      '/usr/local/go/src/text/template/testdata/tmpl2.tmpl',
      '/usr/local/go/src/time',
      '/usr/local/go/src/time/example_test.go',
      '/usr/local/go/src/time/export_android_test.go',
      '/usr/local/go/src/time/export_test.go',
      '/usr/local/go/src/time/export_windows_test.go',
      '/usr/local/go/src/time/format.go',
      '/usr/local/go/src/time/format_test.go',
      '/usr/local/go/src/time/genzabbrs.go',
      '/usr/local/go/src/time/internal_test.go',
      '/usr/local/go/src/time/mono_test.go',
      '/usr/local/go/src/time/sleep.go',
      '/usr/local/go/src/time/sleep_test.go',
      '/usr/local/go/src/time/sys_plan9.go',
      '/usr/local/go/src/time/sys_unix.go',
      '/usr/local/go/src/time/sys_windows.go',
      '/usr/local/go/src/time/tick.go',
      '/usr/local/go/src/time/tick_test.go',
      '/usr/local/go/src/time/time.go',
      '/usr/local/go/src/time/time_test.go',
      '/usr/local/go/src/time/zoneinfo_abbrs_windows.go',
      '/usr/local/go/src/time/zoneinfo_android.go',
      '/usr/local/go/src/time/zoneinfo_android_test.go',
      '/usr/local/go/src/time/zoneinfo.go',
      '/usr/local/go/src/time/zoneinfo_ios.go',
      '/usr/local/go/src/time/zoneinfo_plan9.go',
      '/usr/local/go/src/time/zoneinfo_read.go',
      '/usr/local/go/src/time/zoneinfo_test.go',
      '/usr/local/go/src/time/zoneinfo_unix.go',
      '/usr/local/go/src/time/zoneinfo_windows.go',
      '/usr/local/go/src/time/zoneinfo_windows_test.go',
      '/usr/local/go/src/unicode',
      '/usr/local/go/src/unicode/casetables.go',
      '/usr/local/go/src/unicode/digit.go',
      '/usr/local/go/src/unicode/digit_test.go',
      '/usr/local/go/src/unicode/example_test.go',
      '/usr/local/go/src/unicode/graphic.go',
      '/usr/local/go/src/unicode/graphic_test.go',
      '/usr/local/go/src/unicode/letter.go',
      '/usr/local/go/src/unicode/letter_test.go',
      '/usr/local/go/src/unicode/maketables.go',
      '/usr/local/go/src/unicode/script_test.go',
      '/usr/local/go/src/unicode/tables.go',
      '/usr/local/go/src/unicode/utf16',
      '/usr/local/go/src/unicode/utf16/export_test.go',
      '/usr/local/go/src/unicode/utf16/utf16.go',
      '/usr/local/go/src/unicode/utf16/utf16_test.go',
      '/usr/local/go/src/unicode/utf8',
      '/usr/local/go/src/unicode/utf8/example_test.go',
      '/usr/local/go/src/unicode/utf8/utf8.go',
      '/usr/local/go/src/unicode/utf8/utf8_test.go',
      '/usr/local/go/src/unsafe',
      '/usr/local/go/src/unsafe/unsafe.go',
      '/usr/local/go/src/vendor',
      '/usr/local/go/src/vendor/golang_org',
      '/usr/local/go/src/vendor/golang_org/x',
      '/usr/local/go/src/vendor/golang_org/x/crypto',
      '/usr/local/go/src/vendor/golang_org/x/crypto/chacha20poly1305',
      '/usr/local/go/src/vendor/golang_org/x/crypto/chacha20poly1305/chacha20poly1305_amd64.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/chacha20poly1305/chacha20poly1305_amd64.s',
      '/usr/local/go/src/vendor/golang_org/x/crypto/chacha20poly1305/chacha20poly1305_generic.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/chacha20poly1305/chacha20poly1305.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/chacha20poly1305/chacha20poly1305_noasm.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/chacha20poly1305/chacha20poly1305_test.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/chacha20poly1305/chacha20poly1305_vectors_test.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/chacha20poly1305/internal',
      '/usr/local/go/src/vendor/golang_org/x/crypto/chacha20poly1305/internal/chacha20',
      '/usr/local/go/src/vendor/golang_org/x/crypto/chacha20poly1305/internal/chacha20/chacha_generic.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/chacha20poly1305/internal/chacha20/chacha_test.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/curve25519',
      '/usr/local/go/src/vendor/golang_org/x/crypto/curve25519/const_amd64.h',
      '/usr/local/go/src/vendor/golang_org/x/crypto/curve25519/const_amd64.s',
      '/usr/local/go/src/vendor/golang_org/x/crypto/curve25519/cswap_amd64.s',
      '/usr/local/go/src/vendor/golang_org/x/crypto/curve25519/curve25519.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/curve25519/curve25519_test.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/curve25519/doc.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/curve25519/freeze_amd64.s',
      '/usr/local/go/src/vendor/golang_org/x/crypto/curve25519/ladderstep_amd64.s',
      '/usr/local/go/src/vendor/golang_org/x/crypto/curve25519/mont25519_amd64.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/curve25519/mul_amd64.s',
      '/usr/local/go/src/vendor/golang_org/x/crypto/curve25519/square_amd64.s',
      '/usr/local/go/src/vendor/golang_org/x/crypto/poly1305',
      '/usr/local/go/src/vendor/golang_org/x/crypto/poly1305/poly1305.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/poly1305/poly1305_test.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/poly1305/sum_amd64.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/poly1305/sum_amd64.s',
      '/usr/local/go/src/vendor/golang_org/x/crypto/poly1305/sum_arm.go',
      '/usr/local/go/src/vendor/golang_org/x/crypto/poly1305/sum_arm.s',
      '/usr/local/go/src/vendor/golang_org/x/crypto/poly1305/sum_ref.go',
      '/usr/local/go/src/vendor/golang_org/x/net',
      '/usr/local/go/src/vendor/golang_org/x/net/http2',
      '/usr/local/go/src/vendor/golang_org/x/net/http2/hpack',
      '/usr/local/go/src/vendor/golang_org/x/net/http2/hpack/encode.go',
      '/usr/local/go/src/vendor/golang_org/x/net/http2/hpack/encode_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/http2/hpack/hpack.go',
      '/usr/local/go/src/vendor/golang_org/x/net/http2/hpack/hpack_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/http2/hpack/huffman.go',
      '/usr/local/go/src/vendor/golang_org/x/net/http2/hpack/tables.go',
      '/usr/local/go/src/vendor/golang_org/x/net/http2/hpack/tables_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/idna',
      '/usr/local/go/src/vendor/golang_org/x/net/idna/idna.go',
      '/usr/local/go/src/vendor/golang_org/x/net/idna/punycode.go',
      '/usr/local/go/src/vendor/golang_org/x/net/idna/punycode_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/idna/tables.go',
      '/usr/local/go/src/vendor/golang_org/x/net/idna/trie.go',
      '/usr/local/go/src/vendor/golang_org/x/net/idna/trieval.go',
      '/usr/local/go/src/vendor/golang_org/x/net/lex',
      '/usr/local/go/src/vendor/golang_org/x/net/lex/httplex',
      '/usr/local/go/src/vendor/golang_org/x/net/lex/httplex/httplex.go',
      '/usr/local/go/src/vendor/golang_org/x/net/lex/httplex/httplex_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/lif',
      '/usr/local/go/src/vendor/golang_org/x/net/lif/address.go',
      '/usr/local/go/src/vendor/golang_org/x/net/lif/address_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/lif/binary.go',
      '/usr/local/go/src/vendor/golang_org/x/net/lif/defs_solaris.go',
      '/usr/local/go/src/vendor/golang_org/x/net/lif/lif.go',
      '/usr/local/go/src/vendor/golang_org/x/net/lif/link.go',
      '/usr/local/go/src/vendor/golang_org/x/net/lif/link_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/lif/syscall.go',
      '/usr/local/go/src/vendor/golang_org/x/net/lif/sys.go',
      '/usr/local/go/src/vendor/golang_org/x/net/lif/sys_solaris_amd64.s',
      '/usr/local/go/src/vendor/golang_org/x/net/lif/zsys_solaris_amd64.go',
      '/usr/local/go/src/vendor/golang_org/x/net/nettest',
      '/usr/local/go/src/vendor/golang_org/x/net/nettest/conntest.go',
      '/usr/local/go/src/vendor/golang_org/x/net/nettest/conntest_go16.go',
      '/usr/local/go/src/vendor/golang_org/x/net/nettest/conntest_go17.go',
      '/usr/local/go/src/vendor/golang_org/x/net/nettest/conntest_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/proxy',
      '/usr/local/go/src/vendor/golang_org/x/net/proxy/direct.go',
      '/usr/local/go/src/vendor/golang_org/x/net/proxy/per_host.go',
      '/usr/local/go/src/vendor/golang_org/x/net/proxy/per_host_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/proxy/proxy.go',
      '/usr/local/go/src/vendor/golang_org/x/net/proxy/proxy_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/proxy/socks5.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route',
      '/usr/local/go/src/vendor/golang_org/x/net/route/address_darwin_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/address.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/address_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/binary.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/defs_darwin.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/defs_dragonfly.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/defs_freebsd.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/defs_netbsd.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/defs_openbsd.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/interface_announce.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/interface_classic.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/interface_freebsd.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/interface.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/interface_multicast.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/interface_openbsd.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/message_darwin_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/message_freebsd_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/message.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/message_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/route_classic.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/route.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/route_openbsd.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/route_test.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/syscall.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/sys_darwin.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/sys_dragonfly.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/sys_freebsd.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/sys.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/sys_netbsd.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/sys_openbsd.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/zsys_darwin.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/zsys_dragonfly.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/zsys_freebsd_386.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/zsys_freebsd_amd64.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/zsys_freebsd_arm.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/zsys_netbsd.go',
      '/usr/local/go/src/vendor/golang_org/x/net/route/zsys_openbsd.go',
      '/usr/local/go/src/vendor/golang_org/x/text',
      '/usr/local/go/src/vendor/golang_org/x/text/secure',
      '/usr/local/go/src/vendor/golang_org/x/text/secure/bidirule',
      '/usr/local/go/src/vendor/golang_org/x/text/secure/bidirule/bidirule.go',
      '/usr/local/go/src/vendor/golang_org/x/text/secure/doc.go',
      '/usr/local/go/src/vendor/golang_org/x/text/transform',
      '/usr/local/go/src/vendor/golang_org/x/text/transform/examples_test.go',
      '/usr/local/go/src/vendor/golang_org/x/text/transform/transform.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/bidi',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/bidi/bidi.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/bidi/bracket.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/bidi/core.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/bidi/example_test.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/bidi/prop.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/bidi/tables.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/bidi/trieval.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/doc.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm/composition.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm/example_iter_test.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm/example_test.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm/forminfo.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm/input.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm/iter.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm/normalize.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm/readwriter.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm/tables.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm/transform.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm/triegen.go',
      '/usr/local/go/src/vendor/golang_org/x/text/unicode/norm/trie.go',
      '/usr/local/go/test',
      '/usr/local/go/test/235.go',
      '/usr/local/go/test/64bit.go',
      '/usr/local/go/test/alg.go',
      '/usr/local/go/test/alias1.go',
      '/usr/local/go/test/alias2.go',
      '/usr/local/go/test/alias3.dir',
      '/usr/local/go/test/alias3.dir/a.go',
      '/usr/local/go/test/alias3.dir/b.go',
      '/usr/local/go/test/alias3.dir/c.go',
      '/usr/local/go/test/alias3.go',
      '/usr/local/go/test/alias.go',
      '/usr/local/go/test/append1.go',
      '/usr/local/go/test/append.go',
      '/usr/local/go/test/args.go',
      '/usr/local/go/test/armimm.go',
      '/usr/local/go/test/assign1.go',
      '/usr/local/go/test/assign.go',
      '/usr/local/go/test/atomicload.go',
      '/usr/local/go/test/bench',
      '/usr/local/go/test/bench/garbage',
      '/usr/local/go/test/bench/garbage/Makefile',
      '/usr/local/go/test/bench/garbage/parser.go',
      '/usr/local/go/test/bench/garbage/peano.go',
      '/usr/local/go/test/bench/garbage/stats.go',
      '/usr/local/go/test/bench/garbage/tree2.go',
      '/usr/local/go/test/bench/garbage/tree.go',
      '/usr/local/go/test/bench/go1',
      '/usr/local/go/test/bench/go1/binarytree_test.go',
      '/usr/local/go/test/bench/go1/fannkuch_test.go',
      '/usr/local/go/test/bench/go1/fasta_test.go',
      '/usr/local/go/test/bench/go1/fmt_test.go',
      '/usr/local/go/test/bench/go1/gob_test.go',
      '/usr/local/go/test/bench/go1/gzip_test.go',
      '/usr/local/go/test/bench/go1/http_test.go',
      '/usr/local/go/test/bench/go1/jsondata_test.go',
      '/usr/local/go/test/bench/go1/json_test.go',
      '/usr/local/go/test/bench/go1/mandel_test.go',
      '/usr/local/go/test/bench/go1/parserdata_test.go',
      '/usr/local/go/test/bench/go1/parser_test.go',
      '/usr/local/go/test/bench/go1/regexp_test.go',
      '/usr/local/go/test/bench/go1/revcomp_test.go',
      '/usr/local/go/test/bench/go1/template_test.go',
      '/usr/local/go/test/bench/go1/time_test.go',
      '/usr/local/go/test/bigalg.go',
      '/usr/local/go/test/bigmap.go',
      '/usr/local/go/test/blank1.go',
      '/usr/local/go/test/blank.go',
      '/usr/local/go/test/bombad.go',
      '/usr/local/go/test/bom.go',
      '/usr/local/go/test/bounds.go',
      '/usr/local/go/test/chan',
      '/usr/local/go/test/chan/doubleselect.go',
      '/usr/local/go/test/chan/fifo.go',
      '/usr/local/go/test/chan/goroutines.go',
      '/usr/local/go/test/chan/nonblock.go',
      '/usr/local/go/test/chan/perm.go',
      '/usr/local/go/test/chan/powser1.go',
      '/usr/local/go/test/chan/powser2.go',
      '/usr/local/go/test/chan/select2.go',
      '/usr/local/go/test/chan/select3.go',
      '/usr/local/go/test/chan/select4.go',
      '/usr/local/go/test/chan/select5.go',
      '/usr/local/go/test/chan/select6.go',
      '/usr/local/go/test/chan/select7.go',
      '/usr/local/go/test/chan/select.go',
      '/usr/local/go/test/chan/sendstmt.go',
      '/usr/local/go/test/chan/sieve1.go',
      '/usr/local/go/test/chan/sieve2.go',
      '/usr/local/go/test/chan/zerosize.go',
      '/usr/local/go/test/chancap.go',
      '/usr/local/go/test/chanlinear.go',
      '/usr/local/go/test/char_lit1.go',
      '/usr/local/go/test/char_lit.go',
      '/usr/local/go/test/checkbce.go',
      '/usr/local/go/test/clearfat.go',
      '/usr/local/go/test/closedchan.go',
      '/usr/local/go/test/closure1.go',
      '/usr/local/go/test/closure2.go',
      '/usr/local/go/test/closure.go',
      '/usr/local/go/test/cmp6.go',
      '/usr/local/go/test/cmp.go',
      '/usr/local/go/test/cmplxdivide1.go',
      '/usr/local/go/test/cmplxdivide.c',
      '/usr/local/go/test/cmplxdivide.go',
      '/usr/local/go/test/cmplx.go',
      '/usr/local/go/test/complit1.go',
      '/usr/local/go/test/complit.go',
      '/usr/local/go/test/compos.go',
      '/usr/local/go/test/const1.go',
      '/usr/local/go/test/const2.go',
      '/usr/local/go/test/const3.go',
      '/usr/local/go/test/const4.go',
      '/usr/local/go/test/const5.go',
      '/usr/local/go/test/const6.go',
      '/usr/local/go/test/const.go',
      '/usr/local/go/test/convert1.go',
      '/usr/local/go/test/convert2.go',
      '/usr/local/go/test/convert3.go',
      '/usr/local/go/test/convert.go',
      '/usr/local/go/test/convlit1.go',
      '/usr/local/go/test/convlit.go',
      '/usr/local/go/test/convT2X.go',
      '/usr/local/go/test/copy1.go',
      '/usr/local/go/test/copy.go',
      '/usr/local/go/test/crlf.go',
      '/usr/local/go/test/ddd1.go',
      '/usr/local/go/test/ddd2.dir',
      '/usr/local/go/test/ddd2.dir/ddd2.go',
      '/usr/local/go/test/ddd2.dir/ddd3.go',
      '/usr/local/go/test/ddd2.go',
      '/usr/local/go/test/ddd.go',
      '/usr/local/go/test/declbad.go',
      '/usr/local/go/test/decl.go',
      '/usr/local/go/test/deferfin.go',
      '/usr/local/go/test/defer.go',
      '/usr/local/go/test/deferprint.go',
      '/usr/local/go/test/deferprint.out',
      '/usr/local/go/test/devirt.go',
      '/usr/local/go/test/divide.go',
      '/usr/local/go/test/divmod.go',
      '/usr/local/go/test/dwarf',
      '/usr/local/go/test/dwarf/dwarf.dir',
      '/usr/local/go/test/dwarf/dwarf.dir/main.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z10.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z11.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z12.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z13.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z14.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z15.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z16.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z17.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z18.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z19.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z1.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z20.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z2.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z3.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z4.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z5.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z6.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z7.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z8.go',
      '/usr/local/go/test/dwarf/dwarf.dir/z9.go',
      '/usr/local/go/test/dwarf/dwarf.go',
      '/usr/local/go/test/dwarf/linedirectives.go',
      '/usr/local/go/test/empty.go',
      '/usr/local/go/test/env.go',
      '/usr/local/go/test/eof1.go',
      '/usr/local/go/test/eof.go',
      '/usr/local/go/test/errchk',
      '/usr/local/go/test/escape2.go',
      '/usr/local/go/test/escape2n.go',
      '/usr/local/go/test/escape3.go',
      '/usr/local/go/test/escape4.go',
      '/usr/local/go/test/escape5.go',
      '/usr/local/go/test/escape_array.go',
      '/usr/local/go/test/escape_because.go',
      '/usr/local/go/test/escape_calls.go',
      '/usr/local/go/test/escape_closure.go',
      '/usr/local/go/test/escape_field.go',
      '/usr/local/go/test/escape.go',
      '/usr/local/go/test/escape_iface.go',
      '/usr/local/go/test/escape_indir.go',
      '/usr/local/go/test/escape_level.go',
      '/usr/local/go/test/escape_map.go',
      '/usr/local/go/test/escape_param.go',
      '/usr/local/go/test/escape_slice.go',
      '/usr/local/go/test/escape_struct_param1.go',
      '/usr/local/go/test/escape_struct_param2.go',
      '/usr/local/go/test/escape_struct_return.go',
      '/usr/local/go/test/fibo.go',
      '/usr/local/go/test/finprofiled.go',
      '/usr/local/go/test/fixedbugs',
      '/usr/local/go/test/fixedbugs/bug000.go',
      '/usr/local/go/test/fixedbugs/bug002.go',
      '/usr/local/go/test/fixedbugs/bug003.go',
      '/usr/local/go/test/fixedbugs/bug004.go',
      '/usr/local/go/test/fixedbugs/bug005.go',
      '/usr/local/go/test/fixedbugs/bug006.go',
      '/usr/local/go/test/fixedbugs/bug007.go',
      '/usr/local/go/test/fixedbugs/bug008.go',
      '/usr/local/go/test/fixedbugs/bug009.go',
      '/usr/local/go/test/fixedbugs/bug010.go',
      '/usr/local/go/test/fixedbugs/bug011.go',
      '/usr/local/go/test/fixedbugs/bug012.go',
      '/usr/local/go/test/fixedbugs/bug013.go',
      '/usr/local/go/test/fixedbugs/bug014.go',
      '/usr/local/go/test/fixedbugs/bug015.go',
      '/usr/local/go/test/fixedbugs/bug016.go',
      '/usr/local/go/test/fixedbugs/bug017.go',
      '/usr/local/go/test/fixedbugs/bug020.go',
      '/usr/local/go/test/fixedbugs/bug021.go',
      '/usr/local/go/test/fixedbugs/bug022.go',
      '/usr/local/go/test/fixedbugs/bug023.go',
      '/usr/local/go/test/fixedbugs/bug024.go',
      '/usr/local/go/test/fixedbugs/bug026.go',
      '/usr/local/go/test/fixedbugs/bug027.go',
      '/usr/local/go/test/fixedbugs/bug028.go',
      '/usr/local/go/test/fixedbugs/bug030.go',
      '/usr/local/go/test/fixedbugs/bug031.go',
      '/usr/local/go/test/fixedbugs/bug035.go',
      '/usr/local/go/test/fixedbugs/bug037.go',
      '/usr/local/go/test/fixedbugs/bug039.go',
      '/usr/local/go/test/fixedbugs/bug040.go',
      '/usr/local/go/test/fixedbugs/bug045.go',
      '/usr/local/go/test/fixedbugs/bug046.go',
      '/usr/local/go/test/fixedbugs/bug047.go',
      '/usr/local/go/test/fixedbugs/bug048.go',
      '/usr/local/go/test/fixedbugs/bug049.go',
      '/usr/local/go/test/fixedbugs/bug050.go',
      '/usr/local/go/test/fixedbugs/bug051.go',
      '/usr/local/go/test/fixedbugs/bug052.go',
      '/usr/local/go/test/fixedbugs/bug053.go',
      '/usr/local/go/test/fixedbugs/bug054.go',
      '/usr/local/go/test/fixedbugs/bug055.go',
      '/usr/local/go/test/fixedbugs/bug056.go',
      '/usr/local/go/test/fixedbugs/bug057.go',
      '/usr/local/go/test/fixedbugs/bug058.go',
      '/usr/local/go/test/fixedbugs/bug059.go',
      '/usr/local/go/test/fixedbugs/bug060.go',
      '/usr/local/go/test/fixedbugs/bug061.go',
      '/usr/local/go/test/fixedbugs/bug062.go',
      '/usr/local/go/test/fixedbugs/bug063.go',
      '/usr/local/go/test/fixedbugs/bug064.go',
      '/usr/local/go/test/fixedbugs/bug065.go',
      '/usr/local/go/test/fixedbugs/bug066.go',
      '/usr/local/go/test/fixedbugs/bug067.go',
      '/usr/local/go/test/fixedbugs/bug068.go',
      '/usr/local/go/test/fixedbugs/bug069.go',
      '/usr/local/go/test/fixedbugs/bug070.go',
      '/usr/local/go/test/fixedbugs/bug071.go',
      '/usr/local/go/test/fixedbugs/bug072.go',
      '/usr/local/go/test/fixedbugs/bug073.go',
      '/usr/local/go/test/fixedbugs/bug074.go',
      '/usr/local/go/test/fixedbugs/bug075.go',
      '/usr/local/go/test/fixedbugs/bug076.go',
      '/usr/local/go/test/fixedbugs/bug077.go',
      '/usr/local/go/test/fixedbugs/bug078.go',
      '/usr/local/go/test/fixedbugs/bug080.go',
      '/usr/local/go/test/fixedbugs/bug081.go',
      '/usr/local/go/test/fixedbugs/bug082.go',
      '/usr/local/go/test/fixedbugs/bug083.dir',
      '/usr/local/go/test/fixedbugs/bug083.dir/bug0.go',
      '/usr/local/go/test/fixedbugs/bug083.dir/bug1.go',
      '/usr/local/go/test/fixedbugs/bug083.go',
      '/usr/local/go/test/fixedbugs/bug084.go',
      '/usr/local/go/test/fixedbugs/bug085.go',
      '/usr/local/go/test/fixedbugs/bug086.go',
      '/usr/local/go/test/fixedbugs/bug087.go',
      '/usr/local/go/test/fixedbugs/bug088.dir',
      '/usr/local/go/test/fixedbugs/bug088.dir/bug0.go',
      '/usr/local/go/test/fixedbugs/bug088.dir/bug1.go',
      '/usr/local/go/test/fixedbugs/bug088.go',
      '/usr/local/go/test/fixedbugs/bug089.go',
      '/usr/local/go/test/fixedbugs/bug090.go',
      '/usr/local/go/test/fixedbugs/bug091.go',
      '/usr/local/go/test/fixedbugs/bug092.go',
      '/usr/local/go/test/fixedbugs/bug093.go',
      '/usr/local/go/test/fixedbugs/bug094.go',
      '/usr/local/go/test/fixedbugs/bug096.go',
      '/usr/local/go/test/fixedbugs/bug097.go',
      '/usr/local/go/test/fixedbugs/bug098.go',
      '/usr/local/go/test/fixedbugs/bug099.go',
      '/usr/local/go/test/fixedbugs/bug101.go',
      '/usr/local/go/test/fixedbugs/bug102.go',
      '/usr/local/go/test/fixedbugs/bug103.go',
      '/usr/local/go/test/fixedbugs/bug104.go',
      '/usr/local/go/test/fixedbugs/bug106.dir',
      '/usr/local/go/test/fixedbugs/bug106.dir/bug0.go',
      '/usr/local/go/test/fixedbugs/bug106.dir/bug1.go',
      '/usr/local/go/test/fixedbugs/bug106.go',
      '/usr/local/go/test/fixedbugs/bug107.go',
      '/usr/local/go/test/fixedbugs/bug108.go',
      '/usr/local/go/test/fixedbugs/bug109.go',
      '/usr/local/go/test/fixedbugs/bug110.go',
      '/usr/local/go/test/fixedbugs/bug111.go',
      '/usr/local/go/test/fixedbugs/bug112.go',
      '/usr/local/go/test/fixedbugs/bug113.go',
      '/usr/local/go/test/fixedbugs/bug114.go',
      '/usr/local/go/test/fixedbugs/bug115.go',
      '/usr/local/go/test/fixedbugs/bug116.go',
      '/usr/local/go/test/fixedbugs/bug117.go',
      '/usr/local/go/test/fixedbugs/bug118.go',
      '/usr/local/go/test/fixedbugs/bug119.go',
      '/usr/local/go/test/fixedbugs/bug120.go',
      '/usr/local/go/test/fixedbugs/bug121.go',
      '/usr/local/go/test/fixedbugs/bug122.go',
      '/usr/local/go/test/fixedbugs/bug123.go',
      '/usr/local/go/test/fixedbugs/bug126.go',
      '/usr/local/go/test/fixedbugs/bug127.go',
      '/usr/local/go/test/fixedbugs/bug128.go',
      '/usr/local/go/test/fixedbugs/bug129.go',
      '/usr/local/go/test/fixedbugs/bug130.go',
      '/usr/local/go/test/fixedbugs/bug131.go',
      '/usr/local/go/test/fixedbugs/bug132.go',
      '/usr/local/go/test/fixedbugs/bug13343.go',
      '/usr/local/go/test/fixedbugs/bug133.dir',
      '/usr/local/go/test/fixedbugs/bug133.dir/bug0.go',
      '/usr/local/go/test/fixedbugs/bug133.dir/bug1.go',
      '/usr/local/go/test/fixedbugs/bug133.dir/bug2.go',
      '/usr/local/go/test/fixedbugs/bug133.go',
      '/usr/local/go/test/fixedbugs/bug135.go',
      '/usr/local/go/test/fixedbugs/bug136.go',
      '/usr/local/go/test/fixedbugs/bug137.go',
      '/usr/local/go/test/fixedbugs/bug139.go',
      '/usr/local/go/test/fixedbugs/bug140.go',
      '/usr/local/go/test/fixedbugs/bug141.go',
      '/usr/local/go/test/fixedbugs/bug142.go',
      '/usr/local/go/test/fixedbugs/bug143.go',
      '/usr/local/go/test/fixedbugs/bug144.go',
      '/usr/local/go/test/fixedbugs/bug145.go',
      '/usr/local/go/test/fixedbugs/bug146.go',
      '/usr/local/go/test/fixedbugs/bug147.go',
      '/usr/local/go/test/fixedbugs/bug148.go',
      '/usr/local/go/test/fixedbugs/bug149.go',
      '/usr/local/go/test/fixedbugs/bug150.go',
      '/usr/local/go/test/fixedbugs/bug1515.go',
      '/usr/local/go/test/fixedbugs/bug151.go',
      '/usr/local/go/test/fixedbugs/bug152.go',
      '/usr/local/go/test/fixedbugs/bug154.go',
      '/usr/local/go/test/fixedbugs/bug155.go',
      '/usr/local/go/test/fixedbugs/bug156.go',
      '/usr/local/go/test/fixedbugs/bug157.go',
      '/usr/local/go/test/fixedbugs/bug158.go',
      '/usr/local/go/test/fixedbugs/bug159.go',
      '/usr/local/go/test/fixedbugs/bug160.dir',
      '/usr/local/go/test/fixedbugs/bug160.dir/x.go',
      '/usr/local/go/test/fixedbugs/bug160.dir/y.go',
      '/usr/local/go/test/fixedbugs/bug160.go',
      '/usr/local/go/test/fixedbugs/bug161.go',
      '/usr/local/go/test/fixedbugs/bug163.go',
      '/usr/local/go/test/fixedbugs/bug164.go',
      '/usr/local/go/test/fixedbugs/bug165.go',
      '/usr/local/go/test/fixedbugs/bug167.go',
      '/usr/local/go/test/fixedbugs/bug168.go',
      '/usr/local/go/test/fixedbugs/bug169.go',
      '/usr/local/go/test/fixedbugs/bug170.go',
      '/usr/local/go/test/fixedbugs/bug171.go',
      '/usr/local/go/test/fixedbugs/bug172.go',
      '/usr/local/go/test/fixedbugs/bug173.go',
      '/usr/local/go/test/fixedbugs/bug174.go',
      '/usr/local/go/test/fixedbugs/bug175.go',
      '/usr/local/go/test/fixedbugs/bug176.go',
      '/usr/local/go/test/fixedbugs/bug177.go',
      '/usr/local/go/test/fixedbugs/bug178.go',
      '/usr/local/go/test/fixedbugs/bug179.go',
      '/usr/local/go/test/fixedbugs/bug180.go',
      '/usr/local/go/test/fixedbugs/bug181.go',
      '/usr/local/go/test/fixedbugs/bug182.go',
      '/usr/local/go/test/fixedbugs/bug183.go',
      '/usr/local/go/test/fixedbugs/bug184.go',
      '/usr/local/go/test/fixedbugs/bug185.go',
      '/usr/local/go/test/fixedbugs/bug186.go',
      '/usr/local/go/test/fixedbugs/bug187.go',
      '/usr/local/go/test/fixedbugs/bug188.go',
      '/usr/local/go/test/fixedbugs/bug189.go',
      '/usr/local/go/test/fixedbugs/bug190.go',
      '/usr/local/go/test/fixedbugs/bug191.dir',
      '/usr/local/go/test/fixedbugs/bug191.dir/a.go',
      '/usr/local/go/test/fixedbugs/bug191.dir/b.go',
      '/usr/local/go/test/fixedbugs/bug191.dir/main.go',
      '/usr/local/go/test/fixedbugs/bug191.go',
      '/usr/local/go/test/fixedbugs/bug192.go',
      '/usr/local/go/test/fixedbugs/bug193.go',
      '/usr/local/go/test/fixedbugs/bug19403.go',
      '/usr/local/go/test/fixedbugs/bug194.go',
      '/usr/local/go/test/fixedbugs/bug195.go',
      '/usr/local/go/test/fixedbugs/bug196.go',
      '/usr/local/go/test/fixedbugs/bug197.go',
      '/usr/local/go/test/fixedbugs/bug198.go',
      '/usr/local/go/test/fixedbugs/bug199.go',
      '/usr/local/go/test/fixedbugs/bug200.go',
      '/usr/local/go/test/fixedbugs/bug201.go',
      '/usr/local/go/test/fixedbugs/bug202.go',
      '/usr/local/go/test/fixedbugs/bug203.go',
      '/usr/local/go/test/fixedbugs/bug204.go',
      '/usr/local/go/test/fixedbugs/bug205.go',
      '/usr/local/go/test/fixedbugs/bug206.go',
      '/usr/local/go/test/fixedbugs/bug206.out',
      '/usr/local/go/test/fixedbugs/bug207.go',
      '/usr/local/go/test/fixedbugs/bug208.go',
      '/usr/local/go/test/fixedbugs/bug209.go',
      '/usr/local/go/test/fixedbugs/bug211.go',
      '/usr/local/go/test/fixedbugs/bug212.go',
      '/usr/local/go/test/fixedbugs/bug213.go',
      '/usr/local/go/test/fixedbugs/bug214.go',
      '/usr/local/go/test/fixedbugs/bug215.go',
      '/usr/local/go/test/fixedbugs/bug216.go',
      '/usr/local/go/test/fixedbugs/bug217.go',
      '/usr/local/go/test/fixedbugs/bug218.go',
      '/usr/local/go/test/fixedbugs/bug219.go',
      '/usr/local/go/test/fixedbugs/bug221.go',
      '/usr/local/go/test/fixedbugs/bug222.dir',
      '/usr/local/go/test/fixedbugs/bug222.dir/chanbug2.go',
      '/usr/local/go/test/fixedbugs/bug222.dir/chanbug.go',
      '/usr/local/go/test/fixedbugs/bug222.go',
      '/usr/local/go/test/fixedbugs/bug223.go',
      '/usr/local/go/test/fixedbugs/bug224.go',
      '/usr/local/go/test/fixedbugs/bug225.go',
      '/usr/local/go/test/fixedbugs/bug227.go',
      '/usr/local/go/test/fixedbugs/bug228.go',
      '/usr/local/go/test/fixedbugs/bug229.go',
      '/usr/local/go/test/fixedbugs/bug230.go',
      '/usr/local/go/test/fixedbugs/bug231.go',
      '/usr/local/go/test/fixedbugs/bug232.go',
      '/usr/local/go/test/fixedbugs/bug233.go',
      '/usr/local/go/test/fixedbugs/bug234.go',
      '/usr/local/go/test/fixedbugs/bug235.go',
      '/usr/local/go/test/fixedbugs/bug236.go',
      '/usr/local/go/test/fixedbugs/bug237.go',
      '/usr/local/go/test/fixedbugs/bug238.go',
      '/usr/local/go/test/fixedbugs/bug239.go',
      '/usr/local/go/test/fixedbugs/bug240.go',
      '/usr/local/go/test/fixedbugs/bug241.go',
      '/usr/local/go/test/fixedbugs/bug242.go',
      '/usr/local/go/test/fixedbugs/bug243.go',
      '/usr/local/go/test/fixedbugs/bug244.go',
      '/usr/local/go/test/fixedbugs/bug245.go',
      '/usr/local/go/test/fixedbugs/bug246.go',
      '/usr/local/go/test/fixedbugs/bug247.go',
      '/usr/local/go/test/fixedbugs/bug248.dir',
      '/usr/local/go/test/fixedbugs/bug248.dir/bug0.go',
      '/usr/local/go/test/fixedbugs/bug248.dir/bug1.go',
      '/usr/local/go/test/fixedbugs/bug248.dir/bug2.go',
      '/usr/local/go/test/fixedbugs/bug248.dir/bug3.go',
      '/usr/local/go/test/fixedbugs/bug248.go',
      '/usr/local/go/test/fixedbugs/bug249.go',
      '/usr/local/go/test/fixedbugs/bug250.go',
      '/usr/local/go/test/fixedbugs/bug251.go',
      '/usr/local/go/test/fixedbugs/bug252.go',
      '/usr/local/go/test/fixedbugs/bug253.go',
      '/usr/local/go/test/fixedbugs/bug254.go',
      '/usr/local/go/test/fixedbugs/bug255.go',
      '/usr/local/go/test/fixedbugs/bug256.go',
      '/usr/local/go/test/fixedbugs/bug257.go',
      '/usr/local/go/test/fixedbugs/bug258.go',
      '/usr/local/go/test/fixedbugs/bug259.go',
      '/usr/local/go/test/fixedbugs/bug260.go',
      '/usr/local/go/test/fixedbugs/bug261.go',
      '/usr/local/go/test/fixedbugs/bug262.go',
      '/usr/local/go/test/fixedbugs/bug263.go',
      '/usr/local/go/test/fixedbugs/bug264.go',
      '/usr/local/go/test/fixedbugs/bug265.go',
      '/usr/local/go/test/fixedbugs/bug266.go',
      '/usr/local/go/test/fixedbugs/bug267.go',
      '/usr/local/go/test/fixedbugs/bug269.go',
      '/usr/local/go/test/fixedbugs/bug271.go',
      '/usr/local/go/test/fixedbugs/bug272.go',
      '/usr/local/go/test/fixedbugs/bug273.go',
      '/usr/local/go/test/fixedbugs/bug274.go',
      '/usr/local/go/test/fixedbugs/bug275.go',
      '/usr/local/go/test/fixedbugs/bug276.go',
      '/usr/local/go/test/fixedbugs/bug277.go',
      '/usr/local/go/test/fixedbugs/bug278.go',
      '/usr/local/go/test/fixedbugs/bug279.go',
      '/usr/local/go/test/fixedbugs/bug280.go',
      '/usr/local/go/test/fixedbugs/bug281.go',
      '/usr/local/go/test/fixedbugs/bug282.dir',
      '/usr/local/go/test/fixedbugs/bug282.dir/p1.go',
      '/usr/local/go/test/fixedbugs/bug282.dir/p2.go',
      '/usr/local/go/test/fixedbugs/bug282.go',
      '/usr/local/go/test/fixedbugs/bug283.go',
      '/usr/local/go/test/fixedbugs/bug284.go',
      '/usr/local/go/test/fixedbugs/bug285.go',
      '/usr/local/go/test/fixedbugs/bug286.go',
      '/usr/local/go/test/fixedbugs/bug287.go',
      '/usr/local/go/test/fixedbugs/bug288.go',
      '/usr/local/go/test/fixedbugs/bug289.go',
      '/usr/local/go/test/fixedbugs/bug290.go',
      '/usr/local/go/test/fixedbugs/bug291.go',
      '/usr/local/go/test/fixedbugs/bug292.go',
      '/usr/local/go/test/fixedbugs/bug293.go',
      '/usr/local/go/test/fixedbugs/bug294.go',
      '/usr/local/go/test/fixedbugs/bug295.go',
      '/usr/local/go/test/fixedbugs/bug296.go',
      '/usr/local/go/test/fixedbugs/bug297.go',
      '/usr/local/go/test/fixedbugs/bug298.go',
      '/usr/local/go/test/fixedbugs/bug299.go',
      '/usr/local/go/test/fixedbugs/bug300.go',
      '/usr/local/go/test/fixedbugs/bug301.go',
      '/usr/local/go/test/fixedbugs/bug302.dir',
      '/usr/local/go/test/fixedbugs/bug302.dir/main.go',
      '/usr/local/go/test/fixedbugs/bug302.dir/p.go',
      '/usr/local/go/test/fixedbugs/bug302.go',
      '/usr/local/go/test/fixedbugs/bug303.go',
      '/usr/local/go/test/fixedbugs/bug304.go',
      '/usr/local/go/test/fixedbugs/bug305.go',
      '/usr/local/go/test/fixedbugs/bug306.dir',
      '/usr/local/go/test/fixedbugs/bug306.dir/p1.go',
      '/usr/local/go/test/fixedbugs/bug306.dir/p2.go',
      '/usr/local/go/test/fixedbugs/bug306.go',
      '/usr/local/go/test/fixedbugs/bug307.go',
      '/usr/local/go/test/fixedbugs/bug308.go',
      '/usr/local/go/test/fixedbugs/bug309.go',
      '/usr/local/go/test/fixedbugs/bug311.go',
      '/usr/local/go/test/fixedbugs/bug312.go',
      '/usr/local/go/test/fixedbugs/bug313.dir',
      '/usr/local/go/test/fixedbugs/bug313.dir/a.go',
      '/usr/local/go/test/fixedbugs/bug313.dir/b.go',
      '/usr/local/go/test/fixedbugs/bug313.go',
      '/usr/local/go/test/fixedbugs/bug314.go',
      '/usr/local/go/test/fixedbugs/bug315.go',
      '/usr/local/go/test/fixedbugs/bug316.go',
      '/usr/local/go/test/fixedbugs/bug317.go',
      '/usr/local/go/test/fixedbugs/bug318.go',
      '/usr/local/go/test/fixedbugs/bug319.go',
      '/usr/local/go/test/fixedbugs/bug320.go',
      '/usr/local/go/test/fixedbugs/bug321.go',
      '/usr/local/go/test/fixedbugs/bug322.dir',
      '/usr/local/go/test/fixedbugs/bug322.dir/lib.go',
      '/usr/local/go/test/fixedbugs/bug322.dir/main.go',
      '/usr/local/go/test/fixedbugs/bug322.go',
      '/usr/local/go/test/fixedbugs/bug323.go',
      '/usr/local/go/test/fixedbugs/bug324.dir',
      '/usr/local/go/test/fixedbugs/bug324.dir/p.go',
      '/usr/local/go/test/fixedbugs/bug324.dir/prog.go',
      '/usr/local/go/test/fixedbugs/bug324.go',
      '/usr/local/go/test/fixedbugs/bug325.go',
      '/usr/local/go/test/fixedbugs/bug326.go',
      '/usr/local/go/test/fixedbugs/bug327.go',
      '/usr/local/go/test/fixedbugs/bug328.go',
      '/usr/local/go/test/fixedbugs/bug328.out',
      '/usr/local/go/test/fixedbugs/bug329.go',
      '/usr/local/go/test/fixedbugs/bug330.go',
      '/usr/local/go/test/fixedbugs/bug331.go',
      '/usr/local/go/test/fixedbugs/bug332.go',
      '/usr/local/go/test/fixedbugs/bug333.go',
      '/usr/local/go/test/fixedbugs/bug334.go',
      '/usr/local/go/test/fixedbugs/bug335.dir',
      '/usr/local/go/test/fixedbugs/bug335.dir/a.go',
      '/usr/local/go/test/fixedbugs/bug335.dir/b.go',
      '/usr/local/go/test/fixedbugs/bug335.go',
      '/usr/local/go/test/fixedbugs/bug336.go',
      '/usr/local/go/test/fixedbugs/bug337.go',
      '/usr/local/go/test/fixedbugs/bug338.go',
      '/usr/local/go/test/fixedbugs/bug339.go',
      '/usr/local/go/test/fixedbugs/bug340.go',
      '/usr/local/go/test/fixedbugs/bug341.go',
      '/usr/local/go/test/fixedbugs/bug342.go',
      '/usr/local/go/test/fixedbugs/bug343.go',
      '/usr/local/go/test/fixedbugs/bug344.go',
      '/usr/local/go/test/fixedbugs/bug345.dir',
      '/usr/local/go/test/fixedbugs/bug345.dir/io.go',
      '/usr/local/go/test/fixedbugs/bug345.dir/main.go',
      '/usr/local/go/test/fixedbugs/bug345.go',
      '/usr/local/go/test/fixedbugs/bug346.go',
      '/usr/local/go/test/fixedbugs/bug347.go',
      '/usr/local/go/test/fixedbugs/bug348.go',
      '/usr/local/go/test/fixedbugs/bug349.go',
      '/usr/local/go/test/fixedbugs/bug350.go',
      '/usr/local/go/test/fixedbugs/bug351.go',
      '/usr/local/go/test/fixedbugs/bug352.go',
      '/usr/local/go/test/fixedbugs/bug353.go',
      '/usr/local/go/test/fixedbugs/bug354.go',
      '/usr/local/go/test/fixedbugs/bug355.go',
      '/usr/local/go/test/fixedbugs/bug356.go',
      '/usr/local/go/test/fixedbugs/bug357.go',
      '/usr/local/go/test/fixedbugs/bug358.go',
      '/usr/local/go/test/fixedbugs/bug361.go',
      '/usr/local/go/test/fixedbugs/bug362.go',
      '/usr/local/go/test/fixedbugs/bug363.go',
      '/usr/local/go/test/fixedbugs/bug364.go',
      '/usr/local/go/test/fixedbugs/bug365.go',
      '/usr/local/go/test/fixedbugs/bug366.go',
      '/usr/local/go/test/fixedbugs/bug367.dir',
      '/usr/local/go/test/fixedbugs/bug367.dir/p.go',
      '/usr/local/go/test/fixedbugs/bug367.dir/prog.go',
      '/usr/local/go/test/fixedbugs/bug367.go',
      '/usr/local/go/test/fixedbugs/bug368.go',
      '/usr/local/go/test/fixedbugs/bug369.dir',
      '/usr/local/go/test/fixedbugs/bug369.dir/main.go',
      '/usr/local/go/test/fixedbugs/bug369.dir/pkg.go',
      '/usr/local/go/test/fixedbugs/bug369.go',
      '/usr/local/go/test/fixedbugs/bug370.go',
      '/usr/local/go/test/fixedbugs/bug371.go',
      '/usr/local/go/test/fixedbugs/bug372.go',
      '/usr/local/go/test/fixedbugs/bug373.go',
      '/usr/local/go/test/fixedbugs/bug374.go',
      '/usr/local/go/test/fixedbugs/bug375.go',
      '/usr/local/go/test/fixedbugs/bug376.go',
      '/usr/local/go/test/fixedbugs/bug377.dir',
      '/usr/local/go/test/fixedbugs/bug377.dir/one.go',
      '/usr/local/go/test/fixedbugs/bug377.dir/two.go',
      '/usr/local/go/test/fixedbugs/bug377.go',
      '/usr/local/go/test/fixedbugs/bug378.go',
      '/usr/local/go/test/fixedbugs/bug379.go',
      '/usr/local/go/test/fixedbugs/bug380.go',
      '/usr/local/go/test/fixedbugs/bug381.go',
      '/usr/local/go/test/fixedbugs/bug382.dir',
      '/usr/local/go/test/fixedbugs/bug382.dir/pkg.go',
      '/usr/local/go/test/fixedbugs/bug382.dir/prog.go',
      '/usr/local/go/test/fixedbugs/bug382.go',
      '/usr/local/go/test/fixedbugs/bug383.go',
      '/usr/local/go/test/fixedbugs/bug384.go',
      '/usr/local/go/test/fixedbugs/bug385_32.go',
      '/usr/local/go/test/fixedbugs/bug385_64.go',
      '/usr/local/go/test/fixedbugs/bug386.go',
      '/usr/local/go/test/fixedbugs/bug387.go',
      '/usr/local/go/test/fixedbugs/bug388.go',
      '/usr/local/go/test/fixedbugs/bug389.go',
      '/usr/local/go/test/fixedbugs/bug390.go',
      '/usr/local/go/test/fixedbugs/bug391.go',
      '/usr/local/go/test/fixedbugs/bug392.dir',
      '/usr/local/go/test/fixedbugs/bug392.dir/one.go',
      '/usr/local/go/test/fixedbugs/bug392.dir/pkg2.go',
      '/usr/local/go/test/fixedbugs/bug392.dir/pkg3.go',
      '/usr/local/go/test/fixedbugs/bug392.go',
      '/usr/local/go/test/fixedbugs/bug393.go',
      '/usr/local/go/test/fixedbugs/bug394.go',
      '/usr/local/go/test/fixedbugs/bug396.dir',
      '/usr/local/go/test/fixedbugs/bug396.dir/one.go',
      '/usr/local/go/test/fixedbugs/bug396.dir/two.go',
      '/usr/local/go/test/fixedbugs/bug396.go',
      '/usr/local/go/test/fixedbugs/bug397.go',
      '/usr/local/go/test/fixedbugs/bug398.go',
      '/usr/local/go/test/fixedbugs/bug399.go',
      '/usr/local/go/test/fixedbugs/bug401.go',
      '/usr/local/go/test/fixedbugs/bug402.go',
      '/usr/local/go/test/fixedbugs/bug403.go',
      '/usr/local/go/test/fixedbugs/bug404.dir',
      '/usr/local/go/test/fixedbugs/bug404.dir/one.go',
      '/usr/local/go/test/fixedbugs/bug404.dir/two.go',
      '/usr/local/go/test/fixedbugs/bug404.go',
      '/usr/local/go/test/fixedbugs/bug405.go',
      '/usr/local/go/test/fixedbugs/bug406.go',
      '/usr/local/go/test/fixedbugs/bug407.dir',
      '/usr/local/go/test/fixedbugs/bug407.dir/one.go',
      '/usr/local/go/test/fixedbugs/bug407.dir/two.go',
      '/usr/local/go/test/fixedbugs/bug407.go',
      '/usr/local/go/test/fixedbugs/bug409.go',
      '/usr/local/go/test/fixedbugs/bug409.out',
      '/usr/local/go/test/fixedbugs/bug410.go',
      '/usr/local/go/test/fixedbugs/bug411.go',
      '/usr/local/go/test/fixedbugs/bug412.go',
      '/usr/local/go/test/fixedbugs/bug413.go',
      '/usr/local/go/test/fixedbugs/bug414.dir',
      '/usr/local/go/test/fixedbugs/bug414.dir/p1.go',
      '/usr/local/go/test/fixedbugs/bug414.dir/prog.go',
      '/usr/local/go/test/fixedbugs/bug414.go',
      '/usr/local/go/test/fixedbugs/bug415.dir',
      '/usr/local/go/test/fixedbugs/bug415.dir/p.go',
      '/usr/local/go/test/fixedbugs/bug415.dir/prog.go',
      '/usr/local/go/test/fixedbugs/bug415.go',
      '/usr/local/go/test/fixedbugs/bug416.go',
      '/usr/local/go/test/fixedbugs/bug417.go',
      '/usr/local/go/test/fixedbugs/bug418.go',
      '/usr/local/go/test/fixedbugs/bug419.go',
      '/usr/local/go/test/fixedbugs/bug420.go',
      '/usr/local/go/test/fixedbugs/bug421.go',
      '/usr/local/go/test/fixedbugs/bug422.go',
      '/usr/local/go/test/fixedbugs/bug423.go',
      '/usr/local/go/test/fixedbugs/bug424.dir',
      '/usr/local/go/test/fixedbugs/bug424.dir/lib.go',
      '/usr/local/go/test/fixedbugs/bug424.dir/main.go',
      '/usr/local/go/test/fixedbugs/bug424.go',
      '/usr/local/go/test/fixedbugs/bug425.go',
      '/usr/local/go/test/fixedbugs/bug426.go',
      '/usr/local/go/test/fixedbugs/bug427.go',
      '/usr/local/go/test/fixedbugs/bug428.go',
      '/usr/local/go/test/fixedbugs/bug429.go',
      '/usr/local/go/test/fixedbugs/bug429_run.go',
      '/usr/local/go/test/fixedbugs/bug430.go',
      '/usr/local/go/test/fixedbugs/bug431.go',
      '/usr/local/go/test/fixedbugs/bug432.go',
      '/usr/local/go/test/fixedbugs/bug433.go',
      '/usr/local/go/test/fixedbugs/bug434.go',
      '/usr/local/go/test/fixedbugs/bug435.go',
      '/usr/local/go/test/fixedbugs/bug436.go',
      '/usr/local/go/test/fixedbugs/bug437.dir',
      '/usr/local/go/test/fixedbugs/bug437.dir/one.go',
      '/usr/local/go/test/fixedbugs/bug437.dir/two.go',
      '/usr/local/go/test/fixedbugs/bug437.dir/x.go',
      '/usr/local/go/test/fixedbugs/bug437.go',
      '/usr/local/go/test/fixedbugs/bug438.go',
      '/usr/local/go/test/fixedbugs/bug439.go',
      '/usr/local/go/test/fixedbugs/bug440_32.go',
      '/usr/local/go/test/fixedbugs/bug440_64.go',
      '/usr/local/go/test/fixedbugs/bug441.go',
      '/usr/local/go/test/fixedbugs/bug442.go',
      '/usr/local/go/test/fixedbugs/bug443.go',
      '/usr/local/go/test/fixedbugs/bug444.go',
      '/usr/local/go/test/fixedbugs/bug445.go',
      '/usr/local/go/test/fixedbugs/bug446.go',
      '/usr/local/go/test/fixedbugs/bug447.go',
      '/usr/local/go/test/fixedbugs/bug448.dir',
      '/usr/local/go/test/fixedbugs/bug448.dir/pkg1.go',
      '/usr/local/go/test/fixedbugs/bug448.dir/pkg2.go',
      '/usr/local/go/test/fixedbugs/bug448.go',
      '/usr/local/go/test/fixedbugs/bug449.go',
      '/usr/local/go/test/fixedbugs/bug450.go',
      '/usr/local/go/test/fixedbugs/bug451.go',
      '/usr/local/go/test/fixedbugs/bug452.go',
      '/usr/local/go/test/fixedbugs/bug453.go',
      '/usr/local/go/test/fixedbugs/bug454.go',
      '/usr/local/go/test/fixedbugs/bug455.go',
      '/usr/local/go/test/fixedbugs/bug456.go',
      '/usr/local/go/test/fixedbugs/bug457.go',
      '/usr/local/go/test/fixedbugs/bug458.go',
      '/usr/local/go/test/fixedbugs/bug459.go',
      '/usr/local/go/test/fixedbugs/bug460.dir',
      '/usr/local/go/test/fixedbugs/bug460.dir/a.go',
      '/usr/local/go/test/fixedbugs/bug460.dir/b.go',
      '/usr/local/go/test/fixedbugs/bug460.go',
      '/usr/local/go/test/fixedbugs/bug461.go',
      '/usr/local/go/test/fixedbugs/bug462.go',
      '/usr/local/go/test/fixedbugs/bug463.go',
      '/usr/local/go/test/fixedbugs/bug464.go',
      '/usr/local/go/test/fixedbugs/bug465.dir',
      '/usr/local/go/test/fixedbugs/bug465.dir/a.go',
      '/usr/local/go/test/fixedbugs/bug465.dir/b.go',
      '/usr/local/go/test/fixedbugs/bug465.go',
      '/usr/local/go/test/fixedbugs/bug466.dir',
      '/usr/local/go/test/fixedbugs/bug466.dir/a.go',
      '/usr/local/go/test/fixedbugs/bug466.dir/b.go',
      '/usr/local/go/test/fixedbugs/bug466.go',
      '/usr/local/go/test/fixedbugs/bug467.dir',
      '/usr/local/go/test/fixedbugs/bug467.dir/p1.go',
      '/usr/local/go/test/fixedbugs/bug467.dir/p2.go',
      '/usr/local/go/test/fixedbugs/bug467.dir/p3.go',
      '/usr/local/go/test/fixedbugs/bug467.go',
      '/usr/local/go/test/fixedbugs/bug468.dir',
      '/usr/local/go/test/fixedbugs/bug468.dir/p1.go',
      '/usr/local/go/test/fixedbugs/bug468.dir/p2.go',
      '/usr/local/go/test/fixedbugs/bug468.go',
      '/usr/local/go/test/fixedbugs/bug470.go',
      '/usr/local/go/test/fixedbugs/bug471.go',
      '/usr/local/go/test/fixedbugs/bug472.dir',
      '/usr/local/go/test/fixedbugs/bug472.dir/p1.go',
      '/usr/local/go/test/fixedbugs/bug472.dir/p2.go',
      '/usr/local/go/test/fixedbugs/bug472.dir/z.go',
      '/usr/local/go/test/fixedbugs/bug472.go',
      '/usr/local/go/test/fixedbugs/bug473.go',
      '/usr/local/go/test/fixedbugs/bug474.go',
      '/usr/local/go/test/fixedbugs/bug475.go',
      '/usr/local/go/test/fixedbugs/bug476.go',
      '/usr/local/go/test/fixedbugs/bug477.go',
      '/usr/local/go/test/fixedbugs/bug478.dir',
      '/usr/local/go/test/fixedbugs/bug478.dir/a.go',
      '/usr/local/go/test/fixedbugs/bug478.dir/b.go',
      '/usr/local/go/test/fixedbugs/bug478.go',
      '/usr/local/go/test/fixedbugs/bug479.dir',
      '/usr/local/go/test/fixedbugs/bug479.dir/a.go',
      '/usr/local/go/test/fixedbugs/bug479.dir/b.go',
      '/usr/local/go/test/fixedbugs/bug479.go',
      '/usr/local/go/test/fixedbugs/bug480.dir',
      '/usr/local/go/test/fixedbugs/bug480.dir/a.go',
      '/usr/local/go/test/fixedbugs/bug480.dir/b.go',
      '/usr/local/go/test/fixedbugs/bug480.go',
      '/usr/local/go/test/fixedbugs/bug481.go',
      '/usr/local/go/test/fixedbugs/bug482.go',
      '/usr/local/go/test/fixedbugs/bug483.go',
      '/usr/local/go/test/fixedbugs/bug484.go',
      '/usr/local/go/test/fixedbugs/bug485.go',
      '/usr/local/go/test/fixedbugs/bug486.go',
      '/usr/local/go/test/fixedbugs/bug487.go',
      '/usr/local/go/test/fixedbugs/bug488.dir',
      '/usr/local/go/test/fixedbugs/bug488.dir/a.go',
      '/usr/local/go/test/fixedbugs/bug488.dir/b.go',
      '/usr/local/go/test/fixedbugs/bug488.go',
      '/usr/local/go/test/fixedbugs/bug489.go',
      '/usr/local/go/test/fixedbugs/bug490.go',
      '/usr/local/go/test/fixedbugs/bug491.go',
      '/usr/local/go/test/fixedbugs/bug492.dir',
      '/usr/local/go/test/fixedbugs/bug492.dir/a.go',
      '/usr/local/go/test/fixedbugs/bug492.dir/b.go',
      '/usr/local/go/test/fixedbugs/bug492.go',
      '/usr/local/go/test/fixedbugs/bug493.go',
      '/usr/local/go/test/fixedbugs/bug494.go',
      '/usr/local/go/test/fixedbugs/bug495.go',
      '/usr/local/go/test/fixedbugs/bug496.go',
      '/usr/local/go/test/fixedbugs/bug497.go',
      '/usr/local/go/test/fixedbugs/bug498.go',
      '/usr/local/go/test/fixedbugs/bug499.go',
      '/usr/local/go/test/fixedbugs/bug500.go',
      '/usr/local/go/test/fixedbugs/bug501.go',
      '/usr/local/go/test/fixedbugs/bug502.go',
      '/usr/local/go/test/fixedbugs/gcc61204.go',
      '/usr/local/go/test/fixedbugs/gcc61244.go',
      '/usr/local/go/test/fixedbugs/gcc61246.go',
      '/usr/local/go/test/fixedbugs/gcc61248.go',
      '/usr/local/go/test/fixedbugs/gcc61253.go',
      '/usr/local/go/test/fixedbugs/gcc61254.go',
      '/usr/local/go/test/fixedbugs/gcc61255.go',
      '/usr/local/go/test/fixedbugs/gcc61258.go',
      '/usr/local/go/test/fixedbugs/gcc61264.go',
      '/usr/local/go/test/fixedbugs/gcc61265.go',
      '/usr/local/go/test/fixedbugs/gcc61273.go',
      '/usr/local/go/test/fixedbugs/gcc65755.go',
      '/usr/local/go/test/fixedbugs/gcc67968.dir',
      '/usr/local/go/test/fixedbugs/gcc67968.dir/a.go',
      '/usr/local/go/test/fixedbugs/gcc67968.dir/b.go',
      '/usr/local/go/test/fixedbugs/gcc67968.go',
      '/usr/local/go/test/fixedbugs/gcc78763.go',
      '/usr/local/go/test/fixedbugs/gcc80226.go',
      '/usr/local/go/test/fixedbugs/issue10047.go',
      '/usr/local/go/test/fixedbugs/issue10066.dir',
      '/usr/local/go/test/fixedbugs/issue10066.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue10066.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue10066.go',
      '/usr/local/go/test/fixedbugs/issue10135.go',
      '/usr/local/go/test/fixedbugs/issue10219.dir',
      '/usr/local/go/test/fixedbugs/issue10219.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue10219.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue10219.dir/c.go',
      '/usr/local/go/test/fixedbugs/issue10219.go',
      '/usr/local/go/test/fixedbugs/issue10253.go',
      '/usr/local/go/test/fixedbugs/issue10284.go',
      '/usr/local/go/test/fixedbugs/issue10320.go',
      '/usr/local/go/test/fixedbugs/issue10332.go',
      '/usr/local/go/test/fixedbugs/issue10353.go',
      '/usr/local/go/test/fixedbugs/issue10407.go',
      '/usr/local/go/test/fixedbugs/issue10441.go',
      '/usr/local/go/test/fixedbugs/issue10486.go',
      '/usr/local/go/test/fixedbugs/issue10607a.go',
      '/usr/local/go/test/fixedbugs/issue10607.go',
      '/usr/local/go/test/fixedbugs/issue10654.go',
      '/usr/local/go/test/fixedbugs/issue10700.dir',
      '/usr/local/go/test/fixedbugs/issue10700.dir/other.go',
      '/usr/local/go/test/fixedbugs/issue10700.dir/test.go',
      '/usr/local/go/test/fixedbugs/issue10700.go',
      '/usr/local/go/test/fixedbugs/issue10925.go',
      '/usr/local/go/test/fixedbugs/issue10958.go',
      '/usr/local/go/test/fixedbugs/issue10975.go',
      '/usr/local/go/test/fixedbugs/issue10977.go',
      '/usr/local/go/test/fixedbugs/issue11053.dir',
      '/usr/local/go/test/fixedbugs/issue11053.dir/p.go',
      '/usr/local/go/test/fixedbugs/issue11053.dir/p_test.go',
      '/usr/local/go/test/fixedbugs/issue11053.go',
      '/usr/local/go/test/fixedbugs/issue11053.out',
      '/usr/local/go/test/fixedbugs/issue11256.go',
      '/usr/local/go/test/fixedbugs/issue11286.go',
      '/usr/local/go/test/fixedbugs/issue11326b.go',
      '/usr/local/go/test/fixedbugs/issue11326.go',
      '/usr/local/go/test/fixedbugs/issue11354.go',
      '/usr/local/go/test/fixedbugs/issue11359.go',
      '/usr/local/go/test/fixedbugs/issue11361.go',
      '/usr/local/go/test/fixedbugs/issue11362.go',
      '/usr/local/go/test/fixedbugs/issue11369.go',
      '/usr/local/go/test/fixedbugs/issue11370.go',
      '/usr/local/go/test/fixedbugs/issue11371.go',
      '/usr/local/go/test/fixedbugs/issue11590.go',
      '/usr/local/go/test/fixedbugs/issue11610.go',
      '/usr/local/go/test/fixedbugs/issue11614.go',
      '/usr/local/go/test/fixedbugs/issue11656.go',
      '/usr/local/go/test/fixedbugs/issue11674.go',
      '/usr/local/go/test/fixedbugs/issue11699.go',
      '/usr/local/go/test/fixedbugs/issue11737.go',
      '/usr/local/go/test/fixedbugs/issue11750.go',
      '/usr/local/go/test/fixedbugs/issue11771.go',
      '/usr/local/go/test/fixedbugs/issue11790.go',
      '/usr/local/go/test/fixedbugs/issue11945.go',
      '/usr/local/go/test/fixedbugs/issue11987.go',
      '/usr/local/go/test/fixedbugs/issue12006.go',
      '/usr/local/go/test/fixedbugs/issue12108.go',
      '/usr/local/go/test/fixedbugs/issue12133.go',
      '/usr/local/go/test/fixedbugs/issue12226.go',
      '/usr/local/go/test/fixedbugs/issue12347.go',
      '/usr/local/go/test/fixedbugs/issue12411.go',
      '/usr/local/go/test/fixedbugs/issue12413.go',
      '/usr/local/go/test/fixedbugs/issue12525.go',
      '/usr/local/go/test/fixedbugs/issue12536.go',
      '/usr/local/go/test/fixedbugs/issue12577.go',
      '/usr/local/go/test/fixedbugs/issue12588.go',
      '/usr/local/go/test/fixedbugs/issue12677.dir',
      '/usr/local/go/test/fixedbugs/issue12677.dir/p.go',
      '/usr/local/go/test/fixedbugs/issue12677.dir/q.go',
      '/usr/local/go/test/fixedbugs/issue12677.go',
      '/usr/local/go/test/fixedbugs/issue12686.go',
      '/usr/local/go/test/fixedbugs/issue12944.go',
      '/usr/local/go/test/fixedbugs/issue1304.go',
      '/usr/local/go/test/fixedbugs/issue13160.go',
      '/usr/local/go/test/fixedbugs/issue13162.go',
      '/usr/local/go/test/fixedbugs/issue13169.go',
      '/usr/local/go/test/fixedbugs/issue13171.go',
      '/usr/local/go/test/fixedbugs/issue13248.go',
      '/usr/local/go/test/fixedbugs/issue13261.go',
      '/usr/local/go/test/fixedbugs/issue13262.go',
      '/usr/local/go/test/fixedbugs/issue13263.go',
      '/usr/local/go/test/fixedbugs/issue13266.go',
      '/usr/local/go/test/fixedbugs/issue13268.go',
      '/usr/local/go/test/fixedbugs/issue13273.go',
      '/usr/local/go/test/fixedbugs/issue13274.go',
      '/usr/local/go/test/fixedbugs/issue13319.go',
      '/usr/local/go/test/fixedbugs/issue13337.go',
      '/usr/local/go/test/fixedbugs/issue13365.go',
      '/usr/local/go/test/fixedbugs/issue13415.go',
      '/usr/local/go/test/fixedbugs/issue13471.go',
      '/usr/local/go/test/fixedbugs/issue13480.go',
      '/usr/local/go/test/fixedbugs/issue13485.go',
      '/usr/local/go/test/fixedbugs/issue13539.go',
      '/usr/local/go/test/fixedbugs/issue13559.go',
      '/usr/local/go/test/fixedbugs/issue13587.go',
      '/usr/local/go/test/fixedbugs/issue13684.go',
      '/usr/local/go/test/fixedbugs/issue13777.dir',
      '/usr/local/go/test/fixedbugs/issue13777.dir/burnin.go',
      '/usr/local/go/test/fixedbugs/issue13777.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue13777.go',
      '/usr/local/go/test/fixedbugs/issue13779.go',
      '/usr/local/go/test/fixedbugs/issue13799.go',
      '/usr/local/go/test/fixedbugs/issue13821b.go',
      '/usr/local/go/test/fixedbugs/issue13821.go',
      '/usr/local/go/test/fixedbugs/issue14006.go',
      '/usr/local/go/test/fixedbugs/issue14010.go',
      '/usr/local/go/test/fixedbugs/issue14136.go',
      '/usr/local/go/test/fixedbugs/issue14164.dir',
      '/usr/local/go/test/fixedbugs/issue14164.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue14164.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue14164.go',
      '/usr/local/go/test/fixedbugs/issue14331.dir',
      '/usr/local/go/test/fixedbugs/issue14331.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue14331.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue14331.go',
      '/usr/local/go/test/fixedbugs/issue14405.go',
      '/usr/local/go/test/fixedbugs/issue14520.go',
      '/usr/local/go/test/fixedbugs/issue14553.go',
      '/usr/local/go/test/fixedbugs/issue14591.go',
      '/usr/local/go/test/fixedbugs/issue14636.go',
      '/usr/local/go/test/fixedbugs/issue14646.go',
      '/usr/local/go/test/fixedbugs/issue14651.go',
      '/usr/local/go/test/fixedbugs/issue14652.go',
      '/usr/local/go/test/fixedbugs/issue14725.go',
      '/usr/local/go/test/fixedbugs/issue14729.go',
      '/usr/local/go/test/fixedbugs/issue14988.go',
      '/usr/local/go/test/fixedbugs/issue14999.go',
      '/usr/local/go/test/fixedbugs/issue15002.go',
      '/usr/local/go/test/fixedbugs/issue15013.go',
      '/usr/local/go/test/fixedbugs/issue15039.go',
      '/usr/local/go/test/fixedbugs/issue15042.go',
      '/usr/local/go/test/fixedbugs/issue15055.go',
      '/usr/local/go/test/fixedbugs/issue15071.dir',
      '/usr/local/go/test/fixedbugs/issue15071.dir/exp',
      '/usr/local/go/test/fixedbugs/issue15071.dir/exp/exp.go',
      '/usr/local/go/test/fixedbugs/issue15071.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue15084.go',
      '/usr/local/go/test/fixedbugs/issue15091.go',
      '/usr/local/go/test/fixedbugs/issue15141.go',
      '/usr/local/go/test/fixedbugs/issue15175.go',
      '/usr/local/go/test/fixedbugs/issue15252.go',
      '/usr/local/go/test/fixedbugs/issue15277.go',
      '/usr/local/go/test/fixedbugs/issue15281.go',
      '/usr/local/go/test/fixedbugs/issue15303.go',
      '/usr/local/go/test/fixedbugs/issue15311.go',
      '/usr/local/go/test/fixedbugs/issue15329.go',
      '/usr/local/go/test/fixedbugs/issue15439.go',
      '/usr/local/go/test/fixedbugs/issue15470.dir',
      '/usr/local/go/test/fixedbugs/issue15470.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue15470.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue15470.go',
      '/usr/local/go/test/fixedbugs/issue15514.dir',
      '/usr/local/go/test/fixedbugs/issue15514.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue15514.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue15514.dir/c.go',
      '/usr/local/go/test/fixedbugs/issue15514.go',
      '/usr/local/go/test/fixedbugs/issue15528.go',
      '/usr/local/go/test/fixedbugs/issue15548.dir',
      '/usr/local/go/test/fixedbugs/issue15548.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue15548.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue15548.dir/c.go',
      '/usr/local/go/test/fixedbugs/issue15548.go',
      '/usr/local/go/test/fixedbugs/issue15550.go',
      '/usr/local/go/test/fixedbugs/issue15572.dir',
      '/usr/local/go/test/fixedbugs/issue15572.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue15572.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue15572.go',
      '/usr/local/go/test/fixedbugs/issue15585.go',
      '/usr/local/go/test/fixedbugs/issue15602.go',
      '/usr/local/go/test/fixedbugs/issue15604.go',
      '/usr/local/go/test/fixedbugs/issue15609.dir',
      '/usr/local/go/test/fixedbugs/issue15609.dir/call_386.s',
      '/usr/local/go/test/fixedbugs/issue15609.dir/call_amd64.s',
      '/usr/local/go/test/fixedbugs/issue15609.dir/call_decl.go',
      '/usr/local/go/test/fixedbugs/issue15609.dir/call.go',
      '/usr/local/go/test/fixedbugs/issue15609.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue15611.go',
      '/usr/local/go/test/fixedbugs/issue15646.dir',
      '/usr/local/go/test/fixedbugs/issue15646.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue15646.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue15646.go',
      '/usr/local/go/test/fixedbugs/issue15722.go',
      '/usr/local/go/test/fixedbugs/issue15733.go',
      '/usr/local/go/test/fixedbugs/issue15747b.go',
      '/usr/local/go/test/fixedbugs/issue15747.go',
      '/usr/local/go/test/fixedbugs/issue15838.dir',
      '/usr/local/go/test/fixedbugs/issue15838.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue15838.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue15838.go',
      '/usr/local/go/test/fixedbugs/issue15895.go',
      '/usr/local/go/test/fixedbugs/issue15898.go',
      '/usr/local/go/test/fixedbugs/issue15902.go',
      '/usr/local/go/test/fixedbugs/issue15920.dir',
      '/usr/local/go/test/fixedbugs/issue15920.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue15920.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue15920.go',
      '/usr/local/go/test/fixedbugs/issue15926.go',
      '/usr/local/go/test/fixedbugs/issue15961.go',
      '/usr/local/go/test/fixedbugs/issue15975.go',
      '/usr/local/go/test/fixedbugs/issue15988.go',
      '/usr/local/go/test/fixedbugs/issue16008.go',
      '/usr/local/go/test/fixedbugs/issue16016.go',
      '/usr/local/go/test/fixedbugs/issue16037_run.go',
      '/usr/local/go/test/fixedbugs/issue16095.go',
      '/usr/local/go/test/fixedbugs/issue16130.go',
      '/usr/local/go/test/fixedbugs/issue16133.dir',
      '/usr/local/go/test/fixedbugs/issue16133.dir/a1.go',
      '/usr/local/go/test/fixedbugs/issue16133.dir/a2.go',
      '/usr/local/go/test/fixedbugs/issue16133.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue16133.dir/c.go',
      '/usr/local/go/test/fixedbugs/issue16133.go',
      '/usr/local/go/test/fixedbugs/issue16193.go',
      '/usr/local/go/test/fixedbugs/issue16249.go',
      '/usr/local/go/test/fixedbugs/issue16306.go',
      '/usr/local/go/test/fixedbugs/issue16317.dir',
      '/usr/local/go/test/fixedbugs/issue16317.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue16317.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue16317.go',
      '/usr/local/go/test/fixedbugs/issue16331.go',
      '/usr/local/go/test/fixedbugs/issue16369.go',
      '/usr/local/go/test/fixedbugs/issue16428.go',
      '/usr/local/go/test/fixedbugs/issue16439.go',
      '/usr/local/go/test/fixedbugs/issue16515.go',
      '/usr/local/go/test/fixedbugs/issue16616.dir',
      '/usr/local/go/test/fixedbugs/issue16616.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue16616.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue16616.dir/issue16616.go',
      '/usr/local/go/test/fixedbugs/issue16616.go',
      '/usr/local/go/test/fixedbugs/issue16733.go',
      '/usr/local/go/test/fixedbugs/issue16741.go',
      '/usr/local/go/test/fixedbugs/issue16760.go',
      '/usr/local/go/test/fixedbugs/issue16804.go',
      '/usr/local/go/test/fixedbugs/issue16870.go',
      '/usr/local/go/test/fixedbugs/issue16948.go',
      '/usr/local/go/test/fixedbugs/issue16949.go',
      '/usr/local/go/test/fixedbugs/issue16985.go',
      '/usr/local/go/test/fixedbugs/issue17005.go',
      '/usr/local/go/test/fixedbugs/issue17038.go',
      '/usr/local/go/test/fixedbugs/issue17039.go',
      '/usr/local/go/test/fixedbugs/issue17111.go',
      '/usr/local/go/test/fixedbugs/issue17194.go',
      '/usr/local/go/test/fixedbugs/issue17270.go',
      '/usr/local/go/test/fixedbugs/issue17318.go',
      '/usr/local/go/test/fixedbugs/issue17328.go',
      '/usr/local/go/test/fixedbugs/issue17381.go',
      '/usr/local/go/test/fixedbugs/issue17449.go',
      '/usr/local/go/test/fixedbugs/issue17551.go',
      '/usr/local/go/test/fixedbugs/issue17588.go',
      '/usr/local/go/test/fixedbugs/issue17596.go',
      '/usr/local/go/test/fixedbugs/issue17631.go',
      '/usr/local/go/test/fixedbugs/issue17640.go',
      '/usr/local/go/test/fixedbugs/issue17645.go',
      '/usr/local/go/test/fixedbugs/issue17710.go',
      '/usr/local/go/test/fixedbugs/issue17752.go',
      '/usr/local/go/test/fixedbugs/issue17918.go',
      '/usr/local/go/test/fixedbugs/issue18089.go',
      '/usr/local/go/test/fixedbugs/issue18092.go',
      '/usr/local/go/test/fixedbugs/issue18149.go',
      '/usr/local/go/test/fixedbugs/issue18231.go',
      '/usr/local/go/test/fixedbugs/issue18331.go',
      '/usr/local/go/test/fixedbugs/issue18392.go',
      '/usr/local/go/test/fixedbugs/issue18393.go',
      '/usr/local/go/test/fixedbugs/issue18410.go',
      '/usr/local/go/test/fixedbugs/issue18419.dir',
      '/usr/local/go/test/fixedbugs/issue18419.dir/other.go',
      '/usr/local/go/test/fixedbugs/issue18419.dir/test.go',
      '/usr/local/go/test/fixedbugs/issue18419.go',
      '/usr/local/go/test/fixedbugs/issue18459.go',
      '/usr/local/go/test/fixedbugs/issue18595.go',
      '/usr/local/go/test/fixedbugs/issue18636.go',
      '/usr/local/go/test/fixedbugs/issue18640.go',
      '/usr/local/go/test/fixedbugs/issue18655.go',
      '/usr/local/go/test/fixedbugs/issue18661.go',
      '/usr/local/go/test/fixedbugs/issue18725.go',
      '/usr/local/go/test/fixedbugs/issue18747.go',
      '/usr/local/go/test/fixedbugs/issue18808.go',
      '/usr/local/go/test/fixedbugs/issue18882.go',
      '/usr/local/go/test/fixedbugs/issue18895.dir',
      '/usr/local/go/test/fixedbugs/issue18895.dir/p.go',
      '/usr/local/go/test/fixedbugs/issue18895.dir/q.go',
      '/usr/local/go/test/fixedbugs/issue18895.go',
      '/usr/local/go/test/fixedbugs/issue18902b.go',
      '/usr/local/go/test/fixedbugs/issue18902.go',
      '/usr/local/go/test/fixedbugs/issue18906.go',
      '/usr/local/go/test/fixedbugs/issue18915.go',
      '/usr/local/go/test/fixedbugs/issue18994.go',
      '/usr/local/go/test/fixedbugs/issue19012.go',
      '/usr/local/go/test/fixedbugs/issue19028.dir',
      '/usr/local/go/test/fixedbugs/issue19028.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue19028.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue19028.go',
      '/usr/local/go/test/fixedbugs/issue19040.go',
      '/usr/local/go/test/fixedbugs/issue19056.go',
      '/usr/local/go/test/fixedbugs/issue19078.go',
      '/usr/local/go/test/fixedbugs/issue19084.go',
      '/usr/local/go/test/fixedbugs/issue19137.go',
      '/usr/local/go/test/fixedbugs/issue19168.go',
      '/usr/local/go/test/fixedbugs/issue19182.go',
      '/usr/local/go/test/fixedbugs/issue19201.go',
      '/usr/local/go/test/fixedbugs/issue19217.go',
      '/usr/local/go/test/fixedbugs/issue19246.go',
      '/usr/local/go/test/fixedbugs/issue19275.go',
      '/usr/local/go/test/fixedbugs/issue19323.go',
      '/usr/local/go/test/fixedbugs/issue19359.go',
      '/usr/local/go/test/fixedbugs/issue19467.dir',
      '/usr/local/go/test/fixedbugs/issue19467.dir/mysync.go',
      '/usr/local/go/test/fixedbugs/issue19467.dir/z.go',
      '/usr/local/go/test/fixedbugs/issue19467.go',
      '/usr/local/go/test/fixedbugs/issue19482.go',
      '/usr/local/go/test/fixedbugs/issue19507.dir',
      '/usr/local/go/test/fixedbugs/issue19507.dir/div_arm.s',
      '/usr/local/go/test/fixedbugs/issue19507.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue19507.go',
      '/usr/local/go/test/fixedbugs/issue19515.go',
      '/usr/local/go/test/fixedbugs/issue19548.dir',
      '/usr/local/go/test/fixedbugs/issue19548.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue19548.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue19548.go',
      '/usr/local/go/test/fixedbugs/issue19555.go',
      '/usr/local/go/test/fixedbugs/issue19610.go',
      '/usr/local/go/test/fixedbugs/issue19632.go',
      '/usr/local/go/test/fixedbugs/issue19658.go',
      '/usr/local/go/test/fixedbugs/issue19667.go',
      '/usr/local/go/test/fixedbugs/issue19671.go',
      '/usr/local/go/test/fixedbugs/issue19678.go',
      '/usr/local/go/test/fixedbugs/issue19679.go',
      '/usr/local/go/test/fixedbugs/issue19696.go',
      '/usr/local/go/test/fixedbugs/issue19699b.go',
      '/usr/local/go/test/fixedbugs/issue19699.dir',
      '/usr/local/go/test/fixedbugs/issue19699.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue19699.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue19699.go',
      '/usr/local/go/test/fixedbugs/issue19705.go',
      '/usr/local/go/test/fixedbugs/issue19710.go',
      '/usr/local/go/test/fixedbugs/issue19743.go',
      '/usr/local/go/test/fixedbugs/issue19764.dir',
      '/usr/local/go/test/fixedbugs/issue19764.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue19764.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue19764.go',
      '/usr/local/go/test/fixedbugs/issue19783.go',
      '/usr/local/go/test/fixedbugs/issue19799.go',
      '/usr/local/go/test/fixedbugs/issue19880.go',
      '/usr/local/go/test/fixedbugs/issue19911.go',
      '/usr/local/go/test/fixedbugs/issue19947.go',
      '/usr/local/go/test/fixedbugs/issue19977.go',
      '/usr/local/go/test/fixedbugs/issue20029.go',
      '/usr/local/go/test/fixedbugs/issue20097.go',
      '/usr/local/go/test/fixedbugs/issue20145.go',
      '/usr/local/go/test/fixedbugs/issue20162.go',
      '/usr/local/go/test/fixedbugs/issue20174.go',
      '/usr/local/go/test/fixedbugs/issue20185.go',
      '/usr/local/go/test/fixedbugs/issue20227.go',
      '/usr/local/go/test/fixedbugs/issue20232.go',
      '/usr/local/go/test/fixedbugs/issue20233.go',
      '/usr/local/go/test/fixedbugs/issue20245.go',
      '/usr/local/go/test/fixedbugs/issue20250.go',
      '/usr/local/go/test/fixedbugs/issue20298.go',
      '/usr/local/go/test/fixedbugs/issue20333.go',
      '/usr/local/go/test/fixedbugs/issue20335.go',
      '/usr/local/go/test/fixedbugs/issue20415.go',
      '/usr/local/go/test/fixedbugs/issue20529.go',
      '/usr/local/go/test/fixedbugs/issue20530.go',
      '/usr/local/go/test/fixedbugs/issue20602.go',
      '/usr/local/go/test/fixedbugs/issue20682.dir',
      '/usr/local/go/test/fixedbugs/issue20682.dir/p.go',
      '/usr/local/go/test/fixedbugs/issue20682.dir/q.go',
      '/usr/local/go/test/fixedbugs/issue20682.dir/r.go',
      '/usr/local/go/test/fixedbugs/issue20682.go',
      '/usr/local/go/test/fixedbugs/issue20749.go',
      '/usr/local/go/test/fixedbugs/issue20789.go',
      '/usr/local/go/test/fixedbugs/issue20811.go',
      '/usr/local/go/test/fixedbugs/issue20813.go',
      '/usr/local/go/test/fixedbugs/issue21048.go',
      '/usr/local/go/test/fixedbugs/issue21120.dir',
      '/usr/local/go/test/fixedbugs/issue21120.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue21120.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue21120.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue21120.go',
      '/usr/local/go/test/fixedbugs/issue21655.go',
      '/usr/local/go/test/fixedbugs/issue21963.go',
      '/usr/local/go/test/fixedbugs/issue22083.go',
      '/usr/local/go/test/fixedbugs/issue2615.go',
      '/usr/local/go/test/fixedbugs/issue3552.dir',
      '/usr/local/go/test/fixedbugs/issue3552.dir/one.go',
      '/usr/local/go/test/fixedbugs/issue3552.dir/two.go',
      '/usr/local/go/test/fixedbugs/issue3552.go',
      '/usr/local/go/test/fixedbugs/issue3705.go',
      '/usr/local/go/test/fixedbugs/issue3783.go',
      '/usr/local/go/test/fixedbugs/issue3925.go',
      '/usr/local/go/test/fixedbugs/issue4066.go',
      '/usr/local/go/test/fixedbugs/issue4085a.go',
      '/usr/local/go/test/fixedbugs/issue4085b.go',
      '/usr/local/go/test/fixedbugs/issue4097.go',
      '/usr/local/go/test/fixedbugs/issue4099.go',
      '/usr/local/go/test/fixedbugs/issue4162.go',
      '/usr/local/go/test/fixedbugs/issue4167.go',
      '/usr/local/go/test/fixedbugs/issue4215.go',
      '/usr/local/go/test/fixedbugs/issue4232.go',
      '/usr/local/go/test/fixedbugs/issue4251.go',
      '/usr/local/go/test/fixedbugs/issue4252.dir',
      '/usr/local/go/test/fixedbugs/issue4252.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue4252.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue4252.go',
      '/usr/local/go/test/fixedbugs/issue4264.go',
      '/usr/local/go/test/fixedbugs/issue4283.go',
      '/usr/local/go/test/fixedbugs/issue4313.go',
      '/usr/local/go/test/fixedbugs/issue4316.go',
      '/usr/local/go/test/fixedbugs/issue4323.go',
      '/usr/local/go/test/fixedbugs/issue4326.dir',
      '/usr/local/go/test/fixedbugs/issue4326.dir/p1.go',
      '/usr/local/go/test/fixedbugs/issue4326.dir/p2.go',
      '/usr/local/go/test/fixedbugs/issue4326.dir/q1.go',
      '/usr/local/go/test/fixedbugs/issue4326.dir/q2.go',
      '/usr/local/go/test/fixedbugs/issue4326.dir/z.go',
      '/usr/local/go/test/fixedbugs/issue4326.go',
      '/usr/local/go/test/fixedbugs/issue4348.go',
      '/usr/local/go/test/fixedbugs/issue4353.go',
      '/usr/local/go/test/fixedbugs/issue4359.go',
      '/usr/local/go/test/fixedbugs/issue4365.go',
      '/usr/local/go/test/fixedbugs/issue4370.dir',
      '/usr/local/go/test/fixedbugs/issue4370.dir/p1.go',
      '/usr/local/go/test/fixedbugs/issue4370.dir/p2.go',
      '/usr/local/go/test/fixedbugs/issue4370.dir/p3.go',
      '/usr/local/go/test/fixedbugs/issue4370.go',
      '/usr/local/go/test/fixedbugs/issue4388.go',
      '/usr/local/go/test/fixedbugs/issue4396a.go',
      '/usr/local/go/test/fixedbugs/issue4396b.go',
      '/usr/local/go/test/fixedbugs/issue4399.go',
      '/usr/local/go/test/fixedbugs/issue4405.go',
      '/usr/local/go/test/fixedbugs/issue4429.go',
      '/usr/local/go/test/fixedbugs/issue4448.go',
      '/usr/local/go/test/fixedbugs/issue4452.go',
      '/usr/local/go/test/fixedbugs/issue4458.go',
      '/usr/local/go/test/fixedbugs/issue4463.go',
      '/usr/local/go/test/fixedbugs/issue4468.go',
      '/usr/local/go/test/fixedbugs/issue4470.go',
      '/usr/local/go/test/fixedbugs/issue4495.go',
      '/usr/local/go/test/fixedbugs/issue4510.dir',
      '/usr/local/go/test/fixedbugs/issue4510.dir/f1.go',
      '/usr/local/go/test/fixedbugs/issue4510.dir/f2.go',
      '/usr/local/go/test/fixedbugs/issue4510.go',
      '/usr/local/go/test/fixedbugs/issue4517a.go',
      '/usr/local/go/test/fixedbugs/issue4517b.go',
      '/usr/local/go/test/fixedbugs/issue4517c.go',
      '/usr/local/go/test/fixedbugs/issue4517d.go',
      '/usr/local/go/test/fixedbugs/issue4518.go',
      '/usr/local/go/test/fixedbugs/issue4529.go',
      '/usr/local/go/test/fixedbugs/issue4545.go',
      '/usr/local/go/test/fixedbugs/issue4562.go',
      '/usr/local/go/test/fixedbugs/issue4585.go',
      '/usr/local/go/test/fixedbugs/issue4590.dir',
      '/usr/local/go/test/fixedbugs/issue4590.dir/pkg1.go',
      '/usr/local/go/test/fixedbugs/issue4590.dir/pkg2.go',
      '/usr/local/go/test/fixedbugs/issue4590.dir/prog.go',
      '/usr/local/go/test/fixedbugs/issue4590.go',
      '/usr/local/go/test/fixedbugs/issue4610.go',
      '/usr/local/go/test/fixedbugs/issue4614.go',
      '/usr/local/go/test/fixedbugs/issue4618.go',
      '/usr/local/go/test/fixedbugs/issue4620.go',
      '/usr/local/go/test/fixedbugs/issue4654.go',
      '/usr/local/go/test/fixedbugs/issue4663.go',
      '/usr/local/go/test/fixedbugs/issue4667.go',
      '/usr/local/go/test/fixedbugs/issue4734.go',
      '/usr/local/go/test/fixedbugs/issue4748.go',
      '/usr/local/go/test/fixedbugs/issue4752.go',
      '/usr/local/go/test/fixedbugs/issue4776.go',
      '/usr/local/go/test/fixedbugs/issue4785.go',
      '/usr/local/go/test/fixedbugs/issue4813.go',
      '/usr/local/go/test/fixedbugs/issue4847.go',
      '/usr/local/go/test/fixedbugs/issue4879.dir',
      '/usr/local/go/test/fixedbugs/issue4879.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue4879.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue4879.go',
      '/usr/local/go/test/fixedbugs/issue4909a.go',
      '/usr/local/go/test/fixedbugs/issue4909b.go',
      '/usr/local/go/test/fixedbugs/issue4932.dir',
      '/usr/local/go/test/fixedbugs/issue4932.dir/foo.go',
      '/usr/local/go/test/fixedbugs/issue4932.dir/state2.go',
      '/usr/local/go/test/fixedbugs/issue4932.dir/state.go',
      '/usr/local/go/test/fixedbugs/issue4932.go',
      '/usr/local/go/test/fixedbugs/issue4964.dir',
      '/usr/local/go/test/fixedbugs/issue4964.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue4964.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue4964.go',
      '/usr/local/go/test/fixedbugs/issue5002.go',
      '/usr/local/go/test/fixedbugs/issue5056.go',
      '/usr/local/go/test/fixedbugs/issue5089.go',
      '/usr/local/go/test/fixedbugs/issue5105.dir',
      '/usr/local/go/test/fixedbugs/issue5105.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue5105.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue5105.go',
      '/usr/local/go/test/fixedbugs/issue5125.dir',
      '/usr/local/go/test/fixedbugs/issue5125.dir/bug.go',
      '/usr/local/go/test/fixedbugs/issue5125.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue5125.go',
      '/usr/local/go/test/fixedbugs/issue5162.go',
      '/usr/local/go/test/fixedbugs/issue5172.go',
      '/usr/local/go/test/fixedbugs/issue5231.go',
      '/usr/local/go/test/fixedbugs/issue5244.go',
      '/usr/local/go/test/fixedbugs/issue5259.dir',
      '/usr/local/go/test/fixedbugs/issue5259.dir/bug.go',
      '/usr/local/go/test/fixedbugs/issue5259.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue5259.go',
      '/usr/local/go/test/fixedbugs/issue5260.dir',
      '/usr/local/go/test/fixedbugs/issue5260.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue5260.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue5260.go',
      '/usr/local/go/test/fixedbugs/issue5291.dir',
      '/usr/local/go/test/fixedbugs/issue5291.dir/pkg1.go',
      '/usr/local/go/test/fixedbugs/issue5291.dir/prog.go',
      '/usr/local/go/test/fixedbugs/issue5291.go',
      '/usr/local/go/test/fixedbugs/issue5358.go',
      '/usr/local/go/test/fixedbugs/issue5373.go',
      '/usr/local/go/test/fixedbugs/issue5470.dir',
      '/usr/local/go/test/fixedbugs/issue5470.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue5470.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue5470.go',
      '/usr/local/go/test/fixedbugs/issue5493.go',
      '/usr/local/go/test/fixedbugs/issue5515.go',
      '/usr/local/go/test/fixedbugs/issue5581.go',
      '/usr/local/go/test/fixedbugs/issue5607.go',
      '/usr/local/go/test/fixedbugs/issue5609.go',
      '/usr/local/go/test/fixedbugs/issue5614.dir',
      '/usr/local/go/test/fixedbugs/issue5614.dir/rethinkgo.go',
      '/usr/local/go/test/fixedbugs/issue5614.dir/x.go',
      '/usr/local/go/test/fixedbugs/issue5614.dir/y.go',
      '/usr/local/go/test/fixedbugs/issue5614.go',
      '/usr/local/go/test/fixedbugs/issue5698.go',
      '/usr/local/go/test/fixedbugs/issue5704.go',
      '/usr/local/go/test/fixedbugs/issue5753.go',
      '/usr/local/go/test/fixedbugs/issue5755.dir',
      '/usr/local/go/test/fixedbugs/issue5755.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue5755.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue5755.go',
      '/usr/local/go/test/fixedbugs/issue5793.go',
      '/usr/local/go/test/fixedbugs/issue5809.go',
      '/usr/local/go/test/fixedbugs/issue5820.go',
      '/usr/local/go/test/fixedbugs/issue5841.go',
      '/usr/local/go/test/fixedbugs/issue5856.go',
      '/usr/local/go/test/fixedbugs/issue5910.dir',
      '/usr/local/go/test/fixedbugs/issue5910.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue5910.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue5910.go',
      '/usr/local/go/test/fixedbugs/issue5957.dir',
      '/usr/local/go/test/fixedbugs/issue5957.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue5957.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue5957.dir/c.go',
      '/usr/local/go/test/fixedbugs/issue5957.go',
      '/usr/local/go/test/fixedbugs/issue5963.go',
      '/usr/local/go/test/fixedbugs/issue6004.go',
      '/usr/local/go/test/fixedbugs/issue6036.go',
      '/usr/local/go/test/fixedbugs/issue6055.go',
      '/usr/local/go/test/fixedbugs/issue6131.go',
      '/usr/local/go/test/fixedbugs/issue6140.go',
      '/usr/local/go/test/fixedbugs/issue6247.go',
      '/usr/local/go/test/fixedbugs/issue6269.go',
      '/usr/local/go/test/fixedbugs/issue6295.dir',
      '/usr/local/go/test/fixedbugs/issue6295.dir/p0.go',
      '/usr/local/go/test/fixedbugs/issue6295.dir/p1.go',
      '/usr/local/go/test/fixedbugs/issue6295.dir/p2.go',
      '/usr/local/go/test/fixedbugs/issue6295.go',
      '/usr/local/go/test/fixedbugs/issue6298.go',
      '/usr/local/go/test/fixedbugs/issue6399.go',
      '/usr/local/go/test/fixedbugs/issue6402.go',
      '/usr/local/go/test/fixedbugs/issue6403.go',
      '/usr/local/go/test/fixedbugs/issue6405.go',
      '/usr/local/go/test/fixedbugs/issue6406.go',
      '/usr/local/go/test/fixedbugs/issue6500.go',
      '/usr/local/go/test/fixedbugs/issue6513.dir',
      '/usr/local/go/test/fixedbugs/issue6513.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue6513.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue6513.dir/main.go',
      '/usr/local/go/test/fixedbugs/issue6513.go',
      '/usr/local/go/test/fixedbugs/issue6572.go',
      '/usr/local/go/test/fixedbugs/issue6671.go',
      '/usr/local/go/test/fixedbugs/issue6703a.go',
      '/usr/local/go/test/fixedbugs/issue6703b.go',
      '/usr/local/go/test/fixedbugs/issue6703c.go',
      '/usr/local/go/test/fixedbugs/issue6703d.go',
      '/usr/local/go/test/fixedbugs/issue6703e.go',
      '/usr/local/go/test/fixedbugs/issue6703f.go',
      '/usr/local/go/test/fixedbugs/issue6703g.go',
      '/usr/local/go/test/fixedbugs/issue6703h.go',
      '/usr/local/go/test/fixedbugs/issue6703i.go',
      '/usr/local/go/test/fixedbugs/issue6703j.go',
      '/usr/local/go/test/fixedbugs/issue6703k.go',
      '/usr/local/go/test/fixedbugs/issue6703l.go',
      '/usr/local/go/test/fixedbugs/issue6703m.go',
      '/usr/local/go/test/fixedbugs/issue6703n.go',
      '/usr/local/go/test/fixedbugs/issue6703o.go',
      '/usr/local/go/test/fixedbugs/issue6703p.go',
      '/usr/local/go/test/fixedbugs/issue6703q.go',
      '/usr/local/go/test/fixedbugs/issue6703r.go',
      '/usr/local/go/test/fixedbugs/issue6703s.go',
      '/usr/local/go/test/fixedbugs/issue6703t.go',
      '/usr/local/go/test/fixedbugs/issue6703u.go',
      '/usr/local/go/test/fixedbugs/issue6703v.go',
      '/usr/local/go/test/fixedbugs/issue6703w.go',
      '/usr/local/go/test/fixedbugs/issue6703x.go',
      '/usr/local/go/test/fixedbugs/issue6703y.go',
      '/usr/local/go/test/fixedbugs/issue6703z.go',
      '/usr/local/go/test/fixedbugs/issue6750.go',
      '/usr/local/go/test/fixedbugs/issue6772.go',
      '/usr/local/go/test/fixedbugs/issue6789.dir',
      '/usr/local/go/test/fixedbugs/issue6789.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue6789.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue6789.go',
      '/usr/local/go/test/fixedbugs/issue6847.go',
      '/usr/local/go/test/fixedbugs/issue6866.go',
      '/usr/local/go/test/fixedbugs/issue6889.go',
      '/usr/local/go/test/fixedbugs/issue6899.go',
      '/usr/local/go/test/fixedbugs/issue6899.out',
      '/usr/local/go/test/fixedbugs/issue6902.go',
      '/usr/local/go/test/fixedbugs/issue6964.go',
      '/usr/local/go/test/fixedbugs/issue7023.dir',
      '/usr/local/go/test/fixedbugs/issue7023.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue7023.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue7023.go',
      '/usr/local/go/test/fixedbugs/issue7044.go',
      '/usr/local/go/test/fixedbugs/issue7050.go',
      '/usr/local/go/test/fixedbugs/issue7083.go',
      '/usr/local/go/test/fixedbugs/issue7129.go',
      '/usr/local/go/test/fixedbugs/issue7150.go',
      '/usr/local/go/test/fixedbugs/issue7153.go',
      '/usr/local/go/test/fixedbugs/issue7214.go',
      '/usr/local/go/test/fixedbugs/issue7223.go',
      '/usr/local/go/test/fixedbugs/issue7272.go',
      '/usr/local/go/test/fixedbugs/issue7310.go',
      '/usr/local/go/test/fixedbugs/issue7316.go',
      '/usr/local/go/test/fixedbugs/issue7346.go',
      '/usr/local/go/test/fixedbugs/issue7366.go',
      '/usr/local/go/test/fixedbugs/issue7405.go',
      '/usr/local/go/test/fixedbugs/issue7419.go',
      '/usr/local/go/test/fixedbugs/issue7525b.go',
      '/usr/local/go/test/fixedbugs/issue7525c.go',
      '/usr/local/go/test/fixedbugs/issue7525.go',
      '/usr/local/go/test/fixedbugs/issue7538a.go',
      '/usr/local/go/test/fixedbugs/issue7538b.go',
      '/usr/local/go/test/fixedbugs/issue7547.go',
      '/usr/local/go/test/fixedbugs/issue7550.go',
      '/usr/local/go/test/fixedbugs/issue7590.go',
      '/usr/local/go/test/fixedbugs/issue7648.dir',
      '/usr/local/go/test/fixedbugs/issue7648.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue7648.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue7648.go',
      '/usr/local/go/test/fixedbugs/issue7675.go',
      '/usr/local/go/test/fixedbugs/issue7690.go',
      '/usr/local/go/test/fixedbugs/issue7740.go',
      '/usr/local/go/test/fixedbugs/issue7742.go',
      '/usr/local/go/test/fixedbugs/issue7746.go',
      '/usr/local/go/test/fixedbugs/issue7760.go',
      '/usr/local/go/test/fixedbugs/issue7794.go',
      '/usr/local/go/test/fixedbugs/issue7863.go',
      '/usr/local/go/test/fixedbugs/issue7867.go',
      '/usr/local/go/test/fixedbugs/issue7884.go',
      '/usr/local/go/test/fixedbugs/issue7944.go',
      '/usr/local/go/test/fixedbugs/issue7995b.dir',
      '/usr/local/go/test/fixedbugs/issue7995b.dir/x1.go',
      '/usr/local/go/test/fixedbugs/issue7995b.dir/x2.go',
      '/usr/local/go/test/fixedbugs/issue7995b.go',
      '/usr/local/go/test/fixedbugs/issue7995.go',
      '/usr/local/go/test/fixedbugs/issue7996.go',
      '/usr/local/go/test/fixedbugs/issue7997.go',
      '/usr/local/go/test/fixedbugs/issue7998.go',
      '/usr/local/go/test/fixedbugs/issue8004.go',
      '/usr/local/go/test/fixedbugs/issue8011.go',
      '/usr/local/go/test/fixedbugs/issue8017.go',
      '/usr/local/go/test/fixedbugs/issue8028.go',
      '/usr/local/go/test/fixedbugs/issue8036.go',
      '/usr/local/go/test/fixedbugs/issue8039.go',
      '/usr/local/go/test/fixedbugs/issue8042.go',
      '/usr/local/go/test/fixedbugs/issue8047b.go',
      '/usr/local/go/test/fixedbugs/issue8047.go',
      '/usr/local/go/test/fixedbugs/issue8048.go',
      '/usr/local/go/test/fixedbugs/issue8060.dir',
      '/usr/local/go/test/fixedbugs/issue8060.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue8060.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue8060.go',
      '/usr/local/go/test/fixedbugs/issue8073.go',
      '/usr/local/go/test/fixedbugs/issue8074.go',
      '/usr/local/go/test/fixedbugs/issue8076.go',
      '/usr/local/go/test/fixedbugs/issue8079.go',
      '/usr/local/go/test/fixedbugs/issue8132.go',
      '/usr/local/go/test/fixedbugs/issue8139.go',
      '/usr/local/go/test/fixedbugs/issue8154.go',
      '/usr/local/go/test/fixedbugs/issue8155.go',
      '/usr/local/go/test/fixedbugs/issue8158.go',
      '/usr/local/go/test/fixedbugs/issue8183.go',
      '/usr/local/go/test/fixedbugs/issue8280.dir',
      '/usr/local/go/test/fixedbugs/issue8280.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue8280.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue8280.go',
      '/usr/local/go/test/fixedbugs/issue8311.go',
      '/usr/local/go/test/fixedbugs/issue8325.go',
      '/usr/local/go/test/fixedbugs/issue8336.go',
      '/usr/local/go/test/fixedbugs/issue8347.go',
      '/usr/local/go/test/fixedbugs/issue8385.go',
      '/usr/local/go/test/fixedbugs/issue8438.go',
      '/usr/local/go/test/fixedbugs/issue8440.go',
      '/usr/local/go/test/fixedbugs/issue8475.go',
      '/usr/local/go/test/fixedbugs/issue8501.go',
      '/usr/local/go/test/fixedbugs/issue8507.go',
      '/usr/local/go/test/fixedbugs/issue8612.go',
      '/usr/local/go/test/fixedbugs/issue8613.go',
      '/usr/local/go/test/fixedbugs/issue8620.go',
      '/usr/local/go/test/fixedbugs/issue8745.go',
      '/usr/local/go/test/fixedbugs/issue8761.go',
      '/usr/local/go/test/fixedbugs/issue8836.go',
      '/usr/local/go/test/fixedbugs/issue887.go',
      '/usr/local/go/test/fixedbugs/issue8947.go',
      '/usr/local/go/test/fixedbugs/issue8961.go',
      '/usr/local/go/test/fixedbugs/issue9006.go',
      '/usr/local/go/test/fixedbugs/issue9017.go',
      '/usr/local/go/test/fixedbugs/issue9036.go',
      '/usr/local/go/test/fixedbugs/issue9076.go',
      '/usr/local/go/test/fixedbugs/issue9083.go',
      '/usr/local/go/test/fixedbugs/issue9110.go',
      '/usr/local/go/test/fixedbugs/issue9321.go',
      '/usr/local/go/test/fixedbugs/issue9355.dir',
      '/usr/local/go/test/fixedbugs/issue9355.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue9355.go',
      '/usr/local/go/test/fixedbugs/issue9370.go',
      '/usr/local/go/test/fixedbugs/issue9432.go',
      '/usr/local/go/test/fixedbugs/issue9521.go',
      '/usr/local/go/test/fixedbugs/issue9537.dir',
      '/usr/local/go/test/fixedbugs/issue9537.dir/a.go',
      '/usr/local/go/test/fixedbugs/issue9537.dir/b.go',
      '/usr/local/go/test/fixedbugs/issue9537.go',
      '/usr/local/go/test/fixedbugs/issue9604b.go',
      '/usr/local/go/test/fixedbugs/issue9604.go',
      '/usr/local/go/test/fixedbugs/issue9608.dir',
      '/usr/local/go/test/fixedbugs/issue9608.dir/issue9608.go',
      '/usr/local/go/test/fixedbugs/issue9608.go',
      '/usr/local/go/test/fixedbugs/issue9634.go',
      '/usr/local/go/test/fixedbugs/issue9691.go',
      '/usr/local/go/test/fixedbugs/issue9731.go',
      '/usr/local/go/test/fixedbugs/issue9738.go',
      '/usr/local/go/test/fixedbugs/issue9862.go',
      '/usr/local/go/test/fixedbugs/issue9862_run.go',
      '/usr/local/go/test/floatcmp.go',
      '/usr/local/go/test/float_lit2.go',
      '/usr/local/go/test/float_lit3.go',
      '/usr/local/go/test/float_lit.go',
      '/usr/local/go/test/for.go',
      '/usr/local/go/test/func1.go',
      '/usr/local/go/test/func2.go',
      '/usr/local/go/test/func3.go',
      '/usr/local/go/test/func4.go',
      '/usr/local/go/test/func5.go',
      '/usr/local/go/test/func6.go',
      '/usr/local/go/test/func7.go',
      '/usr/local/go/test/func8.go',
      '/usr/local/go/test/funcdup2.go',
      '/usr/local/go/test/funcdup.go',
      '/usr/local/go/test/func.go',
      '/usr/local/go/test/gc1.go',
      '/usr/local/go/test/gc2.go',
      '/usr/local/go/test/gc.go',
      '/usr/local/go/test/gcstring.go',
      '/usr/local/go/test/goprint.go',
      '/usr/local/go/test/goprint.out',
      '/usr/local/go/test/goto.go',
      '/usr/local/go/test/heapsampling.go',
      '/usr/local/go/test/helloworld.go',
      '/usr/local/go/test/helloworld.out',
      '/usr/local/go/test/if.go',
      '/usr/local/go/test/import1.go',
      '/usr/local/go/test/import2.dir',
      '/usr/local/go/test/import2.dir/import2.go',
      '/usr/local/go/test/import2.dir/import3.go',
      '/usr/local/go/test/import2.go',
      '/usr/local/go/test/import4.dir',
      '/usr/local/go/test/import4.dir/empty.go',
      '/usr/local/go/test/import4.dir/import4.go',
      '/usr/local/go/test/import4.go',
      '/usr/local/go/test/import5.go',
      '/usr/local/go/test/import6.go',
      '/usr/local/go/test/import.go',
      '/usr/local/go/test/index0.go',
      '/usr/local/go/test/index1.go',
      '/usr/local/go/test/index2.go',
      '/usr/local/go/test/index.go',
      '/usr/local/go/test/indirect1.go',
      '/usr/local/go/test/indirect.go',
      '/usr/local/go/test/init1.go',
      '/usr/local/go/test/initcomma.go',
      '/usr/local/go/test/init.go',
      '/usr/local/go/test/initialize.go',
      '/usr/local/go/test/initializerr.go',
      '/usr/local/go/test/initloop.go',
      '/usr/local/go/test/inline_caller.go',
      '/usr/local/go/test/inline_callers.go',
      '/usr/local/go/test/inline.go',
      '/usr/local/go/test/inline_literal.go',
      '/usr/local/go/test/inline_variadic.go',
      '/usr/local/go/test/intcvt.go',
      '/usr/local/go/test/interface',
      '/usr/local/go/test/interface/assertinline.go',
      '/usr/local/go/test/interface/bigdata.go',
      '/usr/local/go/test/interface/convert1.go',
      '/usr/local/go/test/interface/convert2.go',
      '/usr/local/go/test/interface/convert.go',
      '/usr/local/go/test/interface/embed1.dir',
      '/usr/local/go/test/interface/embed1.dir/embed0.go',
      '/usr/local/go/test/interface/embed1.dir/embed1.go',
      '/usr/local/go/test/interface/embed1.go',
      '/usr/local/go/test/interface/embed2.go',
      '/usr/local/go/test/interface/embed.go',
      '/usr/local/go/test/interface/explicit.go',
      '/usr/local/go/test/interface/fail.go',
      '/usr/local/go/test/interface/fake.go',
      '/usr/local/go/test/interface/noeq.go',
      '/usr/local/go/test/interface/pointer.go',
      '/usr/local/go/test/interface/private.dir',
      '/usr/local/go/test/interface/private.dir/private1.go',
      '/usr/local/go/test/interface/private.dir/prog.go',
      '/usr/local/go/test/interface/private.go',
      '/usr/local/go/test/interface/receiver1.go',
      '/usr/local/go/test/interface/receiver.go',
      '/usr/local/go/test/interface/recursive1.dir',
      '/usr/local/go/test/interface/recursive1.dir/recursive1.go',
      '/usr/local/go/test/interface/recursive1.dir/recursive2.go',
      '/usr/local/go/test/interface/recursive1.go',
      '/usr/local/go/test/interface/recursive.go',
      '/usr/local/go/test/interface/returntype.go',
      '/usr/local/go/test/interface/struct.go',
      '/usr/local/go/test/int_lit.go',
      '/usr/local/go/test/intrinsic_atomic.go',
      '/usr/local/go/test/intrinsic.dir',
      '/usr/local/go/test/intrinsic.dir/main.go',
      '/usr/local/go/test/intrinsic.go',
      '/usr/local/go/test/iota.go',
      '/usr/local/go/test/ken',
      '/usr/local/go/test/ken/array.go',
      '/usr/local/go/test/ken/chan1.go',
      '/usr/local/go/test/ken/chan.go',
      '/usr/local/go/test/ken/complit.go',
      '/usr/local/go/test/ken/convert.go',
      '/usr/local/go/test/ken/cplx0.go',
      '/usr/local/go/test/ken/cplx0.out',
      '/usr/local/go/test/ken/cplx1.go',
      '/usr/local/go/test/ken/cplx2.go',
      '/usr/local/go/test/ken/cplx3.go',
      '/usr/local/go/test/ken/cplx4.go',
      '/usr/local/go/test/ken/cplx5.go',
      '/usr/local/go/test/ken/divconst.go',
      '/usr/local/go/test/ken/divmod.go',
      '/usr/local/go/test/ken/embed.go',
      '/usr/local/go/test/ken/for.go',
      '/usr/local/go/test/ken/interbasic.go',
      '/usr/local/go/test/ken/interfun.go',
      '/usr/local/go/test/ken/intervar.go',
      '/usr/local/go/test/ken/label.go',
      '/usr/local/go/test/ken/litfun.go',
      '/usr/local/go/test/ken/mfunc.go',
      '/usr/local/go/test/ken/modconst.go',
      '/usr/local/go/test/ken/ptrfun.go',
      '/usr/local/go/test/ken/ptrvar.go',
      '/usr/local/go/test/ken/range.go',
      '/usr/local/go/test/ken/rob1.go',
      '/usr/local/go/test/ken/rob2.go',
      '/usr/local/go/test/ken/robfor.go',
      '/usr/local/go/test/ken/robfunc.go',
      '/usr/local/go/test/ken/shift.go',
      '/usr/local/go/test/ken/simparray.go',
      '/usr/local/go/test/ken/simpbool.go',
      '/usr/local/go/test/ken/simpconv.go',
      '/usr/local/go/test/ken/simpfun.go',
      '/usr/local/go/test/ken/simpswitch.go',
      '/usr/local/go/test/ken/simpvar.go',
      '/usr/local/go/test/ken/slicearray.go',
      '/usr/local/go/test/ken/sliceslice.go',
      '/usr/local/go/test/ken/string.go',
      '/usr/local/go/test/ken/string.out',
      '/usr/local/go/test/ken/strvar.go',
      '/usr/local/go/test/label1.go',
      '/usr/local/go/test/label.go',
      '/usr/local/go/test/linkmain.go',
      '/usr/local/go/test/linkmain_run.go',
      '/usr/local/go/test/linkname.dir',
      '/usr/local/go/test/linkname.dir/linkname1.go',
      '/usr/local/go/test/linkname.dir/linkname2.go',
      '/usr/local/go/test/linkname.dir/linkname3.go',
      '/usr/local/go/test/linkname.go',
      '/usr/local/go/test/linkobj.go',
      '/usr/local/go/test/linkx.go',
      '/usr/local/go/test/linkx_run.go',
      '/usr/local/go/test/literal.go',
      '/usr/local/go/test/live1.go',
      '/usr/local/go/test/live2.go',
      '/usr/local/go/test/live.go',
      '/usr/local/go/test/live_syscall.go',
      '/usr/local/go/test/locklinear.go',
      '/usr/local/go/test/loopbce.go',
      '/usr/local/go/test/makenew.go',
      '/usr/local/go/test/mallocfin.go',
      '/usr/local/go/test/map1.go',
      '/usr/local/go/test/map.go',
      '/usr/local/go/test/maplinear.go',
      '/usr/local/go/test/method1.go',
      '/usr/local/go/test/method2.go',
      '/usr/local/go/test/method3.go',
      '/usr/local/go/test/method4.dir',
      '/usr/local/go/test/method4.dir/method4a.go',
      '/usr/local/go/test/method4.dir/prog.go',
      '/usr/local/go/test/method4.go',
      '/usr/local/go/test/method5.go',
      '/usr/local/go/test/method.go',
      '/usr/local/go/test/named1.go',
      '/usr/local/go/test/named.go',
      '/usr/local/go/test/nilcheck.go',
      '/usr/local/go/test/nil.go',
      '/usr/local/go/test/nilptr2.go',
      '/usr/local/go/test/nilptr3.go',
      '/usr/local/go/test/nilptr4.go',
      '/usr/local/go/test/nilptr.go',
      '/usr/local/go/test/nosplit.go',
      '/usr/local/go/test/notinheap2.go',
      '/usr/local/go/test/notinheap.go',
      '/usr/local/go/test/nowritebarrier.go',
      '/usr/local/go/test/nul1.go',
      '/usr/local/go/test/opt_branchlikely.go',
      '/usr/local/go/test/parentype.go',
      '/usr/local/go/test/peano.go',
      '/usr/local/go/test/phiopt.go',
      '/usr/local/go/test/printbig.go',
      '/usr/local/go/test/printbig.out',
      '/usr/local/go/test/print.go',
      '/usr/local/go/test/print.out',
      '/usr/local/go/test/prove.go',
      '/usr/local/go/test/range.go',
      '/usr/local/go/test/README.md',
      '/usr/local/go/test/recover1.go',
      '/usr/local/go/test/recover2.go',
      '/usr/local/go/test/recover3.go',
      '/usr/local/go/test/recover4.go',
      '/usr/local/go/test/recover5.go',
      '/usr/local/go/test/recover.go',
      '/usr/local/go/test/reflectmethod1.go',
      '/usr/local/go/test/reflectmethod2.go',
      '/usr/local/go/test/reflectmethod3.go',
      '/usr/local/go/test/reflectmethod4.go',
      '/usr/local/go/test/rename1.go',
      '/usr/local/go/test/rename.go',
      '/usr/local/go/test/reorder2.go',
      '/usr/local/go/test/reorder.go',
      '/usr/local/go/test/return.go',
      '/usr/local/go/test/rotate0.go',
      '/usr/local/go/test/rotate1.go',
      '/usr/local/go/test/rotate2.go',
      '/usr/local/go/test/rotate3.go',
      '/usr/local/go/test/rotate.go',
      '/usr/local/go/test/rune.go',
      '/usr/local/go/test/run.go',
      '/usr/local/go/test/runtime.go',
      '/usr/local/go/test/safe',
      '/usr/local/go/test/safe/main.go',
      '/usr/local/go/test/safe/nousesafe.go',
      '/usr/local/go/test/safe/pkg.go',
      '/usr/local/go/test/safe/usesafe.go',
      '/usr/local/go/test/shift1.go',
      '/usr/local/go/test/shift2.go',
      '/usr/local/go/test/sieve.go',
      '/usr/local/go/test/sigchld.go',
      '/usr/local/go/test/sigchld.out',
      '/usr/local/go/test/simassign.go',
      '/usr/local/go/test/sinit.go',
      '/usr/local/go/test/sinit_run.go',
      '/usr/local/go/test/sizeof.go',
      '/usr/local/go/test/slice3err.go',
      '/usr/local/go/test/slice3.go',
      '/usr/local/go/test/slicecap.go',
      '/usr/local/go/test/sliceopt.go',
      '/usr/local/go/test/solitaire.go',
      '/usr/local/go/test/stack.go',
      '/usr/local/go/test/strength.go',
      '/usr/local/go/test/stress',
      '/usr/local/go/test/stress/maps.go',
      '/usr/local/go/test/stress/parsego.go',
      '/usr/local/go/test/stress/runstress.go',
      '/usr/local/go/test/string_lit.go',
      '/usr/local/go/test/stringrange.go',
      '/usr/local/go/test/struct0.go',
      '/usr/local/go/test/switch2.go',
      '/usr/local/go/test/switch3.go',
      '/usr/local/go/test/switch4.go',
      '/usr/local/go/test/switch5.go',
      '/usr/local/go/test/switch6.go',
      '/usr/local/go/test/switch7.go',
      '/usr/local/go/test/switch.go',
      '/usr/local/go/test/syntax',
      '/usr/local/go/test/syntax/chan1.go',
      '/usr/local/go/test/syntax/chan.go',
      '/usr/local/go/test/syntax/composite.go',
      '/usr/local/go/test/syntax/ddd.go',
      '/usr/local/go/test/syntax/else.go',
      '/usr/local/go/test/syntax/if.go',
      '/usr/local/go/test/syntax/import.go',
      '/usr/local/go/test/syntax/initvar.go',
      '/usr/local/go/test/syntax/interface.go',
      '/usr/local/go/test/syntax/semi1.go',
      '/usr/local/go/test/syntax/semi2.go',
      '/usr/local/go/test/syntax/semi3.go',
      '/usr/local/go/test/syntax/semi4.go',
      '/usr/local/go/test/syntax/semi5.go',
      '/usr/local/go/test/syntax/semi6.go',
      '/usr/local/go/test/syntax/semi7.go',
      '/usr/local/go/test/syntax/topexpr.go',
      '/usr/local/go/test/syntax/typesw.go',
      '/usr/local/go/test/syntax/vareq1.go',
      '/usr/local/go/test/syntax/vareq.go',
      '/usr/local/go/test/tinyfin.go',
      '/usr/local/go/test/torture.go',
      '/usr/local/go/test/turing.go',
      '/usr/local/go/test/typecheck.go',
      '/usr/local/go/test/typecheckloop.go',
      '/usr/local/go/test/typeswitch1.go',
      '/usr/local/go/test/typeswitch2.go',
      '/usr/local/go/test/typeswitch3.go',
      '/usr/local/go/test/typeswitch.go',
      '/usr/local/go/test/uintptrescapes2.go',
      '/usr/local/go/test/uintptrescapes.dir',
      '/usr/local/go/test/uintptrescapes.dir/a.go',
      '/usr/local/go/test/uintptrescapes.dir/main.go',
      '/usr/local/go/test/uintptrescapes.go',
      '/usr/local/go/test/undef.go',
      '/usr/local/go/test/utf.go',
      '/usr/local/go/test/varerr.go',
      '/usr/local/go/test/varinit.go',
      '/usr/local/go/test/writebarrier.go',
      '/usr/local/go/test/zerodivide.go',
      '/usr/local/go/VERSION',
      ],
    }
    # Add Go to System Path
->  file_line{'/usr/local/go/bin added to Path':
      ensure => present,
      path   => '/etc/environment',
      line   => 'PATH="/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/games:/usr/local/games:/usr/local/go/bin"',
      match  => 'PATH="/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/games:/usr/local/games"',
    }
    # install the terraform matchbox provider
->  exec{'go-get-terraform-provider-matchbox':
      environment => [
        'GOPATH=/opt/go',
        'GOBIN=/usr/local/go/bin',
      ],
      command     => '/usr/local/go/bin/go get github.com/coreos/terraform-provider-matchbox',
      creates     => '/usr/local/bin/terraform-provider-matchbox',
      cwd         => '/usr/local/go',
      logoutput   => true,
      timeout     => '0',
      user        => 'root',
    }
    # Add a .terraformrc for matchbox in /root
->  file{ '/root/.terraformrc':
      ensure  => file,
      content => '# Puppet Managed
providers {
  matchbox = "/usr/local/go/bin/terraform-provider-matchbox"
}
',
    }

    # Generate Certificates for FQDN and IP
->  exec{'certgen-for-matchbox-services':
      environment => [
        "SAN=DNS.1:${::fqdn},IP.1:${::ipaddress}",
      ],
      command     => "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/cert-gen",
      cwd         => "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/",
      logoutput   => true,
      timeout     => '0',
      user        => 'root',
      creates     => [
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/certs",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/crl",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/newcerts",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/serial",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/index.txt",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/index.txt.attr",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/ca.crt",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/ca.key",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/server.crt",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/server.key",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/client.crt",
      "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/client.key",
      ],
    }
    # Generated Certs to /etc ca.crt server.crt server.key
->  file{'/etc/matchbox/ca.crt':
      ensure => file,
      source => "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/ca.crt",
    }
->  file{'/etc/matchbox/server.crt':
      ensure => file,
      source => "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/server.crt",
    }
->  file{'/etc/matchbox/server.key':
      ensure => file,
      source => "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/server.key",
    }

    # Add client Certs to /root/.matchbox
->  file{'/root/.matchbox/client.key':
      ensure => file,
      source => "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/client.key",
    }
->  file{'/root/.matchbox/client.crt':
      ensure => file,
      source => "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/client.crt",
    }
->  file{'/root/.matchbox/ca.crt':
      ensure => file,
      source => "/home/matchbox/matchbox-v${quartermaster::matchbox_version}-linux-amd64/scripts/tls/ca.crt",
    }
    if ( $facts[os][distro][id] == 'Ubuntu' ) and ( $facts[os][distro][release][major] == '14.04'){
      package{'systemd':
        ensure => latest
      }
->    file{'/etc/init/matchbox.conf':
        ensure => file,
        source => 'puppet:///modules/quartermaster/coreos/matchbox/upstart.matchbox.conf'
      }
    }
    # Start the Matchbox Service and Enable it
    service{'matchbox':
      ensure  => 'running',
      enable  => true,
      require => Exec['certgen-for-matchbox-services'],
    }
  }
}
